@@ -31,12 +31,12 @@
 #include <ActionWidget.h>
 
 /**
- * 
+ *
  * @ingroup group_cepimaging_actions_itkfilters
- * 
+ *
  * @brief
  * Perform a anisotropic diffusion on the @ref camitk::ImageComponent "ImageComponent"
- * 
+ *
  **/
 class AnisotropicDiffusion : public camitk::Action {
     Q_OBJECT
@@ -44,12 +44,9 @@ class AnisotropicDiffusion : public camitk::Action {
     /// Enumerations
     Q_ENUMS( AnisoDiffType )
 
-    Q_PROPERTY( AnisoDiffType implementation READ getMethod WRITE setMethod)
-
-
 public:
     /// Define the possible implementations of Gaussian filtering
-    enum AnisoDiffType {Gradient, Curvature };
+    enum AnisoDiffType {GRADIENT, CURVATURE};
 
     /// Default Constructor
     AnisotropicDiffusion(camitk::ActionExtension * );
@@ -65,8 +62,12 @@ public slots:
       */
     virtual ApplyStatus apply();
 
-    AnisoDiffType getMethod();
-    void setMethod(AnisoDiffType implementation);
+    /**
+     * @brief Get the diffusion type to be used by the algorithm.
+     * @return The diffusion type as an enum.
+     * @note The diffusion type uses camitk::Property with its ENUM.
+     */
+    AnisoDiffType getDiffusionType();
 
 
 private:
@@ -88,7 +89,7 @@ protected:
     bool keepOrgVoxelType;
     int numberOfIterations;
     double conductance;
-
-    AnisoDiffType implementation;
 };
+
+Q_DECLARE_METATYPE(AnisotropicDiffusion::AnisoDiffType)
 #endif // ANISOTROPICDIFFUSION_H
