@@ -31,16 +31,27 @@
 #include <ActionWidget.h>
 
 /**
- * 
+ *
  * @ingroup group_cepimaging_actions_itkfilters
- * 
+ *
  * @brief
  * Perform a derivative filter on the @ref camitk::ImageComponent "ImageComponent"
- * 
+ *
  **/
 class Derivative : public camitk::Action {
+    Q_OBJECT
+
+    /// Enumerations
+    Q_ENUMS( derivativeOrder )
+    Q_ENUMS( derivativeDirection )
 
 public:
+    /// The 3 different possible derivative orders
+    enum derivativeOrder { ORDER_0, ORDER_1, ORDER_2 };
+
+    /// The direction of the derivative
+    enum derivativeDirection { DIRECTION_X, DIRECTION_Y, DIRECTION_Z };
+
     /// Default Constructor
     Derivative(camitk::ActionExtension *);
 
@@ -82,7 +93,10 @@ protected:
     int direction;
 
     /// The order of the derivative.
-    int derivativeOrder;
+    int order;
 };
 
+Q_DECLARE_METATYPE(Derivative::derivativeOrder)
+Q_DECLARE_METATYPE(Derivative::derivativeDirection)
+
 #endif // DERIVATIVE_H
