@@ -31,12 +31,12 @@
 #include <ActionWidget.h>
 
 /**
- * 
+ *
  * @ingroup group_cepimaging_actions_itkfilters
- * 
+ *
  * @brief
  * Perform a gaussian filter on the @ref camitk::ImageComponent "ImageComponent"
- * 
+ *
  **/
 class GaussianFilter : public camitk::Action {
     Q_OBJECT
@@ -44,12 +44,10 @@ class GaussianFilter : public camitk::Action {
     /// Enumerations
     Q_ENUMS( GaussianType )
 
-    Q_PROPERTY( GaussianType implementation READ getMethod WRITE setMethod)
-
 
 public:
     /// Define the possible implementations of Gaussian filtering
-    enum GaussianType {Standard, Recursive_IIR };
+    enum GaussianType {STANDARD, RECURSIVE_IIR };
 
     /// Default Constructor
     GaussianFilter(camitk::ActionExtension *);
@@ -65,8 +63,11 @@ public slots:
       */
     virtual ApplyStatus apply();
 
-    GaussianType getMethod();
-    void setMethod(GaussianType implementation);
+    /**
+     * @brief Get the type of gaussian filering, between Standard and Recursive.
+     * @return The user selected gaussian filtering type.
+     */
+    GaussianType getType();
 
 private:
     /// helper method to simplify the target component processing
@@ -85,7 +86,8 @@ private:
 
 
 protected:
-    GaussianType implementation;
     double variance;
 };
+
+Q_DECLARE_METATYPE(GaussianFilter::GaussianType)
 #endif // DISCRETEGAUSSIANFILTER_H
