@@ -31,14 +31,15 @@
 #include <ActionWidget.h>
 
 /**
- * 
+ *
  * @ingroup group_cepimaging_actions_itkfilters
- * 
+ *
  * @brief
  * Perform a gradient magnitude recursive filter on the @ref camitk::ImageComponent "ImageComponent"
- * 
+ *
  **/
 class GradientMagnitudeRecursiveGaussian : public camitk::Action {
+    Q_OBJECT
 
 
 public:
