@@ -28,18 +28,18 @@
 #include <ActionExtension.h>
 
 /**
- * 
+ *
  * @ingroup group_cepimaging_actions_itkfilters
- * 
+ *
  * @brief
  * Manager of the ITK filter actions.
- * 
+ *
  **/
 class ITKFiltersExtension : public camitk::ActionExtension {
     Q_OBJECT
     Q_INTERFACES(camitk::ActionExtension);
 
-public: 
+public:
     /// the constructor
     ITKFiltersExtension() : ActionExtension() {};
 
@@ -47,13 +47,17 @@ public:
     virtual ~ITKFiltersExtension() {};
 
     /// Method that return the action extension name
-    virtual QString getName() {return "ITK Filters";};
+    virtual QString getName() {
+        return "ITK Filters";
+    };
 
     /// Method that return the action extension descrption
-    virtual QString getDescription() {return "This extension implements ITK Filters on image volumes. \
+    virtual QString getDescription() {
+        return "This extension implements ITK Filters on image volumes. \
 	See Chapter 6 of  \"The ITK Software Guide\" Second edition for more information about ITK Filters. \
-  ";};
-    /// initialize all the actions 
+  ";
+    };
+    /// initialize all the actions
     virtual void init();
 
 };
