@@ -24,11 +24,17 @@
  ****************************************************************************/
 #include "Laplacian.h"
 
+// CamiTK includes
 #include <Application.h>
 #include <ItkProgressObserver.h>
+#include <Property.h>
+
+// Qt includes
 #include <QMessageBox>
 #include <QString>
 #include <QTextStream>
+
+// Itk includes
 #include <itkImageToVTKImageFilter.h>
 #include <itkVTKImageToImageFilter.h>
 #include <itkCastImageFilter.h>
@@ -41,10 +47,10 @@ using namespace camitk;
 // --------------- constructor -------------------
 Laplacian::Laplacian(ActionExtension * extension) : Action(extension) {
     // Setting name, description and input component
-    setName("Laplacian");
-    setDescription("<br>This filter computes the <b>Laplacian of a scalar-valued image</b>.<br> \
-				   The Laplacian is an isotropic measure of the second spatial derivative of an image. <br> \
-				   The Laplacian of an image highlights regions of rapid intensity change and is therefore often used for edge detection. Often, the Laplacian is applied to an image that has first been smoothed with a Gaussian filter in order to reduce its sensitivity to noise.<br> \
+    setName("Laplacian Filter");
+    setDescription("<br/>This filter computes the <b>Laplacian of a scalar-valued image</b>.<br/><br/> \
+                   The Laplacian is an isotropic measure of the second spatial derivative of an image. <br/><br/> \
+                   The Laplacian of an image highlights regions of rapid intensity change and is therefore often used for edge detection. Often, the Laplacian is applied to an image that has first been smoothed with a Gaussian filter in order to reduce its sensitivity to noise.<br/><br/> \
 				   <i>(source: ITK Developer's Guide)</i><br> \
 				   ");
     setComponent("ImageComponent");
@@ -56,8 +62,8 @@ Laplacian::Laplacian(ActionExtension * extension) : Action(extension) {
     this->addTag("Contours");
 
     // Setting parameters default values
-    setProperty("keepOriginalImageVoxelType", QVariant(true));
-    keepOrgVoxelType = true;
+    Property* keepOrgVoxelTypeProperty = new Property(tr("Keep original voxel type?"), true, tr("Does the output image have the same voxel type as the input one?"), "");
+    addParameter(keepOrgVoxelTypeProperty);
 }
 
 // --------------- destructor -------------------
@@ -76,7 +82,7 @@ Action::ApplyStatus Laplacian::apply() {
 
 void Laplacian::process(ImageComponent * comp) {
     // Get the parameters
-    keepOrgVoxelType = property("keepOrgVoxelType").toBool();
+    this->keepOrgVoxelType = property("Keep original voxel type?").toBool();
 
     // ITK filter implementation using templates
     vtkSmartPointer<vtkImageData> inputImage = comp->getImageData();
@@ -161,8 +167,7 @@ vtkSmartPointer<vtkImageData> Laplacian::itkProcess(vtkSmartPointer<vtkImageData
         observer->Reset();
 
         resultImage = itkToVtkOrgFilter->GetOutput();
-    }
-    else {
+    } else {
         itkToVtkFloatFilter->SetInput(laplacianFilter->GetOutput());
         itkToVtkFloatFilter->AddObserver(itk::ProgressEvent(), observer);
         itkToVtkFloatFilter->Update();
