@@ -22,13 +22,18 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
+// CamiTK includes
 #include "LaplacianRecursiveGaussian.h"
-
 #include <Application.h>
 #include <ItkProgressObserver.h>
+#include <Property.h>
+
+// Qt includes
 #include <QMessageBox>
 #include <QString>
 #include <QTextStream>
+
+// Itk includes
 #include <itkImageToVTKImageFilter.h>
 #include <itkVTKImageToImageFilter.h>
 #include <itkRescaleIntensityImageFilter.h>
@@ -41,7 +46,7 @@ using namespace camitk;
 LaplacianRecursiveGaussian::LaplacianRecursiveGaussian(ActionExtension * extension) : Action(extension) {
     // Setting name, description and input component
     setName("Laplacian Filter With Smoothing");
-    setDescription("<br>Computes the <b>Laplacian of Gaussian (LoG)</b> of an image by convolution with the second derivative of a Gaussian. This filter is implemented using the recursive gaussian filters.");
+    setDescription("<br/>Computes the <b>Laplacian of Gaussian (LoG)</b> of an image by convolution with the second derivative of a Gaussian.<br/><br/> This filter is implemented using the recursive gaussian filters.");
     setComponent("ImageComponent");
 
     // Setting classification family and tags
@@ -53,11 +58,14 @@ LaplacianRecursiveGaussian::LaplacianRecursiveGaussian(ActionExtension * extensi
     this->addTag("Smoothing");
 
     // Setting parameters default values
-    setProperty("keepOriginalImageVoxelType", QVariant(true));
-    setProperty("sigma", QVariant(3.0));
+    Property* keepOrgVoxelTypeProperty = new Property(tr("Keep original voxel type?"), true, tr("Does the output image have the same voxel type as the input one?"), "");
+    addParameter(keepOrgVoxelTypeProperty);
 
-    keepOrgVoxelType = true;
-    sigma = 3.0;
+    Property* standardDeviationProperty = new Property(tr("Standard deviation"), 3.0 ,tr("The standard deviation <i>(sigma)</i> is used as a parameter of the Gaussian convolution kernel. \nThe higher the deviation is, the blurer the resulting image will be."), "");
+    standardDeviationProperty->setAttribute("minimum", 0);
+    standardDeviationProperty->setAttribute("maximum", 100);
+    standardDeviationProperty->setAttribute("singleStep", 0.1);
+    addParameter(standardDeviationProperty);
 
 }
 
@@ -77,8 +85,8 @@ Action::ApplyStatus LaplacianRecursiveGaussian::apply() {
 
 void LaplacianRecursiveGaussian::process(ImageComponent * comp) {
     // Get the parameters
-    keepOrgVoxelType = property("keepOrgVoxelType").toBool();
-    sigma = property("sigma").toDouble();
+    this->keepOrgVoxelType = property("Keep original voxel type?").toBool();
+    this->sigma = property("Standard deviation").toDouble();
 
     // ITK filter implementation using templates
     vtkSmartPointer<vtkImageData> inputImage = comp->getImageData();
@@ -154,8 +162,7 @@ vtkSmartPointer<vtkImageData> LaplacianRecursiveGaussian::itkProcess(vtkSmartPoi
         observer->Reset();
 
         resultImage = itkToVtkOrgFilter->GetOutput();
-    }
-    else {
+    } else {
         itkToVtkFloatFilter->SetInput(recursiveGaussianFilter->GetOutput());
         itkToVtkFloatFilter->AddObserver(itk::ProgressEvent(), observer);
         itkToVtkFloatFilter->Update();
