@@ -33,12 +33,12 @@
 #include <itkImage.h>
 
 /**
- * 
+ *
  * @ingroup group_cepimaging_actions_itkfilters
- * 
+ *
  * @brief
  * Perform some morphological operators such as opening, closing ...
- * 
+ *
  **/
 class MorphologicalOperators : public camitk::Action {
     Q_OBJECT
@@ -47,26 +47,21 @@ class MorphologicalOperators : public camitk::Action {
     Q_ENUMS( MorphoType )
     Q_ENUMS( MorphoOperation )
 
-    Q_PROPERTY( MorphoType      typeOfOperation READ getTypeOfOperation WRITE setTypeOfOperation)
-    Q_PROPERTY( MorphoOperation operation       READ getOperation       WRITE setOperation)
-
-
 public:
-    /// Define the possible types of morphological operatiosn
-    enum MorphoType {Grey_Level, Binary };
+    /// Define the possible types of morphological operations
+    enum MorphoType {GREY_LEVEL, BINARY};
 
     /// Define the possible morphological operations
-    enum MorphoOperation {Erosion, Dilation, Opening, Closing };
+    enum MorphoOperation {EROSION, DILATION, OPENING, CLOSING};
 
     /// Default Constructor
     MorphologicalOperators(camitk::ActionExtension *);
 
-    // Setters and Getters for parameters
-    MorphoType getTypeOfOperation() const ;
-    void setTypeOfOperation(const MorphoType typeOfOperation);
+    /// Get the morphological type of operation
+    MorphoType getMorphoType() const ;
 
-    MorphoOperation getOperation() const ;
-    void setOperation(const MorphoOperation operation);
+    /// Get the morphological operation selected
+    MorphoOperation getMorphoOperation() const ;
 
     /// Default Destructor
     virtual ~MorphologicalOperators();
@@ -119,4 +114,7 @@ protected:
     QString suffix;
 
 };
+
+Q_DECLARE_METATYPE(MorphologicalOperators::MorphoType)
+Q_DECLARE_METATYPE(MorphologicalOperators::MorphoOperation)
 #endif // MORPHOLOGICALOPERATORS_H
