@@ -22,13 +22,18 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
+// CamiTK includes
 #include "SobelEdgeDetection.h"
-
 #include <Application.h>
 #include <ItkProgressObserver.h>
+#include <Property.h>
+
+// Qt includes
 #include <QMessageBox>
 #include <QString>
 #include <QTextStream>
+
+// Itk includes
 #include <itkImageToVTKImageFilter.h>
 #include <itkVTKImageToImageFilter.h>
 #include <itkCastImageFilter.h>
@@ -53,8 +58,8 @@ SobelEdgeDetection::SobelEdgeDetection(ActionExtension * extension) : Action(ext
     this->addTag("Edge Detection");
     this->addTag("Contours");
 
-    setProperty("keepOriginalImageVoxelType", QVariant(true));
-    keepOrgVoxelType = true;
+    Property* keepOrgVoxelTypeProperty = new Property(tr("Keep original voxel type?"), true, tr("Does the output image have the same voxel type as the input one?"), "");
+    addParameter(keepOrgVoxelTypeProperty);
 }
 
 // --------------- destructor -------------------
@@ -71,7 +76,7 @@ Action::ApplyStatus SobelEdgeDetection::apply() {
 }
 
 void SobelEdgeDetection::process(ImageComponent * comp) {
-    keepOrgVoxelType = property("keepOriginalImageVoxelType").toBool();
+    this->keepOrgVoxelType = property("Keep original voxel type?").toBool();
     // ITK filter implementation using templates
     vtkSmartPointer<vtkImageData> inputImage = comp->getImageData();
     vtkSmartPointer<vtkImageData> outputImage = implementProcess (inputImage);
@@ -155,8 +160,7 @@ vtkSmartPointer<vtkImageData> SobelEdgeDetection::itkProcess(vtkSmartPointer<vtk
         observer->Reset();
 
         resultImage = itkToVtkFilter2->GetOutput();
-    }
-    else {
+    } else {
         // From ITK to VTK
         itkToVtkFilter->SetInput(sobelFilter->GetOutput());
         itkToVtkFilter->AddObserver(itk::ProgressEvent(), observer );
