@@ -32,14 +32,15 @@
 #include <ActionWidget.h>
 
 /**
- * 
+ *
  * @ingroup group_cepimaging_actions_itkfilters
- * 
+ *
  * @brief
  * Perform the Sobel edge detection on the @ref camitk::ImageComponent "ImageComponent"
- * 
+ *
  **/
 class SobelEdgeDetection : public camitk::Action {
+    Q_OBJECT
 
 
 public:
