@@ -28,18 +28,18 @@
 #include <ActionExtension.h>
 
 /**
- * 
+ *
  * @ingroup group_cepimaging_actions_itksegmentation
- * 
+ *
  * @brief
  * Manager for the ITK segmentation filter actions.
- * 
+ *
  **/
 class ITKSegmentationExtension : public camitk::ActionExtension {
     Q_OBJECT
     Q_INTERFACES(camitk::ActionExtension);
 
-public: 
+public:
     /// the constructor
     ITKSegmentationExtension() : ActionExtension() {};
 
@@ -47,12 +47,16 @@ public:
     virtual ~ITKSegmentationExtension() {};
 
     /// Method that return the action extension name
-    virtual QString getName() {return "ITK Segmentation";};
+    virtual QString getName() {
+        return "ITK Segmentation";
+    };
 
     /// Method that return the action extension descrption
-    virtual QString getDescription() {return "This extension implements ITK Segmentation Filters on image volumes.\
-											 See Chapter 9 of  <i>The ITK Software Guide</i> Second edition for more information about ITK Segmentation Filters.";};
-    /// initialize all the actions 
+    virtual QString getDescription() {
+        return "This extension implements ITK Segmentation Filters on image volumes.\
+											 See Chapter 9 of  <i>The ITK Software Guide</i> Second edition for more information about ITK Segmentation Filters.";
+    };
+    /// initialize all the actions
     virtual void init();
 
 };
