@@ -22,18 +22,22 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
+// CamiTK incldues
 #include "ManualThreshold.h"
-
 #include <Application.h>
 #include <ItkProgressObserver.h>
+#include <Property.h>
+
+// Qt includes
 #include <QMessageBox>
 #include <QString>
 #include <QTextStream>
+
+// Itk includes
 #include <itkImageToVTKImageFilter.h>
 #include <itkVTKImageToImageFilter.h>
 #include <itkBinaryThresholdImageFilter.h>
 
-
 using namespace camitk;
 
 
@@ -41,7 +45,11 @@ using namespace camitk;
 ManualThreshold::ManualThreshold(ActionExtension * extension) : Action(extension) {
     // Setting name, description and input component
     setName("Manual Threshold Filter");
-    setDescription("Sets all the pixel / voxels <br/>- below <i>lowThreshold</i> and<br/>- above <i>highThreshold</i> <br/>to 0.<br>Sets the other <i>pixels / voxels</i> to 255");
+    setDescription("<br/>Sets all the pixels / voxels scalar value according to the following rules:\
+                   <ul> \
+                   <li>low threshold &lt; scalar value &lt; high threshold \=&gt; white (255) </li> \
+                   <li>scalar value &lt; low threshold OR scalar value &gt; high threshold \=&gt; black (0)</li> \
+                   </ul>");
     setComponent("ImageComponent");
 
     // Setting classification family and tags
@@ -51,8 +59,17 @@ ManualThreshold::ManualThreshold(ActionExtension * extension) : Action(extension
     this->addTag("Classification");
 
     // Setting parameters default values
-    setProperty("lowThreshold", QVariant(128));
-    setProperty("highThreshold", QVariant(255));
+    Property* lowThresholdProperty = new Property(tr("Low threshold"), 128, tr("Voxels which have a scalar value below this threshold will considered as black (0). Above it AND below high threshold, they will be considered as white (255)."), "");
+    lowThresholdProperty->setAttribute("minimum", 0);
+    lowThresholdProperty->setAttribute("maximum", 255);
+    lowThresholdProperty->setAttribute("singleStep", 1);
+    addParameter(lowThresholdProperty);
+
+    Property* highThresholdProperty = new Property(tr("High threshold"), 255, tr("Voxels which have a scalar value above this threshold will considered as black (0). Below it AND above low threshold, they will be considered as white (255)."), "");
+    highThresholdProperty->setAttribute("minimum", 0);
+    highThresholdProperty->setAttribute("maximum", 255);
+    highThresholdProperty->setAttribute("singleStep", 1);
+    addParameter(highThresholdProperty);
 }
 
 // --------------- destructor -------------------
@@ -72,8 +89,8 @@ Action::ApplyStatus ManualThreshold::apply() {
 // --------------- process -------------------
 void ManualThreshold::process(ImageComponent * comp) {
     // Get the parameters
-    lowThreshold = property("lowThreshold").toInt();
-    highThreshold = property("highThreshold").toInt();
+    this->lowThreshold = property("Low threshold").toInt();
+    this->highThreshold = property("High threshold").toInt();
 
     // ITK filter implementation using templates
     vtkSmartPointer<vtkImageData> inputImage = comp->getImageData();
