@@ -29,14 +29,15 @@
 #include <ImageComponent.h>
 
 /**
- * 
+ *
  * @ingroup group_cepimaging_actions_itksegmentation
- * 
+ *
  * @brief
  * Segment the @ref camitk::ImageComponent "ImageComponent" using a manual threshold.
- * 
+ *
  **/
 class ManualThreshold : public camitk::Action {
+    Q_OBJECT
 
 public:
     /// Default Constructor
