@@ -22,13 +22,18 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
+// CamiTK includes
 #include "OtsuFilter.h"
-
 #include <Application.h>
 #include <ItkProgressObserver.h>
+#include <Property.h>
+
+// Qt includes
 #include <QMessageBox>
 #include <QString>
 #include <QTextStream>
+
+// Itk includes
 #include <itkImageToVTKImageFilter.h>
 #include <itkVTKImageToImageFilter.h>
 #include <itkOtsuThresholdImageFilter.h>
@@ -41,7 +46,7 @@ using namespace camitk;
 OtsuFilter::OtsuFilter(ActionExtension * extension) : Action(extension) {
     // Setting name, description and input component
     setName("Otsu Threshold Filter");
-    setDescription("<p>This filters classifies pixels to minimize the error of misclassification. The goal is to find a threshold that classifies the image into two clusters such that we minimize the area under the histogram for one cluster that lies on the other cluster's side of the threshold. This is equivalent to minimizing the within class variance or equivalently maximizing the between class variance.</p>");
+    setDescription("<p> This filter creates a binary thresholded image that separates an image into foreground and background components. <br/>The filter calculates the optimum threshold separating those two classes so that their combined spread (intra-class variance) is minimal (see http://en.wikipedia.org/wiki/Otsu%27s_method).  Then the filter applies that threshold to the input image using an Itk binary fileter. The numberOfHistogram bins can be set for the Otsu Calculator. The insideValue and outsideValue can be set for the Itk binary filter.  The filter produces a labeled volume. <br/><br/>The original reference is: <br/>. <i>Otsu, ''A threshold selection method from gray level histograms,'' IEEE Trans.Syst.ManCybern.SMC-9,62-66 1979.</i></p>");
     setComponent("ImageComponent");
 
     // Setting classification family and tags
@@ -51,10 +56,22 @@ OtsuFilter::OtsuFilter(ActionExtension * extension) : Action(extension) {
     this->addTag("Otsu");
     this->addTag("Region Growing");
 
+    this->computedThresholdProperty = new Property(tr("Computed threshold:"), tr("?"), tr("The computed threshold found by the Otsu filter. \nThis property is read only and only updated after applying the action on a component."), "");
+    computedThresholdProperty->setReadOnly(true);
+    addParameter(computedThresholdProperty);
+
     // Setting parameters default values
-    setProperty("insideValue", QVariant(0));
-    setProperty("outsideValue", QVariant(255));
-    usedThreshold = -1;
+    Property* insideValueProperty = new Property(tr("Inside value"), 0, tr("The scalar type value assigned to voxels which have their scalar type BELOW the threshold value."), "");
+    insideValueProperty->setAttribute("minimum", 0);
+    insideValueProperty->setAttribute("maximum", 255);
+    insideValueProperty->setAttribute("singleStep", 1);
+    addParameter(insideValueProperty);
+
+    Property* outsideValueProperty = new Property(tr("Outside value"), 255, tr("The scalar type value assigned to voxels which have their scalar type ABOVE the threshold value."), "");
+    outsideValueProperty->setAttribute("minimum", 0);
+    outsideValueProperty->setAttribute("maximum", 255);
+    outsideValueProperty->setAttribute("singleStep", 1);
+    addParameter(outsideValueProperty);
 }
 
 // --------------- destructor -------------------
@@ -62,9 +79,6 @@ OtsuFilter::~OtsuFilter() {
     // do not delete the widget has it might have been used in the ActionViewer (i.e. the ownership might have been taken by the stacked widget)
 }
 
-double OtsuFilter::getUsedThreshold() const {
-    return this->usedThreshold;
-}
 
 // --------------- apply -------------------
 Action::ApplyStatus OtsuFilter::apply() {
@@ -77,8 +91,8 @@ Action::ApplyStatus OtsuFilter::apply() {
 
 void OtsuFilter::process(ImageComponent * comp) {
     // Get the parameters
-    insideValue = property("insideValue").toInt();
-    outsideValue = property("outsideValue").toInt();
+    this->insideValue = property("Inside value").toInt();
+    this->outsideValue = property("Outside value").toInt();
 
     // ITK filter implementation using templates
     vtkSmartPointer<vtkImageData> inputImage = comp->getImageData();
@@ -152,7 +166,9 @@ vtkSmartPointer<vtkImageData> OtsuFilter::itkProcess(vtkSmartPointer<vtkImageDat
     // Set CamiTK progress bar back to zero (the processing filter is over)
     observer->Reset();
 
-    this->usedThreshold = (double) filter->GetThreshold();
+    //this->usedThreshold = (double) filter->GetThreshold();
+    QObject::setProperty("Computed threshold:", (double) filter->GetThreshold());
+
 
     return result;
 }
