@@ -30,21 +30,22 @@
 #include <ImageComponent.h>
 #include <ActionWidget.h>
 
+// CamiTK forward declaration
+namespace camitk {
+class Property;
+}
+
 /**
- * 
+ *
  * @ingroup group_cepimaging_actions_itksegmentation
- * 
+ *
  * @brief
  * Segment using the otsu filter the @ref camitk::ImageComponent "ImageComponent"
- * 
+ *
  **/
 class OtsuFilter : public camitk::Action {
     Q_OBJECT
 
-    // declaration of parameters
-    Q_PROPERTY( double usedThreshold READ getUsedThreshold)
-
-
 public:
     /// Default Constructor
     OtsuFilter(camitk::ActionExtension *);
@@ -60,14 +61,14 @@ public slots:
       */
     virtual ApplyStatus apply();
 
-public:
-    double getUsedThreshold() const ;
-
 private:
+    /// camitk::Property that displayed the computed threshold after applying the action.
+    /// @note The camitk::Property is readonly
+    camitk::Property* computedThresholdProperty;
+
     /// helper method to simplify the target component processing
     virtual void process(camitk::ImageComponent * comp);
 
-private:
     vtkSmartPointer<vtkImageData> implementProcess(vtkSmartPointer<vtkImageData> img);
 
     template <class InputPixelType, class OutputPixelType, const int dim>
