@@ -22,7 +22,7 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
-#include <QMessageBox> 
+#include <QMessageBox>
 #include <QFileDialog>
 #include <QList>
 #include <QVector3D>
@@ -32,17 +32,16 @@
 #include "RegionGrowingWidget.h"
 using namespace camitk;
 
-RegionGrowingWidget::RegionGrowingWidget(Action * action) 
-: QWidget()
-{
-	this->myAction = action;
-	ui.setupUi(this);
-	pickingW = new MultiPickingWidget(this);
-	ui.seedPointGroupBox->layout()->addWidget(pickingW);
+RegionGrowingWidget::RegionGrowingWidget(Action * action)
+    : QWidget() {
+    this->myAction = action;
+    ui.setupUi(this);
+    pickingW = new MultiPickingWidget(this);
+    ui.seedPointGroupBox->layout()->addWidget(pickingW);
+
+    QObject::connect(ui.applyButton, SIGNAL(clicked()), myAction, SLOT(apply()));
 
-	QObject::connect(ui.applyButton, SIGNAL(clicked()), myAction, SLOT(apply()));
 
-	
 }
 
 RegionGrowingWidget::~RegionGrowingWidget() {
@@ -50,32 +49,32 @@ RegionGrowingWidget::~RegionGrowingWidget() {
 }
 
 bool RegionGrowingWidget::isSmoothingChecked() {
-	return ui.smoothingGroupBox->isChecked();
+    return ui.smoothingGroupBox->isChecked();
 }
 
 int RegionGrowingWidget::getNumberOfIterations() {
-	return ui.numberOfIterationsSpinBox->value();
+    return ui.numberOfIterationsSpinBox->value();
 }
 
 double RegionGrowingWidget::getTimeStep() {
-	return ui.timeStepDoubleSpinBox->value();
+    return ui.timeStepDoubleSpinBox->value();
 }
 
 int RegionGrowingWidget::getLowThreshold() {
-	return ui.lowThresholdSpinBox->value();
+    return ui.lowThresholdSpinBox->value();
 }
 
 int RegionGrowingWidget::getHighThreshold() {
-	return ui.highThresholdSpinBox->value();
+    return ui.highThresholdSpinBox->value();
 }
 
 QList<QVector3D> * RegionGrowingWidget::getSeedPoints(ImageComponent * image) {
-	return pickingW->getPickedPixelMap(image)->getPixelIndexList();
+    return pickingW->getPickedPixelMap(image)->getPixelIndexList();
 }
 
 
 void RegionGrowingWidget::updateComponent (ImageComponent * image) {
-	ui.componentName->setText(image->getName());
-	pickingW->updateComponent(image);
+    ui.componentName->setText(image->getName());
+    pickingW->updateComponent(image);
 }
 
