@@ -44,7 +44,7 @@ using namespace camitk;
 
 // -------------------- constructor --------------------
 ItkImageComponent::ItkImageComponent(const QString& fileName) throw(AbortException)
-        : ImageComponent(fileName) {
+    : ImageComponent(fileName) {
     createComponent(fileName);
 }
 
@@ -56,12 +56,10 @@ void ItkImageComponent::createComponent(const QString & filename) {
             setImageData(img, false);
             // use file basename as default name
             setName(QFileInfo(filename).baseName());
-        }
-        else {
+        } else {
             throw (AbortException("Could not open file\n"));
         }
-    }
-    else {
+    } else {
         throw (AbortException("No filename found\n"));
     }
 
@@ -115,8 +113,7 @@ vtkSmartPointer<vtkImageData> ItkImageComponent::readVolume(const QString& filen
 
         // set the original slices. Other orientation are build when/if required only.
         newImage->Update();
-    }
-    catch ( itk::ExceptionObject & err ) {
+    } catch ( itk::ExceptionObject & err ) {
         std::cerr << "ExceptionObject caught !" << std::endl;
         std::cerr << err << std::endl;
         return NULL;
