@@ -57,9 +57,9 @@ QString ItkImageComponentExtension::getDescription() const {
 //  + "<li>mnc (MINC / MINC2) is developed over the past 15 years at the Brain Imaging Centre (or Centre) at the Montreal Neurological Institute</li>"
            + "<li>Nrrd is the \"Nearly Raw Raster Data\"</li>"
 //  + "<li>cub see <a href=\"http://www.insight-journal.org/browse/publication/118\">http://www.insight-journal.org/browse/publication/118</a></li></ul><br/>"
-			+ "<li>NIfTI-1 (.nii) is adapted from the widely used ANALYZE 7.5 file format. For more info about image data format: <a href=\"http://nifti.nimh.nih.gov/nifti-1/\">http://nifti.nimh.nih.gov/nifti-1/</a> </li>"
+           + "<li>NIfTI-1 (.nii) is adapted from the widely used ANALYZE 7.5 file format. For more info about image data format: <a href=\"http://nifti.nimh.nih.gov/nifti-1/\">http://nifti.nimh.nih.gov/nifti-1/</a> </li>"
 //  + "<li>cub see <a href=\"http://www.insight-journal.org/browse/publication/118\">http://www.insight-journal.org/browse/publication/118</a></li></ul><br/>"
-			+ "</ul>";
+           + "</ul>";
 }
 
 // --------------- getFileExtensions -------------------
@@ -74,8 +74,7 @@ Component * ItkImageComponentExtension::open(const QString & fileName) throw (Ab
     ItkImageComponent * res = NULL;
     try {
         res = new ItkImageComponent(fileName);
-    }
-    catch (AbortException e) {
+    } catch (AbortException e) {
         throw e;
     }
     return res;
@@ -112,8 +111,7 @@ bool ItkImageComponentExtension::save(Component * c) const {
         if (dim == 2) {
             typedef itk::Image<char, 2> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
-        }
-        else {// if dim == 3
+        } else { // if dim == 3
             typedef itk::Image<char, 3> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
         }
@@ -125,8 +123,7 @@ bool ItkImageComponentExtension::save(Component * c) const {
         if (dim == 2) {
             typedef itk::Image<unsigned char, 2> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
-        }
-        else {// if dim == 3
+        } else { // if dim == 3
             typedef itk::Image<unsigned char, 3> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
         }
@@ -138,8 +135,7 @@ bool ItkImageComponentExtension::save(Component * c) const {
         if (dim == 2) {
             typedef itk::Image<signed char, 2> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
-        }
-        else {// if dim == 3
+        } else { // if dim == 3
             typedef itk::Image<signed char, 3> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
         }
@@ -151,8 +147,7 @@ bool ItkImageComponentExtension::save(Component * c) const {
         if (dim == 2) {
             typedef itk::Image<short, 2> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
-        }
-        else {// if dim == 3
+        } else { // if dim == 3
             typedef itk::Image<short, 3> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
         }
@@ -164,8 +159,7 @@ bool ItkImageComponentExtension::save(Component * c) const {
         if (dim == 2) {
             typedef itk::Image<unsigned short, 2> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
-        }
-        else {// if dim == 3
+        } else { // if dim == 3
             typedef itk::Image<unsigned short, 3> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
         }
@@ -177,8 +171,7 @@ bool ItkImageComponentExtension::save(Component * c) const {
         if (dim == 2) {
             typedef itk::Image<int, 2> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
-        }
-        else {// if dim == 3
+        } else { // if dim == 3
             typedef itk::Image<int, 3> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
         }
@@ -190,8 +183,7 @@ bool ItkImageComponentExtension::save(Component * c) const {
         if (dim == 2) {
             typedef itk::Image<unsigned int, 2> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
-        }
-        else {// if dim == 3
+        } else { // if dim == 3
             typedef itk::Image<unsigned int, 3> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
         }
@@ -203,8 +195,7 @@ bool ItkImageComponentExtension::save(Component * c) const {
         if (dim == 2) {
             typedef itk::Image<long, 2> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
-        }
-        else {// if dim == 3
+        } else { // if dim == 3
             typedef itk::Image<long, 3> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
         }
@@ -216,8 +207,7 @@ bool ItkImageComponentExtension::save(Component * c) const {
         if (dim == 2) {
             typedef itk::Image<unsigned long, 2> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
-        }
-        else {// if dim == 3
+        } else { // if dim == 3
             typedef itk::Image<unsigned long, 3> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
         }
@@ -229,8 +219,7 @@ bool ItkImageComponentExtension::save(Component * c) const {
         if (dim == 2) {
             typedef itk::Image<float, 2> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
-        }
-        else {// if dim == 3
+        } else { // if dim == 3
             typedef itk::Image<float, 3> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
         }
@@ -242,8 +231,7 @@ bool ItkImageComponentExtension::save(Component * c) const {
         if (dim == 2) {
             typedef itk::Image<double, 2> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
-        }
-        else {// if dim == 3
+        } else { // if dim == 3
             typedef itk::Image<double, 3> ImageType;
             succeed = ItkImageComponentExtension::saveImage<ImageType>(img);
         }
@@ -280,8 +268,7 @@ template<class ImageType> bool ItkImageComponentExtension::saveImage(ImageCompon
 
     try {
         writer->Update();
-    }
-    catch (itk::ExceptionObject & err ) {
+    } catch (itk::ExceptionObject & err ) {
         QMessageBox::warning(NULL,"Saving Error", "Problem while saving to file:<br/>" + filename +"<br/>ITK Exception:<br/>"+ err.what());
         return false;
     }
