@@ -48,7 +48,7 @@ CreateSC::CreateSC(ActionExtension* extension) : Action(extension) {
     setProperty("Name Of The New Component", "selection");
     //TODO setProperty("Select Only On Surface", (bool) false);
     setProperty("Bottom Corner", QVector3D(0.0,0.0,0.0));
-    setProperty("Top Corner", QVector3D(0.0,0.0,0.0));    
+    setProperty("Top Corner", QVector3D(0.0,0.0,0.0));
 }
 
 // --------------- getWidget -------------------
@@ -75,16 +75,14 @@ QWidget * CreateSC::getWidget() {
                 QString number = QString::number( numAsStr.toInt() + 1 );
                 number = number.rightJustified( numAsStr.length(), '0' );
                 selectionName.replace( start, numAsStr.length(), number );
-            }
-            else {
+            } else {
                 // no number
                 start = selectionName.lastIndexOf('.');
 
                 if (start != -1) {
                     // has a . somewhere, e.g. it has an extension
                     selectionName.insert(start, '1');
-                }
-                else {
+                } else {
                     // no extension, just tack it on to the end
                     selectionName += '1';
                 }
@@ -160,8 +158,7 @@ Action::ApplyStatus CreateSC::apply() {
         // is going to cascade down and create the new SCDC corresponding to selection
         new MultiComponentDC(pmlDC, pmlDC, pm->getInformativeComponents());
         scdc = pmlDC->getDC(selection);
-    }
-    else {
+    } else {
         // there is already the informative component, just add the new corresponding SCDC
         scdc = new StructuralComponentDC(mcdc,pmlDC,selection);
     }
