@@ -27,13 +27,21 @@
 #define GENERATEMODEL_H
 
 #include <Action.h>
+#include <QVector3D>
+
+#include <set>
+
+namespace camitk {
+class MeshComponent;
+}
+
 /**
  * @ingroup group_cepmodeling_actions_mml
- * 
+ *
  * @brief
  * Action to generate MML/Sofa scn from a vtk mesh.
- * 
- * 
+ *
+ *
  **/
 class GenerateModel : public camitk::Action {
 
@@ -44,13 +52,27 @@ public:
     /// the destructor
     virtual ~GenerateModel() {};
 
-    /// no widget yet
-    virtual QWidget * getWidget() { return NULL; }
-    
+    /// default widget
+    virtual QWidget * getWidget() {
+        return Action::getWidget();
+    }
+
 public slots:
     /// method applied when the action is called
     virtual ApplyStatus apply();
 
+private:
+    /// save the .scn file, TODO add the choice to save MML with another simulator
+    void saveSOFAFile(QString baseFilename);
+
+    /// save all the MML, PML and LML file
+    void saveMMLFiles(QString baseFilename);
+
+    // list of index that are potentially fixed (null displacement constraint)
+    std::set<int> fixedDOFIndex;
+
+    /// The current managed mesh
+    camitk::MeshComponent *targetMesh;
 };
 
 #endif // GENERATEMODEL_H
