@@ -23,15 +23,15 @@
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
 #include "MMLActionExtension.h"
-#include "CreateSC.h"
 
-//#include "GenerateModel.h"
+#include "CreateSC.h"
+#include "GenerateModel.h"
 
 // --------------- declare the extension -------------------
 Q_EXPORT_PLUGIN2(mmlactionextension, MMLActionExtension)
 
 // -------------------- init --------------------
 void MMLActionExtension::init() {
-  //  registerNewAction(GenerateModel);
-  registerNewAction(CreateSC);
+    registerNewAction(GenerateModel);
+    registerNewAction(CreateSC);
 }
