@@ -31,11 +31,11 @@
 #include <ActionExtension.h>
 /**
  * @ingroup group_cepmodeling_actions_mml
- * 
+ *
  * @brief
  * Manager for the MML action.
- * 
- * 
+ *
+ *
  **/
 class MMLActionExtension : public camitk::ActionExtension {
     Q_OBJECT
@@ -52,12 +52,16 @@ public:
     /// the own actions of an extension are load there.
     /// It is necessary to use the method Application::addAction(Action) for each action added in this method.
     virtual void init();
-    
+
     /// Method that return the action extension name
-    virtual QString getName() {return "MML";};
-    
+    virtual QString getName() {
+        return "MML";
+    };
+
     /// Method that return the action extension descrption
-    virtual QString getDescription() {return "Various actions for MML";};
+    virtual QString getDescription() {
+        return "Various actions for MML";
+    };
 
 };
 
