@@ -54,6 +54,8 @@ using namespace camitk;
 #include "AtomDCPopup.h"
 #include "StructuralComponentDC.h"
 #include "AtomDecoration.h"
+#include <LoadsManager.h>
+#include <LoadsSimulation.h>
 
 
 // -------------------- constructor --------------------
@@ -115,7 +117,7 @@ unsigned int AtomDC::registerIndexInSCDC ( std::IndexInParentItemPair p ) {
 
     //cout << "AtomDC " << getName().toStdString() << " registerIndexInSCDC(" << dynamic_cast<StructuralComponentDC *> ( p.first )->getName().toStdString() << "," << p.second << endl;
 
-    return mySCDCindexes.size();
+    return (unsigned int) mySCDCindexes.size();
 }
 
 // -------------------- getOrderNumberInSCDC --------------------
@@ -131,7 +133,7 @@ int AtomDC::getOrderNumberInSCDC ( StructuralComponentDC * parent ) {
 // -------------------- unregisterIndexInSCDC --------------------
 unsigned int AtomDC::unregisterIndexInSCDC ( StructuralComponentDC * parent ) {
     mySCDCindexes.erase ( dynamic_cast<InterfaceNode *> ( parent ) );
-    return mySCDCindexes.size();
+    return (unsigned int) mySCDCindexes.size();
 }
 
 // -------------------- getPopupMenu --------------------
@@ -181,7 +183,7 @@ void AtomDC::initRepresentation() {
     delete [] vtkPointIndex;
 
     // create the new geometry
-    myGeometry = new Geometry ( this->getName(), uGrid, InterfaceGeometry::Points );
+    myGeometry = new Geometry ( this->getName(), uGrid, InterfaceGeometry::None );
 
     if ( isSelectedFlag ) {
         // add the glyph now
@@ -240,7 +242,7 @@ void AtomDC::updatePosition() {
     // for each of them
     //     - get its DC
     //     - tell it that this particular atom has been modified
-    for ( unsigned int i = 0;i < myAtom->getNumberOfStructuralComponents();i++ ) {
+    for ( unsigned int i = 0; i < myAtom->getNumberOfStructuralComponents(); i++ ) {
         // tell the SCDC the atom position has changed
         myPMManagerDC->getDC ( myAtom->getStructuralComponent ( i ) )->updatePosition ( this );
     }
@@ -302,7 +304,7 @@ void AtomDC::setSelected ( const bool d, const bool /*recursive (not used)*/ ) {
                 myPMManagerDC->computeBoundingRadius();
                 includedSphereRadius = myPMManagerDC->getBoundingRadius();
             }
-            
+
             myGeometry->setGlyphType( Sphere, includedSphereRadius / 75.0 );
             myGeometry->getProp("glyph")->VisibilityOn();
         }
@@ -373,6 +375,7 @@ void AtomDC::updatePointData ( const double value ) {
         for ( unsigned int i = 0; i < pointData.size(); i++ ) {
             *pointData[i] = value;
         }
+
     }
 }
 
