@@ -45,23 +45,23 @@ class AtomDecoration;
 
 namespace std {
 
-    /** definition of a couple (=STL pair) [InterfaceNode *, unsigned int]
-        * this associates a parent data component with a subItem order number
-      */
-    typedef std::pair<camitk::InterfaceNode *, unsigned int> IndexInParentItemPair;
-    /** definition of the association set (=map in STL) IndexInParentItemMap.
-      * IndexInParentItemMap allows a DC to associate all its parent DCs with
-      * its order numbers in these parent DCs.
-      * The key is the  parent DC, so that it is simple to retrieve the order number of
-      * a this DC in a particular parent item.
-      */
-    typedef std::map <camitk::InterfaceNode *, unsigned int> IndexInParentItemMap;
-    /** the iterator corresponding to the IndexInParentItemMap map */
-    typedef std::map <camitk::InterfaceNode *, unsigned int>::iterator IndexInParentItemMapIterator;
+/** definition of a couple (=STL pair) [InterfaceNode *, unsigned int]
+    * this associates a parent data component with a subItem order number
+  */
+typedef std::pair<camitk::InterfaceNode *, unsigned int> IndexInParentItemPair;
+/** definition of the association set (=map in STL) IndexInParentItemMap.
+  * IndexInParentItemMap allows a DC to associate all its parent DCs with
+  * its order numbers in these parent DCs.
+  * The key is the  parent DC, so that it is simple to retrieve the order number of
+  * a this DC in a particular parent item.
+  */
+typedef std::map <camitk::InterfaceNode *, unsigned int> IndexInParentItemMap;
+/** the iterator corresponding to the IndexInParentItemMap map */
+typedef std::map <camitk::InterfaceNode *, unsigned int>::iterator IndexInParentItemMapIterator;
 }
 /**
  * @ingroup group_cepmodeling_components_physicalmodel
- * 
+ *
  * @brief
  * The manager of the Atom data.
  * AtomDC are only created in the StructuralComponentDC constructor,
@@ -69,10 +69,10 @@ namespace std {
  * But as Atom can be referenced by more than one Component (StructuralComponent or Cell)
  * AtomDC is a particular type of DC that can have more than one parent DC (setParent is
  * rewritten here).
- * 
+ *
  **/
 class PHYSICALMODEL_COMPONENT_API AtomDC : public camitk::Component {
-Q_OBJECT  
+    Q_OBJECT
 public:
     AtomDC(camitk::Component *parent, PMManagerDC * pmManagerDC, Atom *);
     virtual ~AtomDC();
@@ -88,7 +88,7 @@ public:
 
     /// picking is selecting/unselecting
     void pointPicked(vtkIdType, bool);
-    
+
     /// when seleceted add a sphere glyph around the atom position and set the enhanced mode to Normal
     virtual void setSelected(const bool, const bool recursive=false);
 
@@ -110,7 +110,7 @@ public:
     /// reimplement this method to give the property object to the property editor
     virtual QObject * getPropertyObject();
 
-    /// overloaded method, allows to set the point when double clicked
+    /// overloaded method, allows one to set the point when double clicked
     virtual bool doubleClicked();
     ///@}
 
@@ -132,9 +132,11 @@ public:
     /// get the atom this dc is representing
     Atom * getAtom();
 
-    /// get the PMManagerDC (given during instanciation), allows to get PML/Component maps
-    virtual PMManagerDC * getPMManagerDC() { return myPMManagerDC; }
-    
+    /// get the PMManagerDC (given during instanciation), allows one to get PML/Component maps
+    virtual PMManagerDC * getPMManagerDC() {
+        return myPMManagerDC;
+    }
+
     /** register a StructuralComponentDC and this AtomDC corresponding order number in it (NOTE: this
       * method replace the previous index if there was one)
       * @return the new number of registered SCDC
@@ -166,14 +168,14 @@ public:
       */
     AtomDecoration *getDecoration(const QString & name, camitk::GeometricObject::Geometry t);
 
-  private:
+private:
 
     /// The atom the dc is representing
     Atom *myAtom;
 
     /// the concrete building of the geometry
     virtual void initRepresentation();
-    
+
     /** true if the atom has been already moved by another SC
      *  This is a way to solve the bug which occurs when 2 selected
      *  cells has this atom in common. The call of setRealTransformation()
@@ -213,7 +215,7 @@ public:
 };
 
 inline Atom * AtomDC::getAtom() {
-  return myAtom;
+    return myAtom;
 }
 
 #endif
