@@ -34,14 +34,14 @@ class PMManagerDC;
 #include "PMComponentAPI.h"
 /**
  * @ingroup group_cepmodeling_components_physicalmodel
- * 
+ *
  * @brief
  * The manager of the Component data.
- * 
- * 
+ *
+ *
  **/
 class PHYSICALMODEL_COMPONENT_API ComponentDC : public camitk::MeshComponent {
-  Q_OBJECT
+    Q_OBJECT
 public:
     /// constructors
     ComponentDC(camitk::Component *parent, PMManagerDC * pmManagerDC, ::Component * c=NULL);
@@ -63,15 +63,20 @@ public:
     virtual void setName(const QString &);
 
     /// remove a sub DC: overloaded method to avoir deletion of children that are used in more than one SCDC (that have more than one parent)
-    virtual void deleteChildren() {}     
+    virtual void deleteChildren() {}
+
+    /// return the first non-null subcomponent point set
+    virtual vtkSmartPointer< vtkPointSet > getPointSet();
     ///@}
 
     /// return the component that this dc is managing
     ::Component * getComponent();
 
-    /// get the PMManagerDC (given during instanciation), allows to get PML/Component maps
-    virtual PMManagerDC * getPMManagerDC() { return myPMManagerDC; }
-    
+    /// get the PMManagerDC (given during instanciation), allows one to get PML/Component maps
+    virtual PMManagerDC * getPMManagerDC() {
+        return myPMManagerDC;
+    }
+
     /** create all the point data to display specific information
      *  (only works for SCs that have a surface representation).
      *  This will automatically fills up the AtomDC point data pointers.
@@ -80,20 +85,20 @@ public:
 
     /// destroy all the point data
     virtual void destroyPointData();
-    
+
     /// show all properties
     virtual QObject* getPropertyObject() {
-      return this;      
+        return this;
     }
-      
+
     /// update a specific property
     virtual void updateProperty(QString name, QVariant value);
-    
+
 protected:
 
     /// the PMManagerDC
     PMManagerDC *myPMManagerDC;
-    
+
     /// the managed Component
     ::Component * myComponent;
 };
