@@ -44,31 +44,31 @@ Q_EXPORT_PLUGIN2(physicalmodel, PMComponentExtension);
 
 // --------------- getName -------------------
 QString PMComponentExtension::getName() const {
-  return "Physical Model Component";
+    return "Physical Model Component";
 }
 
 // --------------- getDescription -------------------
 QString PMComponentExtension::getDescription() const {
-  return "Manage Physical Model <em>.pml</em> files in <b>CamiTK</b>.<br/>CamiTK was initially mainly developed to support this format. Lots of things are possible with a physical model!";
+    return "Manage Physical Model <em>.pml</em> files in <b>CamiTK</b>.<br/>CamiTK was initially mainly developed to support this format. Lots of things are possible with a physical model!";
 }
 
 // --------------- getFileExtensions -------------------
 QStringList PMComponentExtension::getFileExtensions() const {
-  QStringList ext;
-  ext << "pml";
-  return ext;
+    QStringList ext;
+    ext << "pml";
+    return ext;
 }
 
 // --------------- open -------------------
 camitk::Component * PMComponentExtension::open(const QString & fileName) throw(AbortException) {
-  Application::showStatusBarMessage("Loading "+ fileName + "...");
+    Application::showStatusBarMessage("Loading "+ fileName + "...");
 
-  PMManagerDC *topLevel = new PMManagerDC(fileName);
+    PMManagerDC *topLevel = new PMManagerDC(fileName);
 
-  // reset the progress bar
-  Application::resetProgressBar();
+    // reset the progress bar
+    Application::resetProgressBar();
 
-  return topLevel;
+    return topLevel;
 }
 
 // --------------- save -------------------
@@ -83,8 +83,7 @@ bool PMComponentExtension::save(camitk::Component* component) const {
         outputFile.close();
         comp->setModified(false);
         return true;
-    }
-    else {
+    } else {
         // save from generic MeshComponent
         MeshComponent *meshComp = dynamic_cast<MeshComponent*>(component);
         if (meshComp && meshComp->getPointSet()->GetNumberOfPoints()>0) {
@@ -98,7 +97,7 @@ bool PMComponentExtension::save(camitk::Component* component) const {
             //-- create the structural components for the atoms
             StructuralComponent *theAtoms = new StructuralComponent(newPM,"The atoms");
             double pos[3];
-            
+
             // create the atom structures
             for (int i = 0; i < thePoints->GetNumberOfPoints(); i++) {
                 thePoints->GetPoint(i, pos);
@@ -111,49 +110,49 @@ bool PMComponentExtension::save(camitk::Component* component) const {
             //-- create the unique structural components containing all the vtkCell, this is an exclusive component
             unsigned int nrOfCells = meshComp->getPointSet()->GetNumberOfCells();
             StructuralComponent *sc = new StructuralComponent(newPM, "The cells (imported VTK)");
-            
+
             // fill in this new structural component with all vtk cells
             for (vtkIdType i = 0; i < (vtkIdType) nrOfCells; i++) {
                 // create a cell for each cell
-                vtkCell * theCell = meshComp->getPointSet()->GetCell(i);                
+                vtkCell * theCell = meshComp->getPointSet()->GetCell(i);
 
                 // translate cell type
                 StructureProperties::GeometricType cellType;
                 switch (theCell->GetCellType()) {
-                    case VTK_TETRA:
-                        cellType = StructureProperties::TETRAHEDRON;
-                        break;
-                    case VTK_HEXAHEDRON:
-                        cellType = StructureProperties::HEXAHEDRON;
-                        break;
-                    case VTK_WEDGE:
-                        cellType = StructureProperties::WEDGE;
-                        break;
-		    case VTK_PYRAMID:
-                        cellType = StructureProperties::PYRAMID;
-                        break;
-		    case VTK_LINE:
-                        cellType = StructureProperties::LINE;
-                        break;
-                    case VTK_POLY_LINE:
-                        cellType = StructureProperties::POLY_LINE;
-                        break;
-                    case VTK_POLY_VERTEX:
-                        cellType = StructureProperties::POLY_VERTEX;
-                        break;
-                    case VTK_TRIANGLE:
-                        cellType = StructureProperties::TRIANGLE;
-                        break;
-                    case VTK_QUAD:
-                        cellType = StructureProperties::QUAD;
-                        break;
-                    default:
-                        cellType = StructureProperties::INVALID;
-                        break;
+                case VTK_TETRA:
+                    cellType = StructureProperties::TETRAHEDRON;
+                    break;
+                case VTK_HEXAHEDRON:
+                    cellType = StructureProperties::HEXAHEDRON;
+                    break;
+                case VTK_WEDGE:
+                    cellType = StructureProperties::WEDGE;
+                    break;
+                case VTK_PYRAMID:
+                    cellType = StructureProperties::PYRAMID;
+                    break;
+                case VTK_LINE:
+                    cellType = StructureProperties::LINE;
+                    break;
+                case VTK_POLY_LINE:
+                    cellType = StructureProperties::POLY_LINE;
+                    break;
+                case VTK_POLY_VERTEX:
+                    cellType = StructureProperties::POLY_VERTEX;
+                    break;
+                case VTK_TRIANGLE:
+                    cellType = StructureProperties::TRIANGLE;
+                    break;
+                case VTK_QUAD:
+                    cellType = StructureProperties::QUAD;
+                    break;
+                default:
+                    cellType = StructureProperties::INVALID;
+                    break;
                 }
                 // create the corresponding PML cell
                 Cell *c = new Cell(newPM, cellType);
-                
+
                 // fill-in the cell structures (atoms)
                 for (int i = 0; i < theCell->GetNumberOfPoints(); i++) {
                     // get the corresponding atom
@@ -164,13 +163,13 @@ bool PMComponentExtension::save(camitk::Component* component) const {
                 // insert the cell in the structure
                 sc->addStructure(c, false);
             }
-            
+
             // create the exclusive multi-component
             MultiComponent * exclusiveComponents = new MultiComponent(newPM);
-            
+
             // insert all the cells (i.e. the sc component)
             exclusiveComponents->addSubComponent(sc);
-            
+
             // insert this exclusive component into the pm
             newPM->setExclusiveComponents(exclusiveComponents);
 
