@@ -92,8 +92,7 @@ PMManagerDC::PMManagerDC(const QString &fileName) throw(AbortException) : MeshCo
 
         //--reset modification flag
         setModified(false);
-    }
-    catch (PMLAbortException & e) {
+    } catch (PMLAbortException & e) {
         // has to do that, because the PMManagerDC constructor
         // inherits from Component constructor, which register the object
         // as a member of the DataManager, i.e. myDCs.size() is equal to 1
@@ -154,7 +153,7 @@ PMManagerDC::~PMManagerDC() {
     myLoadsManager = NULL;
 
     // remove all the adc myself
-    for (unsigned int i = 0;i < myPM->getAtoms()->getNumberOfStructures(); i++) {
+    for (unsigned int i = 0; i < myPM->getAtoms()->getNumberOfStructures(); i++) {
         AtomDC * adc = getDC(dynamic_cast<Atom*>(myPM->getAtoms()->getStructure(i)));
         delete adc;
     }
@@ -369,7 +368,7 @@ void PMManagerDC::getBounds(double bounds[6]) {
     StructuralComponent *theAtoms;
     theAtoms = myPM->getAtoms();
 
-    for (unsigned int i = 0;i < theAtoms->getNumberOfStructures();i++) {
+    for (unsigned int i = 0; i < theAtoms->getNumberOfStructures(); i++) {
         a = (Atom *) theAtoms->getStructure(i);
         a->getPosition(pos);
 
@@ -404,3 +403,21 @@ void PMManagerDC::computeBoundingRadius() {
     initialBoundingRadius = sqrt(xLength * xLength + yLength * yLength + zLength * zLength) / 2.0;
 }
 
+// --------------- getPointSet -------------------
+vtkSmartPointer< vtkPointSet > PMManagerDC::getPointSet() {
+    vtkSmartPointer< vtkPointSet > firstPointSet=NULL;
+    // check the exclusive components first
+    MultiComponentDC *componentsDC = getDC(myPM->getExclusiveComponents());
+    if (componentsDC)
+        firstPointSet = componentsDC->getPointSet();
+    // check the informative components then
+    if (firstPointSet == NULL) {
+        componentsDC = getDC(myPM->getInformativeComponents());
+        if (componentsDC)
+            firstPointSet = componentsDC->getPointSet();
+    }
+    return firstPointSet;
+
+
+}
+
