@@ -84,18 +84,18 @@ typedef std::map <Atom *, AtomDC *>::iterator AtomDCMapIterator;
 }
 /**
  * @ingroup group_cepmodeling_components_physicalmodel
- * 
+ *
  * @brief
  * The manager of the physical model data.
  *
  * @note
  * Each cell has one and only one CellDC (see StructuralComponentDC constructor code).
  * Each atom has one and only one AtomDC (see StructuralComponentDC constructor code).
- * 
- * 
+ *
+ *
  **/
 class PHYSICALMODEL_COMPONENT_API PMManagerDC : public camitk::MeshComponent {
-  Q_OBJECT
+    Q_OBJECT
 public:
     /// Default constructor: give it the name of the file containing the data (either a pml file or scn file)
     PMManagerDC(const QString &) throw(camitk::AbortException);
@@ -149,7 +149,7 @@ public:
 
     /// get the current bounds (calculated when loaded: it is called by getBoundingRadius()
     virtual void getBounds(double bounds[6]);
-    
+
     /// compute the bounding radius using the PhysicalModel atoms' position
     void computeBoundingRadius();
 
@@ -185,6 +185,9 @@ public:
 
     /// add the A/DC pair
     void addAtomDCPair(std::AtomDCPair);
+
+    /// get the first non null point set (PMManagerDC has not representation), first check the informative components, then the exclusive components
+    virtual vtkSmartPointer< vtkPointSet > getPointSet();
     ///@}
 
     ///@name Misc
@@ -209,7 +212,7 @@ private:
      *    represents a whole Physical Model).
      */
     virtual void initRepresentation();
-    
+
     /// Number of Step done yet
     unsigned int nrOfDoneSteps;
 
@@ -250,49 +253,49 @@ private:
 
 // -------------------- getPhysicalModel --------------------
 inline PhysicalModel *PMManagerDC::getPhysicalModel() {
-  return myPM;
+    return myPM;
 }
 
 // -------------------- getBoundingRadius --------------------
 inline double PMManagerDC::getBoundingRadius() {
-  return initialBoundingRadius;
+    return initialBoundingRadius;
 }
 
 // -------------------- getLoadsManager --------------------
 inline LoadsManager * PMManagerDC::getLoadsManager() {
-  return myLoadsManager;
+    return myLoadsManager;
 }
 
 // -------------------- C / DC Map --------------------
 inline ComponentDC * PMManagerDC::getDC(::Component *mc) {
-  if (mc->isInstanceOf("StructuralComponent"))
-    return (ComponentDC *) getDC(dynamic_cast<StructuralComponent *>(mc));
-  else if (mc->isInstanceOf("MultiComponent"))
-    return (ComponentDC *) getDC(dynamic_cast<MultiComponent *>(mc));
-  else
-    return NULL;
+    if (mc->isInstanceOf("StructuralComponent"))
+        return (ComponentDC *) getDC(dynamic_cast<StructuralComponent *>(mc));
+    else if (mc->isInstanceOf("MultiComponent"))
+        return (ComponentDC *) getDC(dynamic_cast<MultiComponent *>(mc));
+    else
+        return NULL;
 }
 
 // -------------------- MC / DC Map --------------------
 inline void PMManagerDC::addMultiComponentDCPair(std::ComponentDCPair p) {
-  myMCDCMap.insert(p);
+    myMCDCMap.insert(p);
 }
 
 // -------------------- SC / DC Map --------------------
 inline void PMManagerDC::addStructuralComponentDCPair(std::ComponentDCPair p) {
-  mySCDCMap.insert(p);
+    mySCDCMap.insert(p);
 }
 
 // -------------------- Atom / DC Map --------------------
 inline void PMManagerDC::addAtomDCPair(std::AtomDCPair p) {
-  myADCMap.insert(p);
+    myADCMap.insert(p);
 }
 
 inline AtomDC * PMManagerDC::getDC(Atom *a) {
-  if (!a)
-    return NULL;
-  std::AtomDCMapIterator result = myADCMap.find(a);
-  return (result == myADCMap.end()) ? NULL : (result->second);
+    if (!a)
+        return NULL;
+    std::AtomDCMapIterator result = myADCMap.find(a);
+    return (result == myADCMap.end()) ? NULL : (result->second);
 }
 
 
