@@ -177,8 +177,7 @@ void StructuralComponentDC::updateAtoms() {
 
         // update the nr of atoms
         nrOfAtoms = atomDCs.size();
-    }
-    else   // ComposedBy ATOMS
+    } else // ComposedBy ATOMS
         if (getSC()->composedBy() == StructuralComponent::ATOMS) {
             // For structural component NOT featuring CELLS, i.e. only ATOMS
             unsigned int atomIndex = 0;
@@ -193,13 +192,13 @@ void StructuralComponentDC::updateAtoms() {
                 // physical model (the method 'getOrderNumberInSCDC' called in 'this->UpdatePosition()'
                 // systematically returns -1 for SC only composed of ATOMS.
                 adc = dynamic_cast<AtomDC *> ( dc );
-          /*
-                // if the atom here is not already there, add <a,atomIndex> in the map and adc in the vector
-                std::vector<AtomDC *>::iterator it = std::find ( atomDCs.begin(), atomDCs.end(), adc );
+                /*
+                      // if the atom here is not already there, add <a,atomIndex> in the map and adc in the vector
+                      std::vector<AtomDC *>::iterator it = std::find ( atomDCs.begin(), atomDCs.end(), adc );
 
-                if ( it == atomDCs.end() ) {
-                    */
-                    adc->registerIndexInSCDC ( std::IndexInParentItemPair ( this, atomIndex++ ) );
+                      if ( it == atomDCs.end() ) {
+                          */
+                adc->registerIndexInSCDC ( std::IndexInParentItemPair ( this, atomIndex++ ) );
                 /*    atomDCs.push_back ( adc );
                 }
                 */
@@ -207,8 +206,7 @@ void StructuralComponentDC::updateAtoms() {
             }
 
             nrOfParts = nrOfAtoms = childrenComponent.size();
-        }
-        else // ComposedBy NOTHING
+        } else // ComposedBy NOTHING
             nrOfParts = nrOfAtoms = childrenComponent.size();
 
 }
@@ -222,14 +220,12 @@ void StructuralComponentDC::initRepresentation() {
         updateAtoms();
         // create the geometry from the atom list
         myGeometry = atomsToGeometry();
+    } else if ( getSC()->composedBy() == StructuralComponent::CELLS ) {
+        // create the vector and map
+        updateAtoms();
+        // create the geometry from the cells
+        myGeometry = cellsToGeometry();
     }
-    else
-        if ( getSC()->composedBy() == StructuralComponent::CELLS ) {
-            // create the vector and map
-            updateAtoms();
-            // create the geometry from the cells
-            myGeometry = cellsToGeometry();
-        }
 
 }
 
@@ -291,36 +287,36 @@ Geometry * StructuralComponentDC::cellsToGeometry() {
         // get the vtk type
 
         switch ( c->getType() ) {
-            case StructureProperties::TETRAHEDRON:
-                *t++ = VTK_TETRA;
-                break;
-            case StructureProperties::HEXAHEDRON:
-                *t++ = VTK_HEXAHEDRON;
-                break;
-            case StructureProperties::WEDGE:
-                *t++ = VTK_WEDGE;
-                break;
-            case StructureProperties::PYRAMID:
-                *t++ = VTK_PYRAMID;
-                break;
-            case StructureProperties::POLY_LINE:
-                *t++ = VTK_POLY_LINE;
-                break;
-            case StructureProperties::LINE:
-                *t++ = VTK_LINE;
-                break;
-            case StructureProperties::POLY_VERTEX:
-                *t++ = VTK_POLY_VERTEX;
-                break;
-            case StructureProperties::TRIANGLE:
-                *t++ = VTK_TRIANGLE;
-                break;
-            case StructureProperties::QUAD:
-                *t++ = VTK_QUAD;
-                break;
-            default:
-                *t++ = VTK_VERTEX;
-                break;
+        case StructureProperties::TETRAHEDRON:
+            *t++ = VTK_TETRA;
+            break;
+        case StructureProperties::HEXAHEDRON:
+            *t++ = VTK_HEXAHEDRON;
+            break;
+        case StructureProperties::WEDGE:
+            *t++ = VTK_WEDGE;
+            break;
+        case StructureProperties::PYRAMID:
+            *t++ = VTK_PYRAMID;
+            break;
+        case StructureProperties::POLY_LINE:
+            *t++ = VTK_POLY_LINE;
+            break;
+        case StructureProperties::LINE:
+            *t++ = VTK_LINE;
+            break;
+        case StructureProperties::POLY_VERTEX:
+            *t++ = VTK_POLY_VERTEX;
+            break;
+        case StructureProperties::TRIANGLE:
+            *t++ = VTK_TRIANGLE;
+            break;
+        case StructureProperties::QUAD:
+            *t++ = VTK_QUAD;
+            break;
+        default:
+            *t++ = VTK_VERTEX;
+            break;
         }
 
         madeOfPolyLines = madeOfPolyLines && ( ( c->getType() == StructureProperties::POLY_LINE ) || ( c->getType() == StructureProperties::LINE ) );
@@ -345,8 +341,7 @@ Geometry * StructuralComponentDC::cellsToGeometry() {
         uGrid->SetPoints ( thePoints );
         // create the new geometry
         o = new Geometry ( this->getName(), uGrid, myPMManagerDC->toDCRenderingMode ( getSC()->getMode() ) );
-    }
-    else {
+    } else {
         // there are only polyline
         polyD->SetLines ( array );
         polyD->SetPoints ( thePoints );
@@ -425,8 +420,7 @@ void StructuralComponentDC::updatePosition ( AtomDC *modifiedAtomDC, int atomOrd
             if ( getSC()->composedBy() == StructuralComponent::ATOMS ) {
                 // get the index of the modified  atom in the list
                 atomOrderNumber = modifiedAtomDC->getOrderNumberInSCDC ( this );
-            }
-            else
+            } else
 
                 // I'm a SC whose cell has an atom that has changed
                 if ( isInstanceOf ( "StructuralComponentDC" ) ) {
@@ -474,17 +468,15 @@ void StructuralComponentDC::setPointSet ( vtkSmartPointer<vtkPointSet> newPointS
             // set the new position for the atom (it will automatically update the DC, the atom, and all the cells, SC containing this atom)
             adc->setPosition ( pos[0], pos[1], pos[2] );
         }
-    }
-    else
-        if ( getSC()->composedBy() == StructuralComponent::CELLS ) {
-            // the atom's DC are in the vector
-            for ( unsigned int i = 0; i < atomDCs.size(); i++ ) {
-                // get the new position
-                vtkPts->GetPoint ( i, pos );
-                // set the new position for the atom (it will automatically update the DC, the atom, and all the cells, SC containing this atom)
-                atomDCs[i]->setPosition ( pos[0], pos[1], pos[2] );
-            }
+    } else if ( getSC()->composedBy() == StructuralComponent::CELLS ) {
+        // the atom's DC are in the vector
+        for ( unsigned int i = 0; i < atomDCs.size(); i++ ) {
+            // get the new position
+            vtkPts->GetPoint ( i, pos );
+            // set the new position for the atom (it will automatically update the DC, the atom, and all the cells, SC containing this atom)
+            atomDCs[i]->setPosition ( pos[0], pos[1], pos[2] );
         }
+    }
 
     // now call parent's method
     camitk::Component::setPointSet ( newPointSet );
@@ -498,15 +490,13 @@ void StructuralComponentDC::pointPicked ( vtkIdType pointId, bool pickingIsSelec
         // the atomsToGeometry was used to create the Geometry...
         // ... thus the atoms are in the same order as the structures in the SC
         childrenComponent[pointId]->setSelected ( pickingIsSelecting );
-    }
-    else {
+    } else {
         if ( getSC()->composedBy() == StructuralComponent::CELLS) {
             // the pointId can be different than
             //CAMITK_ERROR("StructuralComponentDC", "pointPicked", "Picking SC \"" << getName().toStdString() << "\": pointId #" << pointId << " vs atomDCs size=" << atomDCs.size());
             if (pointId >= (vtkIdType) atomDCs.size()) {
                 CAMITK_ERROR("StructuralComponentDC", "pointPicked", "Picking SC \"" << getName().toStdString() << "\": pointId #" << pointId << " is not a valid id (max=" << atomDCs.size() << ")");
-            }
-            else {
+            } else {
                 //CAMITK_ERROR("StructuralComponentDC", "pointPicked", "Picking SC \"" << getName().toStdString() << "\": pointId #" << pointId << " in children DC named " << atomDCs[pointId]->getName().toStdString());
                 // the cellsToGeometry method was used to create the Geometry...
                 // ... thus the atomDC where placed in the vector
@@ -533,8 +523,7 @@ void StructuralComponentDC::setSelected ( const bool s, const bool recursive ) {
     // do not select sub atoms if this is not selected
     if ( recursive && !s && getSC()->composedBy() == StructuralComponent::ATOMS ) {
         camitk::Component::setSelected ( s, true );
-    }
-    else
+    } else
         camitk::Component::setSelected ( s, false );
 }
 
@@ -587,9 +576,8 @@ void StructuralComponentDC::addChild ( InterfaceNode *childNode ) {
 
     if ( dynamic_cast<AtomDC *> ( childNode ) )
         s = dynamic_cast<AtomDC *> ( childNode )->getAtom();
-    else
-        if ( dynamic_cast<CellDC *> ( childNode ) )
-            s = dynamic_cast<CellDC *> ( childNode )->getCell();
+    else if ( dynamic_cast<CellDC *> ( childNode ) )
+        s = dynamic_cast<CellDC *> ( childNode )->getCell();
 
     // check compatibility
     if ( s && getSC()->isCompatible ( s ) ) {
@@ -607,16 +595,14 @@ void StructuralComponentDC::removeChild ( InterfaceNode *childNode ) {
 
     if ( dynamic_cast<AtomDC *> ( childNode ) )
         s = dynamic_cast<AtomDC *> ( childNode )->getAtom();
-    else
-        if ( dynamic_cast<CellDC *> ( childNode ) )
-            s = dynamic_cast<CellDC *> ( childNode )->getCell();
+    else if ( dynamic_cast<CellDC *> ( childNode ) )
+        s = dynamic_cast<CellDC *> ( childNode )->getCell();
 
     if ( s ) {
         // update
         if ( dynamic_cast<AtomDC *> ( childNode ) ) {
             dynamic_cast<AtomDC *> ( childNode )->unregisterIndexInSCDC ( this );
-        }
-        else {
+        } else {
             int id = childrenComponent.indexOf ( dynamic_cast<camitk::Component *> ( childNode ) );
 
             if ( id != -1 )
@@ -684,36 +670,36 @@ vtkSmartPointer<vtkUnstructuredGrid> StructuralComponentDC::structuralComponentT
         // 2. register the type for the i-th cell
         // get the vtk type
         switch ( c->getType() ) {
-            case StructureProperties::TETRAHEDRON:
-                *t++ = VTK_TETRA;
-                break;
-            case StructureProperties::HEXAHEDRON:
-                *t++ = VTK_HEXAHEDRON;
-                break;
-            case StructureProperties::WEDGE:
-                *t++ = VTK_WEDGE;
-                break;
-            case StructureProperties::PYRAMID:
-                *t++ = VTK_PYRAMID;
-                break;
-            case StructureProperties::LINE:
-                *t++ = VTK_LINE;
-                break;
-            case StructureProperties::POLY_LINE:
-                *t++ = VTK_POLY_LINE;
-                break;
-            case StructureProperties::POLY_VERTEX:
-                *t++ = VTK_POLY_VERTEX;
-                break;
-            case StructureProperties::TRIANGLE:
-                *t++ = VTK_TRIANGLE;
-                break;
-            case StructureProperties::QUAD:
-                *t++ = VTK_QUAD;
-                break;
-            default:
-                *t++ = VTK_VERTEX;
-                break;
+        case StructureProperties::TETRAHEDRON:
+            *t++ = VTK_TETRA;
+            break;
+        case StructureProperties::HEXAHEDRON:
+            *t++ = VTK_HEXAHEDRON;
+            break;
+        case StructureProperties::WEDGE:
+            *t++ = VTK_WEDGE;
+            break;
+        case StructureProperties::PYRAMID:
+            *t++ = VTK_PYRAMID;
+            break;
+        case StructureProperties::LINE:
+            *t++ = VTK_LINE;
+            break;
+        case StructureProperties::POLY_LINE:
+            *t++ = VTK_POLY_LINE;
+            break;
+        case StructureProperties::POLY_VERTEX:
+            *t++ = VTK_POLY_VERTEX;
+            break;
+        case StructureProperties::TRIANGLE:
+            *t++ = VTK_TRIANGLE;
+            break;
+        case StructureProperties::QUAD:
+            *t++ = VTK_QUAD;
+            break;
+        default:
+            *t++ = VTK_VERTEX;
+            break;
         }
     }
 
