@@ -63,13 +63,13 @@ void AtomDecoration::update() {
 
 void AtomDecoration::update(const double x, const double y, const double z) {
     switch (myObject->getType()) {
-        case GeometricObject::ARROW:
-            setDirection(x,y,z);
-            update();
-            break;
-        case GeometricObject::SPHERE:
-            setPosition(x,y,z);
-            break;
+    case GeometricObject::ARROW:
+        setDirection(x,y,z);
+        update();
+        break;
+    case GeometricObject::SPHERE:
+        setPosition(x,y,z);
+        break;
     }
 
 }
@@ -81,12 +81,11 @@ void AtomDecoration::update(const double v[3]) {
 // ------------- show --------------
 void AtomDecoration::show(const bool d) {
     if (d) {
-      dc->addProp("AtomDecoration", myObject->getActor());
-      dc->getProp("AtomDecoration")->VisibilityOn();
-    }
-    else {
-      if (dc->getProp("AtomDecoration"))
-        dc->getProp("AtomDecoration")->VisibilityOff();
+        dc->addProp("AtomDecoration", myObject->getActor());
+        dc->getProp("AtomDecoration")->VisibilityOn();
+    } else {
+        if (dc->getProp("AtomDecoration"))
+            dc->getProp("AtomDecoration")->VisibilityOff();
     }
 }
 
