@@ -28,16 +28,15 @@
 
 //--------------- Constructor ---------------------------------
 LoadsAppliedTo::LoadsAppliedTo(TargetList targetList, QWidget* parent) : QDialog(parent) {
-  ui.setupUi(this);
+    ui.setupUi(this);
 
-  for (unsigned int i=0; i< targetList.getNumberOfTargets(); i++)
-    ui.atomList->addItem(QString::number(targetList.getIndexedTarget(i)));
+    for (unsigned int i=0; i< targetList.getNumberOfTargets(); i++)
+        ui.atomList->addItem(QString::number(targetList.getIndexedTarget(i)));
 
 }
 
 //--------------- Destructor ---------------------------------
-LoadsAppliedTo::~LoadsAppliedTo()
-{
+LoadsAppliedTo::~LoadsAppliedTo() {
     // no need to delete child widgets, Qt does it all for us
 }
 
