@@ -28,7 +28,14 @@
 
 #include <QDialog>
 
-#include "ui_AnimationMotorDialog.h"
+#include "PMComponentAPI.h"
+
+class QLineEdit;
+
+// forward declaration for the UI
+namespace Ui {
+class AnimationMotorDialog;
+}
 
 //class used in this file
 class LoadsSimulation;
@@ -37,13 +44,13 @@ class LoadsSimulationDriver;
 class AnimationMotorAddon;
 class QToolBar;
 
-/** This dialog allows to run a simulation using a simulation motor.
+/** This dialog allows one to run a simulation using a simulation motor.
  *	It plays the impload, allowing the user to see the evolution of translations along time.
  *
- *	
+ *
 
  */
-class LoadsSimulation : public QDialog {
+class PHYSICALMODEL_COMPONENT_API LoadsSimulation : public QDialog {
     Q_OBJECT
 
 public:
@@ -65,10 +72,13 @@ public:
     void addTab(QWidget *);
 
     /** update the display (the boolean indicates if the scene3d has to be refresh or not)
-      * @param force if true force display update independantly from refresh dt (default is false)
+      * @param force if true force display update independently from refresh dt (default is false)
      */
     void updateDisplay(bool force);
 
+    /// only update atom data
+    void updateAtomData();
+
 public slots :
 
     /** do one step of simulation
@@ -114,7 +124,7 @@ private :
 
     /// load a animation motor add-on using a filename (shared lib location)
     void loadAddon(QString);
-	QString addonFilename;
+    QString addonFilename;
 
     /// the load manager
     LoadsManager * myLM;
@@ -162,7 +172,7 @@ private :
     double iterationCount;
 
     /// the ui dialog designed in qtdesigner
-    Ui::AnimationMotorDialog ui;
+    Ui::AnimationMotorDialog *ui;
 };
 
 
