@@ -85,12 +85,12 @@ void LoadsSimulationDriver::init() {
     AtomDC * adc;
     Atom *a;
 
-    
+
     /*
     if (you want to show the absolute displacement of only the
       implied atom, just use this code) {
-// => the best in this case is to constrained the scale yourself (user-constrained)
- // which are the implied atoms
+    // => the best in this case is to constrained the scale yourself (user-constrained)
+    // which are the implied atoms
         // get the initial position
         for (unsigned int i = 0; i < currentLoads->numberOfLoads();i++) {
               Load *l = currentLoads->getLoad(i);
@@ -116,7 +116,7 @@ void LoadsSimulationDriver::init() {
     */
     StructuralComponent * theAtoms = pm->getAtoms();
 
-    for ( unsigned int i = 0; i < theAtoms->getNumberOfStructures();i++ ) {
+    for ( unsigned int i = 0; i < theAtoms->getNumberOfStructures(); i++ ) {
         // get the target index
         a = ( Atom * ) theAtoms->getStructure ( i );
         // activate the target's 3D representation
@@ -217,12 +217,12 @@ void LoadsSimulationDriver::updateAtomData() {
 
         //-- initialize the referencePositionMap
         if ( ( myLM->getAtomDataDisplay() == LoadsManager::DISTANCES ||
-               myLM->getAtomDataDisplay() == LoadsManager::RELATIVE_ENERGY_NORM_ERROR ) &&
-             ( referencePositionMap.size() == 0 ) ) {
+                myLM->getAtomDataDisplay() == LoadsManager::RELATIVE_ENERGY_NORM_ERROR ) &&
+                ( referencePositionMap.size() == 0 ) ) {
 
             StructuralComponent * theAtoms = myLM->getReferencePM()->getAtoms();
 
-            for ( unsigned int i = 0; i < theAtoms->getNumberOfStructures();i++ ) {
+            for ( unsigned int i = 0; i < theAtoms->getNumberOfStructures(); i++ ) {
                 // get the target index
                 Atom *a = ( Atom * ) theAtoms->getStructure ( i );
                 double pos[3];
@@ -341,10 +341,10 @@ void LoadsSimulationDriver::updateAtomData() {
 
         if ( !myLM->getUserConstrainedAtomDataScale() ) {
             min = std::numeric_limits<double>::max();
-            max = -1.0;
+            max = -std::numeric_limits<double>::max();
 
             if ( atomDataValues.size() == 0 ) {
-                min = -1.0;
+                min = 0.0;
                 max = 1.0;
             }
 
@@ -382,22 +382,21 @@ void LoadsSimulationDriver::updateAtomData() {
         double val;
         double range = max - min;
 
-        for ( unsigned int i = 0; i < atomDCs.size();i++ ) {
+        for ( unsigned int i = 0; i < atomDCs.size(); i++ ) {
             val = atomDataValues[i].second;
 
             if ( atomDataValues.size() == 0 )
                 val = 0.0;
-            else
-                if ( fabs ( range ) < 1e-10 || val <= min ) {
-                    val = 0.0;
+            else if ( fabs ( range ) < 1e-10 || val <= min ) {
+                val = 0.0;
+            } else {
+                if ( val >= max ) {
+                    val = 1.0;
                 } else {
-                    if ( val >= max ) {
-                        val = 1.0;
-                    } else {
-                        // renormalized the size between min and max
-                        val = ( ( val - min ) / range );
-                    }
+                    // renormalized the size between min and max
+                    val = ( ( val - min ) / range );
                 }
+            }
 
             atomDCs[i]->updatePointData ( 1.0 - val );
         }
@@ -432,7 +431,7 @@ void LoadsSimulationDriver::updatePositions ( bool force ) {
         if ( !currentLoads ) {
             StructuralComponent * theAtoms = pm->getAtoms();
 
-            for ( unsigned int i = 0; i < theAtoms->getNumberOfStructures();i++ ) {
+            for ( unsigned int i = 0; i < theAtoms->getNumberOfStructures(); i++ ) {
                 // get the target index
                 a = ( Atom * ) theAtoms->getStructure ( i );
                 // activate the target's 3D representation
@@ -446,7 +445,7 @@ void LoadsSimulationDriver::updatePositions ( bool force ) {
             }
         } else {
             // get the informations from the current Loads
-            for ( unsigned int i = 0; i < currentLoads->numberOfLoads();i++ ) {
+            for ( unsigned int i = 0; i < currentLoads->numberOfLoads(); i++ ) {
                 l = currentLoads->getLoad ( i );
                 // get the informations
                 value = l->getValue ( t );  // now
@@ -467,7 +466,7 @@ void LoadsSimulationDriver::updatePositions ( bool force ) {
                         // of displacement will sum up to value. (linear interpolation)
                         double n = sqrt ( dir[0] * dir[0] + dir[1] * dir[1] + dir[2] * dir[2] );
 
-                        for ( unsigned int j = 0;j < 3;j++ )
+                        for ( unsigned int j = 0; j < 3; j++ )
                             dir[j] *= ( value - lastValue ) / n;
 
                         // apply the translation to the targets (atoms)
@@ -477,13 +476,13 @@ void LoadsSimulationDriver::updatePositions ( bool force ) {
 
                             if ( a ) {
                                 // compute new displacement
-                                for ( unsigned int j = 0;j < 3;j++ )
+                                for ( unsigned int j = 0; j < 3; j++ )
                                     displ[j] = dir[j];
 
                                 // displ is the displacement vector to transform to a ImpTransform
                                 a->getPosition ( pos );
 
-                                for ( unsigned int j = 0;j < 3;j++ )
+                                for ( unsigned int j = 0; j < 3; j++ )
                                     displ[j] += pos[j];
 
                                 a->setPosition ( displ[0], displ[1], displ[2] );
@@ -635,7 +634,7 @@ void LoadsSimulationDriver::setTime ( double newTime ) {
 
         // see the time passing by up to newTime-dt
 
-        for ( t = tMin - dt; ( t < ( newTime - dt ) ) && fabs ( t - ( newTime - dt ) ) > 1e-15;t += dt )
+        for ( t = tMin - dt; ( t < ( newTime - dt ) ) && fabs ( t - ( newTime - dt ) ) > 1e-15; t += dt )
             updatePositions ( false );
 
     }
