@@ -22,7 +22,7 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
- 
+
 
 #ifndef ACCELERATION_H
 #define ACCELERATION_H
@@ -30,15 +30,18 @@
 #include "Load.h"
 /**
  * @ingroup group_cepmodeling_libraries_lml
- * 
+ *
  * @brief
  * Class that defines the type of Load 'Acceleration', for example to set the gravity.
- * 
+ *
  **/
 class Acceleration : public Load {
 
 public:
-    Acceleration() { typeString="Acceleration";unit=AccelerationUnit::MSm2();}
+    Acceleration() {
+        typeString="Acceleration";
+        unit=AccelerationUnit::MSm2();
+    }
 };
 
 #endif //ACCELERATION_H
