@@ -31,65 +31,78 @@
 #include "libxml/xmlIO.h"
 /**
  * @ingroup group_cepmodeling_libraries_lml
- * 
+ *
  * @brief
  * Class that defines the direction of the Load with x, y and z.
- *  
+ *
  **/
 class Direction {
-  
-public:  
+
+public:
     /// default constructor: nothing is specified
     Direction() : x(0.0), y(0.0), z(0.0), xState(NOT_SPECIFIED), yState(NOT_SPECIFIED), zState(NOT_SPECIFIED), towardIndex(-1) {};
     /// constructor with initialization of the toward
-    Direction(const unsigned int toward) { setToward(toward); };
+    Direction(const unsigned int toward) {
+        setToward(toward);
+    };
     /// constructor with initialization of the 3 directions
-    Direction(double x0, double y0, double z0) { setX(x0); setY(y0); setZ(z0); };
-    /// copy constructor 
-    Direction(const Direction & d) { x=d.x; xState=d.xState; y=d.y; yState=d.yState; z=d.z; zState=d.zState; towardIndex=d.towardIndex;};
-    
+    Direction(double x0, double y0, double z0) {
+        setX(x0);
+        setY(y0);
+        setZ(z0);
+    };
+    /// copy constructor
+    Direction(const Direction & d) {
+        x=d.x;
+        xState=d.xState;
+        y=d.y;
+        yState=d.yState;
+        z=d.z;
+        zState=d.zState;
+        towardIndex=d.towardIndex;
+    };
+
     /// print to an ostream
-    void xmlPrint(std::ostream & o) const {        
+    void xmlPrint(std::ostream & o) const {
         o << "\t<direction ";
         if (isToward()) {
             o << "toward=\"" << towardIndex << "\"";
-        }
-        else {
+        } else {
             switch (xState) {
-                case NOT_SPECIFIED:
-                    break;
-                case NULL_DIR:
-                    o << "x=\"NULL\" ";
-                    break;
-                case SPECIFIED:
-                    o << "x=\"" << x << "\" ";
-                    break;
-                default:
-                    break;
+            case NOT_SPECIFIED:
+                break;
+            case NULL_DIR:
+                o << "x=\"NULL\" ";
+                break;
+            case SPECIFIED:
+                o << "x=\"" << x << "\" ";
+                break;
+            default:
+                break;
             }
             switch (yState) {
-                case NOT_SPECIFIED:
-                    break;
-                case NULL_DIR:
-                    o << "y=\"NULL\" ";
-                    break;
-                case SPECIFIED:
-                    o << "y=\"" << y << "\" ";
-                    break;
-                default:
-                    break;
+            case NOT_SPECIFIED:
+                break;
+            case NULL_DIR:
+                o << "y=\"NULL\" ";
+                break;
+            case SPECIFIED:
+                o << "y=\"" << y << "\" ";
+                break;
+            default:
+                break;
             }
             switch (zState) {
-                case NOT_SPECIFIED:
-                    break;
-                case NULL_DIR:
-                    o << "z=\"NULL\"";
-                    break;
-                case SPECIFIED:
-                    o << "z=\"" << z << "\"";
-                    break;
-                default:
-                    break;
+            case NOT_SPECIFIED:
+                break;
+            case NULL_DIR:
+                o << "z=\"NULL\"";
+                break;
+            case SPECIFIED:
+                o << "z=\"" << z << "\"";
+                break;
+            default:
+                break;
             }
         }
         o << "/>" << std::endl;
@@ -97,7 +110,9 @@ public:
 
     /// set the direction
     void set(const double x, const double y, const double z) {
-        setX(x);setY(y);setZ(z);
+        setX(x);
+        setY(y);
+        setZ(z);
     };
 
     /// get the toward index
@@ -118,61 +133,97 @@ public:
 
     ///@name X direction
     //@{
-    
+
     /// get the x coordinate
-    double getX() const { return x; };
-    
+    double getX() const {
+        return x;
+    };
+
     /// is the x coordinate NULL ?
-    bool isXNull() const { return (xState==NULL_DIR); };
-    
+    bool isXNull() const {
+        return (xState==NULL_DIR);
+    };
+
     /// is the x coordinate specified
-    bool isXSpecified() const { return (xState==SPECIFIED); };
-    
+    bool isXSpecified() const {
+        return (xState==SPECIFIED);
+    };
+
     /// set the x coordinate as NULL
-    void setNullX() { x=0.0; xState = NULL_DIR; };
-    
+    void setNullX() {
+        x=0.0;
+        xState = NULL_DIR;
+    };
+
     /// set the x coordinate
-    void setX(const double x) { this->x = x; xState = SPECIFIED; };
+    void setX(const double x) {
+        this->x = x;
+        xState = SPECIFIED;
+    };
     //@}
-        
+
     ///@name Y direction
     //@{
     /// get the y coordinate
-    double getY() const { return y; };
-    
+    double getY() const {
+        return y;
+    };
+
     /// is the y coordinate NULL ?
-    bool isYNull() const { return (yState==NULL_DIR); };
-    
+    bool isYNull() const {
+        return (yState==NULL_DIR);
+    };
+
     /// is the y coordinate specified
-    bool isYSpecified() const { return (yState==SPECIFIED); };
-    
+    bool isYSpecified() const {
+        return (yState==SPECIFIED);
+    };
+
     /// set the y coordinate as NULL
-    void setNullY() { y=0.0; yState = NULL_DIR; };
-    
+    void setNullY() {
+        y=0.0;
+        yState = NULL_DIR;
+    };
+
     /// set the y coordinate
-    void setY(const double y) { this->y = y; yState = SPECIFIED; };
-    
+    void setY(const double y) {
+        this->y = y;
+        yState = SPECIFIED;
+    };
+
     //@}
-        
+
     ///@name Z direction
     //@{
     /// get the z coordinate
-    double getZ() const { return z; };
-    
+    double getZ() const {
+        return z;
+    };
+
     /// is the z coordinate NULL ?
-    bool isZNull() const { return (zState==NULL_DIR); };
-    
+    bool isZNull() const {
+        return (zState==NULL_DIR);
+    };
+
     /// is the z coordinate specified
-    bool isZSpecified() const { return (zState==SPECIFIED); };
-    
+    bool isZSpecified() const {
+        return (zState==SPECIFIED);
+    };
+
     /// set the z coordinate as NULL
-    void setNullZ() { z=0.0; zState = NULL_DIR; };
-    
+    void setNullZ() {
+        z=0.0;
+        zState = NULL_DIR;
+    };
+
     /// set the z coordinate
-    void setZ(const double z) { this->z = z; zState = SPECIFIED; };
-    
+    void setZ(const double z) {
+        this->z = z;
+        zState = SPECIFIED;
+    };
+
     //@}
-        
+
 private:
     /// state of the x,y and z
     enum DirState {
