@@ -29,27 +29,29 @@
 #include "Unit.h"
 /**
  * @ingroup group_cepmodeling_libraries_lml
- * 
+ *
  * @brief
  * Class that defines the different units of a Load 'Force'.
- * 
+ *
  * @note
  * This class implements the type-safe design pattern.
- *  
+ *
  **/
 class ForceUnit : public Unit {
 
 public:
-  /// picoNewtons
-  static ForceUnit& PN(); 
-  /// Newtons
-  static ForceUnit& N();
-  /// KiloNewtons
-  static ForceUnit& KN(); 
+    /// picoNewtons
+    static ForceUnit& PN();
+    /// Newtons
+    static ForceUnit& N();
+    /// KiloNewtons
+    static ForceUnit& KN();
 
 private:
-  /// private constructor
-  ForceUnit(std::string n) {unitString = n;}
+    /// private constructor
+    ForceUnit(std::string n) {
+        unitString = n;
+    }
 };
 
 
