@@ -155,9 +155,9 @@ double Load::getValue(const double t) {
 
 #if defined(_WIN32) && !defined(__MINGW32__) // MSVC only
 namespace std {
-	bool greater(const ValueEvent* lhs, const ValueEvent* rhs) {
-			return lhs->getDate() < rhs->getDate();
-	}
+bool greater(const ValueEvent* lhs, const ValueEvent* rhs) {
+    return lhs->getDate() < rhs->getDate();
+}
 }
 #else
 // ------------- sorting overloaded function ---------
@@ -165,12 +165,12 @@ namespace std {
 // this kind of overloads where you need them - compiler efficiency?
 // so it is here cause needed in the addEvent method for the sort)
 namespace std {
-    template <>
-    struct greater<ValueEvent*> {
-        bool operator()(const ValueEvent* lhs, const ValueEvent* rhs) const {
-            return lhs->getDate() < rhs->getDate();
-        }
-    };
+template <>
+struct greater<ValueEvent*> {
+    bool operator()(const ValueEvent* lhs, const ValueEvent* rhs) const {
+        return lhs->getDate() < rhs->getDate();
+    }
+};
 }
 #endif
 
@@ -181,9 +181,9 @@ void Load::addEvent(ValueEvent * ve) {
 
     //-- sort the list by date
 #if defined(_WIN32) && !defined(__MINGW32__) && ((_MSC_VER > 1700) || (_MSC_VER < 1600)) // MSVC<10 and MSVC11+ (VS 2012+) only, see http://msdn.microsoft.com/en-us/library/b0084kay%28v=vs.100%29.aspx
-	std::sort(eventList.begin(), eventList.end(), std::greater); // use the greater() method (see above)
+    std::sort(eventList.begin(), eventList.end(), std::greater); // use the greater() method (see above)
 #else
-	std::sort(eventList.begin(), eventList.end(), std::greater<ValueEvent *>()); // use the greater() method (see above)
+    std::sort(eventList.begin(), eventList.end(), std::greater<ValueEvent *>()); // use the greater() method (see above)
 #endif
 
 }
@@ -249,26 +249,26 @@ void Load::setDirection(const Direction &d) {
 // --------------- getValueEvent ---------------
 ValueEvent * Load::getValueEvent(const unsigned int i) const {
     if (i<eventList.size())
-    return eventList[i];
+        return eventList[i];
     else
         return NULL;
-    }
+}
 
-    // --------------- numberOfValueEvents ---------------
-    unsigned int Load::numberOfValueEvents() const {
-            return eventList.size();
-        }
+// --------------- numberOfValueEvents ---------------
+unsigned int Load::numberOfValueEvents() const {
+    return (unsigned int) eventList.size(); // if there are more than MAX_INT events, too bad (that's over 2,147,483,647 anyway...)
+}
 
 
-        // --------------- getUnit ---------------
-        Unit Load::getUnit() const {
-            return unit;
-        }
+// --------------- getUnit ---------------
+Unit Load::getUnit() const {
+    return unit;
+}
 
-        // --------------- setUnit ---------------
-        void Load::setUnit(const Unit u) {
-        unit = u;
-    }
+// --------------- setUnit ---------------
+void Load::setUnit(const Unit u) {
+    unit = u;
+}
 
 
 // --------------- getType --------------
@@ -302,7 +302,7 @@ void  Load::xmlPrint(std::ostream & o) const {
     }
 
     dir.xmlPrint(o);
-   
+
     o << "\t<unit>" << getUnit().getUnitName() << "</unit>" << std::endl;
 
     o << "</load>" << std::endl;
