@@ -22,7 +22,7 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
- 
+
 
 #ifndef PRESSURE_H
 #define PRESSURE_H
@@ -30,15 +30,18 @@
 #include "Load.h"
 /**
  * @ingroup group_cepmodeling_libraries_lml
- * 
+ *
  * @brief
  * Class that defines the type of Load 'Pressure'.
- * 
+ *
  **/
 class Pressure : public Load {
 
 public:
-    Pressure() { typeString="Pressure";unit=PressureUnit::PA();}
+    Pressure() {
+        typeString="Pressure";
+        unit=PressureUnit::PA();
+    }
 };
 
 #endif //PRESSURE_H
