@@ -29,26 +29,28 @@
 #include "Unit.h"
 /**
  * @ingroup group_cepmodeling_libraries_lml
- * 
+ *
  * @brief
  * Class that defines the different units of a Load 'Pressure'.
  *
  * @note
  * This class implements the type-safe design pattern.
- * 
+ *
  **/
 class PressureUnit : public Unit {
 
 public:
-  /// Pascal
-  static PressureUnit& PA();
-  /// kiloPascal
-  static PressureUnit& KPA();
-  /// Millimeters of mercure
-  static PressureUnit& MMHG();
- 
+    /// Pascal
+    static PressureUnit& PA();
+    /// kiloPascal
+    static PressureUnit& KPA();
+    /// Millimeters of mercure
+    static PressureUnit& MMHG();
+
 private:
-  PressureUnit(std::string n) {unitString = n;}
+    PressureUnit(std::string n) {
+        unitString = n;
+    }
 };
 
 
