@@ -29,16 +29,19 @@
 #include "Load.h"
 /**
  * @ingroup group_cepmodeling_libraries_lml
- * 
+ *
  * @brief
  * Class that defines the type of Load 'Rotation'.
- * 
+ *
  **/
 class Rotation : public Load {
 
 public:
-  Rotation() {typeString="Rotation"; unit=RotationUnit::DEG();}
-        
+    Rotation() {
+        typeString="Rotation";
+        unit=RotationUnit::DEG();
+    }
+
 };
 
 #endif //ROTATION_H
