@@ -30,27 +30,29 @@
 #include "Unit.h"
 /**
  * @ingroup group_cepmodeling_libraries_lml
- * 
+ *
  * @brief
  * RotationUnit model the different values that can be taken by the unit
  * field of a rotation.
  *
  * @note
  * This class implements the type-safe design pattern.
- * 
+ *
  **/
 class RotationUnit : public Unit {
 
 public:
-  /// radians
-  static RotationUnit& RAD(); 
-  /// degrees
-  static RotationUnit& DEG(); 
-  
+    /// radians
+    static RotationUnit& RAD();
+    /// degrees
+    static RotationUnit& DEG();
+
 private:
-  RotationUnit(std::string n) {unitString = n;}
+    RotationUnit(std::string n) {
+        unitString = n;
+    }
 };
-      
+
 #endif //ROTATIONUNIT_H
 
 
