@@ -48,8 +48,8 @@ void TargetList::add(const unsigned int index) {
 #define isDigit(c)  ((c)>='0' && (c)<='9')
 
 void TargetList::add(const std::string s) {
-    int begin, end, len, i,j;
-    
+    size_t begin, end, len, i, j;
+
     // inits
     len = s.size();
     begin = end = -1;
@@ -83,13 +83,12 @@ void TargetList::add(const std::string s) {
                     add(begin);
                 else {
                     // target index from begin..save are to be inserted
-                    for (j=begin;j<=end;j++)
+                    for (j=begin; j<=end; j++)
                         add(j);
                 }
                 // init to start again
                 begin=end=-1;
-            }
-            else {
+            } else {
                 if (s[i]!='-') {
                     // this is not a comma, read till the end or the next comma
                     // because this is a new component name
@@ -116,7 +115,7 @@ void TargetList::add(const std::string s) {
             add(begin);
         else {
             // regions from begin..save are to be saved
-            for (j=begin;j<=end;j++)
+            for (j=begin; j<=end; j++)
                 add(j);
         }
     }
@@ -126,9 +125,9 @@ void TargetList::add(const std::string s) {
 // --------------- getNumberOfTargets ---------------
 unsigned int TargetList::getNumberOfTargets() const {
     if (indexedTargets()) {
-        return indexedTargetList.size();
+        return (unsigned int) indexedTargetList.size(); // if there are more than MAX_INT indexed targets, too bad (that's over 2,147,483,647 anyway...)
     } else {
-        return namedTargetList.size();
+        return (unsigned int) namedTargetList.size(); // if there are more than MAX_INT named targets, too bad (that's over 2,147,483,647 anyway...)
     }
 }
 
@@ -187,7 +186,7 @@ std::string TargetList::toString() const {
         }
     } else {
         // targets are named
-        for (unsigned int i=0;i<namedTargetList.size();i++) {
+        for (unsigned int i=0; i<namedTargetList.size(); i++) {
             s << namedTargetList[i];
             if (i!=namedTargetList.size()-1)
                 s << ",";
@@ -247,15 +246,15 @@ bool TargetList::indexedTargets() const {
 
 // --------------- isIn ---------------
 bool TargetList::isIn(unsigned int id) const {
-  if (indexedTargetList.size()==0 && namedTargetList.size()==1 && namedTargetList[0]=="*")
-    return true;
+    if (indexedTargetList.size()==0 && namedTargetList.size()==1 && namedTargetList[0]=="*")
+        return true;
 
-  bool found=false;
-  unsigned int i=0;
-  while(i<indexedTargetList.size() && !found) {
-    found = (indexedTargetList[i]==id);
-    i++;
-  }
-  return found;
+    bool found=false;
+    unsigned int i=0;
+    while(i<indexedTargetList.size() && !found) {
+        found = (indexedTargetList[i]==id);
+        i++;
+    }
+    return found;
 }
 
