@@ -29,31 +29,33 @@
 #include "Unit.h"
 /**
  * @ingroup group_cepmodeling_libraries_lml
- * 
- * 
+ *
+ *
  * @brief
  * TranslationUnit model the different values that can be taken by the unit
  * field of a translation.
  *
  * @note
  * This class implements the type-safe design pattern.
- * 
- * 
+ *
+ *
  **/
 class TranslationUnit : public Unit {
 
 public:
-  /// meters
-  static TranslationUnit& M();
-  /// millimeters
-  static TranslationUnit& MM(); 
-  /// micro meters
-  static TranslationUnit& MICRO_M();
-  /// nano meters
-  static TranslationUnit& NM();
-  
+    /// meters
+    static TranslationUnit& M();
+    /// millimeters
+    static TranslationUnit& MM();
+    /// micro meters
+    static TranslationUnit& MICRO_M();
+    /// nano meters
+    static TranslationUnit& NM();
+
 private:
-  TranslationUnit(std::string n) {unitString = n;}
+    TranslationUnit(std::string n) {
+        unitString = n;
+    }
 };
 
 
