@@ -32,23 +32,25 @@
 class Unit;
 /**
  * @ingroup group_cepmodeling_libraries_lml
- * 
- * 
+ *
+ *
  * @brief
  * Class that defines the unit of the Load.
- * 
- * @note 
+ *
+ * @note
  * All sub classes implement the (nice) type-safe design pattern.
- * 
- * 
- * 
+ *
+ *
+ *
  **/
 class Unit {
 public:
-  virtual ~Unit() {};
-  std::string getUnitName() { return unitString; };
+    virtual ~Unit() {};
+    std::string getUnitName() {
+        return unitString;
+    };
 protected:
-  std::string unitString;
+    std::string unitString;
 };
 
 #endif //UNIT_H
