@@ -179,8 +179,7 @@ bool XMLLoads::parseElement(xmlNodePtr elem) {
 
         xmlFree(ptype);
         return true;
-    }
-    else
+    } else
         return false;
 }
 
@@ -266,22 +265,17 @@ void XMLLoads::readLoadUnit(xmlNodePtr elem, Load *currentLoad) {
         }
         if (!xmlStrcmp(pData, (const xmlChar*)"mm")) {
             currentLoad->setUnit(TranslationUnit::MM());
-        }
-        else if (!xmlStrcmp(pData, (const xmlChar*)"microm")) {
+        } else if (!xmlStrcmp(pData, (const xmlChar*)"microm")) {
             currentLoad->setUnit(TranslationUnit::MICRO_M());
-        }
-        else if (!xmlStrcmp(pData, (const xmlChar*)"nm")) {
+        } else if (!xmlStrcmp(pData, (const xmlChar*)"nm")) {
             currentLoad->setUnit(TranslationUnit::NM());
         }
-    }
-    else if (currentLoad->getType() == "Force") {
+    } else if (currentLoad->getType() == "Force") {
         if (!xmlStrcmp(pData, (const xmlChar*)"N")) {
             currentLoad->setUnit(ForceUnit::N());
-        }
-        else if (!xmlStrcmp(pData, (const xmlChar*)"kN")) {
+        } else if (!xmlStrcmp(pData, (const xmlChar*)"kN")) {
             currentLoad->setUnit(ForceUnit::KN());
-        }
-        else if (!xmlStrcmp(pData, (const xmlChar*)"pN")) {
+        } else if (!xmlStrcmp(pData, (const xmlChar*)"pN")) {
             currentLoad->setUnit(ForceUnit::PN());
         }
     }
@@ -292,8 +286,7 @@ void XMLLoads::readLoadUnit(xmlNodePtr elem, Load *currentLoad) {
         }
         if (!xmlStrcmp(pData, (const xmlChar*)"kPa")) {
             currentLoad->setUnit(PressureUnit::KPA());
-        }
-        else if (!xmlStrcmp(pData, (const xmlChar*)"mmHg")) {
+        } else if (!xmlStrcmp(pData, (const xmlChar*)"mmHg")) {
             currentLoad->setUnit(PressureUnit::MMHG());
         }
     }
@@ -301,20 +294,16 @@ void XMLLoads::readLoadUnit(xmlNodePtr elem, Load *currentLoad) {
     else if (currentLoad->getType() == "Rotation") {
         if (!xmlStrcmp(pData, (const xmlChar*)"radians")) {
             currentLoad->setUnit(RotationUnit::RAD());
-        }
-        else if (!xmlStrcmp(pData, (const xmlChar*)"degrees")) {
+        } else if (!xmlStrcmp(pData, (const xmlChar*)"degrees")) {
             currentLoad->setUnit(RotationUnit::DEG());
         }
 
-    }
-    else if (currentLoad->getType() == "Acceleration") {
+    } else if (currentLoad->getType() == "Acceleration") {
         if (!xmlStrcmp(pData, (const xmlChar*)"m/s^2")) {
             currentLoad->setUnit(AccelerationUnit::MSm2());
-        }
-        else if (!xmlStrcmp(pData, (const xmlChar*)"cm/s^2")) {
+        } else if (!xmlStrcmp(pData, (const xmlChar*)"cm/s^2")) {
             currentLoad->setUnit(AccelerationUnit::CMSm2());
-        }
-        else if (!xmlStrcmp(pData, (const xmlChar*)"mm/s^2")) {
+        } else if (!xmlStrcmp(pData, (const xmlChar*)"mm/s^2")) {
             currentLoad->setUnit(AccelerationUnit::MMSm2());
         }
     }
