@@ -84,40 +84,36 @@ void testActivation(std::string imlFile, double dt, std::string outcsv = "") {
 
                 if (l->getDirection().isToward()) {
                     std::cout << "dir toward Atom#" << l->getDirection().getToward() << ", ";
-                }
-                else {
+                } else {
                     std::cout << "dir=(";
 
                     // x
                     if (l->getDirection().isXSpecified())
                         std::cout << l->getDirection().getX();
+                    else if (l->getDirection().isXNull())
+                        std::cout << "NULL";
                     else
-                        if (l->getDirection().isXNull())
-                            std::cout << "NULL";
-                        else
-                            std::cout << "free";
+                        std::cout << "free";
 
                     std::cout << ",";
 
                     // y
                     if (l->getDirection().isYSpecified())
                         std::cout << l->getDirection().getY();
+                    else if (l->getDirection().isYNull())
+                        std::cout << "NULL";
                     else
-                        if (l->getDirection().isYNull())
-                            std::cout << "NULL";
-                        else
-                            std::cout << "free";
+                        std::cout << "free";
 
                     std::cout << ",";
 
                     // z
                     if (l->getDirection().isZSpecified())
                         std::cout << l->getDirection().getZ();
+                    else if (l->getDirection().isZNull())
+                        std::cout << "NULL";
                     else
-                        if (l->getDirection().isZNull())
-                            std::cout << "NULL";
-                        else
-                            std::cout << "free";
+                        std::cout << "free";
 
                     std::cout << "), ";
                 }
@@ -128,8 +124,7 @@ void testActivation(std::string imlFile, double dt, std::string outcsv = "") {
                 if (outcsv != "") {
                     outStream << l->getValue(t) << " ";
                 }
-            }
-            else {
+            } else {
                 if (outcsv != "") {
                     outStream << 0.0 << " ";
                 }
@@ -194,7 +189,7 @@ int main(int argc, char *argv[]) {
         if (argc>1) {
             std::cout << "Argument errors: ";
             for(int i=1; i<argc; i++) {
-            std::cout << "[" << argv[i] << "] ";
+                std::cout << "[" << argv[i] << "] ";
             }
         }
         std::cout << std::endl;
