@@ -37,28 +37,23 @@
 using namespace std;
 
 int
-main (int argc, char* argv[])
-{
-  if (argc != 2)
-  {
-    cerr << "usage: " << argv[0] << " file.mml" << endl;
-    return 1;
-  }
+main (int argc, char* argv[]) {
+    if (argc != 2) {
+        cerr << "usage: " << argv[0] << " file.mml" << endl;
+        return 1;
+    }
 
-  try
-  {
-    #ifdef MML_GENERATE_GUI
-    QApplication app(argc, argv);
-    #endif
-    MonitoringManager* c=MonitoringManagerFactory::createManager(argv[1]);
+    try {
+#ifdef MML_GENERATE_GUI
+        QApplication app(argc, argv);
+#endif
+        MonitoringManager* c=MonitoringManagerFactory::createManager(argv[1]);
 
-    c->simulate();
-    delete c;
-  }
-  catch (const xml_schema::exception& e)
-  {
-    cerr << e << endl;
-    return 1;
-  }
+        c->simulate();
+        delete c;
+    } catch (const xml_schema::exception& e) {
+        cerr << e << endl;
+        return 1;
+    }
 }
 
