@@ -31,10 +31,9 @@
 using namespace std;
 
 int
-main (int argc, char* argv[])
-{
-  QApplication app(argc, argv);
-  MonitoringGuiManager* manager=new MonitoringGuiManager();
-  return app.exec();
-  delete manager;
+main (int argc, char* argv[]) {
+    QApplication app(argc, argv);
+    MonitoringGuiManager* manager=new MonitoringGuiManager();
+    return app.exec();
+    delete manager;
 }
\ No newline at end of file
