@@ -30,23 +30,20 @@
 #include <limits>
 
 //--------------- Constructor ---------------------------------
-MonitoringDriver::MonitoringDriver(MonitoringGuiManager* guiManager): QObject()
-{
+MonitoringDriver::MonitoringDriver(MonitoringGuiManager* guiManager): QObject() {
     this->guiManager=guiManager;
     timer = NULL; // not started yet
 }
 
 //--------------- Constructor ---------------------------------
-MonitoringDriver::~MonitoringDriver()
-{
+MonitoringDriver::~MonitoringDriver() {
     stopTimer();
     delete timer;
     timer = NULL;
 }
 
 //--------------- Constructor ---------------------------------
-void MonitoringDriver::init()
-{
+void MonitoringDriver::init() {
     // start the timer
     timer = new QTimer ( this );
 
@@ -56,8 +53,7 @@ void MonitoringDriver::init()
 }
 
 //--------------- Constructor ---------------------------------
-void MonitoringDriver::play()
-{
+void MonitoringDriver::play() {
     if ( !timer->isActive() ) {
         // timer wasn't active, action to be done = launch the timer
         startTimer();
@@ -68,20 +64,17 @@ void MonitoringDriver::play()
 }
 
 //--------------- Constructor ---------------------------------
-void MonitoringDriver::startTimer()
-{
+void MonitoringDriver::startTimer() {
     timer->start();
 }
 
 //--------------- Constructor ---------------------------------
-void MonitoringDriver::stopTimer()
-{
+void MonitoringDriver::stopTimer() {
     timer->stop();
 }
 
 //--------------- Constructor ---------------------------------
-bool MonitoringDriver::isTimerActive()
-{
+bool MonitoringDriver::isTimerActive() {
     return timer->isActive();
 }
 
