@@ -34,35 +34,30 @@
 using namespace std;
 
 int
-main (int argc, char* argv[])
-{
-  if (argc != 2)
-  {
-    cerr << "usage: " << argv[0] << " file.scn" << endl;
-    return 1;
-  }
+main (int argc, char* argv[]) {
+    if (argc != 2) {
+        cerr << "usage: " << argv[0] << " file.scn" << endl;
+        return 1;
+    }
 
-  try
-  {
-    #ifdef MML_GENERATE_GUI
-    QApplication app(argc, argv);
-    #endif
-    SofaSimulator* simul =new SofaSimulator(NULL,argv[1]);
-    
-    string pmlFileName=argv[1];
-    string::size_type pLast = pmlFileName.rfind(".");
-    if (pLast != string::npos) {
-      pmlFileName.erase(pLast);
-      pmlFileName += ".pml";
+    try {
+#ifdef MML_GENERATE_GUI
+        QApplication app(argc, argv);
+#endif
+        SofaSimulator* simul =new SofaSimulator(NULL,argv[1]);
+
+        string pmlFileName=argv[1];
+        string::size_type pLast = pmlFileName.rfind(".");
+        if (pLast != string::npos) {
+            pmlFileName.erase(pLast);
+            pmlFileName += ".pml";
+        }
+
+        simul->createPml(argv[1],pmlFileName.c_str());
+
+    } catch (const xml_schema::exception& e) {
+        cerr << e << endl;
+        return 1;
     }
-    
-    simul->createPml(argv[1],pmlFileName.c_str());
-    
-  }
-  catch (const xml_schema::exception& e)
-  {
-    cerr << e << endl;
-    return 1;
-  }
 }
 
