@@ -26,7 +26,7 @@
 
 //----------------------- Class member init -----------------------
 void BasicAtomProperties::resetUniqueIndex() {
-  BasicAtomProperties::maxUniqueIndex = 0;
+    BasicAtomProperties::maxUniqueIndex = 0;
 }
 
 // initializing the static class member
@@ -34,137 +34,136 @@ unsigned int BasicAtomProperties::maxUniqueIndex = 0;
 
 //----------------------- Constructors -----------------------
 BasicAtomProperties::BasicAtomProperties(PhysicalModel * p)  : StructureProperties(p, StructureProperties::ATOM) {
-  allocate();
-  setPosition(0.0, 0.0, 0.0);
-  index = maxUniqueIndex++;
+    allocate();
+    setPosition(0.0, 0.0, 0.0);
+    index = maxUniqueIndex++;
 }
 
 BasicAtomProperties::BasicAtomProperties(PhysicalModel * p, xmlNodePtr node)  : StructureProperties(p, StructureProperties::ATOM) {
-  allocate();
+    allocate();
 
-  //search the name attribute
-  xmlChar *pname = xmlGetProp(node, (const xmlChar*) "name");
+    //search the name attribute
+    xmlChar *pname = xmlGetProp(node, (const xmlChar*) "name");
 
-  if (pname)
-    setName((char*)pname);
+    if (pname)
+        setName((char*)pname);
 
-  xmlFree(pname);
-  
-  //search the known attributes
-  xmlChar *px = xmlGetProp(node, (const xmlChar*) "x");
+    xmlFree(pname);
 
-  xmlChar *py = xmlGetProp(node, (const xmlChar*) "y");
+    //search the known attributes
+    xmlChar *px = xmlGetProp(node, (const xmlChar*) "x");
 
-  xmlChar *pz = xmlGetProp(node, (const xmlChar*) "z");
+    xmlChar *py = xmlGetProp(node, (const xmlChar*) "y");
 
-  if (px && py && pz)
-    setPosition(atof((char*)px), atof((char*)py), atof((char*)pz));
-  else
-    setPosition(0.0, 0.0, 0.0);
-  xmlFree(px);
-  xmlFree(py);
-  xmlFree(pz);
+    xmlChar *pz = xmlGetProp(node, (const xmlChar*) "z");
 
-  xmlChar *pindex = xmlGetProp(node, (const xmlChar*) "index");
+    if (px && py && pz)
+        setPosition(atof((char*)px), atof((char*)py), atof((char*)pz));
+    else
+        setPosition(0.0, 0.0, 0.0);
+    xmlFree(px);
+    xmlFree(py);
+    xmlFree(pz);
 
-  if (pindex)
-    index = atoi((char*)pindex);
-  else
-    index = maxUniqueIndex++;
-  xmlFree(pindex);
-  
-  //search the unknown attributes to fill the property fields map
-  xmlAttr * attrs = node->properties;
+    xmlChar *pindex = xmlGetProp(node, (const xmlChar*) "index");
 
-  xmlNodePtr unknownAttrs = xmlNewNode(NULL, (xmlChar*)("unknownAttrs"));
+    if (pindex)
+        index = atoi((char*)pindex);
+    else
+        index = maxUniqueIndex++;
+    xmlFree(pindex);
 
-  while (attrs)
-  {
-    const xmlChar * pname = attrs->name;
-    xmlChar * pval = attrs->children->content;
+    //search the unknown attributes to fill the property fields map
+    xmlAttr * attrs = node->properties;
 
-    if (pname && xmlStrcmp(pname, (xmlChar*)"name")
-        && xmlStrcmp(pname, (xmlChar*)"x")
-        && xmlStrcmp(pname, (xmlChar*)"y")
-        && xmlStrcmp(pname, (xmlChar*)"z")
-        && xmlStrcmp(pname, (xmlChar*)"index")){
-      xmlSetProp(unknownAttrs, pname, pval);
+    xmlNodePtr unknownAttrs = xmlNewNode(NULL, (xmlChar*)("unknownAttrs"));
+
+    while (attrs) {
+        const xmlChar * pname = attrs->name;
+        xmlChar * pval = attrs->children->content;
+
+        if (pname && xmlStrcmp(pname, (xmlChar*)"name")
+                && xmlStrcmp(pname, (xmlChar*)"x")
+                && xmlStrcmp(pname, (xmlChar*)"y")
+                && xmlStrcmp(pname, (xmlChar*)"z")
+                && xmlStrcmp(pname, (xmlChar*)"index")) {
+            xmlSetProp(unknownAttrs, pname, pval);
+        }
+
+        attrs = attrs->next;
     }
 
-    attrs = attrs->next;
-  }
+    //transform the unknown attributes to a property field map
+    domToFields(unknownAttrs);
 
-  //transform the unknown attributes to a property field map
-  domToFields(unknownAttrs);
-
-  xmlFree(unknownAttrs);
+    xmlFree(unknownAttrs);
 }
 
 BasicAtomProperties::BasicAtomProperties(PhysicalModel *p, const double pos[3]) : StructureProperties(p, StructureProperties::ATOM) {
-  allocate();
-  setPosition(pos);
-  index = maxUniqueIndex++;
+    allocate();
+    setPosition(pos);
+    index = maxUniqueIndex++;
 }
 
 BasicAtomProperties::BasicAtomProperties(PhysicalModel *p, const unsigned int ind)  :  StructureProperties(p, StructureProperties::ATOM) {
-  allocate();
-  setPosition(0.0, 0.0, 0.0);
-  index = ind;
+    allocate();
+    setPosition(0.0, 0.0, 0.0);
+    index = ind;
 
-  if (ind >= maxUniqueIndex)
-    maxUniqueIndex = ind + 1;
+    if (ind >= maxUniqueIndex)
+        maxUniqueIndex = ind + 1;
 }
 
 BasicAtomProperties::BasicAtomProperties(PhysicalModel *p, const unsigned int ind, const double pos[3]) : StructureProperties(p, StructureProperties::ATOM) {
-  allocate();
-  setPosition(pos);
-  index = ind;
+    allocate();
+    setPosition(pos);
+    index = ind;
 
-  if (ind >= maxUniqueIndex)
-    maxUniqueIndex = ind + 1;
+    if (ind >= maxUniqueIndex)
+        maxUniqueIndex = ind + 1;
 }
 
 //----------------------- destructor -----------------------
 BasicAtomProperties::~BasicAtomProperties() {
-  if (allocated)
-    delete [] X;
+    if (allocated)
+        delete [] X;
 }
 
 //----------------------- allocate -----------------------
 void BasicAtomProperties::allocate() {
-  X = new double[3];
-  allocated = true;
+    X = new double[3];
+    allocated = true;
 }
 
 //----------------------- setPositionPointer -----------------------
 void BasicAtomProperties::setPositionPointer(double * ptr, bool update) {
-  // store previous position if needed
-  double pos[3];
-  if (update) {
-    getPosition(pos);
-  }
-  // delete previous memory to avoid memory leaks, if needed
-  if (allocated) {
-    delete [] X;
-    allocated = false;
-  }
-  X = ptr;
-  // restore if needed
-  if (update) {
-    setPosition(pos);
-  }
+    // store previous position if needed
+    double pos[3];
+    if (update) {
+        getPosition(pos);
+    }
+    // delete previous memory to avoid memory leaks, if needed
+    if (allocated) {
+        delete [] X;
+        allocated = false;
+    }
+    X = ptr;
+    // restore if needed
+    if (update) {
+        setPosition(pos);
+    }
 }
 
 //----------------------- beginXML -----------------------
 void BasicAtomProperties::beginXML(std::ostream & o) {
-  o << "<atomProperties index=\"" << index << "\"";
-  o << " x=\"" << X[0] << "\" y=\"" << X[1] << "\" z=\"" << X[2] << "\"";
+    o << "<atomProperties index=\"" << index << "\"";
+    o << " x=\"" << X[0] << "\" y=\"" << X[1] << "\" z=\"" << X[2] << "\"";
 
-  if (getName() != "")
-    o << " name=\"" << getName().c_str() << "\" ";
+    if (getName() != "")
+        o << " name=\"" << getName().c_str() << "\" ";
 }
 
 //----------------------- endXML -----------------------
 void BasicAtomProperties::endXML(std::ostream & o) {
-  o << "/>" << std::endl;
+    o << "/>" << std::endl;
 }
