@@ -26,54 +26,53 @@
 
 //----------------------- Class member init -----------------------
 void BasicCellProperties::resetUniqueIndex() {
-  BasicCellProperties::maxUniqueIndex = 0;
+    BasicCellProperties::maxUniqueIndex = 0;
 }
 
 BasicCellProperties::BasicCellProperties(PhysicalModel * p, const StructureProperties::GeometricType t, xmlNodePtr node)  : StructureProperties(p, t) {
 
-  //search the name attribute
-  xmlChar *pname = xmlGetProp(node, (const xmlChar*) "name");
+    //search the name attribute
+    xmlChar *pname = xmlGetProp(node, (const xmlChar*) "name");
 
-  if (pname)
-    setName((char*)pname);
+    if (pname)
+        setName((char*)pname);
 
-  xmlFree(pname);
+    xmlFree(pname);
 
-  //search the index attribute
-  xmlChar *pindex = xmlGetProp(node, (const xmlChar*) "index");
+    //search the index attribute
+    xmlChar *pindex = xmlGetProp(node, (const xmlChar*) "index");
 
-  if (pindex)
-    index = atoi((char*)pindex);
-  else
-    index = maxUniqueIndex++;
+    if (pindex)
+        index = atoi((char*)pindex);
+    else
+        index = maxUniqueIndex++;
 
-  xmlFree(pindex);
+    xmlFree(pindex);
 
-  //search the unknown attributes to fill the property fields map
-  xmlAttr * attrs = node->properties;
+    //search the unknown attributes to fill the property fields map
+    xmlAttr * attrs = node->properties;
 
-  xmlNodePtr unknownAttrs = xmlNewNode(NULL, (xmlChar*)("unknownAttrs"));
+    xmlNodePtr unknownAttrs = xmlNewNode(NULL, (xmlChar*)("unknownAttrs"));
 
-  while (attrs)
-  {
-    const xmlChar * pname = attrs->name;
-    xmlChar * pval = attrs->children->content;
+    while (attrs) {
+        const xmlChar * pname = attrs->name;
+        xmlChar * pval = attrs->children->content;
 
-    if (pname && xmlStrcmp(pname, (xmlChar*)"name")
-        && xmlStrcmp(pname, (xmlChar*)"x")
-        && xmlStrcmp(pname, (xmlChar*)"y")
-        && xmlStrcmp(pname, (xmlChar*)"z")
-        && xmlStrcmp(pname, (xmlChar*)"type")
-        && xmlStrcmp(pname, (xmlChar*)"index")){
-          xmlSetProp(unknownAttrs, pname, pval);
+        if (pname && xmlStrcmp(pname, (xmlChar*)"name")
+                && xmlStrcmp(pname, (xmlChar*)"x")
+                && xmlStrcmp(pname, (xmlChar*)"y")
+                && xmlStrcmp(pname, (xmlChar*)"z")
+                && xmlStrcmp(pname, (xmlChar*)"type")
+                && xmlStrcmp(pname, (xmlChar*)"index")) {
+            xmlSetProp(unknownAttrs, pname, pval);
+        }
+
+        attrs = attrs->next;
     }
 
-    attrs = attrs->next;
-  }
-
-  //transform the unknown attributes to a property field map
-  domToFields(unknownAttrs);
-  xmlFree(unknownAttrs);
+    //transform the unknown attributes to a property field map
+    domToFields(unknownAttrs);
+    xmlFree(unknownAttrs);
 }
 
 // initializing the static class member
@@ -81,70 +80,70 @@ unsigned int BasicCellProperties::maxUniqueIndex = 0;
 
 //----------------------- Constructors -----------------------
 BasicCellProperties::BasicCellProperties(PhysicalModel *p, const StructureProperties::GeometricType t)  : StructureProperties(p, t) {
-  index = maxUniqueIndex++;
+    index = maxUniqueIndex++;
 }
 
 BasicCellProperties::BasicCellProperties(PhysicalModel *p, const StructureProperties::GeometricType t, const unsigned int ind)  :  StructureProperties(p, t) {
-  index = ind;
+    index = ind;
 
-  if (ind >= maxUniqueIndex)
-    maxUniqueIndex = ind + 1;
+    if (ind >= maxUniqueIndex)
+        maxUniqueIndex = ind + 1;
 }
 
 /// write the default xml properties (beginning)
 void BasicCellProperties::beginXML(std::ostream & o) {
-  o << "<cellProperties index=\"" << index << "\"";
-  // print the type
+    o << "<cellProperties index=\"" << index << "\"";
+    // print the type
 
-  switch (getType()) {
+    switch (getType()) {
 
     case StructureProperties::TETRAHEDRON:
-      o << " type=\"TETRAHEDRON\"";
-      break;
+        o << " type=\"TETRAHEDRON\"";
+        break;
 
     case StructureProperties::HEXAHEDRON:
-      o << " type=\"HEXAHEDRON\"";
-      break;
+        o << " type=\"HEXAHEDRON\"";
+        break;
 
     case StructureProperties::WEDGE:
-      o << " type=\"WEDGE\"";
-      break;
-    
+        o << " type=\"WEDGE\"";
+        break;
+
     case StructureProperties::PYRAMID:
-      o << " type=\"PYRAMID\"";
-      break;
+        o << " type=\"PYRAMID\"";
+        break;
 
     case StructureProperties::POLY_LINE:
-      o << " type=\"POLY_LINE\"";
-      break;
+        o << " type=\"POLY_LINE\"";
+        break;
 
     case StructureProperties::POLY_VERTEX:
-      o << " type=\"POLY_VERTEX\"";
-      break;
+        o << " type=\"POLY_VERTEX\"";
+        break;
 
     case StructureProperties::LINE:
-      o << " type=\"LINE\"";
-      break;
+        o << " type=\"LINE\"";
+        break;
 
     case StructureProperties::TRIANGLE:
-      o << " type=\"TRIANGLE\"";
-      break;
+        o << " type=\"TRIANGLE\"";
+        break;
 
     case StructureProperties::QUAD:
-      o << " type=\"QUAD\"";
-      break;
+        o << " type=\"QUAD\"";
+        break;
 
     default:
-      o << " type=\"???\"";
-      break;
-  }
+        o << " type=\"???\"";
+        break;
+    }
 
-  if (getName() != "")
-    o << " name=\"" << getName().c_str() << "\" ";
+    if (getName() != "")
+        o << " name=\"" << getName().c_str() << "\" ";
 
 }
 
 /// write the default xml properties (end)
 void BasicCellProperties::endXML(std::ostream & o) {
-  o << "/>" << std::endl;
+    o << "/>" << std::endl;
 }
