@@ -56,16 +56,14 @@ BasicSCProperties::BasicSCProperties(PhysicalModel * p, xmlNodePtr node) : Prope
                 setAlpha(atof((char*)pa));
             else
                 setAlpha(1.0);
-        }
-        else
+        } else
             setColor(DEFAULT);
 
         xmlFree(pr);
         xmlFree(pg);
         xmlFree(pb);
         xmlFree(pa);
-    }
-    else
+    } else
         setColor(DEFAULT);
 
     //search the renderingmode attribute
@@ -97,8 +95,7 @@ BasicSCProperties::BasicSCProperties(PhysicalModel * p, xmlNodePtr node) : Prope
             setMode(RenderingMode::WIREFRAME_AND_SURFACE_AND_POINTS);
 
         xmlFree(pmode);
-    }
-    else
+    } else
         setMode(RenderingMode::NONE);
 
 
