@@ -35,7 +35,7 @@ class Cell;
 class MultiComponent;
 /**
   * @ingroup group_cepmodeling_libraries_pml
-  * 
+  *
   * @brief
   * A component is something that composed something and could also be
   *  a part of something.
@@ -43,7 +43,7 @@ class MultiComponent;
   *  (just in case you don't really understand, a good reference is "The hitch
   *  hiker's guide to the galaxy", Douglas Adams, 1952-2001. Thanks for reading
   *  this absolutly clear documentation!!!)
-  *  
+  *
  **/
 class Component {
 public:
@@ -51,7 +51,7 @@ public:
       * If not given name is initialized to the empty string
       */
     Component(PhysicalModel *, std::string n="");
-    
+
     /** Virtual destructor needed here as this is an abstract class (pure virtual) */
     virtual ~Component();
 
@@ -113,17 +113,17 @@ public:
 
     /// get the component structural properties (guarantied to be non NULL)
     Properties* getProperties();
-    
+
 protected:
     Properties* properties;
-    
-    /** this tell the parent components that this component is 
+
+    /** this tell the parent components that this component is
      *  removed from memory.
-     *  As the destructor is virtual, this method has to be called 
+     *  As the destructor is virtual, this method has to be called
      *  in all sub-classes destructors.
      */
     void removeFromParents();
-    
+
     /// delete the "properties" pointer and set it to NULL
     void deleteProperties();
 
@@ -157,7 +157,7 @@ inline std::vector <MultiComponent *> Component::getAllParentMultiComponents() {
     return parentMultiComponentList;
 }
 inline unsigned int Component::getNumberOfParentMultiComponents() const {
-    return parentMultiComponentList.size();
+    return (unsigned int) parentMultiComponentList.size();
 }
 inline MultiComponent * Component::getParentMultiComponent(unsigned int i) {
     if (i<parentMultiComponentList.size())
@@ -183,7 +183,7 @@ inline PhysicalModel * Component::getPhysicalModel() const {
 }
 
 inline Properties* Component::getProperties() {
-  return properties;
+    return properties;
 }
 
 
