@@ -32,20 +32,20 @@
 #include "Component.h"
 /**
   * @ingroup group_cepmodeling_libraries_pml
-  * 
+  *
   * @brief
   * A multi-component stores other components, hence providing a way to have
   * an tree representation of components. Isn't that tricky?
   *
   * \note To delete and free the memory of all the sub components, you have to
   * call the deleteAllSubComponents() method.
-  *  
+  *
  **/
 class MultiComponent : public Component {
 public:
     /** Default Constructor */
     MultiComponent(PhysicalModel *);
-    /// constructor that allows to name the structure (provides a name)
+    /// constructor that allows one to name the structure (provides a name)
     MultiComponent(PhysicalModel *, std::string);
     /// delete all the subcomponents (call the deleteAllSubComponents method)
     ~MultiComponent();
@@ -84,13 +84,13 @@ public:
 
     /// conveniant method to get the sub component of the name given in parameter
     Component * getComponentByName(const std::string);
-    
+
     /// return the state of a visibility mode in all the sub component (if at least one sub component is visible for this mode, it will return true; if none are visible it will return false).
     virtual bool isVisible(const RenderingMode::Mode mode) const;
 
     /// set the state of a visibility mode in all the sub component.
     virtual void setVisible(const RenderingMode::Mode mode, const bool b);
-    
+
     /// set the physical model (recursively)
     virtual void setPhysicalModel(PhysicalModel *);
 
@@ -102,8 +102,8 @@ protected:
 };
 
 // -------------------- inline methods -------------------
-inline 	unsigned int MultiComponent::getNumberOfSubComponents() const {
-    return components.size();
+inline unsigned int MultiComponent::getNumberOfSubComponents() const {
+    return (unsigned int) components.size();
 }
 inline Component * MultiComponent::getSubComponent(const unsigned int i) const {
     if (i<components.size())
