@@ -315,7 +315,7 @@ void PhysicalModel::xmlRead ( const char * n ) {
         statusOk = setlocale(LC_NUMERIC, "C.UTF-8");
     if (statusOk!=NULL)
         statusOk = setlocale(LC_TIME, "C.UTF-8");
-    
+
     // french is: "fr_FR.UTF8"
     if (!statusOk) {
         // try without UTF-8
@@ -380,9 +380,9 @@ bool PhysicalModel::parseTree ( xmlNodePtr root ) {
     std::string name = "";
     if ( pname )
         name = (char *) pname;
-    
+
     properties = new Properties(this, name );
-    
+
     xmlFree ( pname );
 
     // parse the physicalModel options (e.g. the physicalModel node attributes) that holds specific proprerties
@@ -419,8 +419,7 @@ bool PhysicalModel::parseTree ( xmlNodePtr root ) {
     if ( !atomsPtr || xmlStrcmp ( atomsPtr->name, ( const xmlChar* ) "atoms" ) ) {
         std::cerr << "failed to read the atoms" << std::endl;
         return false;
-    }
-    else {
+    } else {
         // if we found the pointer on atoms, parse the sub tree and build the atoms
         parseAtoms ( atomsPtr );
         // allocate the big memory bunch
@@ -445,8 +444,7 @@ bool PhysicalModel::parseTree ( xmlNodePtr root ) {
     if ( !exCompPtr || xmlStrcmp ( exCompPtr->name, ( const xmlChar* ) "exclusiveComponents" ) ) {
         std::cerr << "failed to read the exclusiveComponents" << std::endl;
         return false;
-    }
-    else {
+    } else {
         //if we found the pointer on exclusiveComponents, parse the sub tree and build the exclusiveComponents
         //exclusiveComponents = new MultiComponent(this);
         xmlNodePtr mcNode = exCompPtr->children;
@@ -502,8 +500,7 @@ bool PhysicalModel::parseTree ( xmlNodePtr root ) {
     if ( !infCompPtr || xmlStrcmp ( infCompPtr->name, ( const xmlChar* ) "informativeComponents" ) ) {
         std::cerr << "failed to read the informativeComponents" << std::endl;
         return false;
-    }
-    else {
+    } else {
         //if we found the pointer on informativeComponents, parse the sub tree and build the informativeComponents
         informativeComponents = new MultiComponent ( this );
         xmlNodePtr mcNode = infCompPtr->children;
@@ -771,8 +768,7 @@ bool PhysicalModel::addAtom ( Atom *newA ) {
         // add the atom in the atom structural component
         atoms->addStructure ( newA );
         return true;
-    }
-    else
+    } else
         return false; // atom does not have a unique index
 }
 
@@ -925,7 +921,7 @@ void PhysicalModel::exportAnsysMesh ( std::string filename ) {
         nodeFile << std::setw(8) << ansysIndex << " ";
         for (unsigned int j=0; j<3; j++)
             nodeFile << std::setprecision(8) << std::setw(3) << std::fixed << std::scientific << pos[j] << "     ";
-        nodeFile << std::endl;        
+        nodeFile << std::endl;
     }
 
     nodeFile.close();
@@ -949,98 +945,98 @@ void PhysicalModel::exportAnsysMesh ( std::string filename ) {
 
         switch ( cell->getType() ) {
 
-            case StructureProperties::HEXAHEDRON:
+        case StructureProperties::HEXAHEDRON:
 
-                // I,J,K,L,M,N,O,P,MAT,TYPE,REAL,SECNUM,ESYS,IEL
-                //
-                // Format hex:
-                //   I,J,K,L,M,N,O,P                = indices des noeuds
-                //   MAT,TYPE,REAL,SECNUM et ESYS   = attributes numbers
-                //   SECNUM                         = beam section number
-                //   IEL                            = element number
+            // I,J,K,L,M,N,O,P,MAT,TYPE,REAL,SECNUM,ESYS,IEL
+            //
+            // Format hex:
+            //   I,J,K,L,M,N,O,P                = indices des noeuds
+            //   MAT,TYPE,REAL,SECNUM et ESYS   = attributes numbers
+            //   SECNUM                         = beam section number
+            //   IEL                            = element number
 
-                MAT  = 1;
-                TYPE = 1;
+            MAT  = 1;
+            TYPE = 1;
 
-                for (unsigned int k = 0; k < cell->getNumberOfStructures(); k++ ) {
-                    elemFile << " " << std::setw(5) << cell->getStructure ( k )->getIndex() + 1 ;
-                }
-        
-                elemFile << " " << std::setw(5) << MAT << " " << std::setw(5) << TYPE << "     1     1     0 " << std::setw(5) << ansysIndex << std::endl;
-                break;
+            for (unsigned int k = 0; k < cell->getNumberOfStructures(); k++ ) {
+                elemFile << " " << std::setw(5) << cell->getStructure ( k )->getIndex() + 1 ;
+            }
 
-            case StructureProperties::WEDGE:
+            elemFile << " " << std::setw(5) << MAT << " " << std::setw(5) << TYPE << "     1     1     0 " << std::setw(5) << ansysIndex << std::endl;
+            break;
 
-                // I,J,K,L,M,N,O,P,MAT,TYPE,REAL,SECNUM,ESYS,IEL
-                //
-                // Format prism: on repete les noeuds 3 et 7:
-                //   I,J,K,K,M,N,O,O                = indices des noeuds
-                //   MAT,TYPE,REAL,SECNUM et ESYS   = attributes numbers
-                //   SECNUM                         = beam section number
-                //   IEL                            = element number
-                MAT  = 1;
-                TYPE = 1;
+        case StructureProperties::WEDGE:
 
-                elemFile << " " << std::setw(5) << cell->getStructure ( 0 )->getIndex() + 1;
-                elemFile << " " << std::setw(5) << cell->getStructure ( 1 )->getIndex() + 1;
-                elemFile << " " << std::setw(5) << cell->getStructure ( 2 )->getIndex() + 1;
-                elemFile << " " << std::setw(5) << cell->getStructure ( 2 )->getIndex() + 1;
+            // I,J,K,L,M,N,O,P,MAT,TYPE,REAL,SECNUM,ESYS,IEL
+            //
+            // Format prism: on repete les noeuds 3 et 7:
+            //   I,J,K,K,M,N,O,O                = indices des noeuds
+            //   MAT,TYPE,REAL,SECNUM et ESYS   = attributes numbers
+            //   SECNUM                         = beam section number
+            //   IEL                            = element number
+            MAT  = 1;
+            TYPE = 1;
 
-                elemFile << " " << std::setw(5) << cell->getStructure ( 3 )->getIndex() + 1;
-                elemFile << " " << std::setw(5) << cell->getStructure ( 4 )->getIndex() + 1;
-                elemFile << " " << std::setw(5) << cell->getStructure ( 5 )->getIndex() + 1;
-                elemFile << " " << std::setw(5) << cell->getStructure ( 5 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 0 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 1 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 2 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 2 )->getIndex() + 1;
 
-                elemFile << " " << std::setw(5) << MAT << " " << std::setw(5) << TYPE << "     1     1     0 " << std::setw(5) << ansysIndex << std::endl;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 3 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 4 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 5 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 5 )->getIndex() + 1;
 
-                break;
+            elemFile << " " << std::setw(5) << MAT << " " << std::setw(5) << TYPE << "     1     1     0 " << std::setw(5) << ansysIndex << std::endl;
+
+            break;
 
 
-            case StructureProperties::TETRAHEDRON:
+        case StructureProperties::TETRAHEDRON:
 
-                MAT  = 1;
-                TYPE = 1;
+            MAT  = 1;
+            TYPE = 1;
 
-                elemFile << " " << std::setw(5) <<  cell->getStructure ( 0 )->getIndex() + 1;
-                elemFile << " " << std::setw(5) << cell->getStructure ( 1 )->getIndex() + 1;
-                elemFile << " " << std::setw(5) << cell->getStructure ( 2 )->getIndex() + 1;
-                elemFile << " " << std::setw(5) << cell->getStructure ( 3 )->getIndex() + 1;               
-                elemFile << "     0     0     0     0" ;
+            elemFile << " " << std::setw(5) <<  cell->getStructure ( 0 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 1 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 2 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 3 )->getIndex() + 1;
+            elemFile << "     0     0     0     0" ;
 
-                elemFile << " " << std::setw(5) << MAT << " " << std::setw(5) << TYPE << "     1     1     0 " << std::setw(5) << ansysIndex << std::endl;
-                break;
+            elemFile << " " << std::setw(5) << MAT << " " << std::setw(5) << TYPE << "     1     1     0 " << std::setw(5) << ansysIndex << std::endl;
+            break;
 
 
 
-            case StructureProperties::QUAD:
-                // I,J,K,L,M,N,O,P,MAT,TYPE,REAL,SECNUM,ESYS,IEL
-                //
-                // Format quad:
-                //   I,J,K,K,L,L,L,L                = indices des noeuds
-                //   MAT,TYPE,REAL,SECNUM et ESYS   = attributes numbers
-                //   SECNUM                         = beam section number
-                //   IEL                            = element number
+        case StructureProperties::QUAD:
+            // I,J,K,L,M,N,O,P,MAT,TYPE,REAL,SECNUM,ESYS,IEL
+            //
+            // Format quad:
+            //   I,J,K,K,L,L,L,L                = indices des noeuds
+            //   MAT,TYPE,REAL,SECNUM et ESYS   = attributes numbers
+            //   SECNUM                         = beam section number
+            //   IEL                            = element number
 
-                MAT  = 1;
-                TYPE = 1;
+            MAT  = 1;
+            TYPE = 1;
 
-                elemFile << " " << std::setw(5) << cell->getStructure ( 0 )->getIndex() + 1;
-                elemFile << " " << std::setw(5) << cell->getStructure ( 1 )->getIndex() + 1;
-                elemFile << " " << std::setw(5) << cell->getStructure ( 2 )->getIndex() + 1;
-                elemFile << " " << std::setw(5) << cell->getStructure ( 2 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 0 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 1 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 2 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 2 )->getIndex() + 1;
 
-                elemFile << " " << std::setw(5) << cell->getStructure ( 3 )->getIndex() + 1;
-                elemFile << " " << std::setw(5) << cell->getStructure ( 3 )->getIndex() + 1;
-                elemFile << " " << std::setw(5) << cell->getStructure ( 3 )->getIndex() + 1;
-                elemFile << " " << std::setw(5) << cell->getStructure ( 3 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 3 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 3 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 3 )->getIndex() + 1;
+            elemFile << " " << std::setw(5) << cell->getStructure ( 3 )->getIndex() + 1;
 
-                elemFile << " " << std::setw(5) << MAT << " " << std::setw(5) << TYPE << "     1     1     0 " << std::setw(5) << ansysIndex << std::endl;
-                break;
+            elemFile << " " << std::setw(5) << MAT << " " << std::setw(5) << TYPE << "     1     1     0 " << std::setw(5) << ansysIndex << std::endl;
+            break;
 
 
-            default:
-                std::cerr << "PhysicalModel::exportAnsysMesh : unknown type for cell " << cell->getIndex() + 1 << ", neither HEXAHEDRON, WEDGE, THETRAHEDRON nor QUAD. Cant' export in Patran format." << std::endl;
-                continue;
+        default:
+            std::cerr << "PhysicalModel::exportAnsysMesh : unknown type for cell " << cell->getIndex() + 1 << ", neither HEXAHEDRON, WEDGE, THETRAHEDRON nor QUAD. Cant' export in Patran format." << std::endl;
+            continue;
         }
 
     }
@@ -1079,10 +1075,10 @@ void PhysicalModel::exportPatran ( std::string filename ) {
         getAtom ( i )->getPosition ( pos );
 
         // second line : node coordinates
-         for (unsigned int j=0; j<3; j++)
+        for (unsigned int j=0; j<3; j++)
             outputFile << std::setprecision(8) << std::setw(16) << std::fixed << std::scientific << pos[j];
         outputFile << " " << std::endl;
-        
+
         // third line : ??
         outputFile << "1G       6       0       0  000000\n";
     }
@@ -1098,17 +1094,17 @@ void PhysicalModel::exportPatran ( std::string filename ) {
 
         switch ( cell->getType() ) {
 
-            case StructureProperties::HEXAHEDRON:
-                typeElement = 8;
-                break;
+        case StructureProperties::HEXAHEDRON:
+            typeElement = 8;
+            break;
 
-            case StructureProperties::WEDGE:
-                typeElement = 7;
-                break;
+        case StructureProperties::WEDGE:
+            typeElement = 7;
+            break;
 
-            default:
-                std::cerr << "PhysicalModel::exportPatran : unknown type for cell " << cell->getIndex() + 1 << ", neither HEXAHEDRON nor WEDGE. Cant' export in Patran format." << std::endl;
-                continue;
+        default:
+            std::cerr << "PhysicalModel::exportPatran : unknown type for cell " << cell->getIndex() + 1 << ", neither HEXAHEDRON nor WEDGE. Cant' export in Patran format." << std::endl;
+            continue;
         }
 
         // first element line
