@@ -64,12 +64,12 @@ typedef std::map <unsigned int, Structure *> ::iterator GlobalIndexStructureMapI
 
 /**
   * @ingroup group_cepmodeling_libraries_pml
-  * 
+  *
   * @brief
   * This is the main class of this project.
   * Following a nice concept, a physical model is able to represent any kind of 3D physical model that appeared, appears or will appear on earth.
   * This include FEM meshes, spring-mass networks, phymulob etc...
-  *  
+  *
  **/
 class PhysicalModel {
 
@@ -132,7 +132,7 @@ public:
      *  Save the geometry (atoms/cells) of this PhysicalModel
      *  in the Patran format.
      *
-     *  %%% This method is usefull only for a  FEM (?) mesh.
+     *  %%% This method is useful only for a  FEM (?) mesh.
      *  Maybe it's better to put it in a femPM class that inherits PhysicalModel???
      */
     void exportPatran(std::string filename);
@@ -141,7 +141,7 @@ public:
      *  Save the mesh (atoms/cells) of this PhysicalModel
      *  in the Ansys format.
      *
-     *  //@@@ This method is usefull only for a  FEM (?) mesh.
+     *  //@@@ This method is useful only for a  FEM (?) mesh.
      *  Maybe it's better to put it in a femPM class that inherits PhysicalModel???
      */
     void exportAnsysMesh(std::string filename);
@@ -272,7 +272,7 @@ private:
 
     /// is the current property state modified
     bool isModifiedFlag;
-    
+
     /**
      * Exclusive components are the non-overlaping components : they defined all the components
      * of the physicalModel and the physicalModel could be defined by all this components.
@@ -292,7 +292,7 @@ private:
     */
     StructuralComponent * atoms;
 
-    /// Clear everything. That allows to restart an allready instanciated object from scratch
+    /// Clear everything. That allows one to restart an allready instanciated object from scratch
     void clear();
 
     /// the association couple list, which contains the direct map between the cell's global index and the cell ptr
@@ -343,7 +343,7 @@ inline bool PhysicalModel::isModified() {
 }
 
 inline void PhysicalModel::setModified() {
-    isModifiedFlag = true;   
+    isModifiedFlag = true;
 }
 
 inline MultiComponent * PhysicalModel::getExclusiveComponents() const {
@@ -365,8 +365,7 @@ inline Atom * PhysicalModel::getAtom(const unsigned int id) {
 
     if (quickAccessed && quickAccessed->getIndex()==id) {
         return quickAccessed;
-    }
-    else {
+    } else {
         // if not then check if it could be found in the map
         std::GlobalIndexStructureMapIterator mapIt; // a representation map iterator
         mapIt = atomMap.find(id);
@@ -380,8 +379,7 @@ inline Atom * PhysicalModel::getAtom(const unsigned int id) {
 inline Cell * PhysicalModel::getCell(const unsigned int cellIndex) {
     if (cellIndexOptimized) {
         return optimizedCellList[cellIndex];
-    }
-    else {
+    } else {
         std::GlobalIndexStructureMapIterator mapIt; // a representation map iterator
 
         // check if it was find in the list
