@@ -59,7 +59,7 @@ void Properties::domToFields(xmlNodePtr node) {
 
 // ---------------- numberOfFields -----------------
 unsigned int Properties::numberOfFields() const {
-    return fields.size();
+    return (unsigned int) fields.size();
 }
 
 // ---------------- getField -----------------
