@@ -35,7 +35,7 @@ StructuralComponent::StructuralComponent(PhysicalModel *p) : Component(p) {
     // delete the properties that has just been instanciated by
     // the Component(..) constructor
     deleteProperties();
-    
+
     // create a new proper one
     properties = new StructuralComponentProperties(p);
     atomList = NULL;
@@ -45,7 +45,7 @@ StructuralComponent::StructuralComponent(PhysicalModel *p, xmlNodePtr node) : Co
     // delete the properties that has just been instanciated by
     // the Component(..) constructor
     deleteProperties();
-    
+
     // create a new proper one
     properties = new StructuralComponentProperties(p, node);
 
@@ -56,7 +56,7 @@ StructuralComponent::StructuralComponent(PhysicalModel *p, std::string n) : Comp
     // delete the properties that has just been instanciated by
     // the Component(..) constructor
     deleteProperties();
-    
+
     // create a new proper one
     properties = new StructuralComponentProperties(p,n);
     atomList = NULL;
@@ -65,7 +65,7 @@ StructuralComponent::StructuralComponent(PhysicalModel *p, std::string n) : Comp
 // ------------------ destructor ---------------------
 StructuralComponent::~StructuralComponent() {
     deleteProperties();
-    
+
     if (atomList)
         delete atomList;
     atomList = NULL;
@@ -208,7 +208,7 @@ Cell * StructuralComponent::getCell(unsigned int cellOrderNr) const {
 // --------------- getCellPosition ---------------
 /*
 int StructuralComponent::getCellPosition(const Cell *cell) const {
-	
+
 	// look for the position of this cell in the SC structures list
 	for (unsigned int i=0; i<structures.size(); i++) {
 		if (structures[i]->isInstanceOf("Cell"))
@@ -216,7 +216,7 @@ int StructuralComponent::getCellPosition(const Cell *cell) const {
 			if (cell->getIndex() == structures[i]->getIndex())
 				return i;
 		}
- 
+
 	// This cell is not in this StructuralComponent, return -1
 	return -1;
 }
@@ -233,13 +233,12 @@ bool StructuralComponent::isStructureIn(Structure* s) {
 
 // --------------- addStructureIfNotIn ---------------
 bool StructuralComponent::addStructureIfNotIn(Structure *s) {
-    
+
     if (!isStructureIn(s)) {
         // not in, add it
         addStructure(s);
         return true; // structure added
-    } 
-    else
+    } else
         return false;
 }
 
@@ -262,8 +261,7 @@ StructuralComponent *StructuralComponent::getAtoms() {
 
         if (s->isInstanceOf("Atom")) {
             atomList->addStructureIfNotIn(s);
-        } else // s is a Cell
-        {
+        } else { // s is a Cell
             Cell *cell = (Cell *) s;
             for (unsigned int j=0; j<cell->getNumberOfStructures(); j++) {
                 // there is only atoms in a Cell!
@@ -293,17 +291,17 @@ bool StructuralComponent::isCompatible(Structure *s) {
     cb = composedBy();
     return ((s!=NULL) &&
             ((cb==NOTHING) ||
-            (s->isInstanceOf("Atom") && cb==ATOMS) ||
-            (s->isInstanceOf("Cell") && cb==CELLS)));
+             (s->isInstanceOf("Atom") && cb==ATOMS) ||
+             (s->isInstanceOf("Cell") && cb==CELLS)));
 
 }
 
 // --------------- setPhysicalModel ---------------
 void StructuralComponent::setPhysicalModel(PhysicalModel* pm) {
-  Component::setPhysicalModel(pm);
-  // loop through all structures
-  for (unsigned int i=0; i<this->getNumberOfStructures(); i++)
-      this->getStructure(i)->setPhysicalModel(pm);
+    Component::setPhysicalModel(pm);
+    // loop through all structures
+    for (unsigned int i=0; i<this->getNumberOfStructures(); i++)
+        this->getStructure(i)->setPhysicalModel(pm);
 }
 
 
