@@ -40,21 +40,21 @@ class Object3D;
 #include <string>
 /**
  * @ingroup group_cepmodeling_libraries_pml
- * 
+ *
  * @brief
  * A structural component is composed either by cell or by atoms.
- *  
+ *
  **/
 class StructuralComponent : public Component {
 public:
     /** Default Constructor.
      */
     StructuralComponent(PhysicalModel *);
-    
-    /** constructor from xml node: try to read and get the parmaters from xml */    
+
+    /** constructor from xml node: try to read and get the parmaters from xml */
     StructuralComponent(PhysicalModel *, xmlNodePtr);
-    
-    /** constructor that allows to name the structure.
+
+    /** constructor that allows one to name the structure.
      */
     StructuralComponent(PhysicalModel *, std::string);
 
@@ -238,7 +238,7 @@ inline Structure * StructuralComponent::getStructureByName(const std::string n)
         return (*it);
 }
 inline unsigned int StructuralComponent::getNumberOfStructures() const {
-    return structures.size();
+    return (unsigned int) structures.size();
 }
 inline	void StructuralComponent::removeStructure(Structure *s) {
     if (s) {
