@@ -33,12 +33,12 @@
 class StructuralComponent;
 /**
  * @ingroup group_cepmodeling_libraries_pml
- * 
+ *
  * @brief
  * Pure virtual class that represent an element of the structure.
  * This implies that every structure could be represented in 3D and
  * is a part of a structural component.
- *  
+ *
  **/
 class Structure {
 public:
@@ -60,7 +60,7 @@ public:
 
     /** set the index.
      *  The index <b>have to be unique</b> otherwise this method
-     *  has no effect. 
+     *  has no effect.
      *  The sub-classes method will check that this index is not in use.
      *  @return true only if the index of the structure was changed
      */
@@ -89,9 +89,9 @@ public:
 
     /// get the name of the structure
     std::string getName() const;
-    
+
     /// set the physical model
-    virtual void setPhysicalModel(PhysicalModel *);    
+    virtual void setPhysicalModel(PhysicalModel *);
 
 protected:
 
@@ -110,7 +110,7 @@ inline std::vector <StructuralComponent *> Structure::getAllStructuralComponents
     return mySCs;
 }
 inline unsigned int Structure::getNumberOfStructuralComponents() const {
-    return mySCs.size();
+    return (unsigned int) mySCs.size();
 }
 inline StructuralComponent * Structure::getStructuralComponent(unsigned int i) {
     if (i<mySCs.size())
