@@ -108,21 +108,18 @@ int main ( int argc, char ** argv ) {
             if ( pLast != string::npos ) {
                 filename.erase ( pLast );
                 filename += "-output-pmltest.pml";
-            }
-            else
+            } else
                 filename="output-pmltest.pml";
 
             cout << "-> saved as " << filename << endl;
             ofstream outputFile ( filename.c_str() );
             pm.xmlPrint ( outputFile );
-        }
-        else {
+        } else {
             pm.xmlPrint(cout);
         }
 
         return EXIT_SUCCESS;
-    }
-    catch ( PMLAbortException ae ) {
+    } catch ( PMLAbortException ae ) {
         cout << "AbortException: Physical model aborted:" << endl ;
         cout << ae.what() << endl;
     }
