@@ -41,9 +41,9 @@ StructureProperties::GeometricType type;
 
 // maps to get the correspondance between atom id and node file id
 namespace std {
-    typedef std::pair<unsigned int, Atom *> AtomIndexPair;
-    typedef map <unsigned int, Atom *> AtomIndexMap;
-    typedef map <unsigned int, Atom *> ::iterator AtomIndexMapIterator;
+typedef std::pair<unsigned int, Atom *> AtomIndexPair;
+typedef map <unsigned int, Atom *> AtomIndexMap;
+typedef map <unsigned int, Atom *> ::iterator AtomIndexMapIterator;
 }
 
 // one map for each node file
@@ -58,9 +58,13 @@ public:
     bool eof;
     unsigned int id;
 
-    InputFile(string f, unsigned int index) : fileName(f), id(index) { open(); };
+    InputFile(string f, unsigned int index) : fileName(f), id(index) {
+        open();
+    };
 
-    ~InputFile() { stream.close(); }
+    ~InputFile() {
+        stream.close();
+    }
 
     void init() {
         eof = false;
@@ -111,7 +115,7 @@ void getNextNode(InputFile & nodes) {
         stringstream line(l);
         // if the node id is found
         if ((line >> currentNodeLine.id)) {
-            for (unsigned int i=0;i<3;i++) {
+            for (unsigned int i=0; i<3; i++) {
                 if (!(line >> currentNodeLine.pos[i])) {
                     cerr << "Error in " << nodes.fileName << " line " << nodes.lineNr << " node #" << currentNodeLine.id << ": cannot find coordinate " << i+1 << " (set to 0.0)" << endl;
                     currentNodeLine.pos[i] = 0.0;
@@ -131,7 +135,7 @@ void getNextElem(InputFile & elems) {
         elems.eof = !(elems.stream.getline(l,199));
         elems.lineNr++;
         stringstream line2(l);
-        for (unsigned int i=0;i<14;i++)
+        for (unsigned int i=0; i<14; i++)
             line2 >> data[i];
 
         // mat is the 10th value
@@ -157,8 +161,8 @@ void getNextElem(InputFile & elems) {
 
         // read the second line, no data there
         if (type==StructureProperties::TETRAHEDRON) {
-          elems.eof = !(elems.stream.getline(l,199));
-          elems.lineNr++;
+            elems.eof = !(elems.stream.getline(l,199));
+            elems.lineNr++;
         }
     }
 }
@@ -213,10 +217,10 @@ StructuralComponent * elemToSC(StructuralComponent * elemSC, InputFile & elems)
         if (type==StructureProperties::TETRAHEDRON || currentElemLine.type==2) {
             // create tetrahedron cell
             c = new Cell(NULL, StructureProperties::TETRAHEDRON, currentElemLine.id);
-    
+
             if (c!=NULL) {
                 // add atoms
-                for (unsigned int i=0;i<4;i++) {
+                for (unsigned int i=0; i<4; i++) {
                     // get the atom from the corresponding map
                     AtomIndexMapIterator mapIt;
                     mapIt = maps[elems.id].find(currentElemLine.node[i]);
@@ -232,14 +236,13 @@ StructuralComponent * elemToSC(StructuralComponent * elemSC, InputFile & elems)
                 elemSC->addStructure(c);
                 infoSC->addStructure(c);
             }
-        }
-        else if (type==StructureProperties::QUAD) {
+        } else if (type==StructureProperties::QUAD) {
             // create quad cell
             c = new Cell(NULL, StructureProperties::QUAD, currentElemLine.id);
-    
+
             if (c!=NULL) {
                 // add atoms
-                for (unsigned int i=0;i<4;i++) {
+                for (unsigned int i=0; i<4; i++) {
                     // get the atom from the corresponding map
                     AtomIndexMapIterator mapIt;
                     mapIt = maps[elems.id].find(currentElemLine.node[i]);
@@ -255,8 +258,7 @@ StructuralComponent * elemToSC(StructuralComponent * elemSC, InputFile & elems)
                 elemSC->addStructure(c);
                 infoSC->addStructure(c);
             }
-        }
-        else {
+        } else {
             cerr << "Warning in " << elems.fileName << ", line " << elems.lineNr << ": type is unknown (" << currentElemLine.type << ")" << endl;
         }
 
@@ -306,13 +308,13 @@ void processArg() {
 // -------------------- printArg ------------------------
 void printArg() {
     cout << "ansys2pml generating " << outputPML << " from node files ";
-    for (unsigned int i=0; i<nodeFileNames.size();i++) {
+    for (unsigned int i=0; i<nodeFileNames.size(); i++) {
         cout << nodeFileNames[i];
         if (i!=nodeFileNames.size()-1)
             cout << ",";
     }
     cout << " and elem files ";
-    for (unsigned int i=0; i<elemFileNames.size();i++) {
+    for (unsigned int i=0; i<elemFileNames.size(); i++) {
         cout << elemFileNames[i];
         if (i!=elemFileNames.size()-1)
             cout << ",";
