@@ -66,8 +66,7 @@ int main(int argc, char ** argv) {
         string c2;
         if (argc==3) {
             cout << "component " << c1 << endl;
-        }
-        else if (argc==4) {
+        } else if (argc==4) {
             c2 = argv[3];
             cout << "all cells in " << c1 << " having all atoms in " << c2 << endl;
         }
@@ -90,9 +89,8 @@ int main(int argc, char ** argv) {
 
             ofstream cptOut(cptOutName.c_str());
             cpt1->xmlPrint(cptOut);
-            cptOut.close();            
-        }
-        else if (argc==4) {
+            cptOut.close();
+        } else if (argc==4) {
             cout << "-> get " << c2 << endl;
 
             // atom list of c2
@@ -107,34 +105,32 @@ int main(int argc, char ** argv) {
 
                 // open the file
                 ifstream atomList(c2.c_str());
-                
+
                 while (!atomList.eof()) {
                     char l[200000];
                     // read the next line
                     if (atomList.getline(l,199999)) {
                         // analyze
-                        std::stringstream line(l);                            
+                        std::stringstream line(l);
                         unsigned int id;
                         while ((line >> id)) {
                             Atom *a = pm->getAtom(id);
                             if (a)
                                 atom2->addStructureIfNotIn(a);
                         }
-                    }                    
+                    }
                 }
                 if (atom2->getNumberOfStructures()>0) {
                     cout << "-> found " << atom2->getNumberOfStructures() << " atoms in file " << c2 << endl;
-                }
-                else {
+                } else {
                     throw PMLAbortException("Cannot find any atoms in file " + c2);
                 }
-                
-            }
-            else  {
+
+            } else  {
                 // cpt2 is found, just get all atoms in it
-                for (unsigned int i=0; i<cpt2->getNumberOfCells();i++) {
+                for (unsigned int i=0; i<cpt2->getNumberOfCells(); i++) {
                     Cell *c=cpt2->getCell(i);
-                    for (unsigned int j=0;j<c->getNumberOfStructures();j++)
+                    for (unsigned int j=0; j<c->getNumberOfStructures(); j++)
                         atom2->addStructureIfNotIn(c->getStructure(j));
                 }
                 cout << "-> found " << atom2->getNumberOfStructures() << " atoms in component " << c2 << endl;
@@ -146,10 +142,10 @@ int main(int argc, char ** argv) {
 
             // create atom list of atoms in cell
             cout << "-> please wait while extracting from " << c1 << " (" << cpt1->getNumberOfCells() << " cells)..." << endl;
-    
+
             unsigned int ok=0;
             // check each cell and all atoms in the cell
-            for (unsigned int i=0; i<cpt1->getNumberOfCells();i++) {
+            for (unsigned int i=0; i<cpt1->getNumberOfCells(); i++) {
                 Cell *c = cpt1->getCell(i);
                 unsigned int j=0;
                 bool isOk = true;
@@ -161,7 +157,7 @@ int main(int argc, char ** argv) {
                     ok++;
                     // copy the cell
                     Cell *newCell = new Cell(pm,c->getType());
-                    for (unsigned int j=0;j<c->getNumberOfStructures(); j++)
+                    for (unsigned int j=0; j<c->getNumberOfStructures(); j++)
                         newCell->addStructureIfNotIn(c->getStructure(j));
                     extracted->addStructureIfNotIn(newCell);
                     //cout << '\r' << c->Structure::getName() << endl;
@@ -172,18 +168,17 @@ int main(int argc, char ** argv) {
 
             // add the new SC to the informative component
             pm->getInformativeComponents()->addSubComponent(extracted);
-    
+
             // save the result
             unsigned int pLast = filename.rfind(".");
             if (pLast != string::npos) {
                 filename.erase(pLast);
                 filename += "-extracted.pml";
-            }
-            else
+            } else
                 filename="extracted.pml";
-    
+
             cout << "-> please wait while saving " << filename << " " << endl;
-    
+
             ofstream outputFile(filename.c_str());
             pm->setName(pm->getName()+" "+c1+"/"+c2+" Extracted");
             // do not optimize output (do not touch cell and atom id)
