@@ -65,8 +65,7 @@ int main(int argc, char ** argv) {
     if (pLast != string::npos) {
         basename.erase(pLast);
         filename = basename + "-out.pml";
-    }
-    else
+    } else
         filename += "-out.pml";
     ofstream outputFile(filename.c_str());
     outputFile << "<!-- Created by genatoms (c) E Promayon, TIMC (c) 2005 -->" << endl;
@@ -82,7 +81,7 @@ int main(int argc, char ** argv) {
         // read position
         coordList >> x;
         if (coordList.good())
-          coordList >> y;
+            coordList >> y;
         if (coordList.good()) {
             coordList >> z;
             // write atom
@@ -99,34 +98,34 @@ int main(int argc, char ** argv) {
     // regions
     outputFile << "<exclusiveComponents>" << endl;
     outputFile << "<multiComponent name=\"Exclusive Components\">" << endl;
-/*    outputFile << "<structuralComponent name=\"Regions\" mass=\"1\" viscosityW=\"1\" >" << endl;
-    outputFile << "<cell>" << endl;
-    outputFile << "<cellProperties name=\"cell\" mode=\"NONE\" type=\"POLY_VERTEX\" materialType=\"elastic\" shapeW=\"300\" masterRegion=\"1\" incompressibility=\"0\" />" << endl;
-    outputFile << "<color r=\"0.8\" g=\"0.8\" b=\"0.2\" a=\"1.0\" />" << endl;
-    for (unsigned int i=1; i<=nVertices; i++)
-        outputFile << "<atomRef index=\"" << i <<  "\"/>" << endl;
-    outputFile << "</cell>" << endl;
-    outputFile << "</structuralComponent>" << endl;
-
-    // tetrahedra => elements (we can then convert the elements to neighborhood using the corresponding physicalmodel lib tool)
-    unsigned int nTetra;
-    nobox >> nTetra;
-
-    outputFile << "<structuralComponent name=\"Elements\"  mode=\"WIREFRAME_AND_SURFACE\" >" << endl;
-    outputFile << "<color r=\".95\" g=\"0.89\" b=\"0.63\" a=\"1.0\"/>" << endl;
-
-    int id;
-    for (unsigned int i=0;i<nTetra; i++) {
+    /*    outputFile << "<structuralComponent name=\"Regions\" mass=\"1\" viscosityW=\"1\" >" << endl;
         outputFile << "<cell>" << endl;
-        outputFile << "<cellProperties type=\"TETRAHEDRON\" />" << endl;
-        for (unsigned int j=0; j<4; j++) {
-            nobox >> id;
-            outputFile << "<atomRef index=\"" << id << "\" />" << endl;
-        }
+        outputFile << "<cellProperties name=\"cell\" mode=\"NONE\" type=\"POLY_VERTEX\" materialType=\"elastic\" shapeW=\"300\" masterRegion=\"1\" incompressibility=\"0\" />" << endl;
+        outputFile << "<color r=\"0.8\" g=\"0.8\" b=\"0.2\" a=\"1.0\" />" << endl;
+        for (unsigned int i=1; i<=nVertices; i++)
+            outputFile << "<atomRef index=\"" << i <<  "\"/>" << endl;
         outputFile << "</cell>" << endl;
-    }
+        outputFile << "</structuralComponent>" << endl;
 
-    outputFile << "</structuralComponent>" << endl;*/
+        // tetrahedra => elements (we can then convert the elements to neighborhood using the corresponding physicalmodel lib tool)
+        unsigned int nTetra;
+        nobox >> nTetra;
+
+        outputFile << "<structuralComponent name=\"Elements\"  mode=\"WIREFRAME_AND_SURFACE\" >" << endl;
+        outputFile << "<color r=\".95\" g=\"0.89\" b=\"0.63\" a=\"1.0\"/>" << endl;
+
+        int id;
+        for (unsigned int i=0;i<nTetra; i++) {
+            outputFile << "<cell>" << endl;
+            outputFile << "<cellProperties type=\"TETRAHEDRON\" />" << endl;
+            for (unsigned int j=0; j<4; j++) {
+                nobox >> id;
+                outputFile << "<atomRef index=\"" << id << "\" />" << endl;
+            }
+            outputFile << "</cell>" << endl;
+        }
+
+        outputFile << "</structuralComponent>" << endl;*/
     outputFile << "</multiComponent>" << endl;
     outputFile << "</exclusiveComponents>" << endl;
     outputFile << "<informativeComponents>" << endl;
