@@ -85,15 +85,15 @@ void genFromFile(string filename) {
             }
             cout << "<cellProperties type=\"";
             switch (atomRefs.size()) {
-                case 3:
-                    cout << "TRIANGLE";
-                    break;
-                case 4:
-                    cout << "QUAD";
-                    break;
-                default:
-                    cout << "POLY_VERTEX";
-                    break;
+            case 3:
+                cout << "TRIANGLE";
+                break;
+            case 4:
+                cout << "QUAD";
+                break;
+            default:
+                cout << "POLY_VERTEX";
+                break;
             }
             cout << "\"/>" << endl;
             for (unsigned int i=0; i<atomRefs.size(); i++)
@@ -118,16 +118,14 @@ void genFromIndex(unsigned int start, unsigned int end) {
 
 int main(int argc, char ** argv) {
     if (argc==3) {
-	    cout << "<!-- generating cell from indexes: " << argv[1] << " to " << argv[2] << " -->" << endl;
-	    genFromIndex(atoi(argv[1]), atoi(argv[2]));
-    }
-    else if (argc==2) {
-	    cout << "<!-- generating cell using " << argv[1] << " -->" << endl;
-	    genFromFile(argv[1]);
-    }
-    else {
-	    cout << argv[0] << ", usage:" << endl;
-	    cout << argv[0] << " [fileName | id_start id_end]" << endl;
+        cout << "<!-- generating cell from indexes: " << argv[1] << " to " << argv[2] << " -->" << endl;
+        genFromIndex(atoi(argv[1]), atoi(argv[2]));
+    } else if (argc==2) {
+        cout << "<!-- generating cell using " << argv[1] << " -->" << endl;
+        genFromFile(argv[1]);
+    } else {
+        cout << argv[0] << ", usage:" << endl;
+        cout << argv[0] << " [fileName | id_start id_end]" << endl;
     }
 
 }
