@@ -84,16 +84,16 @@ void processArg() {
     subdiv = atoi(argVal["-l"].c_str());
     shapeType = argVal["-t"];
     if (shapeType=="ico") {
-        for (unsigned int i=0;i<12;i++)
+        for (unsigned int i=0; i<12; i++)
             vertices.push_back(icosahedronVertex[i]);
-        for (unsigned int i=0;i<20;i++)
+        for (unsigned int i=0; i<20; i++)
             faces.push_back(icosahedronFace[i]);
     }
     if (shapeType=="cube") {
-        for (unsigned int i=0;i<8;i++) {
+        for (unsigned int i=0; i<8; i++) {
             vertices.push_back(cubeVertex[i]);
         }
-        for (unsigned int i=0;i<6;i++)
+        for (unsigned int i=0; i<6; i++)
             faces.push_back(cubeFace[i]);
     }
 }
@@ -108,8 +108,8 @@ void printArg() {
 Atom * newAtom(double posA[3]) {
     // look for a similar atom (similar position)
     StructuralComponent *atoms = pm->getAtoms();
-    bool found = false;    
-    unsigned int i=0; 
+    bool found = false;
+    unsigned int i=0;
     while (i<atoms->getNumberOfStructures() && !found) {
         double pos[3];
         ((Atom *)atoms->getStructure(i))->getPosition(pos);
@@ -119,11 +119,10 @@ Atom * newAtom(double posA[3]) {
     if (!found) {
         // new atom
         Atom *a = new Atom(pm, atomIndex, posA);
-        pm->addAtom(a); 
+        pm->addAtom(a);
         atomIndex++;
         return a;
-    }
-    else {
+    } else {
         return ((Atom *)atoms->getStructure(i-1));
     }
 }
@@ -147,7 +146,7 @@ void subdivide(Atom *a1, Atom *a2, Atom *a3, int depth) {
     a1->getPosition(v1);
     a2->getPosition(v2);
     a3->getPosition(v3);
-    
+
     if (depth == 0) {
         normalize(v1);
         a1->setPosition(v1);
@@ -155,7 +154,7 @@ void subdivide(Atom *a1, Atom *a2, Atom *a3, int depth) {
         a2->setPosition(v2);
         normalize(v3);
         a3->setPosition(v3);
-        
+
         // insert a new cell
         Cell *c = new Cell(NULL, StructureProperties::TRIANGLE);
 
@@ -167,8 +166,7 @@ void subdivide(Atom *a1, Atom *a2, Atom *a3, int depth) {
         // add the cell to the informative and exclusive component
         elemSC->addStructure(c);
 
-    } 
-    else {
+    } else {
         double v12[3], v23[3], v31[3];
         // midpoint
         for (unsigned int i = 0; i < 3; i++) {
@@ -203,7 +201,7 @@ void subdivide(Atom *a1, Atom *a2, Atom *a3, Atom *a4, int depth) {
     a2->getPosition(v2);
     a3->getPosition(v3);
     a4->getPosition(v4);
-    
+
     if (depth == 0) {
         normalize(v1);
         a1->setPosition(v1);
@@ -213,7 +211,7 @@ void subdivide(Atom *a1, Atom *a2, Atom *a3, Atom *a4, int depth) {
         a3->setPosition(v3);
         normalize(v4);
         a4->setPosition(v4);
-        
+
         // insert a new cell
         Cell *c = new Cell(NULL, StructureProperties::QUAD);
 
@@ -226,8 +224,7 @@ void subdivide(Atom *a1, Atom *a2, Atom *a3, Atom *a4, int depth) {
         // add the cell to the informative and exclusive component
         elemSC->addStructure(c);
 
-    } 
-    else {
+    } else {
         double v12[3], v23[3], v34[3], v41[3], vc[3];
         // midpoint
         for (unsigned int i = 0; i < 3; i++) {
@@ -282,7 +279,7 @@ int main(int argc, char ** argv) {
         atomIndex=0;
 
         // starts with the the initial shape
-        for (unsigned int i=0;i<vertices.size();i++) {
+        for (unsigned int i=0; i<vertices.size(); i++) {
             Atom *a = new Atom(pm, atomIndex, vertices[i]);
             atoms->addStructure(a);
             atomIndex++;
@@ -295,7 +292,7 @@ int main(int argc, char ** argv) {
         elemSC = new StructuralComponent(NULL, "Elements");
 
         // subdivide each face of the triangle
-        for (unsigned int i=0;i<faces.size();i++) {
+        for (unsigned int i=0; i<faces.size(); i++) {
             if (shapeType=="ico") {
                 subdivide(pm->getAtom(faces[i][0]),
                           pm->getAtom(faces[i][1]),
