@@ -51,7 +51,7 @@ int main(int argc, char ** argv) {
     if (argc!=3 && argc!=4) {
         cout << "Usage:" << endl;
         cout << "\t" << argv[0] << " file.pml \"component\"" << endl;
-        cout << "\tRevert inside/out a given component, i.e. turn TRIANGLE and QUAD facet orientation inside/out or outside/in, output to: file-insideout.pml" << endl;        
+        cout << "\tRevert inside/out a given component, i.e. turn TRIANGLE and QUAD facet orientation inside/out or outside/in, output to: file-insideout.pml" << endl;
         cout << "PML " << PhysicalModel::VERSION << endl;
         exit(-1);
     }
@@ -76,45 +76,44 @@ int main(int argc, char ** argv) {
             throw PMLAbortException("Component \"" + c +"\" is not a Structural Component");
         }
         StructuralComponent *sc=(StructuralComponent *) cpt;
-        if (sc->composedBy()!=StructuralComponent::CELLS || sc->getNumberOfStructures()==0 || (sc->getCell(0)->getType()!=StructureProperties::TRIANGLE && 
-        sc->getCell(0)->getType()!=StructureProperties::QUAD)) {
+        if (sc->composedBy()!=StructuralComponent::CELLS || sc->getNumberOfStructures()==0 || (sc->getCell(0)->getType()!=StructureProperties::TRIANGLE &&
+                sc->getCell(0)->getType()!=StructureProperties::QUAD)) {
             throw PMLAbortException("Component \"" + c + "\": cannot revert component: does not contains any cell geometric type TRIANGLE or QUAD");
         }
 
         //  Transform "inplace"
-        for (unsigned int i=0; i<cpt->getNumberOfCells();i++) {
+        for (unsigned int i=0; i<cpt->getNumberOfCells(); i++) {
             Cell *c=cpt->getCell(i);
-            if (c->getType()==StructureProperties::TRIANGLE 
-                || c->getType()==StructureProperties::QUAD) {
+            if (c->getType()==StructureProperties::TRIANGLE
+                    || c->getType()==StructureProperties::QUAD) {
                 // copy structures
                 vector <Structure *> copy;
-                for (unsigned int j=0;j<c->getNumberOfStructures();j++) {
+                for (unsigned int j=0; j<c->getNumberOfStructures(); j++) {
                     copy.push_back(c->getStructure(j));
                 }
                 c->deleteAllStructures();
                 // invert
-                for (int j=copy.size()-1;j>=0;j--) {
+                for (int j=copy.size()-1; j>=0; j--) {
                     c->addStructure(copy[j]);
                 }
-            }            
+            }
         }
-    
+
         // save the result
         unsigned int pLast = filename.rfind(".");
         if (pLast != string::npos) {
             filename.erase(pLast);
             filename += "-insideout.pml";
-        }
-        else
+        } else
             filename="insideout.pml";
-    
+
         cout << "-> please wait while saving " << filename << " " << endl;
-        
+
         ofstream outputFile(filename.c_str());
         pm->setName(pm->getName()+" reverted " + c);
         // do not optimize output (do not touch cell and atom id)
         pm->xmlPrint(outputFile, false);
-    
+
         delete pm;
 
     } catch(PMLAbortException ae) {
