@@ -25,7 +25,7 @@
 //
 // C++ Implementation: nobox2pml
 //
-// Description: 
+// Description:
 // WARNING: this is NOT a direct .noboite to PML translator !!!
 // the first argument is the name of a file (the nobox file) that you will have to arrange manually from the noboite.
 // The nobox format is as follow :
@@ -298,8 +298,7 @@ int main(int argc, char ** argv) {
     if (pLast != string::npos) {
         filename.erase(pLast);
         filename += "-out.pml";
-    }
-    else
+    } else
         filename += "-out.pml";
     ofstream outputFile(filename.c_str());
     outputFile << "<!-- Created by npbox2pml (c) E Promayon, TIMC (c) 1997-2005 -->" << endl;
@@ -347,7 +346,7 @@ int main(int argc, char ** argv) {
     outputFile << "<color r=\".95\" g=\"0.89\" b=\"0.63\" a=\"1.0\"/>" << endl;
 
     int id;
-    for (unsigned int i=0;i<nTetra; i++) {
+    for (unsigned int i=0; i<nTetra; i++) {
         outputFile << "<cell>" << endl;
         outputFile << "<cellProperties type=\"TETRAHEDRON\" />" << endl;
         for (unsigned int j=0; j<4; j++) {
