@@ -44,8 +44,8 @@ typedef struct {
     string directive;
     string data;
     bool ok;
-} ObjLine;    
-    
+} ObjLine;
+
 ObjLine currentLine;
 
 // -------------------- getNext ------------------------
@@ -54,13 +54,13 @@ void getNext() {
     char l[200];
     string line;
     currentLine.ok = false;
-    
+
     while (!eof && !currentLine.ok) {
         eof = !(objStream.getline(l,199));
         lineNr++;
-        if (l[0]!='#') {    
+        if (l[0]!='#') {
             line = l;
-            
+
             unsigned int space = line.find(' ');
             if (space != string::npos && space != 0) {
                 currentLine.directive = line.substr(0,space);
@@ -69,15 +69,15 @@ void getNext() {
             }
         }
     }
-    
+
 }
 
 // -------------------- getVector ------------------------
 // get the double 3D vector in the current data
 void getVector(double d[3]) {
     stringstream data(currentLine.data, std::stringstream::in);
-    
-    for (unsigned int i=0;i<3;i++)
+
+    for (unsigned int i=0; i<3; i++)
         data >> d[i];
 }
 
@@ -87,14 +87,14 @@ void getVector(double d[3]) {
 unsigned int getFacetType() {
     int count=0;
     unsigned int space = 0;
-    
+
     do {
-	space = currentLine.data.find(' ', space+1);
+        space = currentLine.data.find(' ', space+1);
         if (space != string::npos)
             count++;
     } while (space != string::npos);
-    
-    return count+1; 
+
+    return count+1;
 }
 
 // -------------------- getVertex ------------------------
@@ -102,12 +102,12 @@ unsigned int getFacetType() {
 void getVertex(unsigned int size, int v[]) {
     stringstream data(currentLine.data, std::stringstream::in);
     string buff;
-    
-    for (unsigned int i=0;i<size;i++) {
+
+    for (unsigned int i=0; i<size; i++) {
         data >> buff; // buff is of the form "4/4" or "2/33/32" or "4"
         unsigned int slash = buff.find('/');
         //if (slash != string::npos) {
-            v[i] = atoi(buff.substr(0,slash).c_str());
+        v[i] = atoi(buff.substr(0,slash).c_str());
         //}
     }
 }
@@ -118,15 +118,15 @@ StructuralComponent * vertexToAtoms() {
     StructuralComponent * atoms = new StructuralComponent(NULL, "Atoms");
     double pos[3];
     unsigned int atomIndex;
-    
+
     // very important: start at 1 to have the same index system
     atomIndex=1;
-    
+
     // go to the first v directive
     while (!eof && currentLine.directive!="v") {
         getNext();
     }
-    
+
     do {
         if (currentLine.ok && currentLine.directive=="v") {
             getVector(pos);
@@ -136,7 +136,7 @@ StructuralComponent * vertexToAtoms() {
     } while (!eof);
 
     cout << "Found atom #1 to #" << atomIndex << endl;
-    
+
     return atoms;
 }
 
@@ -146,18 +146,18 @@ void facetsToSC(MultiComponent *mother) {
     int * vertex;
     Cell *c;
     unsigned int type;
-        
+
     // go to the first f directive
     while (!eof && currentLine.directive!="f" && currentLine.directive!="g" && currentLine.directive!="o") {
         getNext();
     }
-    
+
     // process f directives
     do {
         if (currentLine.ok && (currentLine.directive=="g" || currentLine.directive=="o")) {
             // insert the current group if exists
             if (group->getNumberOfStructures()>0)
-                mother->addSubComponent(group);                
+                mother->addSubComponent(group);
             // create a new group
             group = new StructuralComponent(NULL, currentLine.data);
         }
@@ -165,39 +165,39 @@ void facetsToSC(MultiComponent *mother) {
             // create cell depending on type
             type = getFacetType();
             switch (type) {
-                case 3:
-                    c = new Cell(NULL, StructureProperties::TRIANGLE);
-                    break;
-                case 4:
-                    c = new Cell(NULL, StructureProperties::QUAD);
-                    break;
-                default:
-                    c=NULL;
-                    cerr << "line " << lineNr << ": error: cannot manage facet using " << type << " vertices" << endl;
-                    break;
+            case 3:
+                c = new Cell(NULL, StructureProperties::TRIANGLE);
+                break;
+            case 4:
+                c = new Cell(NULL, StructureProperties::QUAD);
+                break;
+            default:
+                c=NULL;
+                cerr << "line " << lineNr << ": error: cannot manage facet using " << type << " vertices" << endl;
+                break;
             }
-    
+
             if (c!=NULL) {
                 // get atom indexes
                 vertex = new int[type];
                 getVertex(type, vertex);
-                
+
                 // add atoms
-                for (unsigned int i=0;i<type;i++) {
+                for (unsigned int i=0; i<type; i++) {
                     Atom *a = pm->getAtom(vertex[i]);
                     if (a!=NULL)
                         c->addStructure(a);
                     else
                         cerr << "line " << lineNr << ": error: cannot find vertex #" << vertex[i] << endl;
                 }
-                
+
                 // add facet to current group
                 group->addStructure(c);
-                
-                delete [] vertex;                
+
+                delete [] vertex;
             }
         }
-                        
+
         // go to the next directive
         getNext();
     } while (!eof);
@@ -206,7 +206,7 @@ void facetsToSC(MultiComponent *mother) {
     if (group->getNumberOfStructures()>0)
         mother->addSubComponent(group);
 
-    cout << "Found " << mother->getNumberOfSubComponents() << " groups, total " << mother->getNumberOfCells() << " facets" << endl;    
+    cout << "Found " << mother->getNumberOfSubComponents() << " groups, total " << mother->getNumberOfCells() << " facets" << endl;
 }
 
 // -------------------- init ------------------------
@@ -229,41 +229,40 @@ int main(int argc, char ** argv) {
     }
 
     try {
-        
+
         // open the obj file
-        string filename(argv[1]);               
+        string filename(argv[1]);
         objStream.open(filename.c_str());
         if (!objStream.is_open()) {
             cerr << "Error: cannot open file " << filename << endl;
             exit(1);
         }
         init();
-            
+
         // create a new physical model
-        pm = new PhysicalModel();        
+        pm = new PhysicalModel();
         pm->setName("PML for " + filename);
-        
+
         // first pass: read the vertex, and build atoms
         pm->setAtoms(vertexToAtoms());
-        
+
         // rewind
         objStream.clear(); // clear the ios::eof flag, etc...
         objStream.seekg(0,ios::beg); // rewind
         init();
-        
+
         // second pass: read the facets and build the corresponding SC
         pm->setExclusiveComponents(new MultiComponent(NULL, "Exclusive Components"));
         facetsToSC(pm->getExclusiveComponents());
         // close input
         objStream.close();
-                
+
         // save the result in the pml file
         unsigned int pLast = filename.rfind(".");
         if (pLast != string::npos) {
             filename.erase(pLast);
             filename += ".pml";
-        }
-        else
+        } else
             filename += ".pml";
         ofstream outputFile(filename.c_str());
         pm->xmlPrint(outputFile);
