@@ -48,13 +48,13 @@ double precision;
 unsigned int nrOfNewAtoms;
 
 /** class Cluster
- * 
+ *
  *  a cluster is a set of point that are nearly at the same place (at a given precision)
  */
 class Cluster {
 public:
     /// create a cluster of this atom, using the given precision
-    Cluster(double distance); 
+    Cluster(double distance);
 
     ~Cluster();
 
@@ -63,7 +63,7 @@ public:
 
     /// add an atom to the cluster if in the given precision (true if added) (update center)
     bool addAtom(Atom *);
-    
+
     /// get the center (create if necessary)
     Atom * getCenter();
 
@@ -72,7 +72,7 @@ public:
 
     /// current atom index for new atoms
     static unsigned int atomIndex;
-    
+
 private:
     /// cluster center
     Atom *center;
@@ -111,16 +111,16 @@ void Cluster::updateCenter() {
     double posC[3];
     unsigned int size = myCell->getNumberOfStructures();
 
-    for (unsigned int j=0;j<3;j++)
+    for (unsigned int j=0; j<3; j++)
         posC[j] = 0.0;
 
-    for (unsigned int i=0;i<size;i++) {
+    for (unsigned int i=0; i<size; i++) {
         ((Atom *)myCell->getStructure(i))->getPosition(pos);
-        for (unsigned int j=0;j<3;j++)
+        for (unsigned int j=0; j<3; j++)
             posC[j] += pos[j];
     }
 
-    for (unsigned int j=0;j<3;j++)
+    for (unsigned int j=0; j<3; j++)
         posC[j] /= ((double)size);
 
     center->setPosition(posC);
@@ -148,7 +148,7 @@ bool Cluster::addAtom(Atom *a) {
     double pos[3];
     a->getPosition(pos);
     double dist = 0.0;
-    for (unsigned int i=0;i<3;i++)
+    for (unsigned int i=0; i<3; i++)
         dist += (posC[i]-pos[i])*(posC[i]-pos[i]);
     dist = sqrt(dist);
 
@@ -156,8 +156,7 @@ bool Cluster::addAtom(Atom *a) {
         myCell->addStructure(a);
         updateCenter();
         return true;
-    }
-    else {
+    } else {
         return false;
     }
 }
@@ -167,23 +166,22 @@ bool Cluster::addAtom(Atom *a) {
 Cluster * insert(Atom *a) {
     vector <Cluster *>::iterator it;
 
-    // look into allClusters for equivalence   
+    // look into allClusters for equivalence
     it = allClusters.begin();
     while (it!=allClusters.end() && !(*it)->addAtom(a))
         it++;
 
     // not found => insert
     if (it==allClusters.end()) {
-        // no cluster found: create a new one 
+        // no cluster found: create a new one
         Cluster *c = new Cluster(precision);
         c->addAtom(a);
         allClusters.push_back(c);
         return c;
-    }
-    else  {
+    } else  {
         return (*it);
     }
-    
+
 }
 
 // -------------------- update ------------------------
@@ -192,18 +190,18 @@ void update(MultiComponent *mc) {
         cout << "0 cells)" << endl;
         return;
     }
-    
+
     cout << mc->getNumberOfCells() << " cells)" << endl;
     unsigned int degeneratedCount=0;
 
     // WARNING non-rentrant loop
-    for (unsigned int i=0;i<mc->getNumberOfCells();i++) {
+    for (unsigned int i=0; i<mc->getNumberOfCells(); i++) {
         Cell *c = mc->getCell(i);
         StructuralComponent *sc = c->getAtoms();
         c->deleteAllStructures();
         cout << '\r' << i << flush;
         // remove previous list
-        for (unsigned int j=0;j<sc->getNumberOfStructures();j++) {
+        for (unsigned int j=0; j<sc->getNumberOfStructures(); j++) {
             c->removeStructure(sc->getStructure(j));
         }
         // check it was done properly
@@ -212,29 +210,28 @@ void update(MultiComponent *mc) {
         }
         // add new atoms
         map<Atom *, Atom *>::iterator proxy;
-        for (unsigned int j=0;j<sc->getNumberOfStructures();j++) {
+        for (unsigned int j=0; j<sc->getNumberOfStructures(); j++) {
             proxy = replacement.find((Atom *)sc->getStructure(j));
             if (proxy==replacement.end()) {
                 // not found?!
                 cout << "Cell #" << c->getIndex() << " cannot find replacement for Atom#" << sc->getStructure(i)->getIndex() << endl;
-            }
-            else {
+            } else {
                 c->addStructureIfNotIn(proxy->second);
             }
         }
         // check that the cell did not degenerate
         StructureProperties::GeometricType t = c->getType();
         int normalSize = ((t == StructureProperties::LINE)?2:
-                         ((t == StructureProperties::TRIANGLE)?3:
-                         ((t == StructureProperties::QUAD)?4:
-                         ((t == StructureProperties::TETRAHEDRON)?4:
-                         ((t == StructureProperties::WEDGE)?6:
-                         ((t == StructureProperties::HEXAHEDRON)?8:-1))))));
+                          ((t == StructureProperties::TRIANGLE)?3:
+                           ((t == StructureProperties::QUAD)?4:
+                            ((t == StructureProperties::TETRAHEDRON)?4:
+                             ((t == StructureProperties::WEDGE)?6:
+                              ((t == StructureProperties::HEXAHEDRON)?8:-1))))));
         if (normalSize!=-1 && normalSize!=(int)c->getNumberOfStructures()) {
             cout << "deleting degenerated Cell #" << c->getIndex() << ": it is a " <<
-            StructureProperties::toString(t) << " and should have " << normalSize << 
-            " atoms, but has now " << c->getNumberOfStructures() << flush;
-	    degeneratedCount++;
+                 StructureProperties::toString(t) << " and should have " << normalSize <<
+                 " atoms, but has now " << c->getNumberOfStructures() << flush;
+            degeneratedCount++;
             c->getStructuralComponent(0)->removeStructure(c);
             // a cell was deleted, as it is a non re-entrant loop, get back one index
             i--;
@@ -248,24 +245,22 @@ void update(MultiComponent *mc) {
 void saveClusters(string clusterFile) {
     stringstream clusterOSS;
     clusterOSS << precision;
-    
+
 
     string nonClusterFile = clusterFile;
     unsigned int pLast = clusterFile.rfind(".");
-    
+
     if (pLast != string::npos) {
         clusterFile.erase(pLast);
         clusterFile += "-clusters-" + clusterOSS.str() + ".txt";
-    }
-    else
+    } else
         clusterFile="clusters-" + clusterOSS.str() + ".txt";
-   
+
     pLast = nonClusterFile.rfind(".");
     if (pLast != string::npos) {
         nonClusterFile.erase(pLast);
         nonClusterFile += "-non-clusters-" + clusterOSS.str() + ".txt";
-    }
-    else
+    } else
         nonClusterFile = "non-clusters-" + clusterOSS.str() + ".txt";
 
     cout << "-> please wait while saving cluster informations in " << clusterFile << " (" << pm->getNumberOfAtoms() - allClusters.size() << " clusters) and non-clusters in " << nonClusterFile << endl;
@@ -274,11 +269,10 @@ void saveClusters(string clusterFile) {
     for (vector <Cluster *>::iterator it = allClusters.begin(); it!=allClusters.end(); it++) {
         if ((*it)->nrOfAtoms()>1) {
             clusterOutputFile << (*it)->getCenter()->getIndex() << " : ";
-            for (unsigned int i=0;i<(*it)->nrOfAtoms();i++)
-            clusterOutputFile << (*it)->getAtom(i)->getIndex() << " ";
-            clusterOutputFile << endl; 
-        }
-        else {
+            for (unsigned int i=0; i<(*it)->nrOfAtoms(); i++)
+                clusterOutputFile << (*it)->getAtom(i)->getIndex() << " ";
+            clusterOutputFile << endl;
+        } else {
             nonClusterOutputFile << (*it)->getAtom(0)->getIndex() << endl;
         }
     }
@@ -291,9 +285,9 @@ void optimize(string clusterFile) {
     StructuralComponent *atoms = pm->getAtoms();
 
     // create clusters
-    for (unsigned int i=0;i<atoms->getNumberOfStructures();i++) {
+    for (unsigned int i=0; i<atoms->getNumberOfStructures(); i++) {
         insert((Atom *) atoms->getStructure(i));
-        cout << '\r' <<  i << flush; 
+        cout << '\r' <<  i << flush;
     }
     cout << endl;
 
@@ -307,11 +301,10 @@ void optimize(string clusterFile) {
         if ((*it)->nrOfAtoms()==1) {
             newAtoms->addStructure((*it)->getAtom(0));
             replacement.insert(pair<Atom*,Atom*>((*it)->getAtom(0), (*it)->getAtom(0)));
-        }
-        else {
+        } else {
             newAtoms->addStructure((*it)->getCenter());
             // memorize replacements
-            for (unsigned int i=0;i<(*it)->nrOfAtoms();i++) {
+            for (unsigned int i=0; i<(*it)->nrOfAtoms(); i++) {
                 replacement.insert(pair<Atom*,Atom*>((*it)->getAtom(i), (*it)->getCenter()));
             }
         }
@@ -351,9 +344,9 @@ int main(int argc, char ** argv) {
 
         cout << "-> please wait while optimizing " << pm->getNumberOfAtoms() << " atoms..." << endl;
 
-        optimize(filename); 
-        /* 
-       // now, we have the right component, let's do some work...
+        optimize(filename);
+        /*
+        // now, we have the right component, let's do some work...
         nrOfNewAtoms = 0;
         StructuralComponent * refined = refine(sc);
 
@@ -369,8 +362,7 @@ int main(int argc, char ** argv) {
         if (pLast != string::npos) {
             filename.erase(pLast);
             filename += "-optimized-" + clusterOSS.str() + ".pml";
-        }
-        else
+        } else
             filename="optimized-" + clusterOSS.str() + ".pml";
 
         cout << "-> please wait while saving " << filename << " (" << nrOfNewAtoms << " new atoms)" << endl;
