@@ -49,7 +49,7 @@ bool isIn(StructuralComponent *sc, Atom *a) {
 // Code inspired from ProgVals "Thinking in C++, 2nd Edition, Volume 2", chapter 4
 // by Bruce Eckel & Chuck Allison, (c) 2001 MindView, Inc.
 // Available at www.BruceEckel.com.
-// Program values can be changed by command lineclass ProgVals 
+// Program values can be changed by command lineclass ProgVals
 #include <map>
 #include <iostream>
 #include <string>
@@ -57,9 +57,9 @@ bool isIn(StructuralComponent *sc, Atom *a) {
 class ProgramArg : public std::map<std::string, std::string> {
 public:
     ProgramArg(std::string defaults[][2], unsigned int sz) {
-        for(unsigned int i=0;i<sz;i++) insert(pair(defaults[i][0], defaults[i][1]));
+        for(unsigned int i=0; i<sz; i++) insert(pair(defaults[i][0], defaults[i][1]));
     };
-    
+
     void parse(int argc, char* argv[], std::string usage, int offset = 1) {
         for(int i = offset; i < argc; i++) {
             string flag(argv[i]);
@@ -77,7 +77,7 @@ public:
             operator[](name) = value;
         }
     };
-    
+
     void print(std::ostream& out = std::cout) {
         out << "Argument values:" << endl;
         for(iterator it = begin(); it != end(); it++)
@@ -86,21 +86,21 @@ public:
 };
 
 string defaultsArg[][2] = {
-  { "-f", "" },
-  { "-select", "" },
-  { "-o", ""},
-  { "-d", "comma"},
+    { "-f", "" },
+    { "-select", "" },
+    { "-o", ""},
+    { "-d", "comma"},
 };
 
 const char* usage = "usage:\n"
-"pml2csv -f=file.pml [-select=name] [-o=output.csv] [-d=space]\n"
-"(Note no space around '=')\n"
-"Where the flags can be any of: \n"
-"-f the input pml document\n"
-"-select the name of the structural component or cell to export as csv\n"
-"        (default = all atoms)\n"
-"-o name of the csv output file (default=file.csv)\n"
-"-d demiter can be either 'space' or 'comma' (default is 'comma')\n";
+                    "pml2csv -f=file.pml [-select=name] [-o=output.csv] [-d=space]\n"
+                    "(Note no space around '=')\n"
+                    "Where the flags can be any of: \n"
+                    "-f the input pml document\n"
+                    "-select the name of the structural component or cell to export as csv\n"
+                    "        (default = all atoms)\n"
+                    "-o name of the csv output file (default=file.csv)\n"
+                    "-d demiter can be either 'space' or 'comma' (default is 'comma')\n";
 
 // global ProgramArgument
 ProgramArg argVal(defaultsArg, sizeof defaultsArg / sizeof *defaultsArg);
@@ -129,15 +129,13 @@ void processArg() {
         if (pLast != string::npos) {
             output.erase(pLast);
             output += ".csv";
-        }
-        else
-            output="pml2csv-output.csv";    
+        } else
+            output="pml2csv-output.csv";
     }
 
     if (argVal["-d"]=="space") {
         separator=' ';
-    }
-    else {
+    } else {
         separator=',';
     }
 
@@ -148,8 +146,7 @@ void printArg() {
     cout << "pml2csv is converting ";
     if (selected!="") {
         cout << "component/cell " << selected;
-    }
-    else {
+    } else {
         cout << "all atoms";
     }
     cout << " of " << filename << " to CSV file " << output << " (delimiter is " << separator << ")"<< endl;
@@ -161,7 +158,7 @@ int main(int argc, char ** argv) {
     // before any code that uses pvals is called:
     argVal.parse(argc, argv, usage);
     //argVal.print();
-    
+
     processArg();
     printArg();
 
@@ -179,8 +176,7 @@ int main(int argc, char ** argv) {
         if (selected=="") {
             cout << "all atoms" << endl;
             atoms = pm->getAtoms();
-        }
-        else {
+        } else {
             cout << selected << endl;
             cpt = pm->getComponentByName(selected);
             if (!cpt) {
@@ -188,8 +184,7 @@ int main(int argc, char ** argv) {
                 Structure *s = pm->getStructureByName(selected);
                 if (s && s->isInstanceOf("Cell")) {
                     cellCpt = (Cell*) s;
-                }
-                else
+                } else
                     throw PMLAbortException("No components/cells named " + selected);
             }
         }
@@ -197,25 +192,22 @@ int main(int argc, char ** argv) {
         // now extract all atoms
         StructuralComponent *selectedAtoms = new StructuralComponent(NULL, "selected atoms");
         if (atoms) {
-            for (unsigned int j=0;j<atoms->getNumberOfStructures();j++)
-                selectedAtoms->addStructureIfNotIn(atoms->getStructure(j));            
-        }
-        else if (cpt) {
+            for (unsigned int j=0; j<atoms->getNumberOfStructures(); j++)
+                selectedAtoms->addStructureIfNotIn(atoms->getStructure(j));
+        } else if (cpt) {
             if (cpt->isInstanceOf("StructuralComponent") && ((StructuralComponent *)cpt)->composedBy()==StructuralComponent::CELLS) {
-                for (unsigned int i=0; i<cpt->getNumberOfCells();i++) {
+                for (unsigned int i=0; i<cpt->getNumberOfCells(); i++) {
                     Cell *c=cpt->getCell(i);
-                    for (unsigned int j=0;j<c->getNumberOfStructures();j++)
+                    for (unsigned int j=0; j<c->getNumberOfStructures(); j++)
                         selectedAtoms->addStructureIfNotIn(c->getStructure(j));
                 }
-            }
-            else {
+            } else {
                 StructuralComponent *sc=(StructuralComponent *)cpt;
-                for (unsigned int j=0;j<sc->getNumberOfStructures();j++)
-                    selectedAtoms->addStructureIfNotIn(sc->getStructure(j));            
+                for (unsigned int j=0; j<sc->getNumberOfStructures(); j++)
+                    selectedAtoms->addStructureIfNotIn(sc->getStructure(j));
             }
-        }
-        else {
-            for (unsigned int j=0;j<cellCpt->getNumberOfStructures();j++)
+        } else {
+            for (unsigned int j=0; j<cellCpt->getNumberOfStructures(); j++)
                 selectedAtoms->addStructureIfNotIn(cellCpt->getStructure(j));
         }
         cout << "-> found " << selectedAtoms->getNumberOfStructures() << " atoms to export as CSV" << endl;
@@ -231,7 +223,7 @@ int main(int argc, char ** argv) {
             outputFile << a->getIndex() << separator << pos[0] << separator << pos[1] << separator << pos[2] << endl;
         }
         outputFile.close();
-        
+
     } catch(PMLAbortException ae) {
         cout << "AbortException: Physical model aborted:" << endl ;
         cout << ae.what() << endl;
