@@ -41,7 +41,7 @@ bool reorder;
 // Code inspired from ProgVals "Thinking in C++, 2nd Edition, Volume 2", chapter 4
 // by Bruce Eckel & Chuck Allison, (c) 2001 MindView, Inc.
 // Available at www.BruceEckel.com.
-// Program values can be changed by command lineclass ProgVals 
+// Program values can be changed by command lineclass ProgVals
 #include <map>
 #include <iostream>
 #include <string>
@@ -49,9 +49,9 @@ bool reorder;
 class ProgramArg : public std::map<std::string, std::string> {
 public:
     ProgramArg(std::string defaults[][2], unsigned int sz) {
-        for(unsigned int i=0;i<sz;i++) insert(pair(defaults[i][0], defaults[i][1]));
+        for(unsigned int i=0; i<sz; i++) insert(pair(defaults[i][0], defaults[i][1]));
     };
-    
+
     void parse(int argc, char* argv[], std::string usage, int offset = 1) {
         for(int i = offset; i < argc; i++) {
             string flag(argv[i]);
@@ -69,7 +69,7 @@ public:
             operator[](name) = value;
         }
     };
-    
+
     void print(std::ostream& out = std::cout) {
         out << "Argument values:" << endl;
         for(iterator it = begin(); it != end(); it++)
@@ -78,17 +78,17 @@ public:
 };
 
 string defaultsArg[][2] = {
-  { "-f", "none" },
-  { "-o", "pml2ghs3d-output.mesh" },
-  { "-reorder", "false"},
+    { "-f", "none" },
+    { "-o", "pml2ghs3d-output.mesh" },
+    { "-reorder", "false"},
 };
 
 const char* usage = "usage:\n"
-"pml2ghs3d -f=document.pml [-o=output] [-reorder=false]\n"
-"Transform a PML document containing an 'Elements' (list of triangles) exclusive structural component to a .mesh (readable in GHS3D), and reorder the index if reorder is true (needed if atom id are not successive number)\n"
-"(Note no space around '=')\n"
-"Where the flags can be any of: \n"
-"f (input pml document), o (output .mesh file name), reorder (true or false, default is false) \n";
+                    "pml2ghs3d -f=document.pml [-o=output] [-reorder=false]\n"
+                    "Transform a PML document containing an 'Elements' (list of triangles) exclusive structural component to a .mesh (readable in GHS3D), and reorder the index if reorder is true (needed if atom id are not successive number)\n"
+                    "(Note no space around '=')\n"
+                    "Where the flags can be any of: \n"
+                    "f (input pml document), o (output .mesh file name), reorder (true or false, default is false) \n";
 
 // global ProgramArgument
 ProgramArg argVal(defaultsArg, sizeof defaultsArg / sizeof *defaultsArg);
@@ -118,12 +118,12 @@ int main(int argc, char ** argv) {
     // before any code that uses pvals is called:
     argVal.parse(argc, argv, usage);
     //argVal.print();
-    
+
     processArg();
     printArg();
-    
+
     try {
-        pm = new PhysicalModel(pmlFile.c_str());    
+        pm = new PhysicalModel(pmlFile.c_str());
 
         //-- create the .mesh
         std::ofstream meshStream;
@@ -147,7 +147,7 @@ int main(int argc, char ** argv) {
         meshStream.setf(ios::fixed, ios::floatfield); // set fixed floating format
         meshStream.precision(6);
         map<unsigned int,unsigned int> atomIdToNodeId;
-        for (unsigned int i=0;i<sc->getNumberOfStructures();i++) {
+        for (unsigned int i=0; i<sc->getNumberOfStructures(); i++) {
             a = (Atom *) sc->getStructure(i);
             a->getPosition(pos);
             meshStream << "\t\t" << pos[0] << "   " << pos[1] << "       \t\t\t " << pos[2] << "                     0\t\t\t\t\t\t" << endl;
@@ -163,13 +163,13 @@ int main(int argc, char ** argv) {
             cerr << "Cannot find any component named \"Elements\". Exiting" << endl;
             exit(-1);
         }
-        
+
         // check if it is a correct one
         if (!cpt->isExclusive() || !cpt->isInstanceOf("StructuralComponent")) {
             cerr << "Cannot translate the \"Elements\" component: not exclusive or not a structural component. Exiting" << endl;
             exit(-2);
         }
-        
+
         // check if c is made of hexahedron
         sc = (StructuralComponent *) cpt;
         if (sc->composedBy()!=StructuralComponent::CELLS || sc->getNumberOfStructures()==0 || (sc->getCell(0)->getType()!=StructureProperties::TRIANGLE)) {
@@ -182,7 +182,7 @@ int main(int argc, char ** argv) {
 
         Cell *c;
         map<unsigned int,unsigned int>::iterator result;
-        for (unsigned int i=0;i<sc->getNumberOfStructures();i++) {
+        for (unsigned int i=0; i<sc->getNumberOfStructures(); i++) {
             c = (Cell *) sc->getCell(i);
             if (c->getType()==StructureProperties::TRIANGLE) {
                 if (!reorder) {
@@ -190,15 +190,13 @@ int main(int argc, char ** argv) {
                                 << c->getStructure(1)->getIndex()+1 << " "
                                 << c->getStructure(2)->getIndex()+1
                                 << " 1" << endl;
-                }
-                else {
-                    for (unsigned int j=0;j<3;j++) {
+                } else {
+                    for (unsigned int j=0; j<3; j++) {
                         result=atomIdToNodeId.find(c->getStructure(j)->getIndex());
                         if (result==atomIdToNodeId.end()) {
                             cerr << "Cell #" << c->getIndex() << ": cannot find atom#" << c->getStructure(j)->getIndex() << " in the map. Exiting." << endl;
                             exit(-4);
-                        }
-                        else {
+                        } else {
                             meshStream  << result->second << " ";
                         }
                     }
