@@ -113,7 +113,7 @@ void processParam(int argc, char **argv) {
 void printParam() {
     cout << pgmName << " generating " << wrlFile << " from " << pmlFile;
     cout << " using components ";
-    for (unsigned int i=0;i<componentNames.size();i++)
+    for (unsigned int i=0; i<componentNames.size(); i++)
         cout << componentNames[i] << "," ;
     cout << endl;
 }
@@ -156,7 +156,7 @@ void printCoordinates(Cell *c) {
         }
     }
 
-        // Warning:the axes are differents with Blender
+    // Warning:the axes are differents with Blender
 //        outputFile << "\t" << "\t" << "\t" << "\t" << pos[0] << " " << pos[2] << " " << pos[1] << "," << endl;
 
 }
@@ -173,8 +173,7 @@ void printSurfaces(Cell *c) {
         it = rankA.find(c->getStructure(k)->getIndex());
         if (it==rankA.end()) {
             cout << "ERROR c#" << c->getIndex() << ": cannot find Atom#" << c->getStructure(0)->getIndex() << endl;
-        }
-        else {
+        } else {
             outputFile << it->second << ", ";
         }
     }
@@ -184,49 +183,49 @@ void printSurfaces(Cell *c) {
 
 // ------------------------ Prologue for VRML2 ---------------------------
 void vrml2Prologue() {
-            outputFile << "# pml2wrl" << endl;
-            outputFile << "    Background {\n"
-"      skyColor [1.000000 1.000000 1.000000, ]\n"
-"    }\n"
-"    Viewpoint {\n"
-"      fieldOfView 0.523599\n"
-"      position 222.803372 287.424506 199.848172\n"
-"      description \"Default View\"\n"
-"      orientation 0.590285 -0.769274 -0.244504 0.987861\n"
-"    }\n"
-"    NavigationInfo {\n"
-"      type [\"EXAMINE\",\"FLY\"]\n"
-"      speed 4.000000\n"
-"      headlight FALSE"
-"     }\n"
-"\n"
-"    DirectionalLight { ambientIntensity 1 intensity 0 # ambient light\n"
-"      color 1.000000 1.000000 1.000000 }\n"
-"\n"
-"    DirectionalLight {\n"
-"      direction -0.577350 -0.577350 -0.577350\n"
-"      color 1.000000 1.000000 1.000000\n"
-"      intensity 1.000000\n"
-"      on TRUE\n"
-"      }\n"
-"    Transform {\n"
-"      translation 0 0 0\n"
-"      rotation 0 0 1 0\n"
-"      scale 1 1 1\n"
-"      children [\n"
-"        Shape {\n"
-"          appearance Appearance {\n"
-"            material Material {\n"
-"              ambientIntensity 0\n"
-"              diffuseColor 0.8 0.2 0.2\n"
-"              specularColor 0 0 0\n"
-"              shininess 0.0078125\n"
-"              transparency 0\n"
-"              }\n"
-"            }\n"
-"          geometry IndexedFaceSet {\n"
-"            solid FALSE\n";
-        outputFile << "            coord DEF pml2wrl Coordinate {" << endl;
+    outputFile << "# pml2wrl" << endl;
+    outputFile << "    Background {\n"
+               "      skyColor [1.000000 1.000000 1.000000, ]\n"
+               "    }\n"
+               "    Viewpoint {\n"
+               "      fieldOfView 0.523599\n"
+               "      position 222.803372 287.424506 199.848172\n"
+               "      description \"Default View\"\n"
+               "      orientation 0.590285 -0.769274 -0.244504 0.987861\n"
+               "    }\n"
+               "    NavigationInfo {\n"
+               "      type [\"EXAMINE\",\"FLY\"]\n"
+               "      speed 4.000000\n"
+               "      headlight FALSE"
+               "     }\n"
+               "\n"
+               "    DirectionalLight { ambientIntensity 1 intensity 0 # ambient light\n"
+               "      color 1.000000 1.000000 1.000000 }\n"
+               "\n"
+               "    DirectionalLight {\n"
+               "      direction -0.577350 -0.577350 -0.577350\n"
+               "      color 1.000000 1.000000 1.000000\n"
+               "      intensity 1.000000\n"
+               "      on TRUE\n"
+               "      }\n"
+               "    Transform {\n"
+               "      translation 0 0 0\n"
+               "      rotation 0 0 1 0\n"
+               "      scale 1 1 1\n"
+               "      children [\n"
+               "        Shape {\n"
+               "          appearance Appearance {\n"
+               "            material Material {\n"
+               "              ambientIntensity 0\n"
+               "              diffuseColor 0.8 0.2 0.2\n"
+               "              specularColor 0 0 0\n"
+               "              shininess 0.0078125\n"
+               "              transparency 0\n"
+               "              }\n"
+               "            }\n"
+               "          geometry IndexedFaceSet {\n"
+               "            solid FALSE\n";
+    outputFile << "            coord DEF pml2wrl Coordinate {" << endl;
 
 
 }
@@ -235,9 +234,9 @@ void vrml1Prologue(StructuralComponent *sc) {
     outputFile << "DEF pml2wrl Separator {\n";
     printMaterial((Cell*)sc->getCell(0));
     outputFile << "\tMaterialBinding { value OVERALL }\n"
-    "\tShapeHints { shapeType SOLID vertexOrdering CLOCKWISE }\n"
-    "\tSeparator {\n"
-    "\tCoordinate3 {\n";
+               "\tShapeHints { shapeType SOLID vertexOrdering CLOCKWISE }\n"
+               "\tSeparator {\n"
+               "\tCoordinate3 {\n";
 }
 
 //------------------------ main ---------------------------
@@ -252,8 +251,7 @@ int main(int argc, char **argv) {
     if (vrml2) {
         outputFile << "#VRML V2.0 utf8" << endl;//"#VRML V1.0 ascii" << endl;
         outputFile << "#WARNING: pml2wrl may have inverted backface culling..." << endl;
-    }
-    else
+    } else
         outputFile << "#VRML V1.0 ascii" << endl;
 
     try {
@@ -262,18 +260,16 @@ int main(int argc, char **argv) {
 
         cout << "-> Please wait while converting to wrl" << endl;
 
-        for (unsigned int cptId=0;cptId<componentNames.size(); cptId++) {
+        for (unsigned int cptId=0; cptId<componentNames.size(); cptId++) {
             // find the multiComponent component
             Component *cpt = pm->getComponentByName(componentNames[cptId]);
             if (!cpt) {
                 cout << "Cannot find any component named \"" << componentNames[cptId] << "\". Skipping" << endl;
-            }
-            else {
+            } else {
                 // check if it is a correct one
                 if (!cpt->isInstanceOf("StructuralComponent")) {
                     cout << "Cannot translate the \"" << componentNames[cptId] << "\" component: not a structural component. Skipping" << endl;
-                }
-                else {
+                } else {
                     sc = (StructuralComponent*)cpt;
 
                     // prologue
@@ -313,8 +309,7 @@ int main(int argc, char **argv) {
                     if (vrml2) {
                         outputFile <<"       ]" << endl;
                         outputFile <<"     }" << endl;
-                    }
-                    else {
+                    } else {
                         outputFile << "}" << endl;
                     }
                     outputFile << endl;
