@@ -42,7 +42,7 @@ string output;
 // Code inspired from ProgVals "Thinking in C++, 2nd Edition, Volume 2", chapter 4
 // by Bruce Eckel & Chuck Allison, (c) 2001 MindView, Inc.
 // Available at www.BruceEckel.com.
-// Program values can be changed by command lineclass ProgVals 
+// Program values can be changed by command lineclass ProgVals
 #include <map>
 #include <iostream>
 #include <string>
@@ -50,9 +50,9 @@ string output;
 class ProgramArg : public std::map<std::string, std::string> {
 public:
     ProgramArg(std::string defaults[][2], unsigned int sz) {
-        for(unsigned int i=0;i<sz;i++) insert(pair(defaults[i][0], defaults[i][1]));
+        for(unsigned int i=0; i<sz; i++) insert(pair(defaults[i][0], defaults[i][1]));
     };
-    
+
     void parse(int argc, char* argv[], std::string usage, int offset = 1) {
         for(int i = offset; i < argc; i++) {
             string flag(argv[i]);
@@ -70,7 +70,7 @@ public:
             operator[](name) = value;
         }
     };
-    
+
     void print(std::ostream& out = std::cout) {
         out << "Argument values:" << endl;
         for(iterator it = begin(); it != end(); it++)
@@ -79,18 +79,18 @@ public:
 };
 
 string defaultsArg[][2] = {
-  { "-src", "none" },
-  { "-dest", "none" },
-  { "-o", "pmldiff-output.lml" },
+    { "-src", "none" },
+    { "-dest", "none" },
+    { "-o", "pmldiff-output.lml" },
 };
 
 const char* usage = "usage:\n"
-"pmldiff -src=f1.pml -dest=f2.pml [-o=diff.lml]\n"
-"Create a LML document which contains the translations needed to transform f1.pml to f2.pml\n"
-"(Note no space around '=')\n"
-"Where mandatory flags are: \n"
-"src (source pml document), dest (destination pml document)\n"
-"The optional o flag allows to specify the resulting LML file name\n";
+                    "pmldiff -src=f1.pml -dest=f2.pml [-o=diff.lml]\n"
+                    "Create a LML document which contains the translations needed to transform f1.pml to f2.pml\n"
+                    "(Note no space around '=')\n"
+                    "Where mandatory flags are: \n"
+                    "src (source pml document), dest (destination pml document)\n"
+                    "The optional o flag allows one to specify the resulting LML file name\n";
 
 // global ProgramArgument
 ProgramArg argVal(defaultsArg, sizeof defaultsArg / sizeof *defaultsArg);
@@ -119,17 +119,17 @@ int main(int argc, char ** argv) {
     // Initialize and parse command line values
     // before any code that uses pvals is called:
     argVal.parse(argc, argv, usage);
-    
+
     processArg();
     printArg();
-    
+
     try {
         PhysicalModel *src = new PhysicalModel(srcFile.c_str());
         PhysicalModel *dest = new PhysicalModel(destFile.c_str());
 
         //-- create the loads
         Loads *transform = new Loads();
-        
+
         //-- compute the differences
         StructuralComponent *srcA = src->getAtoms();
         Atom *a1, *a2;
@@ -137,8 +137,8 @@ int main(int argc, char ** argv) {
         double destPos[3];
         double translation[3];
         double value;
-        
-        for (unsigned int i=0;i<srcA->getNumberOfStructures();i++) {
+
+        for (unsigned int i=0; i<srcA->getNumberOfStructures(); i++) {
             // get the src position
             a1 = (Atom *) srcA->getStructure(i);
             a1->getPosition(srcPos);
@@ -161,7 +161,7 @@ int main(int argc, char ** argv) {
                 // normalize translation
                 for (unsigned int j=0; j<3; j++)
                     translation[j] /= value;
-                
+
                 t->setDirection(translation[0], translation[1], translation[2]);
                 t->addTarget(a1->getIndex());
                 t->addValueEvent(0.0, 0.0);
@@ -181,7 +181,7 @@ int main(int argc, char ** argv) {
         transform->xmlPrint(loadStream);
         loadStream << "<!-- this file (" << output << ") was generated by pml2diff and is the tranformation from " << srcFile << " to " << destFile << " -->" << endl;
         loadStream.close();
-        
+
 
     } catch(PMLAbortException ae) {
         cerr << "AbortException: Physical model aborted:" << endl ;
