@@ -25,7 +25,7 @@
 //
 // C++ Implementation: tri2pml
 //
-// Description: 
+// Description:
 //
 // the first argument is the name of a file (the triangle file)
 // The triangle format is as follow :
@@ -309,8 +309,7 @@ int main(int argc, char ** argv) {
     if (pLast != string::npos) {
         filename.erase(pLast);
         filename += "-out.pml";
-    }
-    else
+    } else
         filename += "-out.pml";
     ofstream outputFile(filename.c_str());
     outputFile << "<!-- Created by tri2pml (c) E Promayon, TIMC (c) 1997-2006 -->" << endl;
@@ -339,7 +338,7 @@ int main(int argc, char ** argv) {
     outputFile << "</structuralComponent>" << endl;
     outputFile << "</atoms>" << endl;
 
-		cout <<  "-> created " << nVertices << " atoms" << endl;
+    cout <<  "-> created " << nVertices << " atoms" << endl;
 
     // regions
     outputFile << "<exclusiveComponents>" << endl;
@@ -353,7 +352,7 @@ int main(int argc, char ** argv) {
     outputFile << "</cell>" << endl;
     outputFile << "</structuralComponent>" << endl;
 
-		cout <<  "-> created region" << endl;
+    cout <<  "-> created region" << endl;
 
 // tetrahedra => elements (we can then convert the elements to neighborhood using the corresponding physicalmodel lib tool)
     unsigned int nTetra;
@@ -362,10 +361,10 @@ int main(int argc, char ** argv) {
     outputFile << "<structuralComponent name=\"Elements\"  mode=\"WIREFRAME_AND_SURFACE\" >" << endl;
     outputFile << "<color r=\".95\" g=\"0.89\" b=\"0.63\" a=\"1.0\"/>" << endl;
 
-		cout <<  "-> creating triangles (offset=" << offset << ", nb of triangles to read=" << nTetra << endl;
+    cout <<  "-> creating triangles (offset=" << offset << ", nb of triangles to read=" << nTetra << endl;
 
-		int id;
-    for (unsigned int i=0;i<nTetra; i++) {
+    int id;
+    for (unsigned int i=0; i<nTetra; i++) {
         outputFile << "<cell>" << endl;
         outputFile << "<cellProperties type=\"TRIANGLE\" />" << endl;
         for (unsigned int j=0; j<3; j++) {
@@ -373,14 +372,14 @@ int main(int argc, char ** argv) {
             outputFile << "<atomRef index=\"" << id << "\" />" << endl;
         }
         // discard the next "offset" number of integer
-        for (unsigned int j=0; j<offset; j++) 
+        for (unsigned int j=0; j<offset; j++)
             nobox >> id;
         outputFile << "</cell>" << endl;
     }
 
-		cout <<  "...finished (" << nTetra << " triangles created)" << endl;
+    cout <<  "...finished (" << nTetra << " triangles created)" << endl;
     cout << "Results in " << filename << endl;
-		
+
     outputFile << "</structuralComponent>" << endl;
     outputFile << "</multiComponent>" << endl;
     outputFile << "</exclusiveComponents>" << endl;
