@@ -73,60 +73,59 @@ int main(int argc, char ** argv) {
         // check each cell, everytime a quad is found, triangulate it
         Cell *c;
         Cell *newCell;
-        for (unsigned int i=0; i<sc->getNumberOfStructures();i++) {
+        for (unsigned int i=0; i<sc->getNumberOfStructures(); i++) {
             c = sc->getCell(i);
             switch (c->getType()) {
-                case StructureProperties::QUAD:
-                    triangulated++;
-                    /*
-                    * QUAD
-                    *   3--------2      lines:  triangulation:
-                    *   |        |      0,1     0,1,3
-                    *   |        |      1,2     1,2,3
-                    *   |        |      2,3
-                    *   0--------1      3,0            
-                    */
-                    newCell = new Cell(pm, StructureProperties::TRIANGLE);
-                    newCell->addStructure(c->getStructure(0));
-                    newCell->addStructure(c->getStructure(1));
-                    newCell->addStructure(c->getStructure(3));
-                    newSc->addStructure(newCell);
-                    newCell = new Cell(pm, StructureProperties::TRIANGLE);
-                    newCell->addStructure(c->getStructure(1));
-                    newCell->addStructure(c->getStructure(2));
-                    newCell->addStructure(c->getStructure(3));
-                    newSc->addStructure(newCell);
-                    break;
-                    
-                case StructureProperties::TRIANGLE:
-                    // create a new identical cell
-                    newCell = new Cell(pm,c->getType());
-                    for (unsigned int j=0;j<c->getNumberOfStructures();j++)
-                        newCell->addStructure(c->getStructure(j));
-                    newSc->addStructure(newCell);
-                    break;
+            case StructureProperties::QUAD:
+                triangulated++;
+                /*
+                * QUAD
+                *   3--------2      lines:  triangulation:
+                *   |        |      0,1     0,1,3
+                *   |        |      1,2     1,2,3
+                *   |        |      2,3
+                *   0--------1      3,0
+                */
+                newCell = new Cell(pm, StructureProperties::TRIANGLE);
+                newCell->addStructure(c->getStructure(0));
+                newCell->addStructure(c->getStructure(1));
+                newCell->addStructure(c->getStructure(3));
+                newSc->addStructure(newCell);
+                newCell = new Cell(pm, StructureProperties::TRIANGLE);
+                newCell->addStructure(c->getStructure(1));
+                newCell->addStructure(c->getStructure(2));
+                newCell->addStructure(c->getStructure(3));
+                newSc->addStructure(newCell);
+                break;
 
-                default:
-                    cout << "Cannot triangulate cell" << c->getIndex() << " (" << StructureProperties::toString(c->getType()) << ")" << endl;
-                    break;
+            case StructureProperties::TRIANGLE:
+                // create a new identical cell
+                newCell = new Cell(pm,c->getType());
+                for (unsigned int j=0; j<c->getNumberOfStructures(); j++)
+                    newCell->addStructure(c->getStructure(j));
+                newSc->addStructure(newCell);
+                break;
+
+            default:
+                cout << "Cannot triangulate cell" << c->getIndex() << " (" << StructureProperties::toString(c->getType()) << ")" << endl;
+                break;
             }
         }
 
         // add the new SC to the informative component
-      if (!pm->getInformativeComponents()) {
-        MultiComponent *mc = new MultiComponent(pm);
-        pm->setInformativeComponents(mc);
-      }
-        
-      pm->getInformativeComponents()->addSubComponent(newSc);
-      
+        if (!pm->getInformativeComponents()) {
+            MultiComponent *mc = new MultiComponent(pm);
+            pm->setInformativeComponents(mc);
+        }
+
+        pm->getInformativeComponents()->addSubComponent(newSc);
+
         // save the result
         unsigned int pLast = filename.rfind(".");
         if (pLast != string::npos) {
             filename.erase(pLast);
             filename += "-triangulated.pml";
-        }
-        else
+        } else
             filename="triangulated.pml";
 
         cout << "-> please wait while saving " << filename << " " << endl;
