@@ -38,13 +38,13 @@ AboutAction::AboutAction(ActionExtension * extension) : Action(extension) {
     // Setting name, description and input component
     setName("About...");
     setEmbedded(false);
-    setDescription("Show a little dialog about the application");
+    setDescription(tr("Show a little dialog about the application"));
     setComponent("");
     setIcon(QPixmap(":/camiTKIcon"));
 
     // Setting classification family and tags
     setFamily("Application");
-    addTag("About");
+    addTag(tr("About"));
 }
 
 // --------------- destructor -------------------
@@ -60,7 +60,7 @@ QWidget * AboutAction::getWidget() {
 // --------------- apply -------------------
 Action::ApplyStatus AboutAction::apply() {
     QDialog *aboutDialog = new QDialog();
-    aboutDialog->setWindowTitle("About " + Application::getName() + "...");
+    aboutDialog->setWindowTitle(tr("About ") + Application::getName() + "...");
     QVBoxLayout *dialogLayout = new QVBoxLayout;
     QHBoxLayout *informationLayout = new QHBoxLayout;
 
@@ -71,10 +71,10 @@ Action::ApplyStatus AboutAction::apply() {
     text->setTextFormat(Qt::RichText);
     text->setOpenExternalLinks(true);
     text->setText("<b>"+Application::getName() + "</b><br/>"
-                  +"Build using "
+                  +tr("Build using ")
                   + QString(Core::version) + "<br/>"
-                  + "Please visit <a href='http://camitk.imag.fr'>camitk.imag.fr</a> for more information.<br/>"
-                  + "(c) UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525");
+                  + tr("Please visit <a href='http://camitk.imag.fr'>camitk.imag.fr</a> for more information.<br/>")
+                  + tr("(c) UJF-Grenoble 1, CNRS, TIMC-IMAG UMR 5525"));
 
     // get the proper text height
     text->adjustSize();
