@@ -29,27 +29,28 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
+ *
+ * @brief
  * The AboutAction class handles the pop-up "About CamiTK" with information about CamiTK.
- * 
- **/ 
+ *
+ **/
 class AboutAction : public camitk::Action {
-
+    Q_OBJECT
+    
 public:
-  /// Default Constructor
-  AboutAction(camitk::ActionExtension * extension);
+    /// Default Constructor
+    AboutAction(camitk::ActionExtension * extension);
 
-  /// Default Destructor
-  virtual ~AboutAction();
+    /// Default Destructor
+    virtual ~AboutAction();
 
-  /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
-  virtual QWidget * getWidget();
+    /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
+    virtual QWidget * getWidget();
 
 public slots:
-  /** this method is automatically called when the action is triggered.
-    * it shows a little about dialog.
-    */
-  virtual ApplyStatus apply();
+    /** this method is automatically called when the action is triggered.
+      * it shows a little about dialog.
+      */
+    virtual ApplyStatus apply();
 };
 #endif // ABOUTACTION_H
