@@ -46,15 +46,13 @@
 #include "Show3DViewer.h"
 #include "ShowAllViewers.h"
 #include "ShowArbitraryViewer.h"
+#include "ChangeLanguage.h"
 
 // --------------- declare the extension -------------------
 Q_EXPORT_PLUGIN2(applicationaction, ApplicationActionExtension)
 
 // --------------- constructor -------------------
-ApplicationActionExtension::ApplicationActionExtension() : ActionExtension() {
-    // initialize the icon resources
-    //Q_INIT_RESOURCE(ApplicationActionExtension);
-}
+ApplicationActionExtension::ApplicationActionExtension() : ActionExtension() {}
 
 // --------------- init -------------------
 void ApplicationActionExtension::init() {
@@ -72,6 +70,7 @@ void ApplicationActionExtension::init() {
     registerNewAction(ShowConsoleAction);
     registerNewAction(AboutAction);
     registerNewAction(RemoveLastInstanciatedAction);
+    registerNewAction(ChangeLanguage);
     // -- medical image viewer manipulation
     registerNewAction(ShowAxialViewer);
     registerNewAction(ShowCoronalViewer);
