@@ -35,11 +35,11 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
+ *
+ * @brief
  * The ApplicationActionExtension class features all the application actions.
- * 
- **/ 
+ *
+ **/
 class ApplicationActionExtension : public camitk::ActionExtension {
     Q_OBJECT
     Q_INTERFACES(camitk::ActionExtension)
@@ -53,12 +53,16 @@ public:
 
     /// initialize all the actions
     virtual void init();
-            
+
     /// Method that return the action extension name
-    virtual QString getName() {return "Application Level Action Extension";};
-    
+    virtual QString getName() {
+        return "Application Level Action Extension";
+    };
+
     /// Method that return the action extension descrption
-    virtual QString getDescription() {return "This extension provides various actions to manipulate components at the application level (open, close, save...)";};
+    virtual QString getDescription() {
+        return "This extension provides various actions to manipulate components at the application level (open, close, save...)";
+    };
 
 };
 
