@@ -35,12 +35,12 @@ ClearSelectionAction::ClearSelectionAction(ActionExtension * extension) : Action
     // Setting name, description and input component
     setName("Clear Selection");
     setEmbedded(false);
-    setDescription("Clear the list of selected item");
+    setDescription(tr("Clear the list of selected item"));
     setComponent("");
 
     // Setting classification family and tags
     setFamily("Application");
-    addTag("Clear Selection");
+    addTag(tr("Clear Selection"));
 
     getQAction()->setShortcut(Qt::Key_Escape);
     getQAction()->setShortcutContext(Qt::ApplicationShortcut);
