@@ -30,26 +30,26 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
+ *
+ * @brief
  * The ClearSelectionAction allows user to clear the selected components in the components explorer.
- * 
+ *
  **/
 class ClearSelectionAction : public camitk::Action {
-
+    Q_OBJECT
 public:
-  /// Default Constructor
-  ClearSelectionAction(camitk::ActionExtension *);
+    /// Default Constructor
+    ClearSelectionAction(camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~ClearSelectionAction();
+    /// Default Destructor
+    virtual ~ClearSelectionAction();
 
-  /// Returns NULL: no widget at all for this action
-  virtual QWidget * getWidget();
+    /// Returns NULL: no widget at all for this action
+    virtual QWidget * getWidget();
 
 public slots:
-  /// apply the action select the last instanciated component
-  virtual ApplyStatus apply();
+    /// apply the action select the last instanciated component
+    virtual ApplyStatus apply();
 
 };
 #endif // CLEARSELECTION_ACTION_H
