@@ -33,13 +33,13 @@ CloseAction::CloseAction(ActionExtension * extension) : Action(extension) {
     // Setting name, description and input component
     setName("Close");
     setEmbedded(false);
-    setDescription("Close the currently selected components");
+    setDescription(tr("Close the currently selected components"));
     setComponent("Component");
     setIcon(QPixmap(":/fileClose"));
 
     // Setting classification family and tags
     setFamily("Application");
-    addTag("Close");
+    addTag(tr("Close"));
 
     // add shortcut
     getQAction()->setShortcut(QKeySequence::Close);
@@ -59,7 +59,7 @@ QWidget * CloseAction::getWidget() {
 // --------------- apply -------------------
 Action::ApplyStatus CloseAction::apply() {
     QSet<Component*> allTopLevel;
-	
+
     // fill the toplevel component set
     foreach (Component *comp, getTargets()) {
         allTopLevel.insert(comp->getTopLevelComponent());
