@@ -31,27 +31,28 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
+ *
+ * @brief
  * The CloseAction class allow to close the selected component.
- * 
+ *
  **/
 class CloseAction : public camitk::Action {
+    Q_OBJECT
 
 public:
-  /// Default Constructor
-  CloseAction(camitk::ActionExtension *);
+    /// Default Constructor
+    CloseAction(camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~CloseAction();
+    /// Default Destructor
+    virtual ~CloseAction();
 
-  /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
-  virtual QWidget * getWidget();
+    /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
+    virtual QWidget * getWidget();
 
 public slots:
-  /** this method is automatically called when the action is triggered.
-    * It gets all the targets' top level component and close them.
-    */
-  virtual ApplyStatus apply();
+    /** this method is automatically called when the action is triggered.
+      * It gets all the targets' top level component and close them.
+      */
+    virtual ApplyStatus apply();
 };
 #endif // CLOSEACTION_H
