@@ -31,28 +31,29 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
- * The CloseAllAction class allows to close all selected component in the current application.
- * 
+ *
+ * @brief
+ * The CloseAllAction class allows one to close all selected component in the current application.
+ *
  **/
 class CloseAllAction : public camitk::Action {
+    Q_OBJECT
 
 public:
-  /// Default Constructor
-  CloseAllAction(camitk::ActionExtension *);
+    /// Default Constructor
+    CloseAllAction(camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~CloseAllAction();
+    /// Default Destructor
+    virtual ~CloseAllAction();
 
-  /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
-  virtual QWidget * getWidget();
+    /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
+    virtual QWidget * getWidget();
 
 public slots:
-  /** this method is automatically called when the action is triggered.
-    * It gets all the targets' top level component and close them.
-    */
-  virtual ApplyStatus apply();
+    /** this method is automatically called when the action is triggered.
+      * It gets all the targets' top level component and close them.
+      */
+    virtual ApplyStatus apply();
 
 };
 #endif // CLOSEALLACTION_H
