@@ -38,14 +38,14 @@ OpenAction::OpenAction (ActionExtension * extension) : Action (extension) {
     // Setting name, description and input component
     setName ("Open");
     setEmbedded (false);
-    setDescription ("Open data (component) from a file");
+    setDescription (tr("Open data (component) from a file"));
     setComponent ("");
     if (qApp->type() != QApplication::Tty)
         setIcon (QPixmap (":/fileOpen"));
 
     // Setting classification family and tags
     setFamily ("Application");
-    addTag ("Open");
+    addTag (tr("Open"));
 
     // add a shortcut
     if (qApp->type() != QApplication::Tty) {
@@ -80,7 +80,7 @@ Action::ApplyStatus OpenAction::apply() {
     }
 
     // Open more than one file
-    QStringList files = QFileDialog::getOpenFileNames (NULL, "Select One or More Files to Open", Application::getLastUsedDirectory().absolutePath(), filter);
+    QStringList files = QFileDialog::getOpenFileNames (NULL,tr("Select One or More Files to Open"), Application::getLastUsedDirectory().absolutePath(), filter);
 
     if (!files.isEmpty()) {
         QStringList listOfFiles = files; // as stated by the Qt doc (although without further information): "If you want to iterate over the list of files, you should iterate over a copy."
@@ -90,13 +90,11 @@ Action::ApplyStatus OpenAction::apply() {
         if (fileIterator == listOfFiles.constEnd()) {
             Application::showStatusBarMessage(tr ("All files loaded."));
             return SUCCESS;
-        }
-        else {
+        } else {
             Application::showStatusBarMessage(tr ("Error loading files: ") + (*fileIterator));
             return ERROR;
         }
-    }
-    else {
+    } else {
         Application::showStatusBarMessage(tr ("Open aborted."));
         return ABORTED;
     }
