@@ -30,16 +30,17 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
+ *
+ * @brief
  * When triggered, open a file open dialog box.
  * the OpenAction display a file open dialog.
  * If one or more files are choosen, the open component method of ExtensionManager is called.
  */
 class OpenAction : public camitk::Action {
+    Q_OBJECT
 
-public: 
-    /// Default Constructor 
+public:
+    /// Default Constructor
     OpenAction(camitk::ActionExtension *);
 
     /// Default Destructor
@@ -47,10 +48,10 @@ public:
 
     /// Returns NULL: no permanent widget for this action. The GUI is shown as a one-shot dialog in apply
     virtual QWidget * getWidget();
-    
-public slots:
-  /// apply the action i.e. show a file dialog and open the selected file(s)
-  virtual ApplyStatus apply();  
 
-}; 
+public slots:
+    /// apply the action i.e. show a file dialog and open the selected file(s)
+    virtual ApplyStatus apply();
+
+};
 #endif // OPENACTION_H
