@@ -33,18 +33,18 @@ using namespace camitk;
 
 // --------------- constructor -------------------
 QuitAction::QuitAction(ActionExtension * extension) : Action(extension) {
-    // Setting name, description and input component 
+    // Setting name, description and input component
     setName("Quit");
     setEmbedded(false);
-    setDescription("Exit the application, prompting for additional information if needed");
+    setDescription(tr("Exit the application, prompting for additional information if needed"));
     setComponent("");
     setIcon (QPixmap (":/fileQuit"));
-    
-    // Setting classification family and tags 
+
+    // Setting classification family and tags
     setFamily("Application");
-    addTag("Quit Application");
-    addTag("Exit Application");
-    
+    addTag(tr("Quit Application"));
+    addTag(tr("Exit Application"));
+
     // add a shortcut
     getQAction()->setShortcut ( QKeySequence::Quit );
     getQAction()->setShortcutContext(Qt::ApplicationShortcut);
