@@ -36,12 +36,12 @@ RemoveLastInstanciatedAction::RemoveLastInstanciatedAction(ActionExtension *exte
     // Setting name, description and input component
     setName("Remove Last Instanciated Top Level Component");
     setEmbedded(false);
-    setDescription("Remove the last top level component that was instanciated without saving it");
+    setDescription(tr("Remove the last top level component that was instanciated without saving it"));
     setComponent("");
 
     // Setting classification family and tags
     setFamily("Application");
-    addTag("Delete Component");
+    addTag(tr("Delete Component"));
 }
 
 // --------------- destructor -------------------
