@@ -30,23 +30,24 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
+ *
+ * @brief
  * Remove the last top-level selected component (if several top level components were selected, the latest one is removed).
  * Note that no prompt is asked to the user to save or not the component if unsaved.
  */
 class RemoveLastInstanciatedAction : public camitk::Action {
+    Q_OBJECT
 
 public:
     /// Default Constructor
     RemoveLastInstanciatedAction(camitk::ActionExtension *);
-	
+
     /// Default Destructor
     virtual ~RemoveLastInstanciatedAction();
-	
+
     /// Returns NULL: no widget at all for this action
     virtual QWidget * getWidget();
-	
+
 public slots:
     /// apply the action select the last instanciated component
     virtual ApplyStatus apply();
