@@ -34,13 +34,13 @@ SaveAction::SaveAction(ActionExtension * extension) : Action(extension) {
     // Setting name, description and input component
     setName("Save");
     setEmbedded(false);
-    setDescription("Save all the top-level of the selected components");
+    setDescription(tr("Save all the top-level of the selected components"));
     setComponent("Component");
     setIcon(QPixmap(":/fileSave"));
 
     // Setting classification family and tags
     setFamily("Application");
-    addTag("Save");
+    addTag(tr("Save"));
 
     // add a shortcut
     getQAction()->setShortcut ( QKeySequence::Save );
