@@ -31,27 +31,28 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
+ *
+ * @brief
  * Save the current selected component.
  */
 class SaveAction : public camitk::Action {
+    Q_OBJECT
 
 public:
-  /// Default Constructor
-  SaveAction(camitk::ActionExtension *);
+    /// Default Constructor
+    SaveAction(camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~SaveAction();
+    /// Default Destructor
+    virtual ~SaveAction();
+
+    /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
+    virtual QWidget * getWidget();
 
-  /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
-  virtual QWidget * getWidget();
-  
 public slots:
-  /** this method is automatically called when the action is triggered.
-    * It gets all the targets' top level components and save them.
-    */
-  virtual ApplyStatus apply();
-  
+    /** this method is automatically called when the action is triggered.
+      * It gets all the targets' top level components and save them.
+      */
+    virtual ApplyStatus apply();
+
 };
 #endif // SAVEACTION_H
