@@ -40,13 +40,13 @@ SaveAllAction::SaveAllAction(ActionExtension * extension) : Action(extension) {
     // Setting name, description and input component
     setName("Save All");
     setEmbedded(false);
-    setDescription("Saves all the currently loaded data");
+    setDescription(tr("Saves all the currently loaded data"));
     setComponent("Component");
     setIcon(QPixmap(":/fileSaveAll"));
 
     // Setting classification family and tags
     setFamily("Application");
-    addTag("Save All");
+    addTag(tr("Save All"));
 }
 
 // --------------- destructor -------------------
@@ -68,7 +68,7 @@ Action::ApplyStatus SaveAllAction::apply() {
     while (it != Application::getTopLevelComponents().constEnd() && Application::save(*it))
         ++it;
 
-    return (it == Application::getTopLevelComponents().constEnd()) ? SUCCESS : ERROR;    
+    return (it == Application::getTopLevelComponents().constEnd()) ? SUCCESS : ERROR;
 
     Application::showStatusBarMessage( tr ( "Ready." ) );
     return ERROR;
