@@ -31,27 +31,28 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
+ *
+ * @brief
  * Save all the current selected components.
  */
 class SaveAllAction : public camitk::Action {
+    Q_OBJECT
 
 public:
-  /// Default Constructor
-  SaveAllAction(camitk::ActionExtension *);
+    /// Default Constructor
+    SaveAllAction(camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~SaveAllAction();
+    /// Default Destructor
+    virtual ~SaveAllAction();
+
+    /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
+    virtual QWidget * getWidget();
 
-  /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
-  virtual QWidget * getWidget();
-  
 public slots:
-  /** this method is automatically called when the action is triggered.
-    * It ask for a filename and call ExtensionManager saveAs method
-    */
-  virtual ApplyStatus apply();
-  
+    /** this method is automatically called when the action is triggered.
+      * It ask for a filename and call ExtensionManager saveAs method
+      */
+    virtual ApplyStatus apply();
+
 };
 #endif // SAVEALLACTION_H
