@@ -41,13 +41,13 @@ SaveAsAction::SaveAsAction(ActionExtension * extension) : Action(extension) {
     // Setting name, description and input component
     setName("Save As");
     setEmbedded(false);
-    setDescription("Save the currently selected data under a different filename or format");
+    setDescription(tr("Save the currently selected data under a different filename or format"));
     setComponent("Component");
     setIcon(QPixmap(":/fileSaveAs"));
 
     // Setting classification family and tags
     setFamily("Application");
-    addTag("Save As");
+    addTag(tr("Save As"));
 
     // add shortcuts
     getQAction()->setShortcut ( QKeySequence::SaveAs );
@@ -95,13 +95,15 @@ Action::ApplyStatus SaveAsAction::apply() {
             const ImageComponentExtension * imageExt = dynamic_cast<const ImageComponentExtension*> (pl);
 
             if (imageExt) {
+                QString imgFilter = imageExt->getName() + " (";
                 foreach (QString ext, imageExt->getFileExtensions()) {
-                    filter += ExtensionManager::getComponentExtension ( ext )->getName() + " (*." + ext + ")";
+                    imgFilter += "*." + ext + " ";
                 }
+                imgFilter += ")";
+                filter += imgFilter;
             }
         }
-    }
-    else {
+    } else {
         // If the selected component is of type MeshComponent, use all MeshComponentExtension
         const MeshComponent  * compAsMesh = dynamic_cast<const MeshComponent *>  ( comp );
 
@@ -110,13 +112,15 @@ Action::ApplyStatus SaveAsAction::apply() {
                 const ComponentExtension * meshExt = dynamic_cast<const MeshComponentExtension*> (pl);
 
                 if (meshExt) {
+                    QString meshFilter =  meshExt->getName() + " (";
                     foreach (QString ext, meshExt->getFileExtensions()) {
-                        filter += ExtensionManager::getComponentExtension(ext)->getName() + " (*." + ext + ")";
+                        meshFilter += "*." + ext + ")";
                     }
+                    meshFilter += ")";
+                    filter += meshFilter;
                 }
             }
-        }
-        else {
+        } else {
             // the selected component is neither ImageComponent or MeshComponent, just
             // ask the component that instanciated it
             foreach ( QString ext, ExtensionManager::getComponentExtension ( extension )->getFileExtensions() ) {
@@ -132,8 +136,7 @@ Action::ApplyStatus SaveAsAction::apply() {
     // use the top level component name if there is no file name
     if (suggestedName.isEmpty()) {
         suggestedName = comp->getName();
-    }
-    else {
+    } else {
         // If the name contains a number then increment it
         QRegExp numSearch( "(^|[^\\d])(\\d+)" ); // we want to match as far left as possible, and when the number is at the start of the name
 
@@ -147,16 +150,14 @@ Action::ApplyStatus SaveAsAction::apply() {
             QString number = QString::number( numAsStr.toInt() + 1 );
             number = number.rightJustified( numAsStr.length(), '0' );
             suggestedName.replace( start, numAsStr.length(), number );
-        }
-        else {
+        } else {
             // no number
             start = suggestedName.lastIndexOf('.');
 
             if (start != -1) {
                 // has a . somewhere, e.g. it has an extension
                 suggestedName.insert(start, '1');
-            }
-            else {
+            } else {
                 // no extension, just tack it on to the end
                 suggestedName += '1';
             }
@@ -166,9 +167,14 @@ Action::ApplyStatus SaveAsAction::apply() {
     // format filter list, sort
     QStringList filterList(filter.toList());
     filterList.sort();
+    QString test = filterList.join(";;");
+
+    QFileDialog saveFileDialog(NULL, tr ( "Save File As..." ), QFileInfo(compfileName).dir().canonicalPath() +"/"+ suggestedName, test);
+    saveFileDialog.setFileMode(QFileDialog::AnyFile);
+    saveFileDialog.setOption(QFileDialog::HideNameFilterDetails, false);
 
     // get the file name
-    QString filename = QFileDialog::getSaveFileName ( NULL, tr ( "Save File As..." ), QFileInfo(compfileName).dir().canonicalPath() +"/"+ suggestedName, filterList.join(";;"));
+    QString filename = QFileDialog::getSaveFileName( NULL, tr ( "Save File As..." ), QFileInfo(compfileName).dir().canonicalPath() +"/"+ suggestedName, test);
 
     if ( !filename.isEmpty() ) {
         // rename the filename of the component and save
@@ -179,13 +185,11 @@ Action::ApplyStatus SaveAsAction::apply() {
         // reset name if there was a problem
         if (saveStatus) {
             return SUCCESS;
-        }
-        else {
+        } else {
             comp->setFileName(compfileName);
             return ERROR;
         }
-    }
-    else {
+    } else {
         Application::showStatusBarMessage( tr ( "Saving aborted" ), 2000 );
         return ABORTED;
     }
