@@ -31,27 +31,28 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
+ *
+ * @brief
  * Save as the current selected component.
  */
 class SaveAsAction : public camitk::Action {
+    Q_OBJECT
 
 public:
-  /// Default Constructor
-  SaveAsAction(camitk::ActionExtension *);
+    /// Default Constructor
+    SaveAsAction(camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~SaveAsAction();
+    /// Default Destructor
+    virtual ~SaveAsAction();
+
+    /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
+    virtual QWidget * getWidget();
 
-  /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
-  virtual QWidget * getWidget();
-  
 public slots:
-  /** this method is automatically called when the action is triggered.
+    /** this method is automatically called when the action is triggered.
     * It ask for a filename and call ExtensionManager saveAs method
     */
-  virtual ApplyStatus apply();
-  
+    virtual ApplyStatus apply();
+
 };
 #endif // SAVEASACTION_H
