@@ -32,15 +32,15 @@ using namespace camitk;
 
 // --------------- constructor -------------------
 SelectLastInstanciatedAction::SelectLastInstanciatedAction(ActionExtension * extension) : Action(extension) {
-    // Setting name, description and input component 
+    // Setting name, description and input component
     setName("Select Last Instanciated Top Level Component");
     setEmbedded(false);
-    setDescription("Select the last top level component that was instanciated");
+    setDescription(tr("Select the last top level component that was instanciated"));
     setComponent("");
 
-    // Setting classification family and tags 
+    // Setting classification family and tags
     setFamily("Application");
-    addTag("Select Component");
+    addTag(tr("Select Component"));
 }
 
 // --------------- destructor -------------------
@@ -55,21 +55,21 @@ QWidget * SelectLastInstanciatedAction::getWidget() {
 // --------------- apply -------------------
 Action::ApplyStatus SelectLastInstanciatedAction::apply() {
     const ComponentList & allComponent = Application::getAllComponents();
-	// unselect all others top level components
-	for (int i=0; i<allComponent.size(); i++)
-		allComponent.at(i)->getTopLevelComponent()->setSelected(false);
-	// select the last instanciated component
+    // unselect all others top level components
+    for (int i=0; i<allComponent.size(); i++)
+        allComponent.at(i)->getTopLevelComponent()->setSelected(false);
+    // select the last instanciated component
     if (!allComponent.isEmpty()) {
-		Component *lastComponent = allComponent.last();
-		// select the top level component associated to this component
-		while (lastComponent->getParentComponent() != NULL)
-			lastComponent = lastComponent->getParentComponent();
-		// select it
+        Component *lastComponent = allComponent.last();
+        // select the top level component associated to this component
+        while (lastComponent->getParentComponent() != NULL)
+            lastComponent = lastComponent->getParentComponent();
+        // select it
         lastComponent->setSelected(true);
-		
-		// refresh all viewers of the application to consider the newly selected top level component
+
+        // refresh all viewers of the application to consider the newly selected top level component
         Application::refresh();
-		return SUCCESS;
+        return SUCCESS;
     }
     return ERROR;
 }
