@@ -30,27 +30,28 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
+ *
+ * @brief
  * Save the current selected component.
- * This action allows to select the last instanciated component.
+ * This action allows one to select the last instanciated component.
  * \note only the last instanciated component will be selected
  */
 class SelectLastInstanciatedAction : public camitk::Action {
+    Q_OBJECT
 
 public:
-  /// Default Constructor
-  SelectLastInstanciatedAction(camitk::ActionExtension *);
+    /// Default Constructor
+    SelectLastInstanciatedAction(camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~SelectLastInstanciatedAction();
+    /// Default Destructor
+    virtual ~SelectLastInstanciatedAction();
 
-  /// Returns NULL: no widget at all for this action
-  virtual QWidget * getWidget();
+    /// Returns NULL: no widget at all for this action
+    virtual QWidget * getWidget();
 
 public slots:
-  /// apply the action select the last instanciated component
-  virtual ApplyStatus apply();
+    /// apply the action select the last instanciated component
+    virtual ApplyStatus apply();
 
 };
 #endif // SELECT_LAST_INSTANCIATED_ACTION_H
