@@ -32,18 +32,18 @@ Show3DViewer::Show3DViewer(ActionExtension * extension) : Action(extension) {
     // Setting name, description and input component
     setName("Show 3D Viewer");
     setEmbedded(false);
-    setDescription("Show the 3D Viewer Only");
+    setDescription(tr("Show the 3D Viewer Only"));
     setComponent("");
 
     // Setting classification family and tags
     setFamily("Application");
-    addTag("3D Viewer");
-    addTag("Geometry");
-    
+    addTag(tr("3D Viewer"));
+    addTag(tr("Geometry"));
+
     // add a shortcut
-    getQAction()->setShortcut ( tr("Ctrl+1") );    
+    getQAction()->setShortcut ( tr("Ctrl+1") );
     getQAction()->setShortcutContext(Qt::ApplicationShortcut);
-    
+
     // can be checked or not (on/off), useful when group in a QActionGroup (radio buttons)
     getQAction()->setCheckable(true);
 }
