@@ -29,27 +29,28 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
+ *
+ * @brief
  * Set the visibility of the MedicalImageViewer in order to only show the 3D viewer
- * 
- */ 
+ *
+ */
 class Show3DViewer : public camitk::Action {
+    Q_OBJECT
 
 public:
-  /// Default Constructor
-  Show3DViewer(camitk::ActionExtension *);
+    /// Default Constructor
+    Show3DViewer(camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~Show3DViewer();
+    /// Default Destructor
+    virtual ~Show3DViewer();
 
-  /// Returns NULL: no widget for this action.
-  virtual QWidget * getWidget();
+    /// Returns NULL: no widget for this action.
+    virtual QWidget * getWidget();
 
 public slots:
-  /** this method is automatically called when the action is triggered.
-    * it calls setVisibility on the MedicalImageViewer instance
-    */
-  virtual ApplyStatus apply();
+    /** this method is automatically called when the action is triggered.
+     * it calls setVisibility on the MedicalImageViewer instance
+     */
+    virtual ApplyStatus apply();
 };
 #endif // SHOW3DVIEWER_H
