@@ -32,18 +32,18 @@ ShowAllViewers::ShowAllViewers(ActionExtension * extension) : Action(extension)
     // Setting name, description and input component
     setName("Show All Viewers");
     setEmbedded(false);
-    setDescription("Show Classical Medical Image Viewer (Axial, Coronal, Sagittal and 3D in a 4 panels)");
+    setDescription(tr("Show Classical Medical Image Viewer (Axial, Coronal, Sagittal and 3D in a 4 panels)"));
     setComponent("");
 
     // Setting classification family and tags
     setFamily("Application");
-    addTag("All Viewers");
-    addTag("Medical Image Viewer");
-    
+    addTag(tr("All Viewers"));
+    addTag(tr("Medical Image Viewer"));
+
     // add a shortcut
-    getQAction()->setShortcut ( tr("Ctrl+0") );    
+    getQAction()->setShortcut ( tr("Ctrl+0") );
     getQAction()->setShortcutContext(Qt::ApplicationShortcut);
-    
+
     // can be checked or not (on/off), useful when group in a QActionGroup (radio buttons)
     getQAction()->setCheckable(true);
 }
