@@ -29,27 +29,28 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
+ *
+ * @brief
  * Within the MedicalImageViewer, display all viewers (except arbitrary).
- * 
- */ 
+ *
+ */
 class ShowAllViewers : public camitk::Action {
+    Q_OBJECT
 
 public:
-  /// Default Constructor
-  ShowAllViewers(camitk::ActionExtension *);
+    /// Default Constructor
+    ShowAllViewers(camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~ShowAllViewers();
+    /// Default Destructor
+    virtual ~ShowAllViewers();
 
-  /// Returns NULL: no widget for this action.
-  virtual QWidget * getWidget();
+    /// Returns NULL: no widget for this action.
+    virtual QWidget * getWidget();
 
 public slots:
-  /** this method is automatically called when the action is triggered.
-    * it calls setVisibility on the MedicalImageViewer instance
-    */
-  virtual ApplyStatus apply();
+    /** this method is automatically called when the action is triggered.
+     * it calls setVisibility on the MedicalImageViewer instance
+     */
+    virtual ApplyStatus apply();
 };
 #endif // SHOWALLVIEWERS_H
