@@ -32,18 +32,18 @@ ShowArbitraryViewer::ShowArbitraryViewer(ActionExtension * extension) : Action(e
     // Setting name, description and input component
     setName("Show Arbitrary Viewer");
     setEmbedded(false);
-    setDescription("Show the Arbitrary Slice Viewer Only");
+    setDescription(tr("Show the Arbitrary Slice Viewer Only"));
     setComponent("");
 
     // Setting classification family and tags
     setFamily("Application");
-    addTag("Arbitrary Slice Viewer");
-    addTag("Slice");
-    
+    addTag(tr("Arbitrary Slice Viewer"));
+    addTag(tr("Slice"));
+
     // add a shortcut
-    getQAction()->setShortcut ( tr("Ctrl+5") );    
+    getQAction()->setShortcut ( tr("Ctrl+5") );
     getQAction()->setShortcutContext(Qt::ApplicationShortcut);
-    
+
     // can be checked or not (on/off), useful when group in a QActionGroup (radio buttons)
     getQAction()->setCheckable(true);
 }
