@@ -32,18 +32,18 @@ ShowAxialViewer::ShowAxialViewer(ActionExtension * extension) : Action(extension
     // Setting name, description and input component
     setName("Show Axial Viewer");
     setEmbedded(false);
-    setDescription("Show the Axial Viewer Only");
+    setDescription(tr("Show the Axial Viewer Only"));
     setComponent("");
 
     // Setting classification family and tags
     setFamily("Application");
-    addTag("Axial Viewer");
-    addTag("Slice");
-    
+    addTag(tr("Axial Viewer"));
+    addTag(tr("Slice"));
+
     // add a shortcut
-    getQAction()->setShortcut ( tr("Ctrl+2") );    
+    getQAction()->setShortcut ( tr("Ctrl+2") );
     getQAction()->setShortcutContext(Qt::ApplicationShortcut);
-    
+
     // can be checked or not (on/off), useful when group in a QActionGroup (radio buttons)
     getQAction()->setCheckable(true);
 }
