@@ -29,27 +29,28 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
+ *
+ * @brief
  * Within the MedicalImageViewer, display the axial viewer.
- * 
+ *
  */
 class ShowAxialViewer : public camitk::Action {
+    Q_OBJECT
 
 public:
-  /// Default Constructor
-  ShowAxialViewer(camitk::ActionExtension *);
+    /// Default Constructor
+    ShowAxialViewer(camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~ShowAxialViewer();
+    /// Default Destructor
+    virtual ~ShowAxialViewer();
 
-  /// Returns NULL: no widget for this action.
-  virtual QWidget * getWidget();
+    /// Returns NULL: no widget for this action.
+    virtual QWidget * getWidget();
 
 public slots:
-  /** this method is automatically called when the action is triggered.
-    * it calls setVisibility on the MedicalImageViewer instance
-    */
-  virtual ApplyStatus apply();
+    /** this method is automatically called when the action is triggered.
+     * it calls setVisibility on the MedicalImageViewer instance
+     */
+    virtual ApplyStatus apply();
 };
 #endif // SHOWAXIALVIEWER_H
