@@ -34,14 +34,14 @@ ShowConsoleAction::ShowConsoleAction(ActionExtension * extension) : Action(exten
     // Setting name, description and input component
     setName("Show Console");
     setEmbedded(false);
-    setDescription("Show the redirection console window (view debugging information, cout, cerr,...)");
+    setDescription(tr("Show the redirection console window (view debugging information, cout, cerr,...)"));
     setComponent("");
     setIcon(QPixmap(":/showConsole"));
 
     // Setting classification family and tags
     setFamily("Application");
-    addTag("Console");
-    addTag("Terminal");
+    addTag(tr("Console"));
+    addTag(tr("Terminal"));
 }
 
 // --------------- destructor -------------------
