@@ -29,27 +29,28 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
+ *
+ * @brief
  * Display the console application widget, which, by default, prints the standard output.
- * 
+ *
  */
 class ShowConsoleAction : public camitk::Action {
+    Q_OBJECT
 
 public:
-  /// Default Constructor
-  ShowConsoleAction(camitk::ActionExtension *);
+    /// Default Constructor
+    ShowConsoleAction(camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~ShowConsoleAction();
+    /// Default Destructor
+    virtual ~ShowConsoleAction();
 
-  /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
-  virtual QWidget * getWidget();
+    /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
+    virtual QWidget * getWidget();
 
 public slots:
-  /** this method is automatically called when the action is triggered.
-    * It show the CamiTK console.
-    */
-  virtual ApplyStatus apply();
+    /** this method is automatically called when the action is triggered.
+      * It show the CamiTK console.
+      */
+    virtual ApplyStatus apply();
 };
 #endif // SHOWCONSOLEACTION_H
