@@ -32,18 +32,18 @@ ShowCoronalViewer::ShowCoronalViewer(ActionExtension * extension) : Action(exten
     // Setting name, description and input component
     setName("Show Coronal Viewer");
     setEmbedded(false);
-    setDescription("Show the Coronal Viewer Only");
+    setDescription(tr("Show the Coronal Viewer Only"));
     setComponent("");
 
     // Setting classification family and tags
     setFamily("Application");
-    addTag("Coronal Viewer");
-    addTag("Slice");
-    
+    addTag(tr("Coronal Viewer"));
+    addTag(tr("Slice"));
+
     // add a shortcut
-    getQAction()->setShortcut ( tr("Ctrl+4") );    
+    getQAction()->setShortcut ( tr("Ctrl+4") );
     getQAction()->setShortcutContext(Qt::ApplicationShortcut);
-    
+
     // can be checked or not (on/off), useful when group in a QActionGroup (radio buttons)
     getQAction()->setCheckable(true);
 }
