@@ -29,27 +29,28 @@
 
 /**
  * @ingroup group_sdk_actions_application
- * 
- * @brief 
+ *
+ * @brief
  * Within the MedicalImageViewer, display the coronal viewer.
- * 
+ *
  */
 class ShowCoronalViewer : public camitk::Action {
+    Q_OBJECT
 
 public:
-  /// Default Constructor
-  ShowCoronalViewer(camitk::ActionExtension *);
+    /// Default Constructor
+    ShowCoronalViewer(camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~ShowCoronalViewer();
+    /// Default Destructor
+    virtual ~ShowCoronalViewer();
 
-  /// Returns NULL: no widget for this action.
-  virtual QWidget * getWidget();
+    /// Returns NULL: no widget for this action.
+    virtual QWidget * getWidget();
 
 public slots:
-  /** this method is automatically called when the action is triggered.
-    * it calls setVisibility on the MedicalImageViewer instance
-    */
-  virtual ApplyStatus apply();
+    /** this method is automatically called when the action is triggered.
+     * it calls setVisibility on the MedicalImageViewer instance
+     */
+    virtual ApplyStatus apply();
 };
 #endif // SHOWCORONALVIEWER_H
