@@ -32,44 +32,43 @@
 
 /**
  * @ingroup group_sdk_actions_image_arbitraryslice
- * 
+ *
  * @brief
  * This class describes the QWidget that allows user to change the X,Y ans Z angle of the arbitrary slice
- * of a 2D image. Moreover it also allows to change the slice number using a slider.
+ * of a 2D image. Moreover it also allows one to change the slice number using a slider.
  * \note
  *  For initialization purpose, widget must be used for only one component (arbitrary).
  *  If several component are selected, do not build / display it.
- * 
+ *
  *  Use corresponding .ui file created with Qt Designer.
- */ 
-class AnglesSetterWidget : public QWidget
-{
-	Q_OBJECT
-	
+ */
+class AnglesSetterWidget : public QWidget {
+    Q_OBJECT
+
 public:
-	 /// Default construtor
+    /// Default construtor
     AnglesSetterWidget(QWidget* parent = 0);
-	
-	/// Destructor
-	virtual ~AnglesSetterWidget();
-	
+
+    /// Destructor
+    virtual ~AnglesSetterWidget();
+
 private:
     Ui::AnglesSetterWidget ui;
-	
+
 private:
-	/// update the angle dialog slider (text + value)
+    /// update the angle dialog slider (text + value)
     void updateAngleSlider(QDial * dial, QLabel * label);
-	
+
 private slots:
-	    
-	/// Update slice number to be displayed
-	void updateSlice(int sliceNumber);
-	
+
+    /// Update slice number to be displayed
+    void updateSlice(int sliceNumber);
+
     /// Method that update the angle dialog slider (text + value)
     void xAngleDialValueChanged (int value);
     void yAngleDialValueChanged (int value);
     void zAngleDialValueChanged (int value);
-	
+
 };
 
 #endif // AnglesSetterWidget_h
