@@ -37,15 +37,15 @@ using namespace camitk;
 // --------------- Constructor -------------------
 SetAnglesAction::SetAnglesAction(ActionExtension * extension) : Action(extension) {
     // Setting name, description and input component
-    setName("Adjust angles");
-    setDescription("This action allows user to adjust the angle of the slice of the arbitrary viewer.");
+    setName("Adjust Angles");
+    setDescription(tr("This action allows user to adjust the angle of the slice of the arbitrary viewer."));
     setComponent("ImageComponent");
 
     // Setting classification family and tags
     setFamily("Arbitrary Slice");
-    addTag("arbitrary slice");
-    addTag("arbitrary");
-    addTag("angle");
+    addTag(tr("arbitrary slice"));
+    addTag(tr("arbitrary"));
+    addTag(tr("angle"));
 
     actionWidget = 0;
 
