@@ -48,17 +48,17 @@ using namespace camitk;
 BoxVOI::BoxVOI ( ActionExtension * extension ) : Action ( extension ) {
     // Setting name, description and input component
     setName ( "Box Volume Of Interest" );
-    setDescription ( "<p>This filter helps you to crop a volume to keep only an interesting subsample. To use it, select respectively the min and the max of each axe (i,j,k), i.e 6 points. It is possible to use only 2 points (the origin of parallelepiped and its opposite diagonal point)." );
+    setDescription ( tr("<p>This filter helps you to crop a volume to keep only an interesting subsample. To use it, select respectively the min and the max of each axe (i,j,k), i.e 6 points. It is possible to use only 2 points (the origin of parallelepiped and its opposite diagonal point)." ));
     setComponent ( "ImageComponent" );
 
     setEmbedded ( true );
 
     // Setting classification family and tags
     this->setFamily ( "Image Processing" );
-    this->addTag ( "Crop Volume" );
-    this->addTag ( "Box" );
-    this->addTag ( "Volume Of Interest" );
-    this->addTag ( "Seed Point" );
+    this->addTag ( tr("Crop Volume") );
+    this->addTag ( tr("Box" ));
+    this->addTag ( tr("Volume Of Interest" ));
+    this->addTag ( tr("Seed Point") );
 
     // Setting the widget containing the parameters
     theWidget = NULL;
