@@ -34,12 +34,13 @@
 
 /**
  * @ingroup group_sdk_actions_image_cropvolume
- * 
+ *
  * @brief
  * Action to crop a volumic image.
- *  
- */ 
+ *
+ */
 class BoxVOI : public camitk::Action {
+    Q_OBJECT
 
 public:
     /// Default Constructor
@@ -48,7 +49,7 @@ public:
     /// Default Destructor
     virtual ~BoxVOI();
 
-    /// Returns the widget that allows to modify the action parameters
+    /// Returns the widget that allows one to modify the action parameters
     virtual QWidget * getWidget();
 
 public slots:
