@@ -30,17 +30,16 @@
 #include "BoxVOIWidget.h"
 using namespace camitk;
 
-BoxVOIWidget::BoxVOIWidget(Action * action) 
-: QWidget()
-{
-	this->myAction = action;
-	ui.setupUi(this);
-	pickingW = new MultiPickingWidget(this);
-	ui.boxPointsGroupBox->layout()->addWidget(pickingW);	
-	ui.descriptionBoxVOI->viewport()->setAutoFillBackground(false);
-    
-	QObject::connect(ui.applyButton, SIGNAL(clicked()), myAction, SLOT(apply()));
-	
+BoxVOIWidget::BoxVOIWidget(Action * action)
+    : QWidget() {
+    this->myAction = action;
+    ui.setupUi(this);
+    pickingW = new MultiPickingWidget(this);
+    ui.boxPointsGroupBox->layout()->addWidget(pickingW);
+    ui.descriptionBoxVOI->viewport()->setAutoFillBackground(false);
+
+    QObject::connect(ui.applyButton, SIGNAL(clicked()), myAction, SLOT(apply()));
+
 }
 
 BoxVOIWidget::~BoxVOIWidget() {
@@ -48,13 +47,13 @@ BoxVOIWidget::~BoxVOIWidget() {
 }
 
 QList<QVector3D> * BoxVOIWidget::getSeedPoints(ImageComponent * image) {
-    
-	return pickingW->getPickedPixelMap(image)->getPixelIndexList();
+
+    return pickingW->getPickedPixelMap(image)->getPixelIndexList();
 }
 
 
 void BoxVOIWidget::updateComponent (ImageComponent * image) {
-  
-	ui.componentName->setText(image->getName());
-	pickingW->updateComponent(image);
+
+    ui.componentName->setText(image->getName());
+    pickingW->updateComponent(image);
 }
