@@ -30,11 +30,11 @@
 
 /**
  * @ingroup group_sdk_actions_image_lut
- * 
+ *
  * @brief
  * The lut action extension
- *  
- */ 
+ *
+ */
 class ImageLutExtension : public camitk::ActionExtension {
     Q_OBJECT
     Q_INTERFACES(camitk::ActionExtension);
@@ -48,12 +48,16 @@ public:
 
     /// initialize all the actions
     virtual void init();
-            
+
     /// Method that return the action extension name
-    virtual QString getName() {return "Image LUT";};
-    
+    virtual QString getName() {
+        return "Image LUT";
+    };
+
     /// Method that return the action extension descrption
-    virtual QString getDescription() {return "This extension provides an action to manipulate the Look Up Table of an image component";};
+    virtual QString getDescription() {
+        return "This extension provides an action to manipulate the Look Up Table of an image component";
+    };
 
 };
 
