@@ -96,8 +96,7 @@ void ImageLutWidget::updateComponent(ImageComponent * comp) {
     if (myComponent->getLut() == NULL) {
         setEnabled(false);
         return;
-    }
-    else {
+    } else {
         setEnabled(true);
     }
 
@@ -172,8 +171,7 @@ void ImageLutWidget::applyLUT() {
     if (!invert) {
         minColor = fadedColor;
         maxColor = strongColor;
-    }
-    else {
+    } else {
         minColor = strongColor;
         maxColor = fadedColor;
     }
@@ -362,9 +360,8 @@ template<class DATATYPE>
 void ImageLutWidget::fillHistogramTable(DATATYPE * data, unsigned int dataDim, DATATYPE minVal, DATATYPE maxVal) {
     // scale factor from [min,max] to [0..nbHistoBins]
     DATATYPE intervalLength = (DATATYPE) ((maxVal - minVal) / (DATATYPE)nbHistoBins);
-        
-    if( intervalLength ) 
-    {
+
+    if( intervalLength ) {
         //-- build histogram
         for (unsigned int i = 0; i < dataDim; i++ ) {
             // Find the corresponding interval index
@@ -377,11 +374,9 @@ void ImageLutWidget::fillHistogramTable(DATATYPE * data, unsigned int dataDim, D
         highestGreyLevel = 0;
         for (unsigned int i = 0; i<nbHistoBins; i++) {
             if (greyLevels[i] > highestGreyLevel)
-                 highestGreyLevel = greyLevels[i];
+                highestGreyLevel = greyLevels[i];
         }
-    }
-    else
-    {
+    } else {
         QString msg = "Division by zero";
         CAMITK_ERROR("ImageLutWidget", "fillHistogramTable", msg.toStdString());
     }
