@@ -35,24 +35,24 @@ using namespace camitk;
 
 // --------------- constructor -------------------
 MultiPicking::MultiPicking (ActionExtension * extension) : Action (extension) {
-  setName ("Multiple Picking");
-  setDescription ("Action to manage several pixel points in an image (coordinates and index).");
-  setComponent ("ImageComponent");
-  setFamily ("Image Processing");
-  addTag ("Picking");
-  addTag("Select Pixels");
-  actionWidget=NULL;
+    setName ("Multiple Picking");
+    setDescription (tr("Action to manage several pixel points in an image (coordinates and index)."));
+    setComponent ("ImageComponent");
+    setFamily ("Image Processing");
+    addTag (tr("Picking"));
+    addTag(tr("Select Pixels"));
+    actionWidget=NULL;
 }
 
 // --------------- getWidget --------------
 QWidget * MultiPicking::getWidget() {
-  //-- create the widget if needed
-  if (!actionWidget) {
-    actionWidget = new MultiPickingWidget();
-  }
+    //-- create the widget if needed
+    if (!actionWidget) {
+        actionWidget = new MultiPickingWidget();
+    }
 
-  //-- update the widget with a PickedPixelMap param
-  actionWidget->updateComponent(dynamic_cast<ImageComponent *> (getTargets().last()));
+    //-- update the widget with a PickedPixelMap param
+    actionWidget->updateComponent(dynamic_cast<ImageComponent *> (getTargets().last()));
 
-  return actionWidget;
+    return actionWidget;
 }
