@@ -34,31 +34,34 @@ class MultiPickingWidget;
 
 /**
  * @ingroup group_sdk_actions_image_multipicking
- * 
+ *
  * @brief
  * This action allows the user to store a list of picked pixels.
- *  
+ *
  */
 class MultiPicking : public camitk::Action {
+    Q_OBJECT
 
 public:
-  /// Default Constructor
-  MultiPicking (camitk::ActionExtension *);
+    /// Default Constructor
+    MultiPicking (camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~MultiPicking() {};
+    /// Default Destructor
+    virtual ~MultiPicking() {};
 
-  /// Returns NULL as this action has no parameters
-  virtual QWidget* getWidget();
+    /// Returns NULL as this action has no parameters
+    virtual QWidget* getWidget();
 
 public slots:
-  /// method called when the action is applied (nothing to do here, everything will be done by the widget)
-  virtual ApplyStatus apply() { return SUCCESS; };
-  
+    /// method called when the action is applied (nothing to do here, everything will be done by the widget)
+    virtual ApplyStatus apply() {
+        return SUCCESS;
+    };
+
 private:
 
-  /// the widget component
-  MultiPickingWidget *actionWidget;
+    /// the widget component
+    MultiPickingWidget *actionWidget;
 
 };
 #endif // MULTIPICKINGACTION_H
