@@ -30,6 +30,7 @@
 
 // -- Core stuff classes
 #include "Application.h"
+#include <Property.h>
 
 // -- QT stuff
 #include <QLineEdit>
@@ -54,27 +55,42 @@
 using namespace camitk;
 
 
-
-
 // -------------------- constructor --------------------
 ImageReconstructionAction::ImageReconstructionAction(ActionExtension* extension) : Action(extension) {
     this->setName("Reconstruction");
-    this->setDescription("Action use to apply a reconstruction image component");
+    this->setDescription("<br /> Marching cubes is a simple algorithm for creating a triangle mesh from an implicit function (one of the form f(x, y, z) = 0).<br /> It works by iterating (\"marching\") over a uniform grid of cubes superimposed over a region of the function. If all 8 vertices of the cube are positive, or all 8 vertices are negative, the cube is entirely above or entirely below the surface and no triangles are emitted. Otherwise, the cube straddles the function and some triangles and vertices are generated. Since each vertex can either be positive or negative, there are technically 28 possible configurations, but many of these are equivalent to one another. <br/> <br/>This action uses this algorithm to build a 3D surfacic mesh of the input image.");
     this->setComponent("ImageComponent");
     this->setFamily("Reconstruction");
     this->addTag("Reconstruction");
 
-    //-- properties managed by the specific UI
-    setProperty("Threshold Value", 0.0); // Grey levels corresponding to the isovalue the isosurface represents
+    // Action parameters
+    Property* thresholdProperty = new Property(tr("Threshold"), 127.5, tr("Grey level value corresponding to the isovalue the isosurface represents."), "");
+    thresholdProperty->setAttribute("minimum", 0.0);
+    thresholdProperty->setAttribute("singleStep", 0.1);
+    addParameter(thresholdProperty);
 
     // Do I keep the largest component ?
-    setProperty("Keep Only Largest Connected Component", true); // If true, keep only the largest component
+    Property* keepLargestCCProperty = new Property(tr("Keep only largest component?"), true, tr("Do we keep only the largest component?"), "");
+    addParameter(keepLargestCCProperty);
 
     // Subsample original image ?
-    setProperty("Subsample Original Image", true); // If true, the image is subsampled by 1/2^3 to simplify the output object
-    setProperty("X Size", 64); // subsampling to apply in the X direction
-    setProperty("Y Size", 64); // subsampling to apply in the Y direction
-    setProperty("Z Size", 64); // subsampling to apply in the Z direction
+    Property* subsampleOrginalImageProperty = new Property(tr("Subsample original image?"), true, tr("Do we subsample input image for faster computation?"), "");
+    addParameter(subsampleOrginalImageProperty);
+
+    Property* subsampledImageX = new Property(tr("Subsampled image width (X)"), 64, tr("The width (X dimension) of the subsampled image"), "");
+    subsampledImageX->setAttribute("minimum", 1);
+    subsampledImageX->setAttribute("singleStep", 1);
+    addParameter(subsampledImageX);
+
+    Property* subsampledImageY = new Property(tr("Subsampled image height (Y)"), 64, tr("The height (Y dimension) of the subsampled image"), "");
+    subsampledImageY->setAttribute("minimum", 1);
+    subsampledImageY->setAttribute("singleStep", 1);
+    addParameter(subsampledImageY);
+
+    Property* subsampledImageZ = new Property(tr("Subsampled image depth (Z)"), 64, tr("The depth (Z dimension) of the subsampled image"), "");
+    subsampledImageZ->setAttribute("minimum", 1);
+    subsampledImageZ->setAttribute("singleStep", 1);
+    addParameter(subsampledImageZ);
 }
 
 // -------------------- destructor --------------------
@@ -83,93 +99,35 @@ ImageReconstructionAction::~ImageReconstructionAction() {
         delete actionWidget;
 }
 
-// -------------------- getWidget --------------------
-QWidget * ImageReconstructionAction::getWidget() {
-    if (actionWidget)
-        delete actionWidget;
-
-    // rebuild widget from scratch
-    actionWidget = new QWidget();
-    myComponent = dynamic_cast<ImageComponent *>(getTargets().last());
-    init();
-
-    return actionWidget;
-}
-
 // -------------------- apply --------------------
 Action::ApplyStatus ImageReconstructionAction::apply() {
-    build3DModel();
-    return SUCCESS;
-}
 
-// ---------------------- init ----------------------------
-void ImageReconstructionAction::init() {
-    ui.setupUi(actionWidget);
-
-    // init thresholds and component name
-    ui.lineImagesName->setText(myComponent->getName());
-    double medianColor = (myComponent->getMaxColor() - myComponent->getMinColor()) / 2.0;
-    setProperty("Threshold Value", medianColor);
-    ui.lineThresholdValue->setText(property("Threshold Value").toString());
-
-    connect(ui.PushButton5, SIGNAL(clicked()), this, SLOT(build3DModel()));
-    connect(ui.keepComponentcheckBox, SIGNAL(toggled( bool )), this, SLOT(keepComponentcheckBox_toggled(bool)));
-    connect(ui.subSamplecheckBox, SIGNAL(toggled( bool )), this, SLOT(subSamplecheckBox_toggled(bool)));
-
-    // init subsample dimensions
-    ui.lineXDimension->setText(property("X Size").toString());
-    ui.lineYDimension->setText(property("Y Size").toString());
-    ui.lineZDimension->setText(property("Z Size").toString());
-}
-
-// ---------------------- build3DModel  ----------------------------
-void ImageReconstructionAction::build3DModel() {
-    // computes the model
-    setProperty("Threshold Value", ui.lineThresholdValue->text().toDouble());
-    setProperty("X Size", ui.lineXDimension->text().toInt());
-    setProperty("Y Size", ui.lineYDimension->text().toInt());
-    setProperty("Z Size", ui.lineZDimension->text().toInt());
+    // get original input ImageComponent
+    this->myComponent = dynamic_cast<ImageComponent *>(getTargets().last());
 
+    // compute model
     vtkSmartPointer<vtkPointSet> resultPointSet = this->getMarchingCubesReconstruction();
-
     new MeshComponent(resultPointSet, myComponent->getName() + "_mesh");
     Application::refresh();
 
-}
-
-// -------------------- keepComponentcheckBox_toggled --------------------
-void ImageReconstructionAction::keepComponentcheckBox_toggled(bool toggled) {
-    setProperty("Keep Only Largest Connected Component", toggled);
-}
-
-// -------------------- subSamplecheckBox_toggled --------------------
-void ImageReconstructionAction::subSamplecheckBox_toggled(bool toggled) {
-    setProperty("Subsample Original Image", toggled);
-    ui.labelImageSize->setEnabled(toggled);
-    ui.label_X_Size->setEnabled(toggled);
-    ui.lineXDimension->setEnabled(toggled);
-    ui.label_Y_Size->setEnabled(toggled);
-    ui.lineYDimension->setEnabled(toggled);
-    ui.label_Z_Size->setEnabled(toggled);
-    ui.lineZDimension->setEnabled(toggled);
+    return SUCCESS;
 }
 
 // -------------------- getMarchingCubesReconstruction --------------------
 vtkSmartPointer<vtkPointSet> ImageReconstructionAction::getMarchingCubesReconstruction() {
-    ImageComponent * image = myComponent;
-    double isoValue = property("Threshold Value").toDouble();
-    bool keepLargestConnectedComponent = property("Keep Only Largest Connected Component").toBool();
-    bool subsample = property("Subsample Original Image").toBool();
-    int subSampledDimX = property("X Size").toInt();
-    int subSampledDimY = property("Y Size").toInt();
-    int subSampledDimZ = property("Z Size").toInt();
+    double isoValue = property("Threshold").toDouble();
+    bool keepLargestConnectedComponent = property("Keep only largest component?").toBool();
+    bool subsample = property("Subsample original image?").toBool();
+    int subSampledDimX = property("Subsampled image width (X)").toInt();
+    int subSampledDimY = property("Subsampled image height (Y)").toInt();
+    int subSampledDimZ = property("Subsampled image depth (Z)").toInt();
 
     Application::showStatusBarMessage("Computing Marching Cube Reconstruction");
     Application::resetProgressBar();
     vtkSmartPointer<vtkCallbackCommand> progressCallback = vtkSmartPointer<vtkCallbackCommand>::New();
     progressCallback->SetCallback(&Application::vtkProgressFunction);
 
-    vtkSmartPointer<vtkImageData> originalImageData = image->getImageData();
+    vtkSmartPointer<vtkImageData> originalImageData = this->myComponent->getImageData();
     vtkSmartPointer<vtkImageData> currentData = originalImageData;
 
     // For medical volumes, marching cubes generates a large number of triangles.
@@ -234,8 +192,7 @@ vtkSmartPointer<vtkPointSet> ImageReconstructionAction::getMarchingCubesReconstr
         connectivityFilter->SetInput(mcSurface->GetOutput());
         connectivityFilter->SetExtractionModeToLargestRegion();
         normalsFilter->SetInput(connectivityFilter->GetOutput());
-    }
-    else
+    } else
         normalsFilter->SetInput(mcSurface->GetOutput());
 
     normalsFilter->AddObserver(vtkCommand::ProgressEvent, progressCallback);
