@@ -27,19 +27,17 @@
 #ifndef ImageReconstructionAction_H
 #define ImageReconstructionAction_H
 
-// -- Core image component stuff
-#include "ui_ImageReconstructionAction.h"
-
+// -- CamiTK includes
 #include <Action.h>
 #include <ImageComponent.h>
 
 /**
  * @ingroup group_sdk_actions_image_reconstruction
- * 
+ *
  * @brief
  * The class ImageReconstructionAction interfaces the reconstruction
  * of 3D volumes from a set of images (ImageComponent), typically using the marching cubes algorithm.
- *  
+ *
  */
 class ImageReconstructionAction : public camitk::Action {
     Q_OBJECT
@@ -52,10 +50,7 @@ public:
     virtual ~ImageReconstructionAction();
 
     /// this method creates and returns the widget containing the user interface for the action
-    virtual QWidget * getWidget();
-
-    /// Initializes the dialog options
-    void init();
+    //virtual QWidget * getWidget();
 
 public slots:
     /// method called when the action is applied (nothing to do here, everything will be done by the widget)
@@ -68,13 +63,8 @@ private:
     /// The initial images, used for the reconstruction.
     camitk::ImageComponent *myComponent;
 
-    /// Qt model designed by QtDesigner (with qt4, nor more inheritance from the ui)
-    Ui::ui_ImageReconstructionAction ui;
 
-public slots:
-    void build3DModel();
-    void keepComponentcheckBox_toggled(bool toggled);
-    void subSamplecheckBox_toggled(bool toggled);
+
 };
 
 //**************************************************************************
