@@ -32,13 +32,13 @@
 
 /**
  * @ingroup group_sdk_actions_image_reconstruction
- * 
+ *
  * @brief
  * This reconstruction action extension.
- *  
+ *
  */
 class ReconstructionExtension : public camitk::ActionExtension {
-  Q_OBJECT
+    Q_OBJECT
     Q_INTERFACES(camitk::ActionExtension);
 
 public:
@@ -50,12 +50,16 @@ public:
 
     /// initialize all the actions
     virtual void init();
-    
+
     /// Method that return the action extension name
-    virtual QString getName() {return "Reconstruction";};
-    
+    virtual QString getName() {
+        return "Reconstruction";
+    };
+
     /// Method that return the action extension descrption
-    virtual QString getDescription() {return "Extension that provides 3D reconstruction from an image component (e.g. marching cube)";};
+    virtual QString getDescription() {
+        return "Extension that provides 3D reconstruction from an image component (e.g. marching cube)";
+    };
 
 };
 
