@@ -30,31 +30,32 @@
 
 /**
  * @ingroup group_sdk_actions_image_showin3d
- * 
+ *
  * @brief
  * Shows the arbitrary slice of the @ref camitk::ImageComponent in the 3D viewer.
- * 
+ *
  * @note
- * The arbitrary slice is not visible by default. 
+ * The arbitrary slice is not visible by default.
  * This action allows you to display it within the 3D viewer.
- *  
+ *
  */
 class ShowArbitrarySliceIn3D : public camitk::Action {
+    Q_OBJECT
 
 public:
-  /// Default Constructor
-  ShowArbitrarySliceIn3D(camitk::ActionExtension *);
+    /// Default Constructor
+    ShowArbitrarySliceIn3D(camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~ShowArbitrarySliceIn3D();
+    /// Default Destructor
+    virtual ~ShowArbitrarySliceIn3D();
 
-  /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
-  virtual QWidget * getWidget();
+    /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
+    virtual QWidget * getWidget();
 
 public slots:
-  /** this method is automatically called when the action is triggered.
-    * It gets all the targets' top level component and close them.
-    */
-  virtual ApplyStatus apply();
+    /** this method is automatically called when the action is triggered.
+      * It gets all the targets' top level component and close them.
+      */
+    virtual ApplyStatus apply();
 };
 #endif // SHOWARBITRARYSLICEIN3D_H
