@@ -33,14 +33,14 @@ using namespace camitk;
 // --------------- constructor -------------------
 ShowAxialSliceIn3D::ShowAxialSliceIn3D(ActionExtension * extension) : Action(extension) {
     // Setting name, description and input component
-    setName("ShowAxialSliceIn3D");
+    setName("Show Axial Slice In 3D");
     setEmbedded(false);
-    setDescription("Toggle display of the axial slice in 3D");
+    setDescription(tr("Toggle display of the axial slice in 3D"));
     setComponent("ImageComponent");
 
     // Setting classification family and tags
     setFamily("Display");
-    addTag("3D Viewer");
+    addTag(tr("3D Viewer"));
 
 }
 
