@@ -31,15 +31,15 @@ using namespace camitk;
 // --------------- constructor -------------------
 ShowImageIn3D::ShowImageIn3D(ActionExtension * extension) : Action(extension) {
     // Setting name, description and input component
-    setName("ShowImageIn3D");
+    setName("Show Image In 3D");
     setEmbedded(false);
-    setDescription("Shows the Image Volume in 3D viewer");
+    setDescription(tr("Shows the Image Volume in 3D viewer"));
     setComponent("ImageComponent");
     // TODO: set a small icon with Axial/Coronal/Sagittal views in 3D
 
     // Setting classification family and tags
     setFamily("Display");
-    addTag("3D Viewer");
+    addTag(tr("3D Viewer"));
 
     // add shortcut
     getQAction()->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_D));
