@@ -29,27 +29,28 @@
 
 /**
  * @ingroup group_sdk_actions_image_showin3d
- * 
+ *
  * @brief
  * Shows the whole volumic image (i.e. the @ref camitk::ImageComponent) in the 3D viewer.
- *  
+ *
  */
 class ShowImageIn3D : public camitk::Action {
+    Q_OBJECT
 
 public:
-  /// Default Constructor
-  ShowImageIn3D(camitk::ActionExtension *);
+    /// Default Constructor
+    ShowImageIn3D(camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~ShowImageIn3D();
+    /// Default Destructor
+    virtual ~ShowImageIn3D();
 
-  /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
-  virtual QWidget * getWidget();
+    /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
+    virtual QWidget * getWidget();
 
 public slots:
-  /** this method is automatically called when the action is triggered.
-    * It gets all the targets' top level component and close them.
-    */
-  virtual ApplyStatus apply();
+    /** this method is automatically called when the action is triggered.
+      * It gets all the targets' top level component and close them.
+      */
+    virtual ApplyStatus apply();
 };
 #endif // SHOWIMAGEIN3D_H
