@@ -30,27 +30,28 @@
 
 /**
  * @ingroup group_sdk_actions_image_showin3d
- * 
+ *
  * @brief
  * Shows the sagittal slice of the volumic image in the 3D viewer.
- *  
+ *
  */
 class ShowSagittalSliceIn3D : public camitk::Action {
+    Q_OBJECT
 
 public:
-  /// Default Constructor
-  ShowSagittalSliceIn3D(camitk::ActionExtension *);
+    /// Default Constructor
+    ShowSagittalSliceIn3D(camitk::ActionExtension *);
 
-  /// Default Destructor
-  virtual ~ShowSagittalSliceIn3D();
+    /// Default Destructor
+    virtual ~ShowSagittalSliceIn3D();
 
-  /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
-  virtual QWidget * getWidget();
+    /// Returns NULL: no permanent widget for this action. The GUI is run shown a one-shot dialog in apply
+    virtual QWidget * getWidget();
 
 public slots:
-  /** this method is automatically called when the action is triggered.
-    * It gets all the targets' top level component and close them.
-    */
-  virtual ApplyStatus apply();
+    /** this method is automatically called when the action is triggered.
+      * It gets all the targets' top level component and close them.
+      */
+    virtual ApplyStatus apply();
 };
 #endif // SHOWSAGITTALSLICEIN3D_H
