@@ -27,62 +27,60 @@
 #include <QColor>
 #include <QColorDialog>
 
-// - Local stuff 
+// - Local stuff
 #include "ColorPointWidget.h"
 #include "VolumeRenderingWidget.h"
 
-ColorPointWidget::ColorPointWidget(QWidget * dad) : QWidget(dad)
-{
+ColorPointWidget::ColorPointWidget(QWidget * dad) : QWidget(dad) {
     ui.setupUi(this);
-    this->dad = dad;	
-	this->currentColor = QColor(255, 255, 255, 255);
-	QString s = "background-color: ";
-	ui.colorPushButton->setStyleSheet(s + currentColor.name());
+    this->dad = dad;
+    this->currentColor = QColor(255, 255, 255, 255);
+    QString s = tr("background-color: ");
+    ui.colorPushButton->setStyleSheet(s + currentColor.name());
 
 }
 
-ColorPointWidget::ColorPointWidget(QWidget * dad, int grayLevel, QColor color) : QWidget(dad)
-{
+ColorPointWidget::ColorPointWidget(QWidget * dad, int grayLevel, QColor color) : QWidget(dad) {
     ui.setupUi(this);
     this->dad = dad;
-	this->currentColor = QColor(255, 255, 255, 255);
+    this->currentColor = QColor(255, 255, 255, 255);
 
-	ui.GrayLevelSpinBox->setValue(grayLevel);
+    ui.GrayLevelSpinBox->setValue(grayLevel);
 
-	if (color.isValid()) 
-		currentColor = color;
-	QString s = "background-color: ";
-	ui.colorPushButton->setStyleSheet(s + currentColor.name());
+    if (color.isValid())
+        currentColor = color;
+    QString s = tr("background-color: ");
+    ui.colorPushButton->setStyleSheet(s + currentColor.name());
 
 }
 
 void ColorPointWidget::remove() {
-	VolumeRenderingWidget * dadVR = dynamic_cast<VolumeRenderingWidget*> (this->dad);
-	if (dadVR)
-		dadVR->removeColorPoint(this);
+    VolumeRenderingWidget * dadVR = dynamic_cast<VolumeRenderingWidget*> (this->dad);
+    if (dadVR)
+        dadVR->removeColorPoint(this);
 }
 
 void ColorPointWidget::colorButtonClicked() {
-	QColor color = QColorDialog::getColor(currentColor, this, "Please choose a color", QColorDialog::ShowAlphaChannel);
+    QColor color = QColorDialog::getColor(currentColor, this, tr("Please choose a color"), QColorDialog::ShowAlphaChannel);
 
-	if (color.isValid()) {
-		currentColor = color;
-		QString s = "background-color: ";
-		ui.colorPushButton->setStyleSheet(s + currentColor.name());
-	}
+    if (color.isValid()) {
+        currentColor = color;
+        QString s = tr("background-color: ");
+        ui.colorPushButton->setStyleSheet(s + currentColor.name());
+    }
 
 }
 
 int ColorPointWidget::getGrayLevel() {
-	return ui.GrayLevelSpinBox->value();
+    return ui.GrayLevelSpinBox->value();
 }
 
 QColor ColorPointWidget::getColor() {
-	return currentColor;
+    return currentColor;
 }
 
 void ColorPointWidget::grayLevelChanged(int gray) {
-	bool oldState = ui.grayLevelSlider->blockSignals(true);
-	ui.grayLevelSlider->setValue(gray);
-	ui.grayLevelSlider->blockSignals(oldState);
+    bool oldState = ui.grayLevelSlider->blockSignals(true);
+    ui.grayLevelSlider->setValue(gray);
+    ui.grayLevelSlider->blockSignals(oldState);
 }
\ No newline at end of file
