@@ -27,44 +27,42 @@
 #include <QColor>
 #include <QColorDialog>
 
-// - Local stuff 
+// - Local stuff
 #include "ColorPointWidget.h"
 #include "VolumeRenderingWidget.h"
 
-GradientOpacityWidget::GradientOpacityWidget(QWidget * dad) : QWidget(dad)
-{
-    ui.setupUi(this);
-    this->dad = dad;	
-}
-
-GradientOpacityWidget::GradientOpacityWidget(QWidget * dad, int grayLevel, double opacity) : QWidget(dad)
-{
+GradientOpacityWidget::GradientOpacityWidget(QWidget * dad) : QWidget(dad) {
     ui.setupUi(this);
     this->dad = dad;
-	
-	ui.grayLevelSpinBox->setValue(grayLevel);
-	ui.opacitySpinBox->setValue(opacity);
+}
+
+GradientOpacityWidget::GradientOpacityWidget(QWidget * dad, int grayLevel, double opacity) : QWidget(dad) {
+    ui.setupUi(this);
+    this->dad = dad;
+
+    ui.grayLevelSpinBox->setValue(grayLevel);
+    ui.opacitySpinBox->setValue(opacity);
 
 }
 
 void GradientOpacityWidget::remove() {
-	VolumeRenderingWidget * dadVR = dynamic_cast<VolumeRenderingWidget*> (this->dad);
-	if (dadVR)
-		dadVR->removeOpacityPoint(this);
+    VolumeRenderingWidget * dadVR = dynamic_cast<VolumeRenderingWidget*> (this->dad);
+    if (dadVR)
+        dadVR->removeOpacityPoint(this);
 }
 
 int GradientOpacityWidget::getGrayLevel() {
-	return ui.grayLevelSpinBox->value();
+    return ui.grayLevelSpinBox->value();
 }
 
 double GradientOpacityWidget::getOpacity() {
-	return ui.opacitySpinBox->value();
+    return ui.opacitySpinBox->value();
 }
 
 void GradientOpacityWidget::grayLevelChanged(int gray) {
-	bool oldState = ui.grayLevelSlider->blockSignals(true);
-	ui.grayLevelSlider->setValue(gray);
-	ui.grayLevelSlider->blockSignals(oldState);
+    bool oldState = ui.grayLevelSlider->blockSignals(true);
+    ui.grayLevelSlider->setValue(gray);
+    ui.grayLevelSlider->blockSignals(oldState);
 }
 
 void GradientOpacityWidget::opacityChanged(double value) {
