@@ -27,44 +27,42 @@
 #include <QColor>
 #include <QColorDialog>
 
-// - Local stuff 
+// - Local stuff
 #include "ColorPointWidget.h"
 #include "VolumeRenderingWidget.h"
 
-TransparencyPointWidget::TransparencyPointWidget(QWidget * dad) : QWidget(dad)
-{
-    ui.setupUi(this);
-    this->dad = dad;	
-}
-
-TransparencyPointWidget::TransparencyPointWidget(QWidget * dad, int grayLevel, double transparency) : QWidget(dad)
-{
+TransparencyPointWidget::TransparencyPointWidget(QWidget * dad) : QWidget(dad) {
     ui.setupUi(this);
     this->dad = dad;
-	
-	ui.grayLevelSpinBox->setValue(grayLevel);
-	ui.transparencySpinBox->setValue(transparency);
+}
+
+TransparencyPointWidget::TransparencyPointWidget(QWidget * dad, int grayLevel, double transparency) : QWidget(dad) {
+    ui.setupUi(this);
+    this->dad = dad;
+
+    ui.grayLevelSpinBox->setValue(grayLevel);
+    ui.transparencySpinBox->setValue(transparency);
 
 }
 
 void TransparencyPointWidget::remove() {
-	VolumeRenderingWidget * dadVR = dynamic_cast<VolumeRenderingWidget*> (this->dad);
-	if (dadVR)
-		dadVR->removeTransparencyPoint(this);
+    VolumeRenderingWidget * dadVR = dynamic_cast<VolumeRenderingWidget*> (this->dad);
+    if (dadVR)
+        dadVR->removeTransparencyPoint(this);
 }
 
 int TransparencyPointWidget::getGrayLevel() {
-	return ui.grayLevelSpinBox->value();
+    return ui.grayLevelSpinBox->value();
 }
 
 double TransparencyPointWidget::getTransparency() {
-	return ui.transparencySpinBox->value();
+    return ui.transparencySpinBox->value();
 }
 
 void TransparencyPointWidget::grayLevelChanged(int gray) {
-	bool oldState = ui.grayLevelSlider->blockSignals(true);
-	ui.grayLevelSlider->setValue(gray);
-	ui.grayLevelSlider->blockSignals(oldState);
+    bool oldState = ui.grayLevelSlider->blockSignals(true);
+    ui.grayLevelSlider->setValue(gray);
+    ui.grayLevelSlider->blockSignals(oldState);
 
 }
 
