@@ -60,44 +60,44 @@ using namespace camitk;
 
 // --------------- constructor -------------------
 VolumeRenderingAction::VolumeRenderingAction(ActionExtension * extension) : Action(extension) {
-	// Init fields
-	myWidget = NULL;
-	volumeName = "volume-rendering";
+    // Init fields
+    myWidget = NULL;
+    volumeName = "volume-rendering";
 
 
     // Setting name, description and input component
     setName("Volume Rendering");
     setEmbedded(false);
-    setDescription("Volume rendering of 3D medical image using ray casting<br/>\
-				   (Use Ctrl+R to render a selected image volume)");
+    setDescription(tr("Volume rendering of 3D medical image using ray casting<br/>\
+				   (Use Ctrl+R to render a selected image volume)"));
     setComponent("ImageComponent");
 
     // Setting classification family and tags
     setFamily("Display");
-    addTag("Volume rendering");
-    addTag("volume");
-    addTag("render");
+    addTag(tr("Volume rendering"));
+    addTag(tr("volume"));
+    addTag(tr("render"));
 
     // add shortcut
-	getQAction()->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_R));
+    getQAction()->setShortcut(QKeySequence(Qt::CTRL + Qt::Key_R));
     getQAction()->setShortcutContext(Qt::ApplicationShortcut);
 
-	/*
-	// Define default colors
-	defaultTransparencies.insert(  0, 0.0);
-	defaultTransparencies.insert(255, 1.0);
+    /*
+    // Define default colors
+    defaultTransparencies.insert(  0, 0.0);
+    defaultTransparencies.insert(255, 1.0);
 
-	defaultColors.insert(  0, QColor(204,  77,  51, 255));
-	defaultColors.insert(255, QColor(128, 128, 128, 255));
+    defaultColors.insert(  0, QColor(204,  77,  51, 255));
+    defaultColors.insert(255, QColor(128, 128, 128, 255));
 
-	defaultGradientOpacities.insert(0, 0.0);
-	defaultGradientOpacities.insert(90, 0.5);
-	defaultGradientOpacities.insert(150, 1.0);
+    defaultGradientOpacities.insert(0, 0.0);
+    defaultGradientOpacities.insert(90, 0.5);
+    defaultGradientOpacities.insert(150, 1.0);
 
-	defaultAmbiant	= 0.4;
-	defaultDiffuse	= 0.6;
-	defaultSpecular = 0.2;
-	*/
+    defaultAmbiant	= 0.4;
+    defaultDiffuse	= 0.6;
+    defaultSpecular = 0.2;
+    */
 }
 
 // --------------- destructor -------------------
@@ -105,7 +105,7 @@ VolumeRenderingAction::~VolumeRenderingAction() {
 }
 
 QWidget * VolumeRenderingAction::getWidget() {
-	return NULL;
+    return NULL;
 }
 
 // --------------- apply -------------------
@@ -119,55 +119,53 @@ Action::ApplyStatus VolumeRenderingAction::apply() {
 }
 
 void VolumeRenderingAction::process(ImageComponent * comp) {
-	bool isVisible	= comp->getVolumeRenderingChild()->getVisibility(InteractiveViewer::get3DViewer());
-	bool existVR	= (comp->getVolumeRenderingChild()->getProp(volumeName) != NULL);
-	if (existVR) {
-		if (isVisible) {
-			comp->getVolumeRenderingChild()->setVisibility(InteractiveViewer::get3DViewer(), false);
-			if (myWidget)
-				myWidget->close();
-			Application::refresh();
-		}
-		else {
-			comp->getVolumeRenderingChild()->setVisibility(InteractiveViewer::get3DViewer(), true);
-			if (myWidget != NULL) {
-				myWidget->show();
-				Application::refresh();
-			}
-		}
-	}
-	else {
-		if (myWidget == NULL)
-			myWidget = new VolumeRenderingWidget(this);
+    bool isVisible	= comp->getVolumeRenderingChild()->getVisibility(InteractiveViewer::get3DViewer());
+    bool existVR	= (comp->getVolumeRenderingChild()->getProp(volumeName) != NULL);
+    if (existVR) {
+        if (isVisible) {
+            comp->getVolumeRenderingChild()->setVisibility(InteractiveViewer::get3DViewer(), false);
+            if (myWidget)
+                myWidget->close();
+            Application::refresh();
+        } else {
+            comp->getVolumeRenderingChild()->setVisibility(InteractiveViewer::get3DViewer(), true);
+            if (myWidget != NULL) {
+                myWidget->show();
+                Application::refresh();
+            }
+        }
+    } else {
+        if (myWidget == NULL)
+            myWidget = new VolumeRenderingWidget(this);
 
-		myWidget->updateImage(comp);
-		myWidget->show();
-	}
+        myWidget->updateImage(comp);
+        myWidget->show();
+    }
 }
 
 
 void VolumeRenderingAction::createVolumeRendering(ImageComponent * comp) {
-	// Get the transfer function from the widget
-	QMap<int, double> transparencies = myWidget->getTransparencyPoints();
-	QMap<int, double>::const_iterator transIt;
+    // Get the transfer function from the widget
+    QMap<int, double> transparencies = myWidget->getTransparencyPoints();
+    QMap<int, double>::const_iterator transIt;
 
-	QMap<int, QColor> transferColors = myWidget->getColorPoints();
-	QMap<int, QColor>::const_iterator colorIt;
+    QMap<int, QColor> transferColors = myWidget->getColorPoints();
+    QMap<int, QColor>::const_iterator colorIt;
 
-	QMap<int, double> gradientOpacities = myWidget->getOpacityPoints();
-	QMap<int, double>::const_iterator gradientIt;
+    QMap<int, double> gradientOpacities = myWidget->getOpacityPoints();
+    QMap<int, double>::const_iterator gradientIt;
 
-	double ambiant	= myWidget->getAmbiant();
-	double diffuse	= myWidget->getDiffuse();
-	double specular = myWidget->getSpecular();
+    double ambiant	= myWidget->getAmbiant();
+    double diffuse	= myWidget->getDiffuse();
+    double specular = myWidget->getSpecular();
 
     // FILTER
     // Cast element type of the image of type unigned short for mapper to work on the image
     vtkSmartPointer<vtkImageCast> imageCast = vtkImageCast::New();
     imageCast->SetInput(comp->getImageData()); // reader->GetOutput());
-	imageCast->SetOutputScalarTypeToUnsignedChar();
+    imageCast->SetOutputScalarTypeToUnsignedChar();
 
-	// Convert RGB images
+    // Convert RGB images
     vtkSmartPointer<vtkImageMagnitude> magnitudeFilter = vtkSmartPointer<vtkImageMagnitude>::New();
     magnitudeFilter->SetInputConnection(imageCast->GetOutputPort());
     magnitudeFilter->Update();
@@ -176,11 +174,11 @@ void VolumeRenderingAction::createVolumeRendering(ImageComponent * comp) {
     vtkSmartPointer<vtkVolumeRayCastMapper> volumeMapper = vtkSmartPointer<vtkVolumeRayCastMapper>::New();
     volumeMapper->SetInput(magnitudeFilter->GetOutput());
 
-	// The volume will be displayed by ray-cast alpha compositing.
+    // The volume will be displayed by ray-cast alpha compositing.
     // A ray-cast mapper is needed to do the ray-casting, and a
     // compositing function is needed to do the compositing along the ray.
-    vtkSmartPointer<vtkVolumeRayCastCompositeFunction> rayCastFunction = 
-		vtkSmartPointer<vtkVolumeRayCastCompositeFunction>::New();
+    vtkSmartPointer<vtkVolumeRayCastCompositeFunction> rayCastFunction =
+        vtkSmartPointer<vtkVolumeRayCastCompositeFunction>::New();
     volumeMapper->SetVolumeRayCastFunction(rayCastFunction);
 
     // RENDERER
@@ -194,12 +192,12 @@ void VolumeRenderingAction::createVolumeRendering(ImageComponent * comp) {
     // where gray is the grayscale value (of type unsigned short)
     vtkSmartPointer<vtkColorTransferFunction> volumeColor = vtkSmartPointer<vtkColorTransferFunction>::New();
     // Set the value that the user has entered in the ui sping box
-	for (colorIt = transferColors.begin(); colorIt != transferColors.end(); colorIt++) {
-		int gray = colorIt.key();
-		QColor color = colorIt.value();
-		volumeColor->AddRGBPoint((double) gray, color.redF(), color.greenF(), color.blueF());
-	}
-	
+    for (colorIt = transferColors.begin(); colorIt != transferColors.end(); colorIt++) {
+        int gray = colorIt.key();
+        QColor color = colorIt.value();
+        volumeColor->AddRGBPoint((double) gray, color.redF(), color.greenF(), color.blueF());
+    }
+
     // 2nd property : volume opacity
     // The opacity transfer function is used to control the opacity of different tissue types.
     // This function associate to a gray scale value a transparancy value (alpha)
@@ -207,13 +205,13 @@ void VolumeRenderingAction::createVolumeRendering(ImageComponent * comp) {
     // f : gray |-> alpha
     // where gray is the grayscale value (of type unsigned short)
     vtkSmartPointer<vtkPiecewiseFunction> volumeScalarOpacity = vtkSmartPointer<vtkPiecewiseFunction>::New();
-	for (transIt = transparencies.begin(); transIt != transparencies.end(); transIt++) {
-		int gray = transIt.key();
-		double trans = transIt.value();
-		volumeScalarOpacity->AddPoint(gray, trans);
-	}
+    for (transIt = transparencies.begin(); transIt != transparencies.end(); transIt++) {
+        int gray = transIt.key();
+        double trans = transIt.value();
+        volumeScalarOpacity->AddPoint(gray, trans);
+    }
 
-	// 3rd property : gradient of opacity function function of the distance
+    // 3rd property : gradient of opacity function function of the distance
     // The gradient opacity function is used to decrease the opacity
     // in the "flat" regions of the volume while maintaining the opacity
     // at the boundaries between tissue types.  The gradient is measured
@@ -224,12 +222,12 @@ void VolumeRenderingAction::createVolumeRendering(ImageComponent * comp) {
     // It enables the function to better render the boundaries between different tissues
     vtkSmartPointer<vtkPiecewiseFunction> volumeGradientOpacity = vtkSmartPointer<vtkPiecewiseFunction>::New();
 
-	for (gradientIt = gradientOpacities.begin(); gradientIt != gradientOpacities.end(); gradientIt++) {
-		int gray = gradientIt.key();
-		double opacity = gradientIt.value();
-		volumeGradientOpacity->AddPoint(gray, opacity);
-	}
-	
+    for (gradientIt = gradientOpacities.begin(); gradientIt != gradientOpacities.end(); gradientIt++) {
+        int gray = gradientIt.key();
+        double opacity = gradientIt.value();
+        volumeGradientOpacity->AddPoint(gray, opacity);
+    }
+
     // Finally : set the properties
     // The VolumeProperty attaches the color and opacity functions to the
     // volume, and sets other volume properties.  The interpolation should
@@ -242,7 +240,7 @@ void VolumeRenderingAction::createVolumeRendering(ImageComponent * comp) {
     // decreased by increasing the Ambient coefficient while decreasing
     // the Diffuse and Specular coefficient.  To increase the impact
     // of shading, decrease the Ambient and increase the Diffuse and Specular.
-	
+
     vtkSmartPointer<vtkVolumeProperty> volumeProperty = vtkSmartPointer<vtkVolumeProperty>::New();
     volumeProperty->SetColor(volumeColor);
     volumeProperty->SetScalarOpacity(volumeScalarOpacity);
@@ -260,8 +258,8 @@ void VolumeRenderingAction::createVolumeRendering(ImageComponent * comp) {
     volume->SetProperty(volumeProperty);
     volume->Update();
 
-	
-	// Remove old volume from the component and the 3D viewer
+
+    // Remove old volume from the component and the 3D viewer
     vtkSmartPointer<vtkProp> oldVolume = comp->getVolumeRenderingChild()->getProp(volumeName);
 
     if (oldVolume) {
@@ -271,12 +269,12 @@ void VolumeRenderingAction::createVolumeRendering(ImageComponent * comp) {
 
     // Add the new computed volume to the component and display it in the 3D viewer
     comp->getVolumeRenderingChild()->addProp(volumeName, volume);
-	comp->getVolumeRenderingChild()->getProp(volumeName)->SetVisibility(true);
-		
+    comp->getVolumeRenderingChild()->getProp(volumeName)->SetVisibility(true);
+
     //InteractiveViewer::get3DViewer()->getRendererWidget()->addProp(volume);
-	comp->getVolumeRenderingChild()->setVisibility(InteractiveViewer::get3DViewer(), true);
-	InteractiveViewer::get3DViewer()->refresh();
-  
+    comp->getVolumeRenderingChild()->setVisibility(InteractiveViewer::get3DViewer(), true);
+    InteractiveViewer::get3DViewer()->refresh();
+
 
 }
 
