@@ -30,16 +30,16 @@
 
 /**
  * @ingroup group_sdk_actions_image_volumerendering
- * 
+ *
  * @brief
  * The volume rendering action extension.
- *   
+ *
  */
 class VolumeRenderingExtension : public camitk::ActionExtension {
     Q_OBJECT
     Q_INTERFACES(camitk::ActionExtension)
 
-public: 
+public:
     /// the constructor
     VolumeRenderingExtension() : ActionExtension() {};
 
@@ -47,11 +47,15 @@ public:
     virtual ~VolumeRenderingExtension() {};
 
     /// Method that return the action extension name
-    virtual QString getName() {return "VolumeRenderingExtension";};
+    virtual QString getName() {
+        return "VolumeRenderingExtension";
+    };
 
     /// Method that return the action extension descrption
-    virtual QString getDescription() {return "This extension allows user to compute volume rendering on .mha images.";};
-    /// initialize all the actions 
+    virtual QString getDescription() {
+        return "This extension allows user to compute volume rendering on .mha images.";
+    };
+    /// initialize all the actions
     virtual void init();
 
 };
