@@ -31,10 +31,10 @@
 
 /**
  * @ingroup group_sdk_actions_mesh_basicmesh
- * 
+ *
  * @brief
  * The basic mesh action extension.
- *  
+ *
  */
 class BasicMeshExtension : public camitk::ActionExtension {
     Q_OBJECT
@@ -49,12 +49,16 @@ public:
 
     /// initialize all the actions
     virtual void init();
-            
+
     /// Method that return the action extension name
-    virtual QString getName() {return "Basic Mesh Extension";};
-    
+    virtual QString getName() {
+        return "Basic Mesh Extension";
+    };
+
     /// Method that return the action extension descrption
-    virtual QString getDescription() {return "This extension provides various basic actions for mesh components";};
+    virtual QString getDescription() {
+        return "This extension provides various basic actions for mesh components";
+    };
 
 };
 
