@@ -83,18 +83,17 @@ Action::ApplyStatus CenterMesh::apply() {
         transform->Translate(-barycenter[0], -barycenter[1], -barycenter[2]);
 
         //-- transform the mesh using the filter
-	vtkSmartPointer<vtkTransformFilter> filter = vtkSmartPointer<vtkTransformFilter>::New();
+        vtkSmartPointer<vtkTransformFilter> filter = vtkSmartPointer<vtkTransformFilter>::New();
         filter->SetInputConnection(targetMesh->getDataPort());
         filter->SetTransform(transform);
-	filter->Update();
+        filter->Update();
 
-	//-- get the resulting mesh
+        //-- get the resulting mesh
         vtkSmartPointer<vtkPointSet> result = vtkPointSet::SafeDownCast(filter->GetOutputDataObject(0));
         if (result) {
             targetMesh->setPointSet(result);
             targetMesh->setModified();
-        }
-        else {
+        } else {
             CAMITK_INFO("CenterMesh", "apply transformation", "Error: filter output is of type: " << filter->GetOutputDataObject(0)->GetClassName());
             return ERROR;
         }
