@@ -30,14 +30,14 @@
 
 /**
  * @ingroup group_sdk_actions_mesh_basicmesh
- * 
+ *
  * @brief
  * Center the current @ref camitk::MeshComponent in the center of the space coordinate.
- *  
+ *
  * @note
  * At the end of the translation, the barycenter of the mesh is in (0,0,0).
- * 
- *  
+ *
+ *
  */
 class CenterMesh : public camitk::Action {
     Q_OBJECT
@@ -47,14 +47,16 @@ public:
     CenterMesh(camitk::ActionExtension*);
 
     /// Destructor
-    virtual ~CenterMesh() {};    
-    
+    virtual ~CenterMesh() {};
+
     /// no widget, just apply the action
-    QWidget * getWidget() { return NULL; };
-    
+    QWidget * getWidget() {
+        return NULL;
+    };
+
 public slots:
     /// method called when the action is applied
-    virtual ApplyStatus apply();    
+    virtual ApplyStatus apply();
 
 };
 
