@@ -35,11 +35,11 @@ using namespace camitk;
 ChangeColor::ChangeColor(ActionExtension *extension) : Action(extension) {
     setName("Change Color");
     setEmbedded(false);
-    setDescription("Change the surface, wireframe or points colors of objects");
+    setDescription(tr("Change the surface, wireframe or points colors of objects"));
     setComponent("MeshComponent");
     setFamily("Basic Mesh");
     setIcon(QPixmap(":/changeColor"));
-    addTag("Color");
+    addTag(tr("Color"));
 }
 
 // --------------- apply -------------------
