@@ -31,15 +31,16 @@
 
 /**
  * @ingroup group_sdk_actions_mesh_basicmesh
- * 
+ *
  * @brief
  * Change the color of the rendering of the current selected mesh.
  * Use its widget (pop-up) to select the desired color.
- * 
+ *
  * \image html actions/basic_mesh_change_color.png "The change color pop-up." width=10cm
- *  
+ *
  */
 class ChangeColor : public camitk::Action {
+    Q_OBJECT
 
 public:
     /// the constructor
@@ -49,7 +50,9 @@ public:
     virtual ~ChangeColor() {};
 
     /// There are no parameters for this action. The GUI is run as a one-shot dialog in apply
-    virtual QWidget * getWidget() { return NULL;}
+    virtual QWidget * getWidget() {
+        return NULL;
+    }
 
 public slots:
     /// method called when the action is applied
