@@ -99,8 +99,7 @@ Action::ApplyStatus MeshPicking::apply() {
         // get the position
         double *pointPosition = meshComponent->getPointSet()->GetPoint(lastPickedPointId);
         message += "<b>Point Position:</b> "+ QString("(%1,%2,%3)").arg(pointPosition[0], 6).arg(pointPosition[1], 6).arg(pointPosition[2], 6) + "<br/>";
-    }
-    else {
+    } else {
         message += "<b>No point picked</b><br/>";
     }
 
@@ -127,8 +126,7 @@ Action::ApplyStatus MeshPicking::apply() {
 
         // add information
         message += "<b>Barycenter:</b> " + QString("(%1,%2,%3)").arg(cellBarycenter[0], 6).arg(cellBarycenter[1], 6).arg(cellBarycenter[2], 6);
-    }
-    else {
+    } else {
         message += "<b>No cell picked</b>";
     }
 
