@@ -198,8 +198,7 @@ void MeshQuality::computeMeasure(int i) {
     QApplication::restoreOverrideCursor();
 }
 
-void MeshQuality::updateMeshColor(vtkSmartPointer< vtkDoubleArray > qualityArray)
-{
+void MeshQuality::updateMeshColor(vtkSmartPointer< vtkDoubleArray > qualityArray) {
     std::vector<vtkIdType> indices;
     MeshComponent * meshComponent = dynamic_cast<MeshComponent *>(getTargets().last());
 
@@ -274,7 +273,7 @@ void MeshQuality::updateTableWidget(vtkSmartPointer< vtkDoubleArray > qualityArr
         indices = elementsMap[VTK_QUAD];
     }
     // resize the table
-    qualityInfo->setRowCount(indices.size());
+    qualityInfo->setRowCount((int)indices.size()); // if there are more than MAX_INT cells, too bad (that's over 2,147,483,647 cells anyway...)
 
     minV = VTK_DOUBLE_MAX;
     maxV = VTK_DOUBLE_MIN;
