@@ -22,15 +22,19 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
+// CamiTK includes
 #include "MeshToImageStencil.h"
+#include <Application.h>
+#include <Property.h>
 
+// Qt includes
 #include <QColor>
 #include <QVector3D>
 #include <QString>
 #include <QMessageBox>
 #include <QTextStream>
-#include <Application.h>
 
+// Vtk includes
 #include <vtkSmartPointer.h>
 #include <vtkPolyData.h>
 #include <vtkImageData.h>
@@ -46,21 +50,29 @@ using namespace camitk;
 // --------------- Constructor -------------------
 MeshToImageStencil::MeshToImageStencil(ActionExtension * extension) : Action(extension) {
     // Setting name, description and input component
-    setName("MeshToImageStencil");
-    setDescription("This action generates a new volume image and converts the mesh into volume representation (vtkImageData) where the foreground voxels are colored and the background voxels are black.");
+    setName("Mesh To Image Stencil");
+    setDescription(tr("This action generates a new volume image and converts the mesh into a volume representation (vtkImageData) where the foreground voxels are colored and the background voxels are black."));
     setComponent("MeshComponent");
 
     // Setting classification family and tags
     setFamily("Basic Mesh");
-    addTag("STE");
+    addTag(tr("STE"));
 
     // Setting the action's parameters
-    setProperty("color", QVariant(QColor(255, 255, 255, 255)));
-    setProperty("dimension", QVariant(QVector3D(0.0, 0.0, 0.0)));
-    setProperty("origin", QVariant(QVector3D(0.0, 0.0, 0.0)));
-    setProperty("spacing", QVariant(QVector3D(0.0, 0.0, 0.0)));
-    setProperty("output File", QString(""));
+//    Property* colorProperty = new Property(tr("Color"), QVariant(QColor(255, 255, 255, 255)), tr("Foreground voxels colour."), "");
+//    addParameter(colorProperty);
 
+    Property* dimensionProperty = new Property(tr("Dimension"), QVariant(QVector3D(0.0, 0.0, 0.0)), tr("The dimension of the output volumic image"), "");
+    addParameter(dimensionProperty);
+
+    Property* originProperty = new Property(tr("Origin"), QVariant(QVector3D(0.0, 0.0, 0.0)), tr("The origin frame position"), "");
+    addParameter(originProperty);
+
+    Property* spacingProperty = new Property(tr("Spacing"), QVariant(QVector3D(0.0, 0.0, 0.0)), tr("The spacing between each voxel"), "");
+    addParameter(spacingProperty);
+
+    Property* outputFileProperty = new Property(tr("Output file"), "", tr("The output filename"), "");
+    addParameter(outputFileProperty);
 }
 
 // --------------- destructor -------------------
@@ -81,10 +93,10 @@ Action::ApplyStatus MeshToImageStencil::apply() {
 
 void MeshToImageStencil::process(MeshComponent * comp) {
     // Get the parameters
-    QVector3D dimension = property("dimension").value<QVector3D>();
-    QVector3D origin = property("origin").value<QVector3D>();
-    QVector3D spacing = property("spacing").value<QVector3D>();
-    QString file = property("output File").value<QString>();
+    QVector3D dimension = property("Dimension").value<QVector3D>();
+    QVector3D origin = property("Origin").value<QVector3D>();
+    QVector3D spacing = property("Spacing").value<QVector3D>();
+    QString file = property("Output file").value<QString>();
 
     // get mesh as polydata
     vtkSmartPointer<vtkPolyData> pd = vtkPolyData::SafeDownCast(comp->getPointSet());
