@@ -30,18 +30,19 @@
 
 /**
  * @ingroup group_sdk_actions_mesh_basicmesh
- * 
+ *
  * @brief
  * Convert the image into an image stencil.
- * 
+ *
  * \image html actions/basic_mesh_stencil.png "The mesh to image stencil widget." width=10cm
- *  
+ *
  */
 class MeshToImageStencil : public camitk::Action {
+    Q_OBJECT
 
-public: 
+public:
 
-    /// Default Constructor 
+    /// Default Constructor
     MeshToImageStencil(camitk::ActionExtension * extension);
 
     /// Default Destructor
@@ -50,17 +51,17 @@ public:
 public slots:
     /** this method is automatically called when the action is triggered.
       * Call getTargets() method to get the list of components to use.
-      * \note getTargets() is automatically filtered so that it only contains compatible components, 
+      * \note getTargets() is automatically filtered so that it only contains compatible components,
       * i.e., instances of MeshToImageStencil (or a subclass).
       */
     virtual ApplyStatus apply();
 
-private: 
+private:
     /// helper method to simplify the target component processing
     virtual void process(camitk::MeshComponent * comp);
-	
 
-}; 
+
+};
 
 #endif // MESHTOIMAGESTENCIL_H
 
