@@ -22,40 +22,52 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
-
+// CamiTK includes
 #include "RenderingOption.h"
-
-
 #include <MeshComponent.h>
 #include <InteractiveViewer.h>
+#include <Property.h>
+
+// C++ includes
 #include <complex>
 
-using namespace camitk;
-
-//-- normal generation
+//-- Vtk includes
 #include <vtkDataSetSurfaceFilter.h>
 #include <vtkPolyDataNormals.h>
 #include <vtkDataSetMapper.h>
 #include <vtkGlyph3D.h>
 #include <vtkArrowSource.h>
 
+using namespace camitk;
 
 // --------------- constructor -------------------
 RenderingOption::RenderingOption(ActionExtension* extension) : Action(extension) {
     setName("Rendering Option");
     setIcon(QPixmap(":/renderingOption"));
-    setDescription("Change the rendering option (surface, wireframe, points, label...)");
+    setDescription("Change the rendering option (surface, wireframe, points, label...) of the selected mesh(es).");
     setComponent("MeshComponent");
     setFamily("Basic Mesh");
     addTag("RenderingMode");
     addTag("Label");
 
-    setProperty("Surface", false);
-    setProperty("Wireframe", false);
-    setProperty("Points", false);
-    setProperty("Label", false);
-    setProperty("Glyph", false);
-    setProperty("Normals", false);
+
+    Property* surfaceProperty = new Property(tr("Surface representation?"), false, tr("Allow the selected mesh(es) to be representated as a surface?"), "");
+    addParameter(surfaceProperty);
+
+    Property* wireframeProperty = new Property(tr("Wireframe representation?"), false, tr("Allow the selected mesh(es) to be representated as wireframes?"), "");
+    addParameter(wireframeProperty);
+
+    Property* pointsProperty = new Property(tr("Points representation?"), false, tr("Allow the selected mesh(es) to be representated as with points?"), "");
+    addParameter(surfaceProperty);
+
+    Property* labelProperty = new Property(tr("Label representation?"), false, tr("Allow the selected mesh(es) to be representated with its label?"), "");
+    addParameter(labelProperty);
+
+    Property* glyphProperty = new Property(tr("Glyph representation?"), false, tr("Allow the selected mesh(es) to have glyphes representation?"), "");
+    addParameter(glyphProperty);
+
+    Property* normalProperty = new Property(tr("Normals representation?"), false, tr("Allow the selected mesh(es) to be representated with its normals?"), "");
+    addParameter(normalProperty);
 }
 
 RenderingOption::~RenderingOption() {
@@ -68,11 +80,10 @@ QWidget * RenderingOption::getWidget() {
     //-- init the property values using the selection state
     if (getTargets().size() == 1) {
         // only one selected, easy!
-        setProperty("Surface", (bool) (getTargets().first()->getRenderingModes() & InterfaceGeometry::Surface));
-        setProperty("Wireframe", (bool) (getTargets().first()->getRenderingModes() & InterfaceGeometry::Wireframe));
-        setProperty("Points", (bool) (getTargets().first()->getRenderingModes() & InterfaceGeometry::Points));
-    }
-    else {
+        setProperty("Surface representation?", (bool) (getTargets().first()->getRenderingModes() & InterfaceGeometry::Surface));
+        setProperty("Wireframe representation?", (bool) (getTargets().first()->getRenderingModes() & InterfaceGeometry::Wireframe));
+        setProperty("Points representation?", (bool) (getTargets().first()->getRenderingModes() & InterfaceGeometry::Points));
+    } else {
         // more than one: they should all have the same rendering mode to set a proper state
         InterfaceGeometry::RenderingModes m = getTargets().first()->getRenderingModes();
         int i = 1;
@@ -81,18 +92,18 @@ QWidget * RenderingOption::getWidget() {
             i++;
 
         if (i == getTargets().size()) {
-            setProperty("Surface", (bool) (m & InterfaceGeometry::Surface));
-            setProperty("Wireframe", (bool) (m & InterfaceGeometry::Wireframe));
-            setProperty("Points", (bool) (m & InterfaceGeometry::Points) );
+            setProperty("Surface representation?", (bool) (m & InterfaceGeometry::Surface));
+            setProperty("Wireframe representation?", (bool) (m & InterfaceGeometry::Wireframe));
+            setProperty("Points representation?", (bool) (m & InterfaceGeometry::Points) );
         }
     }
 
     // additional prop visibility
     if (getTargets().size()>0) {
-        setProperty("Glyph", (bool) (getTargets().first()->getProp("glyph")->GetVisibility()));
-        setProperty("Label", (bool) (getTargets().first()->getProp("label")->GetVisibility()));
+        setProperty("Glyph representation?", (bool) (getTargets().first()->getProp("glyph")->GetVisibility()));
+        setProperty("Label representation?", (bool) (getTargets().first()->getProp("label")->GetVisibility()));
         // normal is an extra prop build by this action if needed, check if it exists first)
-        setProperty("Normals", getTargets().first()->getProp("normals")!=NULL && (bool) (getTargets().first()->getProp("normals")->GetVisibility()));
+        setProperty("Normals representation?", getTargets().first()->getProp("normals")!=NULL && (bool) (getTargets().first()->getProp("normals")->GetVisibility()));
     }
 
     return Action::getWidget();
@@ -104,25 +115,25 @@ Action::ApplyStatus RenderingOption::apply() {
     // get the current rendering mode from the property values
     InterfaceGeometry::RenderingModes m = InterfaceGeometry::None;
 
-    if (property("Surface").toBool())
+    if (property("Surface representation?").toBool())
         m |= InterfaceGeometry::Surface;
 
-    if (property("Wireframe").toBool())
+    if (property("Wireframe representation?").toBool())
         m |= InterfaceGeometry::Wireframe;
 
-    if (property("Points").toBool())
+    if (property("Points representation?").toBool())
         m |= InterfaceGeometry::Points;
 
     // update the rendering mode of selected
     foreach(Component *comp, getTargets()) {
         comp->setRenderingModes(m);
         // set the additional prop visibility
-        comp->getProp("glyph")->SetVisibility(property("Glyph").toBool());
-        comp->getProp("label")->SetVisibility(property("Label").toBool());
+        comp->getProp("glyph")->SetVisibility(property("Glyph represenation?").toBool());
+        comp->getProp("label")->SetVisibility(property("Label represenation?").toBool());
 
         // normal is a specific prop, create it only if needed
         if (comp->getProp("normals") == NULL) {
-            if (property("Normals").toBool()) {
+            if (property("Normals representation?").toBool()) {
 
                 //-- get the surface (in order to have polygon only)
                 vtkSmartPointer<vtkDataSetSurfaceFilter> surfaceFilter = vtkSmartPointer<vtkDataSetSurfaceFilter>::New();
@@ -159,13 +170,12 @@ Action::ApplyStatus RenderingOption::apply() {
                 comp->getProp("normals")->SetVisibility(true);
             }
             // else: nothing todo there is no normal to display anyway
-        }
-        else {
+        } else {
             // check weither to show the normals or no
-            comp->getProp("normals")->SetVisibility(property("Normals").toBool());
+            comp->getProp("normals")->SetVisibility(property("Normals represenation?").toBool());
         }
 
-        
+
     }
 
     // refresh the viewers (here only the viewer of the last component, but should be ok)
