@@ -42,7 +42,7 @@ using namespace camitk;
 // --------------- constructor -------------------
 RigidTransform::RigidTransform(ActionExtension* extension) : Action(extension) {
     setName("Rigid Transform");
-    setEmbedded(false);    
+    setEmbedded(false);
     setDescription("Rigid transformation of Components");
     setComponent("MeshComponent");
     setFamily("Basic Mesh");
@@ -173,8 +173,7 @@ void RigidTransform::update(bool forceUpdate) {
             sx = double(myUI.sX->getValue());
             sy = double(myUI.sX->getValue());
             sz = double(myUI.sX->getValue());
-        }
-        else {
+        } else {
             sx = double(myUI.sX->getValue());
             sy = double(myUI.sY->getValue());
             sz = double(myUI.sZ->getValue());
@@ -198,11 +197,10 @@ Action::ApplyStatus RigidTransform::apply() {
         if (result) {
             comp->setPointSet(result);
             comp->setModified();
-        }
-        else {
+        } else {
             CAMITK_INFO("RigidTransform", "applyTransform", "Error: filter output is of type: " << filterList[i]->GetOutputDataObject(0)->GetClassName());
-	    return ERROR;
-	}
+            return ERROR;
+        }
         // next filter
         i++;
     }
@@ -236,7 +234,7 @@ void RigidTransform::load() {
     if (!fn.isNull()) {
         std::ifstream in(fn.toStdString().c_str());
         double x, y, z, t;
-        for (unsigned int i = 0;i < 4; i++) {
+        for (unsigned int i = 0; i < 4; i++) {
             in >> x >> y >> z >> t;
             transformation->GetMatrix()->SetElement(i, 0, x);
             transformation->GetMatrix()->SetElement(i, 1, y);
@@ -262,8 +260,8 @@ void RigidTransform::save() {
     QString fn = QFileDialog::getSaveFileName(dialog, "Save Current Transformation");
     if (!fn.isNull()) {
         std::ofstream out(fn.toStdString().c_str());
-        for (unsigned int i = 0;i < 4;i++) {
-            for (unsigned int j = 0;j < 4;j++)
+        for (unsigned int i = 0; i < 4; i++) {
+            for (unsigned int j = 0; j < 4; j++)
                 out << transformation->GetMatrix()->GetElement(i, j) << " ";
             out << endl;
         }
