@@ -31,18 +31,18 @@
 
 /**
  * @ingroup group_sdk_actions_mesh_basictopology
- * 
+ *
  * @brief
  * The basic topology action extension
- *  
+ *
  */
 class BasicTopologyExtension : public camitk::ActionExtension {
-  
+
     Q_OBJECT
     Q_INTERFACES(camitk::ActionExtension)
 
 public:
-  
+
     /// the constructor
     BasicTopologyExtension() : ActionExtension() {};
 
@@ -51,12 +51,16 @@ public:
 
     /// initialize all the actions
     virtual void init();
-    
+
     /// Method that return the action extension name
-    virtual QString getName() {return "Basic Topology";};
-    
+    virtual QString getName() {
+        return "Basic Topology";
+    };
+
     /// Method that return the action extension descrption
-    virtual QString getDescription() {return "This extension provides actions to build basic topology mesh";};
+    virtual QString getDescription() {
+        return "This extension provides actions to build basic topology mesh";
+    };
 
 };
 
