@@ -22,13 +22,18 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
+// CamiTK includes
 #include "SphereTopology.h"
 #include <MeshComponent.h>
 #include <Log.h>
 #include <Application.h>
 #include <MainWindow.h>
-using namespace camitk;
+#include <Property.h>
 
+// Qt includes
+#include <QVector3D>
+
+// Vtk includes
 #include <vtkCell.h>
 #include <vtkPoints.h>
 #include <vtkSmartPointer.h>
@@ -37,6 +42,8 @@ using namespace camitk;
 #include <vtkCellArray.h>
 #include <vtkSphereSource.h>
 
+using namespace camitk;
+
 SphereTopology::SphereTopology(ActionExtension *extension) : Action(extension) {
     setName("Sphere Topology");
     setEmbedded(true);
@@ -45,27 +52,37 @@ SphereTopology::SphereTopology(ActionExtension *extension) : Action(extension) {
     setFamily("Mesh Processing");
     addTag("Build Sphere");
 
-    setProperty("Center X", 0.);
-    setProperty("Center Y", 0.);
-    setProperty("Center Z", 0.);
-    setProperty("Radius", 1.);
-    setProperty("Phi Resolution", 10);
-    setProperty("Theta Resolution", 10);
+    // parameters
+    Property* centerProperty = new Property(tr("Center"), QVector3D(0.0, 0.0, 0.0), tr("This coordinate represents the center of the sphere. <br />By default this value is (0,0,0)."), "");
+    addParameter(centerProperty);
+
+    Property* radiusProperty = new Property(tr("Radius"), 0.5, tr(" This is the radius of the sphere. <br />The default value is 0.5."), "");
+    radiusProperty->setAttribute("minimum", 0.1);
+    radiusProperty->setAttribute("singleStep", 0.1);
+    addParameter(radiusProperty);
+
+    Property* phiProperty = new Property(tr("Phi resolution"), 8, tr("This number represents the number of division between start phi and end phi on the sphere. <br />The phi divisions are similar to latitude lines on the earth. <br /><br />The default phi resolution is 8"), "");
+    phiProperty->setAttribute("minimum", 1);
+    phiProperty->setAttribute("singleStep", 1);
+    addParameter(phiProperty);
+
+    Property* thetaProperty = new Property(tr("Theta resolution"), 8, tr("This number represents the number of division between start theta and end theta around the sphere. <br />The theta divisions are similar to longitude lines on the earth. <br />The higher the resolution the closer the approximation will come to a sphere and the more polygons there will be. <br /><br />The default theta resolution is 8."), "");
+    thetaProperty->setAttribute("minimum", 1);
+    thetaProperty->setAttribute("singleStep", 1);
+    addParameter(thetaProperty);
 }
 
 SphereTopology::~SphereTopology() {
 }
 
 Action::ApplyStatus SphereTopology::apply() {
-    double cX = property("Center X").toDouble();
-    double cY = property("Center Y").toDouble();
-    double cZ = property("Center Z").toDouble();
+    QVector3D center = property("Center").value<QVector3D>();
     double radius = property("Radius").toDouble();
-    int phiRes = property("Phi Resolution").toDouble();;
-    int thetaRes = property("Theta Resolution").toDouble();;
+    int phiRes = property("Phi resolution").toDouble();;
+    int thetaRes = property("Theta resolution").toDouble();;
 
     vtkSmartPointer<vtkSphereSource> sphere = vtkSmartPointer<vtkSphereSource>::New();
-    sphere->SetCenter(cX, cY, cZ);
+    sphere->SetCenter(center.x(), center.y(), center.z());
     sphere->SetRadius(radius);
     sphere->SetPhiResolution(phiRes);
     sphere->SetThetaResolution(thetaRes);
@@ -74,10 +91,10 @@ Action::ApplyStatus SphereTopology::apply() {
     vtkSmartPointer<vtkPolyData> pData = sphere->GetOutput();
 
     new MeshComponent(pData, "Sphere");
-    
+
     Application::refresh();
     Application::resetProgressBar();
     Application::showStatusBarMessage("");
 
     return SUCCESS;
-}
\ No newline at end of file
+}
