@@ -30,18 +30,19 @@
 
 /**
  * @ingroup group_sdk_actions_mesh_basictopology
- * 
+ *
  * @brief
  * Create a sphere mesh.
- * 
+ *
  * The sphere topology action widget allows you to select the desired dimensions of your sphere.
  * \image html actions/basic_topology_sphere.png "The sphere topology widget." width=10cm
- *  
+ *
  */
 class SphereTopology : public camitk::Action {
+    Q_OBJECT
 
 public:
-  
+
     /// the constructor
     SphereTopology(camitk::ActionExtension *);
 
@@ -50,15 +51,15 @@ public:
 
     /// method called when the action when the action is triggered (i.e. started)
     //virtual QWidget * getWidget();
-    
+
 public slots:
-  
+
     /// method called when the action is applied
     virtual ApplyStatus apply();
-    
+
 private:
     QWidget* myWidget;
-    
+
 };
 
-#endif // SPHERE_TOPOLOGY_H
\ No newline at end of file
+#endif // SPHERE_TOPOLOGY_H
