@@ -38,16 +38,16 @@ using namespace camitk;
 
 // -------------------- CleanPolyData --------------------
 CleanPolyData::CleanPolyData(ActionExtension* extension) : Action(extension) {
-    // Setting name, description and input component 
+    // Setting name, description and input component
     setName("Clean Mesh");
-    setDescription("Merge duplicate points, and/or remove unused points and/or remove degenerate cells.");
+    setDescription(tr("Merge duplicate points, and/or remove unused points and/or remove degenerate cells."));
     setComponent("MeshComponent");
-    
+
     // Setting classification family and tags
     setFamily("Mesh Processing");
-    addTag("vtkCleanPolyData");
-    addTag("Clean vtkPolyData");
-    
+    addTag(tr("vtkCleanPolyData"));
+    addTag(tr("Clean vtkPolyData"));
+
     Property *tolerance = new Property("Tolerance", QVariant(1.0), "Tolerance is given as a percentage of the bounding box<br/>E.g. for a Tolerance value of <tt>1.0</tt>, if points are closer than <i>1.0%</i> of the bounding box dimensions, then they are merged.", "%");
     tolerance->setAttribute("minimum",  QVariant(0.0));
     tolerance->setAttribute("maximum",  QVariant(100.0));
@@ -70,7 +70,7 @@ Action::ApplyStatus CleanPolyData::apply() {
 
     //-- check if this is a polydata and if this is an unstructured grid, extract the surface
     vtkSmartPointer<vtkPolyData> targetPolyData = VtkMeshUtil::vtkPointSetToVtkPolyData(targetMesh->getPointSet());
-    
+
     //-- clean the polydata
     // remove redundant points
     vtkSmartPointer<vtkCleanPolyData> cleaner = vtkSmartPointer<vtkCleanPolyData>::New();
@@ -80,7 +80,7 @@ Action::ApplyStatus CleanPolyData::apply() {
     cleaner->ConvertLinesToPointsOn ();
     cleaner->ConvertPolysToLinesOn ();
     cleaner->ConvertStripsToPolysOn ();
-    
+
     vtkSmartPointer<vtkCallbackCommand> progressCallback = vtkSmartPointer<vtkCallbackCommand>::New();
     progressCallback->SetCallback(&Application::vtkProgressFunction);
     cleaner->AddObserver(vtkCommand::ProgressEvent, progressCallback);
@@ -91,7 +91,7 @@ Action::ApplyStatus CleanPolyData::apply() {
     // Create a mesh Component
     vtkSmartPointer<vtkPointSet> resultPointSet = cleaner->GetOutput();
     new MeshComponent(resultPointSet, targetMesh->getName() + " clean");
-    Application::refresh();    
+    Application::refresh();
 
     // restore the normal cursor and progress bar
     Application::resetProgressBar();
