@@ -29,12 +29,13 @@
 #include <Action.h>
 /**
  * @ingroup group_sdk_actions_mesh_meshprocessing
- * 
+ *
  * @brief
  * Using vtkCleanPolyData for example to clean nodes that are too close.
  *
  */
 class CleanPolyData : public camitk::Action {
+    Q_OBJECT
 
 public:
     /// the constructor
@@ -42,7 +43,7 @@ public:
 
     /// the destructor
     virtual ~CleanPolyData() {};
-    
+
 public slots:
     /// method called when the action is applied
     virtual ApplyStatus apply();
