@@ -27,31 +27,28 @@
 #ifndef DECIMATION_H
 #define DECIMATION_H
 
-#include <QObject>
 #include <Action.h>
 
 class DecimationWidget;
 
 /**
  * @ingroup group_sdk_actions_mesh_meshprocessing
- * 
+ *
  * @brief
  * Decimate the input mesh in order to reduce its number of triangles.
  *
- * @see camitk::DecimationWidget 
+ * @see camitk::DecimationWidget
  *
  */
 class Decimation : public camitk::Action {
-    
+    Q_OBJECT
+
 public:
     /// the constructor
     Decimation(camitk::ActionExtension*);
 
     /// the destructor
     virtual ~Decimation();
-    
-    /// this method creates and returns the widget containing the user interface for the action
-    virtual QWidget * getWidget();
 
 public slots:
     /// method called when the action is applied
@@ -63,4 +60,4 @@ private:
 
 };
 
-#endif // DECIMATION_H
\ No newline at end of file
+#endif // DECIMATION_H
