@@ -31,6 +31,7 @@
 #include <vtkGeometryFilter.h>
 #include <vtkCleanPolyData.h>
 #include <vtkExtractEdges.h>
+#include <vtkCallbackCommand.h>
 
 using namespace camitk;
 
@@ -38,10 +39,10 @@ using namespace camitk;
 
 ExtractEdges::ExtractEdges(ActionExtension* extension) : Action(extension) {
     this->setName("Extract Edges");
-    this->setDescription("Extract edges from a mesh");
+    this->setDescription(tr("Extract edges from a mesh"));
     this->setComponent("MeshComponent");
     this->setFamily("Mesh Processing");
-    this->addTag("ExtractEdges");
+    this->addTag(tr("ExtractEdges"));
 }
 
 
@@ -50,19 +51,22 @@ Action::ApplyStatus ExtractEdges::apply() {
 
     // set waiting cursor and status bar
     QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
-    Application::showStatusBarMessage("Extracting edges...");
+    Application::showStatusBarMessage(tr("Extracting edges..."));
     Application::resetProgressBar();
+    vtkSmartPointer<vtkCallbackCommand> progressCallback = vtkSmartPointer<vtkCallbackCommand>::New();
+    progressCallback->SetCallback(&Application::vtkProgressFunction);
 
     // use the last target
     MeshComponent *targetMesh = dynamic_cast<MeshComponent*>(getTargets().last());
 
     vtkSmartPointer<vtkExtractEdges> extractEdgesFilter = vtkSmartPointer<vtkExtractEdges>::New();
     extractEdgesFilter->SetInput(targetMesh->getPointSet());
+    extractEdgesFilter->AddObserver(vtkCommand::ProgressEvent, progressCallback);
     extractEdgesFilter->Update();
-    
-    // create a new mesh Component    
+
+    // create a new mesh Component
     new MeshComponent(extractEdgesFilter->GetOutput(), targetMesh->getName() + " edges");
-    Application::refresh();    
+    Application::refresh();
 
     // restore the normal cursor and progress bar
     Application::resetProgressBar();
