@@ -31,16 +31,17 @@ using namespace camitk;
 #include <vtkUnstructuredGrid.h>
 #include <vtkGeometryFilter.h>
 #include <vtkCleanPolyData.h>
+#include <vtkCallbackCommand.h>
 
 #include "ExtractSurface.h"
 
 // -------------------- ExtractSurface --------------------
 ExtractSurface::ExtractSurface(ActionExtension* extension) : Action(extension) {
     this->setName("ExtractSurface");
-    this->setDescription("Extract Surface from Volumetric Mesh");
+    this->setDescription(tr("Extract Surface from Volumetric Mesh"));
     this->setComponent("MeshComponent");
     this->setFamily("Mesh Processing");
-    this->addTag("ExtractSurface");
+    this->addTag(tr("ExtractSurface"));
 }
 
 // --------------- apply -------------------
@@ -49,22 +50,25 @@ Action::ApplyStatus ExtractSurface::apply() {
 
     // set waiting cursor and status bar
     QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
-    Application::showStatusBarMessage("Extracting Surface...");
+    Application::showStatusBarMessage(tr("Extracting Surface..."));
     Application::resetProgressBar();
+    vtkSmartPointer<vtkCallbackCommand> progressCallback = vtkSmartPointer<vtkCallbackCommand>::New();
+    progressCallback->SetCallback(&Application::vtkProgressFunction);
 
     // use the last target
     MeshComponent *targetMesh = dynamic_cast<MeshComponent*>(getTargets().last());
 
     vtkSmartPointer<vtkGeometryFilter> geometryFilter = vtkSmartPointer<vtkGeometryFilter>::New();
     vtkSmartPointer<vtkCleanPolyData> cleanFilter = vtkSmartPointer<vtkCleanPolyData>::New();
-    
+
     geometryFilter->SetInput(targetMesh->getPointSet());
     cleanFilter->SetInputConnection(geometryFilter->GetOutputPort());
+    cleanFilter->AddObserver(vtkCommand::ProgressEvent, progressCallback);
     cleanFilter->Update();
-    
-    // create a new mesh Component    
+
+    // create a new mesh Component
     new MeshComponent(cleanFilter->GetOutput(), targetMesh->getName() + " surface");
-    Application::refresh();    
+    Application::refresh();
 
     // restore the normal cursor and progress bar
     Application::resetProgressBar();
