@@ -22,67 +22,73 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
+// CamiTK includes
 #include "FillWithPoints.h"
-
 #include <Application.h>
 #include <MeshComponent.h>
 #include <Log.h>
-using namespace camitk;
-
+#include <Property.h>
 
+// Vtk includes
 #include <VtkMeshUtil.h>
-
 #include <vtkPointLocator.h>
 #include <vtkCallbackCommand.h>
 #include <vtkPolyData.h>
 #include <vtkSelectEnclosedPoints.h>
 #include <vtkAppendPolyData.h>
 
+// Qt includes
 #include <QDateTime>
 
+using namespace camitk;
+
 // -------------------- FillWithPoints --------------------
 FillWithPoints::FillWithPoints(ActionExtension* extension) : Action(extension) {
     setName("Fill With Points");
-    setDescription("Fill a surfacic mesh with regularly spaced nodes (create new nodes inside the mesh).");
+    setDescription(tr("Fill a surfacic mesh with regularly spaced nodes by creating new nodes inside the mesh."));
 
     setComponent("MeshComponent");
     setFamily("Mesh Processing");
-    addTag("Add Nodes");
+    addTag(tr("Add Nodes"));
 
-    setProperty("Bucket Size", QVariant(1));  // nv of points per buckets, higher = coarser filling, 1 = highest density possible
-    setProperty("Randomize", QVariant(true)); // randomize the position of the point +/- 0.5
+    Property* bucketSizeProperty = new Property(tr("Points per bucket"), 1, tr("The number of points per bucket. <br />A bucket represent a group of points in the input mesh.<br /> The less this number is, the higher the output mesh points density will be."), "Number of points");
+    bucketSizeProperty->setAttribute("minimum", 1);
+    bucketSizeProperty->setAttribute("singleStep", 1);
+    addParameter(bucketSizeProperty);
+
+    Property* randomizeProperty = new Property(tr("Randomize?"), true, tr("Randomize the position of the added points by +/- 0.5"), "");
+    addParameter(randomizeProperty);
 }
 
 // --------------- apply -------------------
 Action::ApplyStatus FillWithPoints::apply() {
-    //CAMITK_INFO("FillWithPoints", "apply", "Adding inside nodes to " << getTargets().last()->getName().toStdString());
 
     // set waiting cursor and status bar
     QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
     Application::showStatusBarMessage("Filling With Nodes...");
     Application::resetProgressBar();
+    vtkSmartPointer<vtkCallbackCommand> progressCallback = vtkSmartPointer<vtkCallbackCommand>::New();
+    progressCallback->SetCallback(&Application::vtkProgressFunction);
 
     // use the last target
     MeshComponent *targetMesh = dynamic_cast<MeshComponent*>(getTargets().last());
 
     //-- check if this is a polydata and if this is an unstructured grid, extract the surface
     vtkSmartPointer<vtkPolyData> targetPolyData = VtkMeshUtil::vtkPointSetToVtkPolyData(targetMesh->getPointSet());
-    //CAMITK_INFO("FillWithPoints", "apply", "polydata: points:" << targetPolyData->GetNumberOfPoints() << " , cells:" << targetPolyData->GetNumberOfCells());
-    
+
     //-- computes the subdivision depending on the mesh resolution
     vtkSmartPointer<vtkPointLocator> subdivisionLocator = vtkSmartPointer<vtkPointLocator>::New();
     subdivisionLocator->SetDataSet ( targetPolyData );
-    subdivisionLocator->SetNumberOfPointsPerBucket(property("Bucket Size").toInt());
+    subdivisionLocator->SetNumberOfPointsPerBucket(property("Points per bucket").toInt());
     subdivisionLocator->BuildLocator();
     // number of subdivisions for the x, y and z axis. If the mesh density is high the nbDiv will be high
     // nbDiv is computed so that there is bucketSize nodes per division
     int nbDiv[3];
     subdivisionLocator->GetDivisions(nbDiv);
-    //CAMITK_INFO("FillWithPoints", "apply", "Nb divisions: " << nbDiv[0] << "," << nbDiv[1] << "," << nbDiv[2]);
 
     // length of the divisions in the x-axis, y-axis and z-axis
     double *bounds = targetPolyData->GetPoints()->GetBounds(); // [xmin,xmax, ymin,ymax, zmin,zmax]
-    double xDiv = ( bounds[1] - bounds[0] ) / nbDiv[0]; 
+    double xDiv = ( bounds[1] - bounds[0] ) / nbDiv[0];
     double yDiv = ( bounds[3] - bounds[2] ) / nbDiv[1];
     double zDiv = ( bounds[5] - bounds[4] ) / nbDiv[2];
 
@@ -92,7 +98,7 @@ Action::ApplyStatus FillWithPoints::apply() {
     // position for generated points
     double x, y, z;
 
-    if (property("Randomize").toBool())
+    if (property("Randomize?").toBool())
         qsrand ( QDateTime::currentDateTime().toTime_t() );
     for ( int i = 0; i <= nbDiv[0]; i++ ) {
         x = bounds[0] + i * xDiv;
@@ -103,13 +109,12 @@ Action::ApplyStatus FillWithPoints::apply() {
             for ( int k = 0; k <= nbDiv[2]; k++ ) {
                 z = bounds[4] + k * zDiv;
                 // randomize
-		if (property("Randomize").toBool()) {
-		    x += ( xDiv / 10.0 ) * ( 0.5 - double ( qrand() ) / ( double ( RAND_MAX ) + 1.0 ) );
-		    y += ( yDiv / 10.0 ) * ( 0.5 - double ( qrand() ) / ( double ( RAND_MAX ) + 1.0 ) );
-		    z += ( zDiv / 10.0 ) * ( 0.5 - double ( qrand() ) / ( double ( RAND_MAX ) + 1.0 ) );
-		}
-		//CAMITK_INFO("FillWithPoints", "apply", "insert point: (" << x << "," << y << "," << z << ")");
-		points->InsertNextPoint ( x, y, z );
+                if (property("Randomize?").toBool()) {
+                    x += ( xDiv / 10.0 ) * ( 0.5 - double ( qrand() ) / ( double ( RAND_MAX ) + 1.0 ) );
+                    y += ( yDiv / 10.0 ) * ( 0.5 - double ( qrand() ) / ( double ( RAND_MAX ) + 1.0 ) );
+                    z += ( zDiv / 10.0 ) * ( 0.5 - double ( qrand() ) / ( double ( RAND_MAX ) + 1.0 ) );
+                }
+                points->InsertNextPoint ( x, y, z );
             }
         }
     }
@@ -120,6 +125,7 @@ Action::ApplyStatus FillWithPoints::apply() {
     vtkSmartPointer<vtkSelectEnclosedPoints> select = vtkSmartPointer<vtkSelectEnclosedPoints>::New();
     select->SetInput ( gridPoints );
     select->SetSurface ( targetPolyData );
+    select->AddObserver(vtkCommand::ProgressEvent, progressCallback);
     select->Update();
 
     //-- create a new polydata that contains only the internal selected points
@@ -129,29 +135,28 @@ Action::ApplyStatus FillWithPoints::apply() {
             insidePointsPoints->InsertNextPoint ( gridPoints->GetPoints()->GetPoint ( i ) );
         }
     }
-    
+
     vtkSmartPointer<vtkPolyData> insidePoints = vtkSmartPointer<vtkPolyData>::New();
     insidePoints->SetPoints ( insidePointsPoints );
     insidePoints->Allocate ( 2 );
     vtkIdType *vtkPointIndex = new vtkIdType [insidePointsPoints->GetNumberOfPoints()];
     for (vtkIdType i=0; i<insidePointsPoints->GetNumberOfPoints(); i++)
-	vtkPointIndex[i] = i;
+        vtkPointIndex[i] = i;
     insidePoints->InsertNextCell(VTK_POLY_VERTEX, insidePointsPoints->GetNumberOfPoints(),vtkPointIndex);
+    insidePoints->AddObserver(vtkCommand::ProgressEvent, progressCallback);
     insidePoints->Update();
 
     //-- Generates one structure with all the points (append targetPolyData and insidePoints)
     vtkSmartPointer<vtkAppendPolyData> appender = vtkSmartPointer<vtkAppendPolyData>::New();
     appender->AddInput ( targetPolyData );
     appender->AddInput ( insidePoints );
+    appender->AddObserver(vtkCommand::ProgressEvent, progressCallback);
     appender->Update();
-    //CAMITK_INFO("FillWithPoints", "apply", "insidePointsPoints: points:" << insidePointsPoints->GetNumberOfPoints());
-    //CAMITK_INFO("FillWithPoints", "apply", "targetPolyData: points:" << targetPolyData->GetNumberOfPoints() << " , cells:" << targetPolyData->GetNumberOfCells());
 
     //-- Create a new mesh Component using an unstructured grid (to show the isolated nodes)
     vtkSmartPointer<vtkPointSet> resultPointSet = appender->GetOutput();
-    //CAMITK_INFO("FillWithPoints", "apply", "resultPointSet: points:" << resultPointSet->GetNumberOfPoints() << " , cells:" << resultPointSet->GetNumberOfCells());
     new MeshComponent(resultPointSet, targetMesh->getName() + " filled");
-    Application::refresh();    
+    Application::refresh();
 
     // restore the normal cursor and progress bar
     Application::resetProgressBar();
