@@ -29,15 +29,16 @@
 #include <Action.h>
 /**
  * @ingroup group_sdk_actions_mesh_meshprocessing
- * 
+ *
  * @brief
  * Fill a surfacic mesh with regularly spaced nodes (create new nodes inside the mesh).
- * 
+ *
  * @note
  * Use the camitk action viewer default widget.
- * 
+ *
  */
 class FillWithPoints : public camitk::Action {
+    Q_OBJECT
 
 public:
     /// the constructor
