@@ -22,33 +22,44 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
-
+// CamiTK includes
 #include "ICPRegistration.h"
-
 #include <Application.h>
 #include <MeshComponent.h>
 #include <Log.h>
+#include <Property.h>
 
+// Vtk includes
 #include <vtkIterativeClosestPointTransform.h>
 #include <vtkTransformPolyDataFilter.h>
 #include <vtkLandmarkTransform.h>
+#include <vtkCallbackCommand.h>
 
 using namespace camitk;
 
 ICPRegistration::ICPRegistration ( camitk::ActionExtension* ext ) : Action ( ext ) {
-  
+
     this->setName ( "ICP Registration" );
-    this->setDescription ( QString ( "Iterative Closest Point algorithm bewteen two mesh.<br/>" ) +
-                           QString ( "At least two mesh components must be selected :" ) +
+    this->setDescription ( QString (tr( "Iterative Closest Point algorithm bewteen two mesh.<br/>" )) +
+                           QString (tr( "At least two mesh components must be selected :" )) +
                            QString ( "<ul>" ) +
-                           QString ( "<li> The first one is the source mesh (the one to be registered) </li>" ) +
-                           QString ( "<li> The second one is the target mesh </li>" ) +
+                           QString ( tr("<li> The first one is the source mesh (the one to be registered) </li>" )) +
+                           QString ( tr("<li> The second one is the target mesh </li>" )) +
                            QString ( "</ul>" ) );
     this->setComponent ( "MeshComponent" );
     this->setFamily ( "Mesh Processing" );
-    this->addTag ( "registration" );
-    setProperty ( "Number of Iterations", 20 );
+    this->addTag ( tr("registration") );
     distanceMeasureType = RMS;
+
+    Property* numberOfIterationsProperty = new Property(tr("Number of iterations"), 20, tr("The number of iteration of the ICP algorithm."), "");
+    addParameter(numberOfIterationsProperty);
+
+    Property* distanceMesureTypeProperty = new Property(tr("Distance mesure type"), RMS, tr("The distance mesure type use by the ICP algorithm."), "");
+    distanceMesureTypeProperty->setEnumTypeName("DistanceMeasureType");
+    QStringList distanceMesureTypeName;
+    distanceMesureTypeName << "RMS" << "ABS";
+    distanceMesureTypeProperty->setAttribute("enumNames", distanceMesureTypeName);
+    addParameter(distanceMesureTypeProperty);
 }
 
 ICPRegistration::~ICPRegistration() {
@@ -59,6 +70,8 @@ camitk::Action::ApplyStatus ICPRegistration::apply() {
     QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
     Application::showStatusBarMessage ( "Registration..." );
     Application::resetProgressBar();
+    vtkSmartPointer<vtkCallbackCommand> progressCallback = vtkSmartPointer<vtkCallbackCommand>::New();
+    progressCallback->SetCallback(&Application::vtkProgressFunction);
 
     // at least 2 targets must be selected
     if ( getTargets().size() < 2 ) {
@@ -88,18 +101,19 @@ camitk::Action::ApplyStatus ICPRegistration::apply() {
     icp->SetSource ( sourceMesh->getPointSet() );
     icp->SetTarget ( targetMesh->getPointSet() );
     icp->GetLandmarkTransform()->SetModeToRigidBody();
-    icp->SetMaximumNumberOfIterations ( property ( "Number of Iterations" ).toInt() );
-    switch (property("distanceMeasureType").toInt()) {
-      case RMS :
-	icp->SetMeanDistanceModeToRMS();
-	break;
-      case ABS :
-	icp->SetMeanDistanceModeToAbsoluteValue();
-	break;
-      default:
-	icp->SetMeanDistanceModeToRMS();
-	break;
+    icp->SetMaximumNumberOfIterations ( property ( "Number of iterations" ).toInt() );
+    switch (property("Distance mesure type").toInt()) {
+    case RMS :
+        icp->SetMeanDistanceModeToRMS();
+        break;
+    case ABS :
+        icp->SetMeanDistanceModeToAbsoluteValue();
+        break;
+    default:
+        icp->SetMeanDistanceModeToRMS();
+        break;
     }
+    icp->AddObserver( vtkCommand::ProgressEvent, progressCallback);
     icp->Modified();
     icp->Update();
 
@@ -112,6 +126,7 @@ camitk::Action::ApplyStatus ICPRegistration::apply() {
     icpTransformFilter->SetInputData ( sourceMesh->getPointSet() );
 #endif
     icpTransformFilter->SetTransform ( icp );
+    icpTransformFilter->AddObserver(vtkCommand::ProgressEvent, progressCallback);
     icpTransformFilter->Update();
 
     // create a new MeshComponent for the result
