@@ -32,16 +32,15 @@
 
 /**
  * @ingroup group_sdk_actions_mesh_meshprocessing
- * 
+ *
  * @brief
  * Perform an Iterative Closest Point registration between two meshes.
- * 
+ *
  */
 class ICPRegistration : public camitk::Action {
 
     Q_OBJECT
     Q_ENUMS ( DistanceMeasureType )
-    Q_PROPERTY ( DistanceMeasureType distanceMeasureType READ getDistanceMeasureType WRITE setDistanceMeasureType )
 
 public:
 
@@ -54,7 +53,7 @@ public:
 
     /// the constructor
     ICPRegistration ( camitk::ActionExtension* ext );
-    
+
     /// the destructor
     virtual ~ICPRegistration();
 
@@ -64,20 +63,12 @@ public slots :
     /// method applied when the action is called
     virtual ApplyStatus apply();
 
-    /// get the distance measure type
-    DistanceMeasureType getDistanceMeasureType() {
-        return distanceMeasureType;
-    }
-
-    /// set the distance measure type
-    void setDistanceMeasureType ( DistanceMeasureType t ) {
-        distanceMeasureType = t;
-    }
-    
 protected :
 
     DistanceMeasureType distanceMeasureType;
 
 };
 
-#endif // ICP_REGISTRATION_H
\ No newline at end of file
+Q_DECLARE_METATYPE(ICPRegistration::DistanceMeasureType)
+
+#endif // ICP_REGISTRATION_H
