@@ -32,6 +32,7 @@
 
 #include <vtkPolyDataNormals.h>
 #include <vtkSmartPointer.h>
+#include <vtkCallbackCommand.h>
 
 using namespace camitk;
 
@@ -40,14 +41,14 @@ using namespace camitk;
 InvertMesh::InvertMesh(ActionExtension * extension) : Action(extension) {
     // Setting name, description and input component
     setName("Invert Mesh");
-    setDescription("Invert the mesh faces");
+    setDescription(tr("Invert the mesh faces"));
     setComponent("MeshComponent");
 
     // Setting classification family and tags
     setFamily("Mesh Processing");
-    addTag("Inside Out");
-    addTag("Normal");
-    addTag("Flip");
+    addTag(tr("Inside Out"));
+    addTag(tr("Normal"));
+    addTag(tr("Flip"));
 }
 
 // --------------- destructor -------------------
@@ -71,14 +72,20 @@ void InvertMesh::process(MeshComponent * comp) {
 
     vtkSmartPointer<vtkPolyDataNormals> polydataNormals = vtkSmartPointer<vtkPolyDataNormals>::New();
     vtkSmartPointer<vtkPolyData> poly = vtkPolyData::SafeDownCast(comp->getPointSet());
+    vtkSmartPointer<vtkCallbackCommand> progressCallback = vtkSmartPointer<vtkCallbackCommand>::New();
+    progressCallback->SetCallback(&Application::vtkProgressFunction);
 
     polydataNormals->SetInput(poly);
     polydataNormals->SetFlipNormals(1);
+    polydataNormals->AddObserver(vtkCommand::ProgressEvent, progressCallback);
     polydataNormals->Update();
 
     comp->setPointSet(vtkPointSet::SafeDownCast(polydataNormals->GetOutput()));
     comp->refresh();
 
+    // restore the normal cursor and progress bar
+    Application::resetProgressBar();
+    QApplication::restoreOverrideCursor();
 }
 
 
