@@ -30,16 +30,17 @@
 
 /**
  * @ingroup group_sdk_actions_mesh_meshprocessing
- * 
+ *
  * @brief
  * Invert the input mesh.
- * 
+ *
  */
 class InvertMesh : public camitk::Action {
+    Q_OBJECT
 
-public: 
+public:
 
-    /// Default Constructor 
+    /// Default Constructor
     InvertMesh(camitk::ActionExtension * extension);
 
     /// Default Destructor
@@ -48,17 +49,17 @@ public:
 public slots:
     /** this method is automatically called when the action is triggered.
       * Call getTargets() method to get the list of components to use.
-      * \note getTargets() is automatically filtered so that it only contains compatible components, 
+      * \note getTargets() is automatically filtered so that it only contains compatible components,
       * i.e., instances of InvertMesh (or a subclass).
       */
     virtual ApplyStatus apply();
 
-private: 
+private:
     /// helper method to simplify the target component processing
     virtual void process(camitk::MeshComponent * comp);
-	
 
-}; 
+
+};
 
 #endif // INVERTMESH_H
 
