@@ -34,6 +34,11 @@
 #include "ExtractEdges.h"
 #include "MergeMeshs.h"
 #include "MeshClipping.h"
+#include "ComputeCurvatures.h"
+#include "LoadTransformation.h"
+#include "ExportAsMDL.h"
+#include "LoadTextureFromBMP.h"
+#include "SaveDisplacementFromTransformation.h"
 
 #include "Application.h"
 
@@ -48,11 +53,16 @@ void MeshProcessingExtension::init() {
     registerNewAction(WarpOut);
     registerNewAction(ExtractSurface);
     registerNewAction(ICPRegistration);
-	registerNewAction(InvertMesh);
-	registerNewAction(SmoothFilter);
+    registerNewAction(InvertMesh);
+    registerNewAction(SmoothFilter);
     registerNewAction(ExtractEdges);
-	registerNewAction(MergeMeshs);
+    registerNewAction(MergeMeshs);
     registerNewAction(MeshClipping);
+    registerNewAction(ComputeCurvatures);
+    registerNewAction(LoadTransformation);
+    registerNewAction(ExportAsMDL);
+    registerNewAction(LoadTextureFromBMP);
+    registerNewAction(SaveDisplacementFromTransformation);
 }
 
 
