@@ -32,10 +32,10 @@
 
 /**
  * @ingroup group_sdk_actions_mesh_meshprocessing
- * 
+ *
  * @brief
  * The mesh processing actions extension.
- * 
+ *
  */
 class MeshProcessingExtension : public camitk::ActionExtension {
     Q_OBJECT
@@ -50,12 +50,16 @@ public:
 
     /// initialize all the actions
     virtual void init();
-    
+
     /// Method that return the action extension name
-    virtual QString getName() {return "Mesh Processing";};
-    
+    virtual QString getName() {
+        return "Mesh Processing";
+    };
+
     /// Method that return the action extension descrption
-    virtual QString getDescription() {return "This extension provides some mesh algorithms";};
+    virtual QString getDescription() {
+        return "This extension provides some mesh algorithms";
+    };
 
 };
 
