@@ -22,19 +22,21 @@
  *
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
-
+// CamiTK includes
 #include "WarpOut.h"
-
 #include <Application.h>
 #include <MeshComponent.h>
 #include <Log.h>
-using namespace camitk;
+#include <Property.h>
 
+// Qt includes
 #include <QMessageBox>
 
+// C++ includes
 #include <set>
 #include <complex>
 
+// Vtk includes
 #include <vtkPointSet.h>
 #include <vtkPolyDataNormals.h>
 #include <vtkDataSetSurfaceFilter.h>
@@ -43,6 +45,9 @@ using namespace camitk;
 #include <vtkCellLocator.h>
 #include <vtkPolyDataConnectivityFilter.h>
 #include <vtkUnstructuredGrid.h>
+#include <vtkCallbackCommand.h>
+
+using namespace camitk;
 
 //#include <vtkFeatureEdges.h>
 
@@ -50,15 +55,19 @@ using namespace camitk;
 WarpOut::WarpOut(ActionExtension* extension) : Action(extension) {
     // Setting name, description and input component
     setName("Warp Out");
-    setDescription("Move the outside points along the normal in order to thicken a volumic mesh (works only with closed- centered- mesh).");
+    setDescription(tr("Move the outside points along the normal in order to thicken a volumic mesh (works only with closed- centered- mesh)."));
     setComponent("MeshComponent");
 
     // Setting classification family and tags
     setFamily("Mesh Processing");
-    addTag("Grow");
-    addTag("Thicken");
+    addTag(tr("Grow"));
+    addTag(tr("Thicken"));
+
+    Property* displacementProperty = new Property(tr("Displacement"), 1.0, tr("The length of the displacement of the mesh toward its normals."), "");
+    displacementProperty->setAttribute("minimum", 0.0);
+    displacementProperty->setAttribute("singleStep", 0.1);
+    addParameter(displacementProperty);
 
-    setProperty("Displacement", QVariant(1.0)); // Total displacement to use the nodes
 }
 
 
@@ -70,6 +79,8 @@ Action::ApplyStatus WarpOut::apply() {
     QApplication::setOverrideCursor ( QCursor ( Qt::WaitCursor ) );
     Application::showStatusBarMessage("Warping out...");
     Application::resetProgressBar();
+    vtkSmartPointer<vtkCallbackCommand> progressCallback = vtkSmartPointer<vtkCallbackCommand>::New();
+    progressCallback->SetCallback(&Application::vtkProgressFunction);
 
     // use the last target
     MeshComponent *targetMesh = dynamic_cast<MeshComponent*>(getTargets().last());
@@ -77,18 +88,16 @@ Action::ApplyStatus WarpOut::apply() {
 
     if ( vtkUnstructuredGrid::SafeDownCast ( targetMesh->getPointSet() ) ) {
         resultPointSet = vtkSmartPointer<vtkUnstructuredGrid>::New();
+    } else if ( vtkPolyData::SafeDownCast ( targetMesh->getPointSet() ) ) {
+        resultPointSet = vtkSmartPointer<vtkPolyData>::New();
+    } else {
+        QMessageBox::warning(NULL, tr("Warp Out"), tr("Invalid mesh: the selected component (\"" )+ targetMesh->getName() + tr("\") is not an unstructured grid nor a polydata."), QMessageBox::Abort);
+        return ABORTED;
     }
-    else
-        if ( vtkPolyData::SafeDownCast ( targetMesh->getPointSet() ) ) {
-            resultPointSet = vtkSmartPointer<vtkPolyData>::New();
-        }
-        else {
-	    QMessageBox::warning(NULL, "Warp Out", "Invalid mesh: the selected component (\"" + targetMesh->getName() + "\") is not an unstructured grid nor a polydata.", QMessageBox::Abort);	
-            return ABORTED;
-	}
-	
-    resultPointSet->DeepCopy(targetMesh->getPointSet());
 
+    resultPointSet->AddObserver(vtkCommand::ProgressEvent, progressCallback);
+    resultPointSet->DeepCopy(targetMesh->getPointSet());
+    resultPointSet->Update();
     //-- add the id as point data in order to match normal to the points
     vtkSmartPointer<vtkIdTypeArray> pointId = vtkSmartPointer<vtkIdTypeArray>::New();
     pointId->SetNumberOfComponents(1);
@@ -103,6 +112,7 @@ Action::ApplyStatus WarpOut::apply() {
     //-- extract the surface
     vtkSmartPointer<vtkDataSetSurfaceFilter> surfaceFilter = vtkSmartPointer<vtkDataSetSurfaceFilter>::New();
     surfaceFilter->SetInput(resultPointSet);
+    surfaceFilter->AddObserver(vtkCommand::ProgressEvent, progressCallback);
     surfaceFilter->Update();
 
     //-- generate the normals
@@ -111,6 +121,7 @@ Action::ApplyStatus WarpOut::apply() {
     normalGenerator->ComputePointNormalsOn();
     normalGenerator->ComputeCellNormalsOff();
     normalGenerator->SplittingOff();
+    normalGenerator->AddObserver(vtkCommand::ProgressEvent, progressCallback);
     normalGenerator->Update();
 
     //-- Find the outer surface (see ExtractOutsideSurface Cxx example)
@@ -143,6 +154,7 @@ Action::ApplyStatus WarpOut::apply() {
     connectivityFilter->SetExtractionModeToCellSeededRegions();
     connectivityFilter->InitializeSeedList();
     connectivityFilter->AddSeed(cellId);
+    connectivityFilter->AddObserver(vtkCommand::ProgressEvent, progressCallback);
     connectivityFilter->Update();
 
     /*
