@@ -29,18 +29,19 @@
 #include <Action.h>
 /**
  * @ingroup group_sdk_actions_mesh_meshprocessing
- * 
+ *
  * @brief
  * This action extracts the outer surface of a multiple surface polydata model and warp it outward.
- * 
- * It assumes the outside surface is closed and there is only one outside surface. 
- * It also assumes that the center of the model lies inside the outer surface. 
- * 
- * @note 
+ *
+ * It assumes the outside surface is closed and there is only one outside surface.
+ * It also assumes that the center of the model lies inside the outer surface.
+ *
+ * @note
  * Grow only the outward surface of a mesh.
- * 
+ *
  */
 class WarpOut : public camitk::Action {
+    Q_OBJECT
 
 public:
     /// the constructor
@@ -48,7 +49,7 @@ public:
 
     /// the destructor
     virtual ~WarpOut() {};
-    
+
 public slots:
     /// method called when the action is applied
     virtual ApplyStatus apply();
