@@ -87,8 +87,7 @@ ActionTransition * ActionState::addActionTransition(QString buttonText, QAbstrac
         QMap<Action::ApplyStatus, QVector<QPushButton * > >::iterator buts = conditionalButtons.find(status);
         if (buts != conditionalButtons.end()) {
             buts.value().append(button);
-        }
-        else {
+        } else {
             QVector<QPushButton *> vect;
             vect.append(button);
             conditionalButtons.insert(status, vect);
@@ -178,8 +177,7 @@ void ActionState::setPreviousActionStatus(camitk::Action::ApplyStatus status) {
     QMap<Action::ApplyStatus, QString>::const_iterator desc = conditionalDescriptions.find(status);
     if (desc != conditionalDescriptions.end()) {
         myStateWidget->setDescription(desc.value());
-    }
-    else {
+    } else {
         myStateWidget->setDescription(description);
     }
 
