@@ -66,17 +66,15 @@ ActionStateMachine::ActionStateMachine(int &argc, char ** argv, QString inputFil
     // Read parameters or ask for scxml file name and output save directory
     QString filename;
     if (inputFileName.isEmpty()) {
-        filename = QFileDialog::getOpenFileName( NULL, "Please select an xml file");
-    }
-    else {
+        filename = QFileDialog::getOpenFileName( NULL, tr("Please select an xml file"));
+    } else {
         filename = inputFileName;
     }
 
     // Get the name of the saving directory
     if (outputDirectory.isEmpty()) {
-        saveDirectory = QFileDialog::getExistingDirectory(this->mainWindow, "Please select a directory where to save log and component files");
-    }
-    else {
+        saveDirectory = QFileDialog::getExistingDirectory(this->mainWindow, tr("Please select a directory where to save log and component files"));
+    } else {
         saveDirectory = QDir(outputDirectory);
     }
 
@@ -85,10 +83,10 @@ ActionStateMachine::ActionStateMachine(int &argc, char ** argv, QString inputFil
 
     QDateTime now = QDateTime::currentDateTime();
     // NOTE on Windows ":" (colon) is reserved by the system for separating drive names, therefore hh:mm:ss cannot be used
-    QString newDir = now.toString("yyyy-MM-dd") + "T" + now.toString("hh-mm-ss"); 
+    QString newDir = now.toString("yyyy-MM-dd") + "T" + now.toString("hh-mm-ss");
 
     if (! saveDirectory.mkdir(newDir))  {
-        saveDirectory = QFileDialog::getExistingDirectory(this->mainWindow, "Please select a directory where to save log and component files");
+        saveDirectory = QFileDialog::getExistingDirectory(this->mainWindow, tr("Please select a directory where to save log and component files"));
         saveDirectory.mkdir(newDir);
     }
     saveDirectory.cd(newDir);
@@ -157,14 +155,14 @@ void ActionStateMachine::checkSCXMLFile(QString filename) throw (AbortException)
     //read the file
     QFile file(filename);
     if (!file.open(QIODevice::ReadOnly)) {
-        msg = "File not found: the file " + filename + " was not found";
+        msg = tr("File not found: the file ") + filename + tr(" was not found");
         CAMITK_ERROR("ActionStateMachine", "setFileName", msg.toStdString());
-        msg = "Error: cannot find file " + filename + " sorry...";
+        msg = tr("Error: cannot find file ") + filename + tr(" sorry...");
         throw AbortException (msg.toStdString());
     }
     if (!doc.setContent(&file)) {
         file.close();
-        msg = "File " + filename + " have no valid root (not a valid XML file format)";
+        msg = tr("File ") + filename + tr(" have no valid root (not a valid XML file format)");
         CAMITK_ERROR("ActionStateMachine", "setFileName", msg.toStdString());
         throw AbortException(msg.toStdString());
     }
@@ -172,7 +170,7 @@ void ActionStateMachine::checkSCXMLFile(QString filename) throw (AbortException)
     QString rootName = doc.documentElement().nodeName();
     if (rootName != QString("scxml")) {
         file.close();
-        msg = "File " + filename + " is not a SCXML file (" + getDomNodeLocation(doc.documentElement()) + "root node not equals to \"scxml\")";
+        msg = tr("File ") + filename + tr(" is not a SCXML file (") + getDomNodeLocation(doc.documentElement()) + tr("root node not equals to \"scxml\")");
         CAMITK_ERROR("ActionStateMachineWindow", "setFileName", msg.toStdString());
         throw AbortException(msg.toStdString());
     }
@@ -247,8 +245,7 @@ void ActionStateMachine::createAllActionStates(QDomNodeList nodeList) throw(Abor
                         delete(state);
                         state = new SaveActionState(&machine, stateId, stateDescription, saveDirectory.absolutePath(), logStream);
                         setCamiTKSaveAction((SaveActionState *) state, actionElement);
-                    }
-                    else {
+                    } else {
                         setCamiTKAction(state, actionElement);
                     }
                 }
@@ -279,8 +276,7 @@ void ActionStateMachine::createAllActionStates(QDomNodeList nodeList) throw(Abor
             if (inputNames.values().contains(inputCompName)) {
                 QString msg = "Warning: same input \"" + inputCompName + "\" for more than one state. It might be wrong.\n";
                 CAMITK_ERROR("ActionStateMachine", "createAllActionStates", msg.toStdString());
-            }
-            else
+            } else
                 inputNames.insert(it.value(),inputCompName);
         }
         foreach(QString outputCompName, it.value()->getOutputComponents().keys()) {
@@ -288,8 +284,7 @@ void ActionStateMachine::createAllActionStates(QDomNodeList nodeList) throw(Abor
                 QString msg = "Error: same output name \"" + outputCompName + "\" for more than one state. Please rename the output of \"" + it.value()->getName() + "\"\n";
                 CAMITK_ERROR("ActionStateMachine", "createAllActionStates", msg.toStdString());
                 throw AbortException (msg.toStdString());
-            }
-            else
+            } else
                 outputNames.insert(it.value(),outputCompName);
         }
         ++it;
@@ -381,17 +376,13 @@ QVector<Action::ApplyStatus> ActionStateMachine::stringToStatus(QString listOfSt
     for (QStringList::iterator it = statusStringList.begin(); it != statusStringList.end(); it++) {
         if((*it) == "SUCCESS") {
             statusList.append(Action::SUCCESS);
-        }
-        else if ((*it) == "ERROR") {
+        } else if ((*it) == "ERROR") {
             statusList.append(Action::ERROR);
-        }
-        else if ((*it) == "WARNING") {
+        } else if ((*it) == "WARNING") {
             statusList.append(Action::WARNING);
-        }
-        else if ((*it) == "ABORTED") {
+        } else if ((*it) == "ABORTED") {
             statusList.append(Action::ABORTED);
-        }
-        else if ((*it) == "TRIGGERED") {
+        } else if ((*it) == "TRIGGERED") {
             statusList.append(Action::TRIGGERED);
         }
     }
