@@ -60,8 +60,7 @@ QWidget * ActionStateViewer::getWidget(QWidget * parent) {
             QDialog *myWidgetIsADialog = new QDialog(NULL);
             myWidgetIsADialog->setWindowTitle(objectName());
             myWidget = myWidgetIsADialog;
-        }
-        else
+        } else
             myWidget = new QWidget();
 
         QVBoxLayout * actionStateWidgetLayout = new QVBoxLayout();
