@@ -53,32 +53,26 @@ int main(int argc, char **argv) {
         if (o.help()) {
             usage(argv[0]);
             return EXIT_SUCCESS;
-        }
-        else if(o.file() == "" || o.outDir() == "") {
+        } else if(o.file() == "" || o.outDir() == "") {
             usage(argv[0]);
             return EXIT_SUCCESS;
-        }
-        else {
+        } else {
             // create a camitk application
             ActionStateMachine am(argc, argv, QString(o.file().c_str()), QString(o.outDir().c_str()));
 
             return am.exec();
         }
-    }
-    catch (const cli::exception& e) {
+    } catch (const cli::exception& e) {
         cerr << e << endl;
         usage(argv[0]);
         return EXIT_FAILURE;
-    }
-    catch (camitk::AbortException& e) {
+    } catch (camitk::AbortException& e) {
         std::cout << argv[0] << " aborted..." << std::endl << "camitk AbortException:" << std::endl << e.what() << std::endl;
         return EXIT_FAILURE;
-    }
-    catch (std::exception& e) {
+    } catch (std::exception& e) {
         std::cout << argv[0] << " aborted..." << std::endl << "std AbortException:" << std::endl << e.what() << std::endl;
         return EXIT_FAILURE;
-    }
-    catch (...) {
+    } catch (...) {
         std::cout << argv[0] << " aborted..." << std::endl << "Unknown Exception" << std::endl;
         return EXIT_FAILURE;
     }
