@@ -36,6 +36,7 @@
 #include <Log.h>
 #include <Core.h> // for getActionDirectories()
 #include <Explorer.h>
+#include <FrameExplorer.h>
 #include <PropertyExplorer.h>
 
 using namespace camitk;
@@ -53,6 +54,7 @@ using namespace camitk;
 #include <QStatusBar>
 #include <QMessageBox>
 #include <QDockWidget>
+#include <QTranslator>
 
 // ------------- constructor -----------------
 ImpMainWindow::ImpMainWindow() : MainWindow( "imp" ) {
@@ -71,8 +73,18 @@ ImpMainWindow::ImpMainWindow() : MainWindow( "imp" ) {
     // now add the different viewers
     setCentralViewer(MedicalImageViewer::getInstance());
     addDockViewer(Qt::LeftDockWidgetArea, Explorer::getInstance());
+    addDockViewer(Qt::LeftDockWidgetArea, FrameExplorer::getInstance());
     addDockViewer(Qt::LeftDockWidgetArea, PropertyExplorer::getInstance());
     addDockViewer(Qt::RightDockWidgetArea, ActionViewer::getActionViewer());
+
+    //Merge Explorer and FrameExplorer viewers in one layout
+    QDockWidget* dockWidgetExplorer = dockWidgetMap.value(Explorer::getInstance(), NULL);
+    QDockWidget* dockWidgetFrameExplorer = dockWidgetMap.value(FrameExplorer::getInstance(), NULL);
+    if (dockWidgetExplorer && dockWidgetFrameExplorer) {
+        tabifyDockWidget(dockWidgetExplorer, dockWidgetFrameExplorer);
+        dockWidgetExplorer->raise();
+    }
+
     showViewer(ActionViewer::getActionViewer(), false);
     ActionViewer::getActionViewer()->setSearchPanelVisible(true);
     showStatusBar(true);
@@ -132,7 +144,7 @@ void ImpMainWindow::initActions() {
             applicationActionExtension = current;
     }
     if (applicationActionExtension==NULL) {
-        QMessageBox::critical(this,"Application Error", "This application <b>needs</b> the Application Action Extension and could not find it in any of the action extension directories (<tt>" + Core::getActionDirectories().join(", ") + "</tt>).<br/><br/>Please check your CamiTK configuration and/or installation<br/><br/>E.g., run <tt>camitk-config --config</tt> to check the action extension directories and your installation.");
+        QMessageBox::critical(this,tr("Application Error"), tr("This application <b>needs</b> the Application Action Extension and could not find it in any of the action extension directories (<tt>") + Core::getActionDirectories().join(", ") + tr("</tt>).<br/><br/>Please check your CamiTK configuration and/or installation<br/><br/>E.g., run <tt>camitk-config --config</tt> to check the action extension directories and your installation."));
         exit(EXIT_FAILURE);
     }
 
@@ -165,7 +177,7 @@ void ImpMainWindow::initActions() {
     editApplicationSettings->setStatusTip ( tr ( "Edit the preferences" ) );
     editApplicationSettings->setWhatsThis ( tr ( "Preferences\n\nEdit the settings and preferences of imp" ) );
     connect ( editApplicationSettings, SIGNAL ( triggered() ), this, SLOT ( editSettings() ) );
-    
+
     // save history as SCXML
     saveHistory = new QAction(tr("&Save history"), this);
     saveHistory->setStatusTip(tr("Save the history of actions processed as an SCXML file."));
@@ -198,13 +210,14 @@ void ImpMainWindow::initActions() {
     viewStatusBar->setWhatsThis ( tr ( "Hide/show the status bar." ) );
     connect ( viewStatusBar, SIGNAL ( toggled ( bool ) ), this, SLOT ( showStatusBar(bool)) );
 
-    viewResetWindows = new QAction("Reset Windows", this);
-    viewResetWindows->setStatusTip("Reset all windows in the initial state");
+    viewResetWindows = new QAction(tr("Reset Windows"), this);
+    viewResetWindows->setStatusTip(tr("Reset all windows in the initial state"));
     connect ( viewResetWindows, SIGNAL ( triggered () ), this, SLOT ( resetWindows () ) );
 
     //--- actions of the Help menu
     helpAboutApp = Application::getAction ("About...")->getQAction();
     helpShowConsole = Application::getAction ("Show Console")->getQAction();
+    changeLanguage = Application::getAction("Change Language")->getQAction();
 
 }
 
@@ -237,14 +250,14 @@ void ImpMainWindow::initMenuBar() {
     fileMenu->addSeparator();
     fileMenu->addSeparator();
     fileMenu->addAction ( fileQuit );
-    
+
 
     // -- edit
     QMenu * editMenu = new QMenu ( tr ( "&Edit" ) );
     editMenu->addAction ( editClearSelection );
     editMenu->addSeparator();
     editMenu->addAction ( editApplicationSettings );
-    
+
 
     // -- View menu
     viewMenu = new QMenu ( tr ( "&View" ) );
@@ -259,6 +272,8 @@ void ImpMainWindow::initMenuBar() {
     helpMenu->addSeparator();
     helpMenu->addAction ( helpShowConsole );
     helpMenu->addSeparator();
+    helpMenu->addAction(changeLanguage);
+    helpMenu->addSeparator();
     helpMenu->addAction ( helpAboutApp );
 
     // -- action
@@ -309,15 +324,14 @@ void ImpMainWindow::updateActionStates() {
         Component * comp = Application::getSelectedComponents().last();
 
         if (comp) {
-            QMenu *compActionsMenu = comp->getActionAndPopupMenu();
+            QMenu *compActionsMenu = comp->getActionMenu();
 
             if (compActionsMenu) {
                 actionMenu->addActions(compActionsMenu->actions());
                 actionMenu->setEnabled ( true );
             }
         }
-    }
-    else {
+    } else {
         // add all generic actions
         ActionList allActions = Application::getActions(NULL);
         foreach (Action* action, allActions) {
@@ -342,7 +356,7 @@ void ImpMainWindow::showToolbar ( bool b ) {
 void ImpMainWindow::showMenuBar ( bool b ) {
     // warn the user first
     if (!b) {
-        if (QMessageBox::warning(this, "Hide menu", "The menu is going to be hidden. There is only one way to make it reappear: you need to press CTRL+M again.", QMessageBox::Apply | QMessageBox::Abort) == QMessageBox::Abort) {
+        if (QMessageBox::warning(this, tr("Hide menu"), tr("The menu is going to be hidden. There is only one way to make it reappear: you need to press CTRL+M again."), QMessageBox::Apply | QMessageBox::Abort) == QMessageBox::Abort) {
             viewMenuBar->blockSignals ( true );
             viewMenuBar->setChecked ( true );
             viewMenuBar->blockSignals ( false );
@@ -369,18 +383,27 @@ void ImpMainWindow::resetWindows() {
             removeDockWidget(it.value());
             addDockWidget ( Qt::LeftDockWidgetArea, it.value() );
             it.value()->show();
-        }
-        else if (it.value()->widget() == PropertyExplorer::getInstance()->getWidget()) {
+        } else if (it.value()->widget() == FrameExplorer::getInstance()->getWidget(NULL)) {
+            removeDockWidget(it.value());
+            addDockWidget(Qt::LeftDockWidgetArea, it.value());
+            it.value()->show();
+        } else if (it.value()->widget() == PropertyExplorer::getInstance()->getWidget()) {
             removeDockWidget(it.value());
             addDockWidget(Qt::LeftDockWidgetArea, it.value() );
             it.value()->show();
-        }
-        else if (it.value()->widget() == ActionViewer::getActionViewer()->getWidget()) {
+        } else if (it.value()->widget() == ActionViewer::getActionViewer()->getWidget()) {
             removeDockWidget(it.value());
             addDockWidget(Qt::RightDockWidgetArea, it.value());
             it.value()->show();
         }
     }
+    //Merge Explorer and FrameExplorer viewers in one layout
+    QDockWidget* dockWidgetExplorer = dockWidgetMap.value(Explorer::getInstance(), NULL);
+    QDockWidget* dockWidgetFrameExplorer = dockWidgetMap.value(FrameExplorer::getInstance(), NULL);
+    if (dockWidgetExplorer && dockWidgetFrameExplorer) {
+        tabifyDockWidget(dockWidgetExplorer, dockWidgetFrameExplorer);
+        dockWidgetExplorer->raise();
+    }
 
     showStatusBar(true);
     showMenuBar(true);
@@ -432,8 +455,7 @@ void ImpMainWindow::openDirectory ( QAction *emitter ) {
 
         if ( !comp ) {
             statusBar()->showMessage ( tr ( "Error loading directory:" ) + dir );
-        }
-        else {
+        } else {
             // TODO add to recent document and manage directories as recent documents
             statusBar()->showMessage ( tr ( QString("Directory " + dir + " successfully loaded" ).toStdString().c_str()) );
 
@@ -542,10 +564,12 @@ void ImpMainWindow::openRecentDocuments() {
 
     if ( action ) {
         // check if this recent document still exists!
-        if (QFileInfo(action->data().toString()).exists())
-            Application::open ( action->data().toString() );
-        else
-            QMessageBox::warning(this, "Open Recent", "Recent document:<br/>" + action->data().toString() + "<br/>Does not exist anymore, sorry...");
+        if (QFileInfo(action->data().toString()).exists()) {
+            Action* openFileAction = Application::getAction("Open File");
+            openFileAction->setProperty("File Name", action->data().toString()); // avoid opening a dialog, as the file path is already know
+            openFileAction->applyAndRegister();
+        } else
+            QMessageBox::warning(this, tr("Open Recent"), tr("Recent document:<br/>") + action->data().toString() + tr("<br/>Does not exist anymore, sorry..."));
     }
 
 }
@@ -572,8 +596,7 @@ void ImpMainWindow::updateRecentDocumentsMenu() {
 }
 
 // ------------------------------ saveHistoryAsSCXML -------------------------------
-void ImpMainWindow::saveHistoryAsSCXML()
-{
+void ImpMainWindow::saveHistoryAsSCXML() {
     Application::saveHistoryAsSXML();
 }
 
