@@ -27,15 +27,13 @@
 #include "RemovableLineEditWidget.h"
 
 /**  Constructor */
-RemovableLineEditWidget::RemovableLineEditWidget(QWidget * parent) : QWidget(parent)
-{
+RemovableLineEditWidget::RemovableLineEditWidget(QWidget * parent) : QWidget(parent) {
     ui.setupUi(this);
 }
 /**  Destructor */
 RemovableLineEditWidget::~RemovableLineEditWidget() {}
 
-void RemovableLineEditWidget::remove()
-{
+void RemovableLineEditWidget::remove() {
     emit removeLineEdit();
 }
 
