@@ -27,14 +27,12 @@
 #include "WelcomeWidget.h"
 
 /**  Constructor */
-WelcomeWidget::WelcomeWidget(QWidget * parent) : QWidget(parent)
- {
-	ui.setupUi(this);
+WelcomeWidget::WelcomeWidget(QWidget * parent) : QWidget(parent) {
+    ui.setupUi(this);
 }
 /**  Destructor */
-WelcomeWidget::~WelcomeWidget(){}
+WelcomeWidget::~WelcomeWidget() {}
 
-void WelcomeWidget::nextButtonClicked()
-{
+void WelcomeWidget::nextButtonClicked() {
     emit next();
 }
