@@ -30,14 +30,14 @@
 
 /**
  * @ingroup group_sdk_components_msh
- * 
- * @brief 
- * This simple MSH Component allows you to manipulate .msh legacy files (gmsh).
- * 
- * @see 
+ *
+ * @brief
+ * This simple MSH Component allows you to manipulate .msh legacy and V2 files (gmsh).
+ *
+ * @see
  * www.geuz.org/gmsh/doc/texinfo/gmsh.html for more information about this format
- * 
- **/ 
+ *
+ **/
 class MshComponent : public camitk::MeshComponent {
 
     Q_OBJECT
@@ -47,6 +47,13 @@ public:
     /// default constructor
     MshComponent(const QString & file) throw(camitk::AbortException);
 
+
+private :
+
+    void readLegacyFormat( std::ifstream& fileStream);
+
+    void readV2Format( std::ifstream& fileStream);
+
 };
 
 #endif
