@@ -48,7 +48,7 @@ QString OffExtension::getName() const {
 }
 
 QString OffExtension::getDescription() const {
-    return "OFF <em>.off</em> files in <b>CamiTK</b>.(very few support!) <br>(c)TIMC-IMAG UJF 2012";
+    return tr("OFF <em>.off</em> files in <b>CamiTK</b>.(very few support!) <br>(c)TIMC-IMAG UJF 2012");
 }
 
 QStringList OffExtension::getFileExtensions() const {
@@ -68,10 +68,10 @@ bool OffExtension::save(Component* component) const {
     vtkSmartPointer<vtkPointSet> ps =  component->getPointSet();
 
     if (ps == NULL || ps->GetNumberOfPoints()==0 || ps->GetNumberOfCells() == 0) {
-		QMessageBox::warning(NULL, "Save As msh", "The selected component does not have any points or cells. This is an invalid mesh.", QMessageBox::Abort);
-		return false;
+        QMessageBox::warning(NULL, "Save As msh", tr("The selected component does not have any points or cells. This is an invalid mesh."), QMessageBox::Abort);
+        return false;
     }
-    
+
     QString baseFilename = QFileInfo(component->getFileName()).absolutePath() + "/" + QFileInfo(component->getFileName()).completeBaseName();
 
     QString offFilename = baseFilename + ".off";
@@ -79,29 +79,29 @@ bool OffExtension::save(Component* component) const {
     ofstream offFile ( offFilename.toUtf8() );
     double xyz[3];
     offFile << "OFF" << endl;
-	// write the number of points, cells and edges
-	offFile << ps->GetPoints()->GetNumberOfPoints()  << " " << ps->GetNumberOfCells() << " " << ps->GetNumberOfElements(vtkPointSet::EDGE) << endl;
+    // write the number of points, cells and edges
+    offFile << ps->GetPoints()->GetNumberOfPoints()  << " " << ps->GetNumberOfCells() << " " << ps->GetNumberOfElements(vtkPointSet::EDGE) << endl;
     // list the points
-	for ( int i = 0; i < ps->GetPoints()->GetNumberOfPoints(); i++ ) {
+    for ( int i = 0; i < ps->GetPoints()->GetNumberOfPoints(); i++ ) {
         ps->GetPoints()->GetPoint(i, xyz);
         // write atom
         offFile << xyz[0] << " " << xyz[1] << " " << xyz[2] << endl;
     }
- 
+
     for ( vtkIdType i = 0; i < ps->GetNumberOfCells() ; i++ ) {
         switch (ps->GetCell(i)->GetCellType()) {
-			case VTK_TRIANGLE :
-				offFile << "3 ";
-				for (vtkIdType j=0;j<ps->GetCell(i)->GetNumberOfPoints();j++)
-					offFile << ps->GetCell(i)->GetPointId(j) << " ";
-				offFile << endl;
-				break;
-			case VTK_QUAD :
-				offFile << "4 ";
-				for (vtkIdType j=0;j<ps->GetCell(i)->GetNumberOfPoints();j++)
-					offFile << ps->GetCell(i)->GetPointId(j) << " ";
-				offFile << endl;
-				break;
+        case VTK_TRIANGLE :
+            offFile << "3 ";
+            for (vtkIdType j=0; j<ps->GetCell(i)->GetNumberOfPoints(); j++)
+                offFile << ps->GetCell(i)->GetPointId(j) << " ";
+            offFile << endl;
+            break;
+        case VTK_QUAD :
+            offFile << "4 ";
+            for (vtkIdType j=0; j<ps->GetCell(i)->GetNumberOfPoints(); j++)
+                offFile << ps->GetCell(i)->GetPointId(j) << " ";
+            offFile << endl;
+            break;
         default:
             saveOk = false;
             CAMITK_ERROR("VolumetricMeshExtension", "save", "unsupported element");
