@@ -45,7 +45,7 @@ QString VRMLComponentExtension::getName() const {
 
 // --------------- getDescription -------------------
 QString VRMLComponentExtension::getDescription() const {
-    return "Manage VRML 2 <em>.wrl .vrml</em> files in <b>CamiTK</b>.(very few support!)";
+    return tr("Manage VRML 2 <em>.wrl .vrml</em> files in <b>CamiTK</b>.(very few support!)");
 }
 
 // --------------- getFileExtensions -------------------
@@ -72,8 +72,7 @@ bool VRMLComponentExtension::save(Component* component) const {
         exporter->SetFileName(mesh->getFileName().toStdString().c_str());
         exporter->Write();
         return true;
-    }
-    else
+    } else
         return false;
 }
 
