@@ -23,20 +23,22 @@
  * $CAMITK_LICENCE_END$
  ****************************************************************************/
 
-// -- Core image component stuff
+// -- Core image component includes
 #include "RawDataDialog.h"
 #include "RawImageComponent.h"
+#include <ImageOrientationHelper.h>
 
-// -- QT stuff
+// -- QT includes
 #include <QString>
+#include <QMetaEnum>
 
-// -- VTK stuff
+// -- VTK includes
 #include <vtkConfigure.h>
 
 
 //--------------- Constructor ---------------------------------
 RawDataDialog::RawDataDialog(QString filename)
-        : QDialog() {
+    : QDialog() {
     this->filename = filename;
     ui.setupUi(this);
     init();
@@ -44,6 +46,8 @@ RawDataDialog::RawDataDialog(QString filename)
 
 //--------------- Destructor ---------------------------------
 RawDataDialog::~RawDataDialog() {
+//     if(this->imgOrientation)
+//         delete this->imgOrientation;
 }
 
 void RawDataDialog::init() {
@@ -73,6 +77,8 @@ void RawDataDialog::init() {
 
     ui.headerSizeLineEdit->setText(QString("0"));
 
+    // fill the Image orientation combobox with the possible orientation
+    ui.orientationComboBox->addItems(camitk::ImageOrientationHelper::getPossibleImageOrientations());
 }
 
 
@@ -98,7 +104,7 @@ int RawDataDialog::getVoxelType() {
     case 1: // "char"
         scalarType = VTK_SIGNED_CHAR;
         break;
-    case 2: // "unsinged short"
+    case 2: // "unsigned short"
         scalarType = VTK_UNSIGNED_SHORT;
         break;
     case 3: // "short"
@@ -251,3 +257,11 @@ QString RawDataDialog::getFilename() {
 bool RawDataDialog::isLowerLeftOrigin() {
     return ui.lloCheckBox->isChecked();
 }
+
+camitk::ImageOrientationHelper::PossibleImageOrientations RawDataDialog::getOrientation() {
+    return (camitk::ImageOrientationHelper::PossibleImageOrientations) ui.orientationComboBox->currentIndex();
+}
+
+
+
+
