@@ -28,6 +28,8 @@
 
 // -- Core image component stuff
 #include "ui_RawDataDialog.h"
+#include <ImageOrientationHelper.h>
+
 
 // -- Core image component stuff classes
 class RawImageComponent;
@@ -37,11 +39,11 @@ class RawImageComponent;
 
 /**
  * @ingroup group_sdk_components_vtkimage
- * 
- * @brief 
+ *
+ * @brief
  * Input of the parameter to read a raw data file
- * 
- **/ 
+ *
+ **/
 class RawDataDialog : public QDialog {
     Q_OBJECT
 
@@ -54,29 +56,35 @@ public:
     /// Initializes the dialog options
     void init();
 
-	int getVoxelType();
-	int getDimX();
-	int getDimY();
-	int getDimZ();
-	bool isBigEndian();
-	int getNbScalarComponents();
-	double getVoxelSizeX();
-	double getVoxelSizeY();
-	double getVoxelSizeZ();
-	double getOriginX();
-	double getOriginY();
-	double getOriginZ();
-	int getHeaderSize();
-	bool isLowerLeftOrigin();
-	QString getFilename();
+    /**
+    * @name Accessors
+    * Get the raw data information
+    */
+    ///@{
+    int getVoxelType();
+    int getDimX();
+    int getDimY();
+    int getDimZ();
+    bool isBigEndian();
+    int getNbScalarComponents();
+    double getVoxelSizeX();
+    double getVoxelSizeY();
+    double getVoxelSizeZ();
+    double getOriginX();
+    double getOriginY();
+    double getOriginZ();
+    int getHeaderSize();
+    bool isLowerLeftOrigin();
+    QString getFilename();
+    camitk::ImageOrientationHelper::PossibleImageOrientations getOrientation();
+    ///@}
+
 
-	
 public slots :
-	virtual void voxelTypeChanged(int);
+    virtual void voxelTypeChanged(int);
 
 private :
-	QString filename;
-
+    QString filename;
 
     // Qt model designed by QtDesigner (with qt4, nor more inheritance from the ui)
     Ui::RawDataDialog ui;
