@@ -28,7 +28,6 @@
 
 // -- Core stuff
 #include <Log.h>
-using namespace camitk;
 
 // -- VTK stuff
 #include <vtkImageReader2.h>
@@ -36,9 +35,11 @@ using namespace camitk;
 //-- Qt
 #include<QFileInfo>
 
+using namespace camitk;
+
 // -------------------- constructor --------------------
 RawImageComponent::RawImageComponent(const QString& fileName) throw(AbortException)
-        : ImageComponent(fileName) {
+    : ImageComponent(fileName) {
     if (!fileName.isNull()) {
         // restore the normal cursor
         QApplication::restoreOverrideCursor();
@@ -46,12 +47,10 @@ RawImageComponent::RawImageComponent(const QString& fileName) throw(AbortExcepti
         myDialog = new RawDataDialog(fileName);
         if (myDialog->exec() == QDialog::Accepted) {
             createComponent();
-        }
-        else {
+        } else {
             throw AbortException("Opening cancelled by user\n");
         }
-    }
-    else {
+    } else {
         throw AbortException("No file name\n");
     }
 }
@@ -62,11 +61,6 @@ RawImageComponent::~RawImageComponent() {
         delete (myDialog);
 }
 
-// -------------------- createDialog --------------------
-void RawImageComponent::createDialog() {
-    //FIXME TODO is this method needed?
-}
-
 // -------------------- createComponent --------------------
 void RawImageComponent::createComponent() {
     QString filename       = myDialog->getFilename();
@@ -84,6 +78,7 @@ void RawImageComponent::createComponent() {
     double Oz              = myDialog->getOriginZ();
     int headerSize         = myDialog->getHeaderSize();
     bool lowerLeftOrigin   = myDialog->isLowerLeftOrigin();
+    orientation            = myDialog->getOrientation();
 
     // Reader and image variables
     vtkSmartPointer<vtkImageReader2> reader = vtkSmartPointer<vtkImageReader2>::New();
@@ -103,21 +98,17 @@ void RawImageComponent::createComponent() {
         reader->FileLowerLeftOn();
     else
         reader->FileLowerLeftOff();
-
     reader->SetHeaderSize(headerSize);
-
     image = reader->GetOutput();
 
     try {
         reader->Update();
-    }
-    catch (...) {
+    } catch (...) {
         throw AbortException("VTK was unable to read file " + filename.toStdString());
     }
 
-    setImageData(image, false);
-    // use file basename as default name
-    setName(QFileInfo(filename).baseName());
+    setImageData(image, false, orientation);
+
 }
 
 
