@@ -32,18 +32,19 @@
 
 // -- Core image component stuff
 #include <ImageComponent.h>
+#include <ImageOrientationHelper.h>
 
 // -- VTK stuff
 #include <vtkSmartPointer.h>
 #include <vtkImageData.h>
 /**
  * @ingroup group_sdk_components_vtkimage
- * 
- * @brief 
+ *
+ * @brief
  * This class manage raw images, i.e., images that are directly loaded from a file containing only the binary values of the voxels.
  * The user has to fill a form in order to describe the parameters (volume and voxel sizes, binary type...)
- * 
- **/ 
+ *
+ **/
 class RawImageComponent : public camitk::ImageComponent  {
     Q_OBJECT
 public:
@@ -53,12 +54,16 @@ public:
     /// Destructor
     ~RawImageComponent();
 
+    /// Create the component using the different option given by the user in the dialog box
     virtual void createComponent();
 
-    void createDialog();
-
 protected:
-    RawDataDialog * myDialog;
+    /// The UI asking for the user to select information on the Raw image
+    RawDataDialog* myDialog;
+
+private:
+    /// The orientation of the image
+    camitk::ImageOrientationHelper::PossibleImageOrientations orientation;
 
 };
 
