@@ -34,11 +34,11 @@
 #include <QMetaProperty>
 /**
  * @ingroup group_sdk_components_vtkimage
- * 
- * @brief 
+ *
+ * @brief
  * This class manage vtk images, i.e images that can be loaded in CamiTK by using an VTK importer.
- * 
- **/ 
+ *
+ **/
 class VTK_IMAGE_COMPONENT_API VtkImageComponent : public camitk::ImageComponent  {
     Q_OBJECT
 public:
@@ -46,10 +46,18 @@ public:
     VtkImageComponent(const QString&) throw (camitk::AbortException);
 
     /// needed for deleting
-    virtual ~VtkImageComponent() {};
+    virtual ~VtkImageComponent() {}
 
     /// actually create the component from the file
     virtual void createComponent(const QString&);
+
+private:
+    /**
+     * Read the TranformMatrix tag (rotation of the image) from the input MHA/MHD image
+     * @param fileName The input MHA / MHD file name to read the tag from.
+     * @return A 4x4 homogenious matrix containing the Rotation information of the image
+     */
+    vtkSmartPointer<vtkMatrix4x4> readMetaImageTransformMatrix(const QString & fileName);
 };
 
 
