@@ -45,7 +45,7 @@ using namespace camitk;
 #include <vtkMetaImageWriter.h>
 
 // --------------- declare the plugin -------------------
-Q_EXPORT_PLUGIN2(vtkimage, VtkImageComponentExtension);
+Q_EXPORT_PLUGIN2(vtkimage, VtkImageComponentExtension)
 
 
 // --------------- getName -------------------
@@ -55,7 +55,7 @@ QString VtkImageComponentExtension::getName() const {
 
 // --------------- getDescription -------------------
 QString VtkImageComponentExtension::getDescription() const {
-    return "Manage any file type supported by vtk in <b>CamiTK</b>";
+    return tr("Manage any file type supported by vtk in <b>CamiTK</b>");
 }
 
 // --------------- getFileExtensions -------------------
@@ -75,8 +75,7 @@ Component * VtkImageComponentExtension::open(const QString & fileName) throw (Ab
         else
             return new VtkImageComponent( fileName );
 
-    }
-    catch (AbortException e) {
+    } catch (AbortException e) {
         throw e;
     }
 }
@@ -87,6 +86,7 @@ bool VtkImageComponentExtension::save(Component* component) const {
     if (!img)
         return false;
     else {
+
         QFileInfo fileInfo(component->getFileName());
         vtkSmartPointer<vtkImageData> image = img->getImageData();
 
@@ -103,12 +103,11 @@ bool VtkImageComponentExtension::save(Component* component) const {
 
             try {
                 writer->Write();
-            }
-            catch (...) {
+            } catch (...) {
                 return false;
             }
 
-            // Write info in a separted file
+            // Write info in a separated file
             QFile infoFile(fileInfo.absoluteDir().absolutePath() + fileInfo.baseName() + ".info");
             infoFile.open(QIODevice::ReadWrite | QIODevice::Text);
             QTextStream out(&infoFile);
@@ -125,8 +124,7 @@ bool VtkImageComponentExtension::save(Component* component) const {
             infoFile.flush();
             infoFile.close();
             return true;
-        }
-        else {
+        } else {
             //-- save as vtk image
             // vtk writer
             vtkSmartPointer<vtkImageWriter> writer;
@@ -142,40 +140,31 @@ bool VtkImageComponentExtension::save(Component* component) const {
             if (QString::compare(fileExt, "jpg", Qt::CaseInsensitive) == 0) {
                 writer = vtkSmartPointer<vtkJPEGWriter>::New();
                 writer->SetFileDimensionality(2);
+            } else if (QString::compare(fileExt, "png", Qt::CaseInsensitive) == 0) {
+                writer = vtkSmartPointer<vtkPNGWriter>::New();
+                writer->SetFileDimensionality(2);
+            } else if ((QString::compare(fileExt, "tiff", Qt::CaseInsensitive) == 0) ||
+                       (QString::compare(fileExt, "tif",  Qt::CaseInsensitive) == 0)) {
+                writer = vtkSmartPointer<vtkTIFFWriter>::New();
+                writer->SetFileDimensionality(2);
+            } else if (QString::compare(fileExt, "bmp", Qt::CaseInsensitive) == 0) {
+                writer = vtkSmartPointer<vtkBMPWriter>::New();
+                writer->SetFileDimensionality(2);
+            } else if ((QString::compare(fileExt, "pbm", Qt::CaseInsensitive) == 0) ||
+                       (QString::compare(fileExt, "pgm", Qt::CaseInsensitive) == 0) ||
+                       (QString::compare(fileExt, "ppm", Qt::CaseInsensitive) == 0)) {
+                writer = vtkSmartPointer<vtkPNMWriter>::New();
+                writer->SetFileDimensionality(2);
+            } else if ((QString::compare(fileExt, "mhd", Qt::CaseInsensitive) == 0) ||
+                       (QString::compare(fileExt, "mha", Qt::CaseInsensitive) == 0)) {
+                vtkSmartPointer<vtkMetaImageWriter> metaImgWriter = vtkSmartPointer<vtkMetaImageWriter>::New();
+                metaImgWriter->SetCompression(false);
+                writer = metaImgWriter;
+                writer->SetFileDimensionality(3);
+            } else {
+                QMessageBox::warning(NULL, "Saving Error", tr("Cannot save file: unrecognized extension \".") + fileExt + "\"");
+                return false;
             }
-            else
-                if (QString::compare(fileExt, "png", Qt::CaseInsensitive) == 0) {
-                    writer = vtkSmartPointer<vtkPNGWriter>::New();
-                    writer->SetFileDimensionality(2);
-                }
-                else
-                    if ((QString::compare(fileExt, "tiff", Qt::CaseInsensitive) == 0) ||
-                            (QString::compare(fileExt, "tif",  Qt::CaseInsensitive) == 0)) {
-                        writer = vtkSmartPointer<vtkTIFFWriter>::New();
-                        writer->SetFileDimensionality(2);
-                    }
-                    else
-                        if (QString::compare(fileExt, "bmp", Qt::CaseInsensitive) == 0) {
-                            writer = vtkSmartPointer<vtkBMPWriter>::New();
-                            writer->SetFileDimensionality(2);
-                        }
-                        else
-                            if ((QString::compare(fileExt, "pbm", Qt::CaseInsensitive) == 0) ||
-                                    (QString::compare(fileExt, "pgm", Qt::CaseInsensitive) == 0) ||
-                                    (QString::compare(fileExt, "ppm", Qt::CaseInsensitive) == 0)) {
-                                writer = vtkSmartPointer<vtkPNMWriter>::New();
-                                writer->SetFileDimensionality(2);
-                            }
-                            else
-                                if ((QString::compare(fileExt, "mhd", Qt::CaseInsensitive) == 0) ||
-                                        (QString::compare(fileExt, "mha", Qt::CaseInsensitive) == 0)) {
-                                    writer = vtkSmartPointer<vtkMetaImageWriter>::New();
-                                    writer->SetFileDimensionality(3);
-                                }
-                                else {
-                                    QMessageBox::warning(NULL, "Saving Error", "Cannot save file: unrecognized extension \"." + fileExt + "\"");
-                                    return false;
-                                }
 
             if (writer) {
                 if ((image->GetDataDimension() == 2 ) ||
@@ -188,6 +177,36 @@ bool VtkImageComponentExtension::save(Component* component) const {
                 writer->SetInput(image);
                 writer->Write();
 
+                // Save image orientation for compatible header (as it is not possible to store it either in
+                // vtkImageData or vtkMetaImageWriter classes
+                // we are obliged to open the whole image, as a text, replace the anatomical orientation string
+                // store it back in ASCII (to preserve data format)
+                if ((QString::compare(fileExt, "mha", Qt::CaseInsensitive) == 0) || (QString::compare(fileExt, "mhd", Qt::CaseInsensitive) == 0)) {
+                    QByteArray fileData;
+                    QFile file(component->getFileName());
+                    file.open(QIODevice::ReadWrite);
+                    fileData = file.readAll();
+
+                    QString text(fileData);
+                    // Store anatomical orientation in header
+                    text.replace(QString("AnatomicalOrientation = ???"), QString("AnatomicalOrientation = ") + ImageOrientationHelper::getOrientationAsQString(img->getInitialOrientation()));
+
+                    // Retrieve orientation information
+                    vtkSmartPointer<vtkMatrix4x4> rotationMatrix = img->getRotationMatrix();
+                    QString rotationInfo = "TransformMatrix = ";
+                    for(int j=0; j < 3; j++){
+                        for(int i=0; i < 3; i++){
+                            rotationInfo += QString::number(rotationMatrix->GetElement(i, j)) + " ";
+                        }
+                    }
+                    rotationInfo += "\n";
+                    text.replace(QRegExp("TransformMatrix = (([-+]?(?:\\b[0-9]+(?:\\.[0-9]*)?|\\.[0-9]+\\b)(?:[eE][-+]?[0-9]+\\b)?)[ |\\n])+"), rotationInfo);
+
+                    file.seek(0); // go to the beginning of the file
+                    file.write(text.toAscii()); // write back the file, in ASCII to preserve data format
+
+                    file.close(); // close the file handle.
+                }
             }
 
             return true;
