@@ -24,7 +24,6 @@
  ****************************************************************************/
 
 #include "VtkMeshComponent.h"
-#include "VtkMeshComponentPopup.h"
 
 // -- CamiTK stuff
 #include <Application.h>
@@ -58,7 +57,6 @@ VtkMeshComponent::VtkMeshComponent (const QString& fileName)  throw(AbortExcepti
 
     setName(VtkMeshUtil::getVtkPointSetHeaderString(myFileName.toStdString()).c_str());
 
-    myPopupMenu = NULL;
     myProperties = NULL;
     initialPointData = NULL;
     demoPointData = NULL;
@@ -142,8 +140,7 @@ void VtkMeshComponent::showPointData(VTK_COMPONENT_POINT_DATA_TYPE type) {
             InteractiveViewer::get3DViewer()->setColorScaleMinMax ( range[0], range[1] );
             InteractiveViewer::get3DViewer()->setColorScaleTitle("VTK Point Data");
             InteractiveViewer::get3DViewer()->setColorScale ( true );
-        }
-        else {
+        } else {
             InteractiveViewer::get3DViewer()->setColorScale ( false );
         }
         break;
@@ -211,8 +208,7 @@ bool VtkMeshComponent::exportMDL ( std::string filename ) {
                 ds->GetPointData()->GetNormals()->GetTuple ( i, pt );
                 o << pt[0] << " " << pt[1] << " " << pt[2] << std::endl;
             }
-        }
-        else {
+        } else {
             // compute the normals
             vtkPolyDataNormals * pNormals = vtkPolyDataNormals::New();
             pNormals->SetInput ( ds );
@@ -247,21 +243,10 @@ bool VtkMeshComponent::exportMDL ( std::string filename ) {
         }
         return true;
 
-    }
-    else
+    } else
         return false;
 }
 
-
-// -------------------- getPopupMenu --------------------
-QMenu * VtkMeshComponent::getPopupMenu ( QWidget* parent ) {
-    if ( !myPopupMenu ) {
-        myPopupMenu = new VtkMeshComponentPopup ( this, parent );
-    }
-
-    return myPopupMenu; // Do NOT forget to delete this object in the destructor
-}
-
 //------------------------ getPixmap ---------------------
 #include "vtklogo_20x20.xpm"
 QPixmap * VtkMeshComponent::myPixmap = NULL;
@@ -281,7 +266,7 @@ void VtkMeshComponent::initDynamicProperties() {
     double initialValue = 0.0;
     if( getActor( InterfaceGeometry::Surface ) )
         initialValue = getActor( InterfaceGeometry::Surface )->GetProperty()->GetAmbient();
-    Property *ambiant = new Property("Ambient", initialValue, "Ambient Lightning Coefficient. Warning: this cannot be saved in the VTK file.", "%");
+    Property *ambiant = new Property("Ambient", initialValue, tr("Ambient Lightning Coefficient. Warning: this cannot be saved in the VTK file."), "%");
     ambiant->setAttribute("minimum",0.0);
     ambiant->setAttribute("maximum",1.0);
     ambiant->setAttribute("decimals",2);
@@ -290,7 +275,7 @@ void VtkMeshComponent::initDynamicProperties() {
 
     if( getActor( InterfaceGeometry::Surface ) )
         initialValue = getActor( InterfaceGeometry::Surface )->GetProperty()->GetDiffuse();
-    Property *diffuse = new Property("Diffuse", initialValue, "Diffuse Lightning Coefficient. Warning: this cannot be saved in the VTK file.", "%");
+    Property *diffuse = new Property("Diffuse", initialValue, tr("Diffuse Lightning Coefficient. Warning: this cannot be saved in the VTK file."), "%");
     diffuse->setAttribute("minimum",0.0);
     diffuse->setAttribute("maximum",1.0);
     diffuse->setAttribute("decimals",2);
@@ -299,7 +284,7 @@ void VtkMeshComponent::initDynamicProperties() {
 
     if( getActor( InterfaceGeometry::Surface ) )
         initialValue = getActor( InterfaceGeometry::Surface )->GetProperty()->GetSpecular();
-    Property *specular = new Property("Specular", initialValue, "Specular Lightning Coefficient. Warning: this cannot be saved in the VTK file.", "%");
+    Property *specular = new Property("Specular", initialValue, tr("Specular Lightning Coefficient. Warning: this cannot be saved in the VTK file."), "%");
     specular->setAttribute("minimum",0.0);
     specular->setAttribute("maximum",1.0);
     specular->setAttribute("decimals",2);
@@ -308,14 +293,14 @@ void VtkMeshComponent::initDynamicProperties() {
 
     if( getActor( InterfaceGeometry::Surface ) )
         initialValue = getActor( InterfaceGeometry::Surface )->GetProperty()->GetSpecularPower();
-    Property *specularPower = new Property("Specular Power", initialValue, "Specular Power. Warning: this cannot be saved in the VTK file.", "%");
+    Property *specularPower = new Property("Specular Power", initialValue, tr("Specular Power. Warning: this cannot be saved in the VTK file."), "%");
     specularPower->setAttribute("minimum",0.0);
     specularPower->setAttribute("maximum",128.0);
     addProperty(specularPower);
 
     if( getActor( InterfaceGeometry::Surface ) )
         initialValue = getActor( InterfaceGeometry::Surface )->GetProperty()->GetOpacity();
-    Property *opacity = new Property("Opacity", initialValue, "The object's opacity. 1.0 is totally opaque and 0.0 is completely transparent. Warning: this cannot be saved in the VTK file.", "%");
+    Property *opacity = new Property("Opacity", initialValue, tr("The object's opacity. 1.0 is totally opaque and 0.0 is completely transparent. Warning: this cannot be saved in the VTK file."), "%");
     opacity->setAttribute("minimum",0.0);
     opacity->setAttribute("maximum",1.0);
     opacity->setAttribute("decimals",2);
@@ -324,10 +309,10 @@ void VtkMeshComponent::initDynamicProperties() {
 
     double initialColor[3] = {0.8,0.8,0.8};
     if( getActor( InterfaceGeometry::Surface ) )
-         getActor( InterfaceGeometry::Surface )->GetProperty()->GetColor(initialColor);
+        getActor( InterfaceGeometry::Surface )->GetProperty()->GetColor(initialColor);
     QColor initialQColor;
     initialQColor.setRgbF(initialColor[0],initialColor[1],initialColor[2]);
-    addProperty(new Property("Specular Color", initialQColor, "Specular Surface Color", "RGB"));
+    addProperty(new Property("Specular Color", initialQColor, tr("Specular Surface Color"), "RGB"));
 
 }
 
@@ -336,30 +321,24 @@ void VtkMeshComponent::updateProperty(QString name, QVariant value) {
     if( name == "Ambient" ) {
         if( getActor( InterfaceGeometry::Surface ) )
             getActor( InterfaceGeometry::Surface )->GetProperty()->SetAmbient( value.toDouble());
-    }
-    else if( name == "Diffuse" ) {
+    } else if( name == "Diffuse" ) {
         if( getActor( InterfaceGeometry::Surface ) )
             getActor( InterfaceGeometry::Surface )->GetProperty()->SetDiffuse( value.toDouble() );
-    }
-    else if( name == "Specular" ) {
+    } else if( name == "Specular" ) {
         if( getActor( InterfaceGeometry::Surface ) )
             getActor( InterfaceGeometry::Surface )->GetProperty()->SetSpecular( value.toDouble() );
-    }
-    else if( name == "Specular Power" ) {
+    } else if( name == "Specular Power" ) {
         if( getActor( InterfaceGeometry::Surface ) )
             getActor( InterfaceGeometry::Surface )->GetProperty()->SetSpecularPower( value.toDouble() );
-    }
-    else if( name == "Opacity" ) {
+    } else if( name == "Opacity" ) {
         if( getActor( InterfaceGeometry::Surface ) )
             getActor( InterfaceGeometry::Surface )->GetProperty()->SetOpacity( value.toDouble() );
-    }
-    else if( name == "Specular Color" ) {
+    } else if( name == "Specular Color" ) {
         if( getActor( InterfaceGeometry::Surface ) ) {
             QColor newColor = value.value<QColor>();
             getActor( InterfaceGeometry::Surface )->GetProperty()->SetSpecularColor( newColor.redF(), newColor.greenF(), newColor.blueF() );
         }
-    }
-    else {
+    } else {
         // just in case there is an inherited property to manage
         MeshComponent::updateProperty(name, value);
     }
