@@ -30,7 +30,6 @@
 
 #include "VtkMeshComponentAPI.h"
 #include "VtkMeshUtil.h"
-class VtkMeshComponentPopup;
 
 #include <vtkSmartPointer.h>
 
@@ -64,9 +63,6 @@ public:
     /// Export as MDL (see Geometry).
     bool exportMDL ( std::string filename );
 
-    /// Overriden method so that we actually can build a popup menu with different actions
-    virtual QMenu * getPopupMenu ( QWidget* parent );
-
     /// the vtk logo (for the explorer viewer)
     virtual QPixmap getIcon();
 
@@ -82,15 +78,12 @@ public:
 
     /// update a specific property
     virtual void updateProperty(QString name, QVariant value);
-    
+
 private:
 
     /// subtype of vtkPointSet
     VtkMeshUtil::VtkPointSetType whatIsIt;
 
-    /// the popup menu
-    VtkMeshComponentPopup * myPopupMenu;
-
     /// properties for vtk mesh type
     VtkMeshComponentProperties * myProperties;
 
