@@ -33,34 +33,33 @@ Q_EXPORT_PLUGIN2(vtk, VtkMeshComponentExtension)
 
 // --------------- getName -------------------
 QString VtkMeshComponentExtension::getName() const {
-  return "VTK Component";
+    return "VTK Component";
 }
 
 // --------------- getDescription -------------------
 QString VtkMeshComponentExtension::getDescription() const {
-  return "Manage VTK <em>.vtk</em> files in <b>CamiTK</b>.<br/>CamiTK is based on vtk. Lots of things are possible with a vtk model!";
+    return tr("Manage VTK <em>.vtk</em> files in <b>CamiTK</b>.<br/>CamiTK is based on vtk. Lots of things are possible with a vtk model!");
 }
 
 // --------------- getFileExtensions -------------------
 QStringList VtkMeshComponentExtension::getFileExtensions() const {
-  QStringList ext;
-  ext << "vtk";
-  return ext;
+    QStringList ext;
+    ext << "vtk";
+    return ext;
 }
 
 // --------------- open -------------------
 Component * VtkMeshComponentExtension::open(const QString & fileName) throw (AbortException) {
-  return new VtkMeshComponent(fileName);
+    return new VtkMeshComponent(fileName);
 }
 
 // --------------- save -------------------
 bool VtkMeshComponentExtension::save(Component* component) const {
     MeshComponent* mesh = dynamic_cast<MeshComponent*>(component);
     if (mesh->getPointSet()) {
-         VtkMeshUtil::savePointSetToFile(mesh->getPointSet(), mesh->getFileName().toStdString(), mesh->getName().toStdString());
-         mesh->setModified(false);
-         return true;
-    }
-    else
-        return false;    
+        VtkMeshUtil::savePointSetToFile(mesh->getPointSet(), mesh->getFileName().toStdString(), mesh->getName().toStdString());
+        mesh->setModified(false);
+        return true;
+    } else
+        return false;
 }
