@@ -70,35 +70,35 @@ vtkSmartPointer<vtkPointSet> VtkMeshUtil::buildVtkPointSet(std::string vtkFileNa
 
     // create the Geometry depending on the type
     switch (whatIsIt) {
-        case VtkMeshUtil::UNSTRUCTURED_GRID: {
-                vtkSmartPointer<vtkUnstructuredGridReader>uGridReader = vtkSmartPointer<vtkUnstructuredGridReader>::New();
-                uGridReader->SetFileName(vtkFileName.c_str());
-                uGridReader->Update();
+    case VtkMeshUtil::UNSTRUCTURED_GRID: {
+        vtkSmartPointer<vtkUnstructuredGridReader>uGridReader = vtkSmartPointer<vtkUnstructuredGridReader>::New();
+        uGridReader->SetFileName(vtkFileName.c_str());
+        uGridReader->Update();
 
-                return uGridReader->GetOutput();
-                break;
-            }
+        return uGridReader->GetOutput();
+        break;
+    }
 
-        case VtkMeshUtil::STRUCTURED_GRID: {
-                vtkSmartPointer<vtkStructuredGridReader>sGridReader = vtkSmartPointer<vtkStructuredGridReader>::New();
-                sGridReader->SetFileName(vtkFileName.c_str());
-                sGridReader->Update();
+    case VtkMeshUtil::STRUCTURED_GRID: {
+        vtkSmartPointer<vtkStructuredGridReader>sGridReader = vtkSmartPointer<vtkStructuredGridReader>::New();
+        sGridReader->SetFileName(vtkFileName.c_str());
+        sGridReader->Update();
 
-                return sGridReader->GetOutput();
-                break;
-            }
-        case VtkMeshUtil::POLY_DATA: {
-                vtkSmartPointer<vtkPolyDataReader>polyDataReader = vtkSmartPointer<vtkPolyDataReader>::New();
-                polyDataReader->SetFileName(vtkFileName.c_str());
-                polyDataReader->Update();
+        return sGridReader->GetOutput();
+        break;
+    }
+    case VtkMeshUtil::POLY_DATA: {
+        vtkSmartPointer<vtkPolyDataReader>polyDataReader = vtkSmartPointer<vtkPolyDataReader>::New();
+        polyDataReader->SetFileName(vtkFileName.c_str());
+        polyDataReader->Update();
 
-                return polyDataReader->GetOutput();
-                break;
-            }
-        case VtkMeshUtil::UNKNOWN: {
-                return NULL;
-                break;
-            }
+        return polyDataReader->GetOutput();
+        break;
+    }
+    case VtkMeshUtil::UNKNOWN: {
+        return NULL;
+        break;
+    }
     }
 
     return NULL;
@@ -115,17 +115,17 @@ bool VtkMeshUtil::savePointSetToFile(vtkSmartPointer<vtkPointSet> ps, std::strin
     VtkPointSetType whatIsIt = typeOf(ps);
 
     switch(whatIsIt) {
-        case VtkMeshUtil::UNSTRUCTURED_GRID:
-            saveUnstructuredGridToFile(vtkUnstructuredGrid::SafeDownCast(ps), fname, oname);
-            return true;
-        case VtkMeshUtil::POLY_DATA:
-            savePolyDataToFile(vtkPolyData::SafeDownCast(ps), fname, oname);
-            return true;
-        case VtkMeshUtil::STRUCTURED_GRID:
-            saveStructuredGridToFile(vtkStructuredGrid::SafeDownCast(ps),fname,oname);
-            return true;
-        default:
-            return false; // unknown type
+    case VtkMeshUtil::UNSTRUCTURED_GRID:
+        saveUnstructuredGridToFile(vtkUnstructuredGrid::SafeDownCast(ps), fname, oname);
+        return true;
+    case VtkMeshUtil::POLY_DATA:
+        savePolyDataToFile(vtkPolyData::SafeDownCast(ps), fname, oname);
+        return true;
+    case VtkMeshUtil::STRUCTURED_GRID:
+        saveStructuredGridToFile(vtkStructuredGrid::SafeDownCast(ps),fname,oname);
+        return true;
+    default:
+        return false; // unknown type
     }
 }
 
@@ -172,37 +172,37 @@ std::string VtkMeshUtil::getVtkPointSetHeaderString(std::string vtkFileName, Vtk
 
     switch (whatIsIt) {
 
-        case VtkMeshUtil::UNSTRUCTURED_GRID: {
-                vtkSmartPointer<vtkUnstructuredGridReader> uGridReader = vtkSmartPointer<vtkUnstructuredGridReader>::New();
-                uGridReader->SetFileName(vtkFileName.c_str());
-                uGridReader->Update();
+    case VtkMeshUtil::UNSTRUCTURED_GRID: {
+        vtkSmartPointer<vtkUnstructuredGridReader> uGridReader = vtkSmartPointer<vtkUnstructuredGridReader>::New();
+        uGridReader->SetFileName(vtkFileName.c_str());
+        uGridReader->Update();
 
-                headerStr = uGridReader->GetHeader();
+        headerStr = uGridReader->GetHeader();
 
-                break;
-            }
-        case VtkMeshUtil::POLY_DATA: {
-                vtkSmartPointer<vtkPolyDataReader> polyDataReader = vtkSmartPointer<vtkPolyDataReader>::New();
-                polyDataReader->SetFileName(vtkFileName.c_str());
-                polyDataReader->Update();
+        break;
+    }
+    case VtkMeshUtil::POLY_DATA: {
+        vtkSmartPointer<vtkPolyDataReader> polyDataReader = vtkSmartPointer<vtkPolyDataReader>::New();
+        polyDataReader->SetFileName(vtkFileName.c_str());
+        polyDataReader->Update();
 
-                headerStr = polyDataReader->GetHeader();
-                break;
-            }
-        case VtkMeshUtil::STRUCTURED_GRID: {
-                vtkSmartPointer<vtkStructuredGridReader> sGridReader = vtkSmartPointer<vtkStructuredGridReader>::New();
-                sGridReader->SetFileName(vtkFileName.c_str());
-                sGridReader->Update();
+        headerStr = polyDataReader->GetHeader();
+        break;
+    }
+    case VtkMeshUtil::STRUCTURED_GRID: {
+        vtkSmartPointer<vtkStructuredGridReader> sGridReader = vtkSmartPointer<vtkStructuredGridReader>::New();
+        sGridReader->SetFileName(vtkFileName.c_str());
+        sGridReader->Update();
 
-                headerStr = sGridReader->GetHeader();
-                break;
-            }
-        case VtkMeshUtil::UNKNOWN: {
-                int nbegin = vtkFileName.find_last_of('/');
-                int nend = vtkFileName.find_last_of('.');
-                headerStr = vtkFileName.substr(nbegin+1, nend - nbegin - 1);
-                break;
-            }
+        headerStr = sGridReader->GetHeader();
+        break;
+    }
+    case VtkMeshUtil::UNKNOWN: {
+        size_t nbegin = vtkFileName.find_last_of('/');
+        size_t nend = vtkFileName.find_last_of('.');
+        headerStr = vtkFileName.substr(nbegin+1, nend - nbegin - 1);
+        break;
+    }
     }
 
     return headerStr;
@@ -237,15 +237,11 @@ VtkMeshUtil::VtkPointSetType VtkMeshUtil::typeOf(vtkSmartPointer<vtkPointSet> aP
 
     if (aPointSet->IsA("vtkPolyData"))     {
         whatIsIt = VtkMeshUtil::POLY_DATA;
+    } else if (aPointSet->IsA("vtkUnstructuredGrid"))     {
+        whatIsIt = VtkMeshUtil::UNSTRUCTURED_GRID;
+    } else if (aPointSet->IsA("vtkStructuredGrid"))     {
+        whatIsIt = VtkMeshUtil::STRUCTURED_GRID;
     }
-    else
-        if (aPointSet->IsA("vtkUnstructuredGrid"))     {
-            whatIsIt = VtkMeshUtil::UNSTRUCTURED_GRID;
-        }
-        else
-            if (aPointSet->IsA("vtkStructuredGrid"))     {
-                whatIsIt = VtkMeshUtil::STRUCTURED_GRID;
-            }
 
     return whatIsIt;
 }
@@ -258,12 +254,12 @@ vtkSmartPointer< vtkPolyData > VtkMeshUtil::vtkPointSetToVtkPolyData(vtkSmartPoi
 
     if (whatIsIt == VtkMeshUtil::POLY_DATA)
         result = vtkPolyData::SafeDownCast(aPointSet);
-    else {        
+    else {
         vtkSmartPointer<vtkDataSetSurfaceFilter> surfaceFilter = vtkSmartPointer<vtkDataSetSurfaceFilter>::New();
         surfaceFilter->SetInput(aPointSet);
         surfaceFilter->Update();
-	
-	result = surfaceFilter->GetOutput();
+
+        result = surfaceFilter->GetOutput();
     }
     return result;
 }
