@@ -31,7 +31,6 @@
 #include <iostream>
 #include <memory>
 
-
 // includes from Qt
 #include <QFileInfo>
 #include <QDir>
@@ -44,36 +43,29 @@
 
 using namespace cepcoreschema;
 
-ActionGenerator::ActionGenerator(QString xmlFileName, QString licence) throw (QString)
-{
+ActionGenerator::ActionGenerator(QString xmlFileName, QString licence) throw (QString) {
     this->licence = licence;
     QFileInfo xmlFile(xmlFileName);
-    if ((! xmlFile.exists()) || (! xmlFile.isFile()))
-    {
+    if ((! xmlFile.exists()) || (! xmlFile.isFile())) {
         QString msg = "Exception from ActionExtension generation: \n     The file " + xmlFileName +  " does not exist or is not a file...\n";
         throw (msg);
     }
-    try
-    {
+    try {
         std::string xmlFileStr = xmlFileName.toStdString();
         std::auto_ptr<Action> domAction = action(xmlFileStr, xml_schema::flags::dont_validate);
         createFromDom(*domAction);
-    }
-    catch (...)
-    {
+    } catch (...) {
         QString msg = "Action XML file not valid.";
         throw msg;
     }
 }
 
-ActionGenerator::ActionGenerator( Action & domAction, QString licence)
-{
+ActionGenerator::ActionGenerator( Action & domAction, QString licence) {
     this->licence = licence;
     createFromDom(domAction);
 }
 
-void ActionGenerator::createFromDom(Action & dom)
-{
+void ActionGenerator::createFromDom(Action & dom) {
     std::cout << "Creating action..." << std::endl;
     this->name              = QString(dom.name().c_str());
     this->description    = QString(dom.description().c_str()).simplified();
@@ -84,24 +76,20 @@ void ActionGenerator::createFromDom(Action & dom)
     // 1- Family
     this->family           = QString(dom.classification().family().c_str());
     // 2- Checking tags
-    for (Classification::tag_const_iterator it = dom.classification().tag().begin(); it !=dom.classification().tag().end(); it++)
-    {
+    for (Classification::tag_const_iterator it = dom.classification().tag().begin(); it !=dom.classification().tag().end(); it++) {
         tags << QString((*it).c_str());
     }
     // 3- Checking  itk flag
     this->isItkFilter = false;
-    if (dom.classification().itkFilter().present())
-    {
+    if (dom.classification().itkFilter().present()) {
         this->isItkFilter = true;
         this->itkFilterOutputType = QString(dom.classification().itkFilter().get().outputType().c_str());
     }
 
     // parameters
-    if (dom.parameters().present())
-    {
+    if (dom.parameters().present()) {
         Parameters theParameters = dom.parameters().get();
-        for (Parameters::parameter_iterator param= theParameters.parameter().begin(); param != theParameters.parameter().end(); param++)
-        {
+        for (Parameters::parameter_iterator param= theParameters.parameter().begin(); param != theParameters.parameter().end(); param++) {
             Parameter & oneParameter = (*param);
             actionParameters.append(new ParameterGenerator(oneParameter));
         }
@@ -109,28 +97,23 @@ void ActionGenerator::createFromDom(Action & dom)
     }
 }
 
-ActionGenerator::~ActionGenerator()
-{
+ActionGenerator::~ActionGenerator() {
 }
 
-QString ActionGenerator::getClassName() const
-{
+QString ActionGenerator::getClassName() const {
     return this->className;
 }
 
 
-void ActionGenerator::generateFiles(QString directoryName)
-{
+void ActionGenerator::generateFiles(QString directoryName) {
     writeHFile(directoryName);
     writeCFile(directoryName);
-    if (isItkFilter)
-    {
+    if (isItkFilter) {
         writeSpecialItkFile(directoryName);
     }
 }
 
-void ActionGenerator::writeHFile(QString directoryName)
-{
+void ActionGenerator::writeHFile(QString directoryName) {
 
     // Setting the right input and output files
     QFile initFile(":/resources/Action.h.in");
@@ -141,127 +124,82 @@ void ActionGenerator::writeHFile(QString directoryName)
     extFilePath.setFile(directoryName, className + ".h");
     QFile extFile(extFilePath.absoluteFilePath());
 
-    if (! extFile.open(QIODevice::WriteOnly | QIODevice::Text))
-    {
+    if (! extFile.open(QIODevice::WriteOnly | QIODevice::Text)) {
         QString msg = "Exception from extension generation: \n    Cannot write on file " + extFilePath.fileName() + "\n";
         throw (msg);
     }
     std::cout << "generating " << extFilePath.absolutePath().toStdString() << "/" << className.toStdString() << ".h" << std::endl;
     QTextStream out(&extFile);
     QString text;
-    do
-    {
+    do {
         text = in.readLine();
         text.replace(QRegExp("@LICENCE@"), licence);
         text.replace(QRegExp("@HEADDEF@"), className.toUpper());
         text.replace(QRegExp("@COMPONENTNAME@"), componentName);
         text.replace(QRegExp("@ACTIONCLASSNAME@"), className);
 
-        if (text.contains(QRegExp("@IF_NOCOMP@")))
-        {
-            if (componentName != "")
-            {
-                do
-                {
+        if (text.contains(QRegExp("@IF_NOCOMP@"))) {
+            if (componentName != "") {
+                do {
                     text = in.readLine();
-                }
-                while ( (! text.contains(QRegExp("@ELSEIF_NOCOMP@"))) &&
-                        (! text.contains(QRegExp("@END_NOCOMP@"))));
+                } while ( (! text.contains(QRegExp("@ELSEIF_NOCOMP@"))) &&
+                          (! text.contains(QRegExp("@END_NOCOMP@"))));
             }
-        }
-        else if (text.contains(QRegExp("@ELSEIF_NOCOMP@")))
-        {
-            if (componentName == "")
-            {
-                do
-                {
+        } else if (text.contains(QRegExp("@ELSEIF_NOCOMP@"))) {
+            if (componentName == "") {
+                do {
                     text = in.readLine();
-                }
-                while (! text.contains(QRegExp("@END_NOCOMP@")));
+                } while (! text.contains(QRegExp("@END_NOCOMP@")));
             }
-        }
-        else if (text.contains(QRegExp("@END_NOCOMP@")))
-        {
+        } else if (text.contains(QRegExp("@END_NOCOMP@"))) {
             // Go to next line...
-        }
-        else if (text.contains(QRegExp("@IF_DEFCOMPONENT@")))
-        {
-            if ((componentName == "Component") || (componentName == ""))
-            {
-                do
-                {
+        } else if (text.contains(QRegExp("@IF_DEFCOMPONENT@"))) {
+            if ((componentName == "Component") || (componentName == "")) {
+                do {
                     text = in.readLine();
-                }
-                while ( (! text.contains(QRegExp("@ENDIF_DEFCOMPONENT@"))) &&
-                        (! text.contains(QRegExp("@ELSEIF_DEFCOMPONENT@"))));
+                } while ( (! text.contains(QRegExp("@ENDIF_DEFCOMPONENT@"))) &&
+                          (! text.contains(QRegExp("@ELSEIF_DEFCOMPONENT@"))));
             }
-        }
-        else if ((text.contains(QRegExp("@ELSEIF_DEFCOMPONENT@"))))
-        {
-            if ((componentName != "Component") && (componentName != ""))
-            {
-                do
-                {
+        } else if ((text.contains(QRegExp("@ELSEIF_DEFCOMPONENT@")))) {
+            if ((componentName != "Component") && (componentName != "")) {
+                do {
                     text = in.readLine();
-                }
-                while (! text.contains(QRegExp("@ENDIF_DEFCOMPONENT@")));
+                } while (! text.contains(QRegExp("@ENDIF_DEFCOMPONENT@")));
             }
-        }
-        else if (text.contains(QRegExp("@ENDIF_DEFCOMPONENT@")))
-        {
+        } else if (text.contains(QRegExp("@ENDIF_DEFCOMPONENT@"))) {
             // Go to next line...
-        }
-        else if (text.contains(QRegExp("@IF_IMAGECOMPONENT@")))
-        {
-            if ((componentName != "ImageComponent") || (isItkFilter))
-            {
-                do
-                {
+        } else if (text.contains(QRegExp("@IF_IMAGECOMPONENT@"))) {
+            if ((componentName != "ImageComponent") || (isItkFilter)) {
+                do {
                     text = in.readLine();
-                }
-                while (! text.contains(QRegExp("@ENDIF_IMAGECOMPONENT@")));
+                } while (! text.contains(QRegExp("@ENDIF_IMAGECOMPONENT@")));
             }
-        }
-        else if (text.contains(QRegExp("@ENDIF_IMAGECOMPONENT@")))
-        {
+        } else if (text.contains(QRegExp("@ENDIF_IMAGECOMPONENT@"))) {
             // Go to the next line...
-        }
-        else if (text.contains(QRegExp("@IF_ITKFILTER@")))
-        {
-            if (! isItkFilter)
-            {
-                do
-                {
+        } else if (text.contains(QRegExp("@IF_ITKFILTER@"))) {
+            if (! isItkFilter) {
+                do {
                     text = in.readLine();
-                }
-                while (! text.contains(QRegExp("@ENDIF_ITKFILTER@")));
+                } while (! text.contains(QRegExp("@ENDIF_ITKFILTER@")));
             }
-        }
-        else if (text.contains(QRegExp("@ENDIF_ITKFILTER@")))
-        {
+        } else if (text.contains(QRegExp("@ENDIF_ITKFILTER@"))) {
             // Go to the next line...
-        }
-        else
-        {
+        } else {
             out << text << endl;
         }
-    }
-    while (! text.isNull());
+    } while (! text.isNull());
 
     extFile.close();
     initFile.close();
 }
 
 
-void ActionGenerator::writeCFile(QString directoryName)
-{
+void ActionGenerator::writeCFile(QString directoryName) {
     // Additional includes needed by parameter types
     QSet<QString> additionalIncludes;
     // here we use a QSet to avoid the repetion of includes
-    for(QVector<ParameterGenerator *>::const_iterator it =  actionParameters.begin(); it != actionParameters.end(); it++)
-    {
-        if ((*it)->needsAdditionalInclude())
-        {
+    for(QVector<ParameterGenerator *>::const_iterator it =  actionParameters.begin(); it != actionParameters.end(); it++) {
+        if ((*it)->needsAdditionalInclude()) {
             additionalIncludes.insert((*it)->getAdditionalInclude());
         }
     }
@@ -275,8 +213,7 @@ void ActionGenerator::writeCFile(QString directoryName)
     QFileInfo extFilePath;
     extFilePath.setFile(directoryName, className + ".cpp");
     QFile extFile(extFilePath.absoluteFilePath());
-    if (! extFile.open(QIODevice::WriteOnly | QIODevice::Text))
-    {
+    if (! extFile.open(QIODevice::WriteOnly | QIODevice::Text)) {
         QString msg = "Exception from extension generation: \n    Cannot write on file " + extFilePath.fileName() + "\n";
         throw (msg);
     }
@@ -284,8 +221,7 @@ void ActionGenerator::writeCFile(QString directoryName)
 
     // Parsing init file to fill destinaiton file.
     QString text;
-    do
-    {
+    do {
         text = in.readLine();
         text.replace(QRegExp("@LICENCE@"), licence);
         text.replace(QRegExp("@COMPONENTNAME@"), componentName);
@@ -293,165 +229,104 @@ void ActionGenerator::writeCFile(QString directoryName)
         text.replace(QRegExp("@ACTION_NAME@"), name);
         text.replace(QRegExp("@ACTION_DESCRIPTION@"), description);
         text.replace(QRegExp("@FAMILY@"), family);
-        if (text.contains(QRegExp("@ADDITIONAL_INCLUDES@")))
-        {
-            for (QSet<QString>::const_iterator incl = additionalIncludes.begin(); incl != additionalIncludes.end(); incl++)
-            {
+        if (text.contains(QRegExp("@ADDITIONAL_INCLUDES@"))) {
+            for (QSet<QString>::const_iterator incl = additionalIncludes.begin(); incl != additionalIncludes.end(); incl++) {
                 out << (*incl) << endl;
             }
-        }
-        else if (text.contains(QRegExp("@IF_NOCOMP@")))
-        {
-            if (componentName != "")
-            {
-                do
-                {
+        } else if (text.contains(QRegExp("@IF_NOCOMP@"))) {
+            if (componentName != "") {
+                do {
                     text = in.readLine();
-                }
-                while ( (! text.contains(QRegExp("@ELSEIF_NOCOMP@"))) &&
-                        (! text.contains(QRegExp("@END_NOCOMP@"))));
+                } while ( (! text.contains(QRegExp("@ELSEIF_NOCOMP@"))) &&
+                          (! text.contains(QRegExp("@END_NOCOMP@"))));
             }
-        }
-        else if (text.contains(QRegExp("@ELSEIF_NOCOMP@")))
-        {
-            if (componentName == "")
-            {
-                do
-                {
+        } else if (text.contains(QRegExp("@ELSEIF_NOCOMP@"))) {
+            if (componentName == "") {
+                do {
                     text = in.readLine();
-                }
-                while (! text.contains(QRegExp("@END_NOCOMP@")));
+                } while (! text.contains(QRegExp("@END_NOCOMP@")));
             }
-        }
-        else if (text.contains(QRegExp("@END_NOCOMP@")))
-        {
+        } else if (text.contains(QRegExp("@END_NOCOMP@"))) {
             // Go to next line...
-        }
-        else if (text.contains(QRegExp("@IF_DEFCOMPONENT@")))
-        {
-            if ((componentName == "Component") || (componentName == ""))
-            {
-                do
-                {
+        } else if (text.contains(QRegExp("@IF_DEFCOMPONENT@"))) {
+            if ((componentName == "Component") || (componentName == "")) {
+                do {
                     text = in.readLine();
-                }
-                while ( (! text.contains(QRegExp("@ENDIF_DEFCOMPONENT@"))) &&
-                        (! text.contains(QRegExp("@ELSEIF_DEFCOMPONENT@"))));
+                } while ( (! text.contains(QRegExp("@ENDIF_DEFCOMPONENT@"))) &&
+                          (! text.contains(QRegExp("@ELSEIF_DEFCOMPONENT@"))));
             }
-        }
-        else if ((text.contains(QRegExp("@ELSEIF_DEFCOMPONENT@"))))
-        {
-            if (componentName != "Component")
-            {
-                do
-                {
+        } else if ((text.contains(QRegExp("@ELSEIF_DEFCOMPONENT@")))) {
+            if (componentName != "Component") {
+                do {
                     text = in.readLine();
-                }
-                while (! text.contains(QRegExp("@ENDIF_DEFCOMPONENT@")));
+                } while (! text.contains(QRegExp("@ENDIF_DEFCOMPONENT@")));
             }
-        }
-        else if (text.contains(QRegExp("@ENDIF_DEFCOMPONENT@")))
-        {
+        } else if (text.contains(QRegExp("@ENDIF_DEFCOMPONENT@"))) {
             // Go to next line...
-        }
-        else if (text.contains(QRegExp("@IF_IMAGECOMPONENT@")))
-        {
-            if ((componentName != "ImageComponent") || (isItkFilter))
-            {
-                do
-                {
+        } else if (text.contains(QRegExp("@IF_IMAGECOMPONENT@"))) {
+            if ((componentName != "ImageComponent") || (isItkFilter)) {
+                do {
                     text = in.readLine();
-                }
-                while (! text.contains(QRegExp("@ENDIF_IMAGECOMPONENT@")));
+                } while (! text.contains(QRegExp("@ENDIF_IMAGECOMPONENT@")));
             }
-        }
-        else if (text.contains(QRegExp("@ENDIF_IMAGECOMPONENT@")))
-        {
+        } else if (text.contains(QRegExp("@ENDIF_IMAGECOMPONENT@"))) {
             // Go to the next line...
-        }
-        else if (text.contains(QRegExp("@IF_ITKFILTER@")))
-        {
-            if (! isItkFilter)
-            {
-                do
-                {
+        } else if (text.contains(QRegExp("@IF_ITKFILTER@"))) {
+            if (! isItkFilter) {
+                do {
                     text = in.readLine();
-                }
-                while (! text.contains(QRegExp("@ENDIF_ITKFILTER@")));
+                } while (! text.contains(QRegExp("@ENDIF_ITKFILTER@")));
             }
-        }
-        else if (text.contains(QRegExp("@ENDIF_ITKFILTER@")))
-        {
+        } else if (text.contains(QRegExp("@ENDIF_ITKFILTER@"))) {
             // Go to the next line...
-        }
-        else if (text.contains(QRegExp("@BEGIN_ADDTAGS@")))
-        {
+        } else if (text.contains(QRegExp("@BEGIN_ADDTAGS@"))) {
             text = in.readLine();
-            if (tags.size())
-            {
+            if (tags.size()) {
                 QStringList addTheTags;
-                while (! text.contains(QRegExp("@END_ADDTAG@")) && ! text.contains(QRegExp("@ELSE_ADDTAG@")) )
-                {
-                    for (int tagIdx = 0; tagIdx < tags.size(); tagIdx++)
-                    {
+                while (! text.contains(QRegExp("@END_ADDTAG@")) && ! text.contains(QRegExp("@ELSE_ADDTAG@")) ) {
+                    for (int tagIdx = 0; tagIdx < tags.size(); tagIdx++) {
                         QString textTmp = text;
                         textTmp.replace(QRegExp("@TAG@"), tags[tagIdx]);
                         addTheTags << textTmp;
                     }
                     text = in.readLine();
                 }
-                if (text.contains("@ELSE_ADDTAG@"))
-                {
-                    while (! text.contains("@END_ADDTAG@"))
-                    {
+                if (text.contains("@ELSE_ADDTAG@")) {
+                    while (! text.contains("@END_ADDTAG@")) {
                         text = in.readLine();
                     }
                 }
-                for (int t =0; t < addTheTags.size(); t++)
-                {
+                for (int t =0; t < addTheTags.size(); t++) {
                     out << addTheTags.at(t) << endl;
                 }
-            }
-            else
-            {
+            } else {
                 while ((! text.contains("@ELSE_ADDTAG@")) && (! text.contains("@END_ADDTAG@")))
                     text = in.readLine();
-                if (text.contains("@ELSE_ADDTAG@"))
-                {
+                if (text.contains("@ELSE_ADDTAG@")) {
                     text = in.readLine();
-                    while (! text.contains("@END_ADDTAG@"))
-                    {
+                    while (! text.contains("@END_ADDTAG@")) {
                         out << text << endl;
                         text = in.readLine();
                     }
                 }
                 text = in.readLine();
             }
-        }
-        else if (text.contains(QRegExp("@IF_ADDPROPERTIES@")))
-        {
+        } else if (text.contains(QRegExp("@IF_ADDPROPERTIES@"))) {
             text = in.readLine();
-            while (! text.contains(QRegExp("@ENDIF_ADDPROPERTIES@")))
-            {
-                if ( ! actionParameters.isEmpty())
-                {
+            while (! text.contains(QRegExp("@ENDIF_ADDPROPERTIES@"))) {
+                if ( ! actionParameters.isEmpty()) {
                     out << text << endl;
                 }
                 text = in.readLine();
             }
-        }
-        else if (text.contains(QRegExp("@BEGIN_ADDPROPERTIES@")))
-        {
+        } else if (text.contains(QRegExp("@BEGIN_ADDPROPERTIES@"))) {
             text = in.readLine();
-            if (actionParameters.size() > 0)
-            {
+            if (actionParameters.size() > 0) {
                 QStringList addTheProps;
                 while (! text.contains(QRegExp("@END_ADDPROPERTIES@")) &&
-                        ! text.contains(QRegExp("@ELSE_ADDPROPERTIES@")) )
-                {
+                        ! text.contains(QRegExp("@ELSE_ADDPROPERTIES@")) ) {
                     for (QVector<ParameterGenerator *>::const_iterator it =  actionParameters.begin();
-                            it != actionParameters.end(); it++)
-                    {
+                            it != actionParameters.end(); it++) {
                         ParameterGenerator * param = (*it);
                         QString textTmp = text;
 
@@ -462,40 +337,33 @@ void ActionGenerator::writeCFile(QString directoryName)
                         textTmp.replace(QRegExp("@PROPERTY_QVARIANT@"), param->getPropertyQVariant());
                         textTmp.replace(QRegExp("@PROPERTY_VALUE@"), param->getDefaultValue());
                         textTmp.replace(QRegExp("@PROPERTY_TOTYPE@"), param->getQVariantConversion());
+                        textTmp.replace(QRegExp("@PROPERTY_DESCRIPTION@"), param->getDescription());
+                        textTmp.replace(QRegExp("@PROPERTY_UNIT@"), param->getUnit());
 
                         addTheProps << textTmp;
                     }
                     text = in.readLine();
                 }
-                if (text.contains("@ELSE_ADDPROPERTIES@"))
-                {
-                    while (! text.contains("@END_ADDPROPERTIES@"))
-                    {
+                if (text.contains("@ELSE_ADDPROPERTIES@")) {
+                    while (! text.contains("@END_ADDPROPERTIES@")) {
                         text = in.readLine();
                     }
                 }
-                for (int p = 0; p < addTheProps.size(); p++)
-                {
+                for (int p = 0; p < addTheProps.size(); p++) {
                     out << addTheProps.at(p) << endl;
                 }
-            }
-            else
-            {
+            } else {
                 while ((! text.contains("@ELSE_ADDPROPERTIES@")) && (! text.contains("@END_ADDPROPERTIES@")))
                     text = in.readLine();
-                if (text.contains("@ELSE_ADDPROPERTIES@"))
-                {
+                if (text.contains("@ELSE_ADDPROPERTIES@")) {
                     text = in.readLine();
-                    while (! text.contains("@END_ADDPROPERTIES@"))
-                    {
+                    while (! text.contains("@END_ADDPROPERTIES@")) {
                         out << text << endl;
                         text = in.readLine();
                     }
                 }
             }
-        }
-        else
-        {
+        } else {
             out << text << endl;
         }
     }
@@ -507,15 +375,11 @@ void ActionGenerator::writeCFile(QString directoryName)
 
 }
 
-void ActionGenerator::writeSpecialItkFile(QString directoryName)
-{
+void ActionGenerator::writeSpecialItkFile(QString directoryName) {
     QString initFileName;
-    if (itkFilterOutputType == "Same as Input")
-    {
+    if (itkFilterOutputType == "Same as Input") {
         initFileName = QString(":/resources/ActionImplementation.sai.cpp.in");
-    }
-    else
-    {
+    } else {
         initFileName = QString(":/resources/ActionImplementation.cpp.in");
     }
 
@@ -526,23 +390,20 @@ void ActionGenerator::writeSpecialItkFile(QString directoryName)
     QFileInfo extFilePath;
     extFilePath.setFile(directoryName, className + ".impl");
     QFile extFile(extFilePath.absoluteFilePath());
-    if (! extFile.open(QIODevice::WriteOnly | QIODevice::Text))
-    {
+    if (! extFile.open(QIODevice::WriteOnly | QIODevice::Text)) {
         QString msg = "Exception from extension generation: \n    Cannot write on file " + extFilePath.fileName() + "\n";
         throw (msg);
     }
     QTextStream out(&extFile);
 
     QString text;
-    do
-    {
+    do {
         text = in.readLine();
         text.replace(QRegExp("@LICENCE@"), licence);
         text.replace(QRegExp("@ACTIONCLASSNAME@"), className);
         text.replace(QRegExp("@OUTPUTTYPE@"), itkFilterOutputType);
         out << text << endl;
-    }
-    while (! text.isNull());
+    } while (! text.isNull());
 
     extFile.close();
     initFile.close();
