@@ -27,6 +27,7 @@
 #include "ActionExtensionGenerator.h"
 #include "ComponentExtensionGenerator.h"
 #include "LibraryGenerator.h"
+#include "ClassNameHandler.h"
 
 // includes from std
 #include <iostream>
@@ -46,18 +47,15 @@ static const QString cepManifestName = "CEPContent";
 static const QString cepManifestExtension = ".xml";
 static const QString cepSchemaNamespace = "http://camitk.imag.fr/cepcoreschema";
 
-inline void initMyResource()
-{
+inline void initMyResource() {
     Q_INIT_RESOURCE(cepgenerator);
 }
 
 using namespace cepcoreschema;
 
-bool CepGenerator::generateCEP(QString xmlFileName, QString devDirectoryName)
-{
+bool CepGenerator::generateCEP(QString xmlFileName, QString devDirectoryName) {
 
-    try
-    {
+    try {
         std::cout << "Generating CEP..." << std::endl;
         CepGenerator * generator = new CepGenerator(xmlFileName, devDirectoryName);
         generator->createDomTree();
@@ -67,9 +65,7 @@ bool CepGenerator::generateCEP(QString xmlFileName, QString devDirectoryName)
         generator->createLibrarieDoms();
         generator->generateExtensions();
         delete generator;
-    }
-    catch (QString msg)
-    {
+    } catch (QString msg) {
         std::cout << msg.toStdString() << std::endl;
         std::cout << "Could not generate CEP, sorry..." << std::endl;
         return false;
@@ -78,11 +74,9 @@ bool CepGenerator::generateCEP(QString xmlFileName, QString devDirectoryName)
     return true;
 }
 
-bool CepGenerator::generateCEP(std::auto_ptr<cepcoreschema::Cep> domCep, QString devDirectoryName)
-{
+bool CepGenerator::generateCEP(std::auto_ptr<cepcoreschema::Cep> domCep, QString devDirectoryName) {
 
-    try
-    {
+    try {
         std::cout << "Generating CEP..." << std::endl;
         CepGenerator * generator = new CepGenerator(domCep, devDirectoryName);
 //        generator->createDomTree();
@@ -92,9 +86,7 @@ bool CepGenerator::generateCEP(std::auto_ptr<cepcoreschema::Cep> domCep, QString
         generator->createLibrarieDoms();
         generator->generateExtensions();
         delete generator;
-    }
-    catch (QString msg)
-    {
+    } catch (QString msg) {
         std::cout << msg.toStdString() << std::endl;
         std::cout << "Could not generate CEP, sorry..." << std::endl;
         return false;
@@ -103,15 +95,13 @@ bool CepGenerator::generateCEP(std::auto_ptr<cepcoreschema::Cep> domCep, QString
     return true;
 }
 
-CepGenerator::CepGenerator(QString xmlFilename, QString devDirectoryName)
-{
+CepGenerator::CepGenerator(QString xmlFilename, QString devDirectoryName) {
     initMyResource();
     setXmlFileName(xmlFilename);
     setDevDirectoryName(devDirectoryName);
 }
 
-CepGenerator::CepGenerator(std::auto_ptr<cepcoreschema::Cep> domCep, QString devDirectoryName)
-{
+CepGenerator::CepGenerator(std::auto_ptr<cepcoreschema::Cep> domCep, QString devDirectoryName) {
     initMyResource();
     this->domCep = domCep;
     setDevDirectoryName(devDirectoryName);
@@ -124,12 +114,10 @@ CepGenerator::~CepGenerator() {
     }
 }
 
-void CepGenerator::setXmlFileName(QString xmlFileName) throw (QString)
-{
+void CepGenerator::setXmlFileName(QString xmlFileName) throw (QString) {
     QFileInfo xmlFile(xmlFileName);
 
-    if ((! xmlFile.exists()) || (! xmlFile.isFile()))
-    {
+    if ((! xmlFile.exists()) || (! xmlFile.isFile())) {
         QString msg = "Exception from Cep generation: \n     The file " + xmlFileName +  " does not exist or is not a file...\n";
         throw (msg);
     }
@@ -137,13 +125,11 @@ void CepGenerator::setXmlFileName(QString xmlFileName) throw (QString)
     this->xmlFileName = xmlFile;
 }
 
-void CepGenerator::setDevDirectoryName(QString devDirectoryName) throw (QString)
-{
+void CepGenerator::setDevDirectoryName(QString devDirectoryName) throw (QString) {
     devDirectoryName = devDirectoryName + "/";
     QFileInfo devDir(devDirectoryName);
 
-    if ( ! devDir.isDir())
-    {
+    if ( ! devDir.isDir()) {
         QString msg = "Exception from Cep generation: \n The path " + devDirectoryName + " is not a directory\n";
         throw (msg);
     }
@@ -151,34 +137,27 @@ void CepGenerator::setDevDirectoryName(QString devDirectoryName) throw (QString)
     this->devDirectoryName = devDir.absoluteDir();
 }
 
-void CepGenerator::createDomTree() throw (QString)
-{
+void CepGenerator::createDomTree() throw (QString) {
     std::cout << "Creating Dom Tree..." << std::endl;
     std::string xmlFileStr = this->xmlFileName.canonicalFilePath().toStdString();
 
-    try
-    {
+    try {
         this->domCep = cep(xmlFileStr, xml_schema::flags::dont_validate);
         setLicence();
-    }
-    catch (...)
-    {
-        QString msg = "XML file not valid.";
-        throw msg;
+    } catch (const xml_schema::exception& e) {        
+        std::cout << "Error Parsing XML file:" << std::endl;
+        std::cout << e << std::endl;
+        throw QString(e.what());
     }
 }
 
-void CepGenerator::generateDirectoryTree() throw (QString)
-{
+void CepGenerator::generateDirectoryTree() throw (QString) {
     std::cout << "Generating Directory Tree..." << std::endl;
 
     // --------------------   Create a sub-directory with the CEP name
     QString cepName(domCep->name().c_str());
     // A directory name should be low case with no space
-    this->cepDirectoryName = cepName;
-    cepDirectoryName = cepDirectoryName.simplified(); // change every whitespace (\t, \n, etc.) to single ASCII space
-    cepDirectoryName = cepDirectoryName.replace( " ", "" ); // remove white spaces
-    cepDirectoryName = cepDirectoryName.toLower(); // to lower case
+    this->cepDirectoryName = ClassNameHandler::getDirectoryName(cepName);
 
     QDir currentDirectory;
     currentDirectory.cd(devDirectoryName.absolutePath());
@@ -211,8 +190,7 @@ void CepGenerator::generateDirectoryTree() throw (QString)
 }
 
 
-void CepGenerator::serializeManifest()
-{
+void CepGenerator::serializeManifest() {
     // Add a comment for the user NOT to manually modify this file...
     // TODO, how ?????
     // Setting the CEP root directory where the manifest should be
@@ -224,8 +202,7 @@ void CepGenerator::serializeManifest()
     QFileInfo xmlFileInfo;
     xmlFileInfo.setFile(currentDirectory.absolutePath(), cepManifestName + cepManifestExtension);
     QFile xmlFile(xmlFileInfo.absoluteFilePath());
-    if (! xmlFile.open(QIODevice::WriteOnly | QIODevice::Text))
-    {
+    if (! xmlFile.open(QIODevice::WriteOnly | QIODevice::Text)) {
         QString msg = "Exception from cep file generation \n    Cannot write on file " + xmlFileInfo.absoluteFilePath() + "\n";
         throw msg;
     }
@@ -245,16 +222,14 @@ void CepGenerator::serializeManifest()
 }
 
 
-void CepGenerator::generateGlobalCMakeLists()
-{
+void CepGenerator::generateGlobalCMakeLists() {
     // Setting CMakeLists parameters
     // project name
     QString projectNameString(domCep->name().c_str());
     // contacts
     QString contactString = "";
     Contact contact = domCep->contact();
-    for (Contact::email_const_iterator i = contact.email().begin(); i != contact.email().end(); i++)
-    {
+    for (Contact::email_const_iterator i = contact.email().begin(); i != contact.email().end(); i++) {
         contactString += QString((*i).c_str());
         if ((i+1) != contact.email().end())
             contactString += ", ";
@@ -276,23 +251,20 @@ void CepGenerator::generateGlobalCMakeLists()
     QFileInfo cmakelistsOutFileInfo;
     cmakelistsOutFileInfo.setFile(currentDirectory.absolutePath(), "CMakeLists.txt");
     QFile cmakelistsOutFile(cmakelistsOutFileInfo.absoluteFilePath());
-    if (! cmakelistsOutFile.open(QIODevice::WriteOnly | QIODevice::Text))
-    {
+    if (! cmakelistsOutFile.open(QIODevice::WriteOnly | QIODevice::Text)) {
         QString msg = "Exception from cep file generation \n    Cannot write on file " + cmakelistsOutFileInfo.absoluteFilePath() + "\n";
         throw msg;
     }
 
     QTextStream out(&cmakelistsOutFile);
     QString text;
-    do
-    {
+    do {
         text = in.readLine();
         text.replace(QRegExp("@PROJECT_NAME@"), projectNameString);
         text.replace(QRegExp("@CONTACT@"), contactString);
         text.replace(QRegExp("@DESCRIPTION@"), descriptionString);
         out << text << endl;
-    }
-    while (! text.isNull());
+    } while (! text.isNull());
     cmakelistsOutFile.close();
     initFile.close();
 
@@ -300,13 +272,10 @@ void CepGenerator::generateGlobalCMakeLists()
 
 void CepGenerator::setLicence() {
     // Get the copyright in the CEP DOM...
-    if (domCep->copyright().present())
-    {
+    if (domCep->copyright().present()) {
         std::cout << "I found a licence ! " <<std::endl;
         this->licence = QString(domCep->copyright().get().c_str());
-    }
-    else
-    {
+    } else {
         std::cout << "No licence found... Copying the default one..." << endl;
         QFile defaultLicenceFile(":/resources/COPYRIGHT.in");
         defaultLicenceFile.open(QIODevice::ReadOnly | QIODevice::Text);
@@ -322,8 +291,7 @@ void CepGenerator::setLicence() {
     }
 }
 
-void CepGenerator::generateCopyright()
-{
+void CepGenerator::generateCopyright() {
     // Setting the CEP root directory where the copyright should be
     QDir currentDirectory;
     currentDirectory.cd(devDirectoryName.absolutePath());
@@ -333,8 +301,7 @@ void CepGenerator::generateCopyright()
     QFileInfo copyrightOutFileInfo;
     copyrightOutFileInfo.setFile(currentDirectory.absolutePath(), "COPYRIGHT");
     QFile copyrightOutFile(copyrightOutFileInfo.absoluteFilePath());
-    if (! copyrightOutFile.open(QIODevice::WriteOnly | QIODevice::Text))
-    {
+    if (! copyrightOutFile.open(QIODevice::WriteOnly | QIODevice::Text)) {
         QString msg = "Exception from cep file generation \n    Cannot write on file " + copyrightOutFileInfo.absoluteFilePath() + "\n";
         throw msg;
     }
@@ -342,32 +309,28 @@ void CepGenerator::generateCopyright()
 
     QTextStream in(&(this->licence));
     QString text;
-    do
-    {
-       text = in.readLine();
-       out << text << endl;
+    do {
+        text = in.readLine();
+        out << text << endl;
     } while (! text.isNull());
-    
+
     copyrightOutFile.close();
-    
+
 }
 
-void CepGenerator::generateReadme()
-{
+void CepGenerator::generateReadme() {
     // Setting the CEP root directory where the copyright should be
     QDir currentDirectory;
     currentDirectory.cd(devDirectoryName.absolutePath());
     currentDirectory.cd(cepDirectoryName);
 
     // Get the copyright in the CEP DOM...
-    if (domCep->readme().present())
-    {
+    if (domCep->readme().present()) {
         // Set the right output file name
         QFileInfo readmeOutFileInfo;
         readmeOutFileInfo.setFile(currentDirectory.absolutePath(), "README");
         QFile readmeOutFile(readmeOutFileInfo.absoluteFilePath());
-        if (! readmeOutFile.open(QIODevice::WriteOnly | QIODevice::Text))
-        {
+        if (! readmeOutFile.open(QIODevice::WriteOnly | QIODevice::Text)) {
             QString msg = "Exception from cep file generation \n    Cannot write on file " + readmeOutFileInfo.absoluteFilePath() + "\n";
             throw msg;
         }
@@ -378,24 +341,20 @@ void CepGenerator::generateReadme()
 
         QString text;
 
-        do
-        {
+        do {
             text = in.readLine();
             out << text << endl;
-        }
-        while (! text.isNull());
+        } while (! text.isNull());
     }
     // ...Or copy the default one
-    else
-    {
+    else {
         QString outputFileName = currentDirectory.absolutePath() + "/README";
         QFile::copy(":/resources/README.in", outputFileName);
     }
 
 }
 
-void CepGenerator::copyFindCamiTK()
-{
+void CepGenerator::copyFindCamiTK() {
 
     // Setting the CEP root directory where the manifest should be
     QDir currentDirectory;
@@ -405,8 +364,7 @@ void CepGenerator::copyFindCamiTK()
     QFile::copy(":/resources/FindCamiTK.cmake.in", outputFileName);
 }
 
-void CepGenerator::generateActionsDirectory()
-{
+void CepGenerator::generateActionsDirectory() {
     QString cmakelistFileName;
     QDir currentDirectory;
     currentDirectory.cd(devDirectoryName.absolutePath());
@@ -418,8 +376,7 @@ void CepGenerator::generateActionsDirectory()
     cmakelistFileName = currentDirectory.absolutePath() + "/CMakeLists.txt";
     QFile::copy(":/resources/actions.CMakeLists.txt.in", cmakelistFileName);
 }
-void CepGenerator::generateApplicationsDirectory()
-{
+void CepGenerator::generateApplicationsDirectory() {
     QString cmakelistFileName;
     QDir currentDirectory;
     currentDirectory.cd(devDirectoryName.absolutePath());
@@ -431,8 +388,7 @@ void CepGenerator::generateApplicationsDirectory()
     cmakelistFileName = currentDirectory.absolutePath() + "/CMakeLists.txt";
     QFile::copy(":/resources/applications.CMakeLists.txt.in", cmakelistFileName);
 }
-void CepGenerator::generateComponentsDirectory()
-{
+void CepGenerator::generateComponentsDirectory() {
     QString cmakelistFileName;
     QDir currentDirectory;
     currentDirectory.cd(devDirectoryName.absolutePath());
@@ -444,8 +400,7 @@ void CepGenerator::generateComponentsDirectory()
     cmakelistFileName = currentDirectory.absolutePath() + "/CMakeLists.txt";
     QFile::copy(":/resources/components.CMakeLists.txt.in", cmakelistFileName);
 }
-void CepGenerator::generateLibrariesDirectory()
-{
+void CepGenerator::generateLibrariesDirectory() {
     QString cmakelistFileName;
     QDir currentDirectory;
     currentDirectory.cd(devDirectoryName.absolutePath());
@@ -469,8 +424,7 @@ void CepGenerator::createActionExtensionDoms() {
 
     if (domCep->actionExtensions().present()) {
         ActionExtensions extensions = domCep->actionExtensions().get();
-        for (ActionExtensions::actionExtension_iterator i = extensions.actionExtension().begin(); i != extensions.actionExtension().end(); i++)
-        {
+        for (ActionExtensions::actionExtension_iterator i = extensions.actionExtension().begin(); i != extensions.actionExtension().end(); i++) {
             // TODO: find a way to use std:auto_ptr here for the dom extension instead of creating a new instance
             // Is it only possible ? http://stackoverflow.com/questions/12674735/function-wont-accept-iterator-to-auto-ptr
             ActionExtension & extension = (*i);
@@ -487,11 +441,10 @@ void CepGenerator::createComponentExtensionDoms() {
     currentDirectory.cd(devDirectoryName.absolutePath());
     currentDirectory.cd(cepDirectoryName);
     currentDirectory.cd(cepComponentsDirectoryName);
-    
+
     if (domCep->componentExtensions().present()) {
         ComponentExtensions extensions = domCep->componentExtensions().get();
-        for (ComponentExtensions::componentExtension_iterator i = extensions.componentExtension().begin(); i != extensions.componentExtension().end(); i++)
-        {
+        for (ComponentExtensions::componentExtension_iterator i = extensions.componentExtension().begin(); i != extensions.componentExtension().end(); i++) {
             // TODO: find a way to use std:auto_ptr here for the dom extension instead of creating a new instance
             // Is it only possible ? http://stackoverflow.com/questions/12674735/function-wont-accept-iterator-to-auto-ptr
             ComponentExtension & extension = (*i);
@@ -501,17 +454,16 @@ void CepGenerator::createComponentExtensionDoms() {
     }
 }
 
-void CepGenerator::createLibrarieDoms(){
+void CepGenerator::createLibrarieDoms() {
     std::cout << "creating library doms..." << std::endl;
     QDir currentDirectory;
     currentDirectory.cd(devDirectoryName.absolutePath());
     currentDirectory.cd(cepDirectoryName);
     currentDirectory.cd(cepLibrariesDirectoryName);
-    
+
     if (domCep->libraries().present()) {
         Libraries libs = domCep->libraries().get();
-        for (Libraries::library_iterator i = libs.library().begin(); i != libs.library().end(); i++)
-        {
+        for (Libraries::library_iterator i = libs.library().begin(); i != libs.library().end(); i++) {
             // TODO: find a way to use std:auto_ptr here for the dom extension instead of creating a new instance
             // Is it only possible ? http://stackoverflow.com/questions/12674735/function-wont-accept-iterator-to-auto-ptr
             Library & lib = (*i);
@@ -519,17 +471,15 @@ void CepGenerator::createLibrarieDoms(){
             this->extensions.append(generator);
         }
     }
-   
+
 }
 
-void CepGenerator::generateExtensions()
-{
+void CepGenerator::generateExtensions() {
     std::cout << "inside generateExtension" << std::endl;
 
     // Component and Action extensions genration
-    for (QVector<ExtensionGenerator *>::iterator c = extensions.begin(); c != extensions.end(); c++)
-    {
+    for (QVector<ExtensionGenerator *>::iterator c = extensions.begin(); c != extensions.end(); c++) {
         (*c)->generateExtension();
     }
-    
+
 }
