@@ -29,13 +29,12 @@
 #include <QString>
 /**
  * @ingroup group_sdk_libraries_cepgenerator
- * 
- * @brief 
+ *
+ * @brief
  * Helper class to handle class names
- * 
+ *
  **/
-class ClassNameHandler
-{
+class ClassNameHandler {
 
 public:
     static QString getClassName(QString genericName);
