@@ -40,26 +40,8 @@ namespace camitk {
 
 // -------------------- autoload --------------------
 void ExtensionManager::autoload() {
-    // add the private lib dir to the current application environment's PATH variable
-    // This modifies the current PATH variable in order for the OS to find the private
-    // libraries compiled as shared objects/dll/dylib needed by some extensions
-    QDir privateLibDir(Core::getGlobalInstallDir());
-    if (privateLibDir.cd("lib/"+QString(Core::shortVersion))) {
-        QByteArray privateLibDirPath = privateLibDir.canonicalPath().toUtf8();
-#ifdef WIN32
-        // update path for windows
-        QByteArray path = qgetenv("PATH");
-        path.append(";");
-        path.append(privateLibDirPath);
-        qputenv("PATH",path);
-#endif
-        // update the application / qt plugins library path
-        Application::instance()->addLibraryPath(privateLibDirPath);
-    }
-
     autoload(COMPONENT);
     autoload(ACTION);
-
 }
 
 void ExtensionManager::autoload(ExtensionManager::ExtensionType type) {
@@ -80,24 +62,19 @@ void ExtensionManager::autoload(ExtensionManager::ExtensionType type) {
     //-- remove duplicates
     QStringList extensionFileNames;
     QStringList extensionAbsoluteFileNames;
-    QMap<QString, QDir> extensionUniqueDir;    
-    foreach(QString dirName, extensionDir)
-    {
+    QMap<QString, QDir> extensionUniqueDir;
+    foreach(QString dirName, extensionDir) {
         QDir dir(dirName);
         QStringList pluginFileNames = getPluginFileNames(dir);
-        foreach(QString pluginFile, pluginFileNames) 
-        {
+        foreach(QString pluginFile, pluginFileNames) {
             QString pluginAbsoluteFileName = dir.absoluteFilePath(pluginFile);
-            if (!extensionFileNames.contains(pluginFile)) 
-            {
+            if (!extensionFileNames.contains(pluginFile)) {
                 extensionFileNames.append(pluginFile);
                 extensionUniqueDir.insert(pluginFile,dir);
                 extensionAbsoluteFileNames.append(pluginAbsoluteFileName);
-            }
-            else 
-            {
+            } else {
                 CAMITK_INFO("ExtensionManager", "autoload", "Warning: duplicate extension: " << pluginFile.toStdString() << " found in " << dir.absolutePath().toStdString() << ".\nUsing extension in " << extensionUniqueDir.value(pluginFile).absolutePath().toStdString() << " instead (higher priority)");
-            }                        
+            }
         }
     }
 
@@ -133,8 +110,7 @@ void ExtensionManager::autoload(ExtensionManager::ExtensionType type) {
 
             if (!plugin) {
                 errorStrings << QString("Plugin " + fileName + ", error: " + pluginLoader.errorString());
-            }
-            else {
+            } else {
                 errorStrings << QString("Plugin " + fileName + ", no error (you need to decrease your number of dependency level, or contact the CamiTK SDK developer team)");
             }
         }
@@ -148,7 +124,7 @@ void ExtensionManager::autoload(ExtensionManager::ExtensionType type) {
                              + "</li></ul>"
                              + "List of path:<ul><li>"
 #ifdef WIN32
-                             + QString(qgetenv("PATH")).split(":").join("</li><li>")
+                             + QString(qgetenv("PATH")).split(";").join("</li><li>")
 #else
                              + QString(qgetenv("LD_LIBRARY_PATH")).split(":").join("</li><li>")
 #endif
@@ -181,6 +157,10 @@ void ExtensionManager::autoload(ExtensionManager::ExtensionType type) {
 
 // -------------------- loadExtension --------------------
 bool ExtensionManager::loadExtension(ExtensionManager::ExtensionType type, QString fileName) {
+
+    // First of all, check we have the private library directories in our session PATH
+    initPrivateLibDirs();
+
     bool returnValue = false;
     QPluginLoader pluginLoader(fileName);
     QObject *extension = pluginLoader.instance();
@@ -191,6 +171,9 @@ bool ExtensionManager::loadExtension(ExtensionManager::ExtensionType type, QStri
             ActionExtension *ext = qobject_cast<ActionExtension *> (extension);
 
             if (ext) {
+                ext->setLocation(fileName);
+                ext->initResources();
+
                 //-- register the filename
                 getActionExtensionMap().insert(fileName, ext);
                 // initialize all actions
@@ -207,12 +190,12 @@ bool ExtensionManager::loadExtension(ExtensionManager::ExtensionType type, QStri
 
             if (cp) {
                 cp->setLocation(fileName);
+                cp->initResources();
 
                 //-- insert the ComponentExtension plugin in the application wide list
                 if (cp->hasDataDirectory()) {
                     getDataDirectoryComponentExtensionMap().insert(cp->getName(), cp);
-                }
-                else {
+                } else {
                     // (cannot do that in the constructor because the virtual symbol table seems to be confused!)
                     foreach(QString ext, cp->getFileExtensions()) {
                         getComponentExtensionMap().insert(ext, cp);
@@ -228,8 +211,7 @@ bool ExtensionManager::loadExtension(ExtensionManager::ExtensionType type, QStri
             CAMITK_DEBUG("ExtensionManager", "loadExtension of unknown type", "type should be either ACTION or COMPONENT, other extensions are not implemented yet");
             break;
         }
-    }
-    else {
+    } else {
         pluginLoader.unload();  // to make sure we could try again later
 
         // try to load the missing shared object directly from private dir (give absolute path)
@@ -257,14 +239,11 @@ QString ExtensionManager::getInstallationString(QString file) {
     QString absolutePath = dir.absolutePath();
     if (absolutePath == Core::getGlobalInstallDir()) {
         whichInstallDir = "[G]";
-    }
-    else if (absolutePath == Core::getUserInstallDir()) {
+    } else if (absolutePath == Core::getUserInstallDir()) {
         whichInstallDir = "[L]";
-    }
-    else if (absolutePath == Core::getCurrentWorkingDir()) {
+    } else if (absolutePath == Core::getCurrentWorkingDir()) {
         whichInstallDir = "[W]";
-    }
-    else {
+    } else {
         whichInstallDir = "[U]";
     }
     return whichInstallDir;
@@ -277,6 +256,8 @@ QMap< QString, ComponentExtension* > &  ExtensionManager::getComponentExtensionM
     return componentExtensionMap;
 }
 
+
+
 // -------------------- getDataDirectoryComponentExtensionMap --------------------
 QMap< QString, ComponentExtension* > & ExtensionManager::getDataDirectoryComponentExtensionMap() {
     static QMap<QString, ComponentExtension*> dataDirectoryComponentExtensionMap;
@@ -312,11 +293,27 @@ const QMap<QString, ComponentExtension*> & ExtensionManager::getComponentExtensi
     return getComponentExtensionMap();
 }
 
+// -------------------- getComponentExtensionsList --------------------
+const QList< ComponentExtension* > ExtensionManager::getComponentExtensionsList() {
+    QList< ComponentExtension* > sortedList = getComponentExtensionMap().values().toSet().toList(); // to remove duplicates
+    qSort(sortedList.begin(), sortedList.end(), ExtensionManager::componentExtensionLessThan);
+
+    return sortedList;
+}
+
 // -------------------- getDataDirectoryComponents --------------------
 const QMap<QString, ComponentExtension*> & ExtensionManager::getDataDirectoryComponents() {
     return getDataDirectoryComponentExtensionMap();
 }
 
+// -------------------- getDataDirectoryComponentsList --------------------
+const QList< ComponentExtension* > ExtensionManager::getDataDirectoryComponentsList() {
+    QList< ComponentExtension* > sortedList = getDataDirectoryComponentExtensionMap().values().toSet().toList(); // to remove duplicates
+    qSort(sortedList.begin(), sortedList.end(), ExtensionManager::componentExtensionLessThan);
+
+    return sortedList;
+}
+
 // -------------------- getFileExtensions --------------------
 QStringList ExtensionManager::getFileExtensions() {
     return ExtensionManager::getComponentExtensions().keys();
@@ -340,6 +337,14 @@ const QMap< QString, ActionExtension* >& ExtensionManager::getActionExtensions()
     return getActionExtensionMap();
 }
 
+// -------------------- getActionExtensionsList --------------------
+const QList< ActionExtension* > ExtensionManager::getActionExtensionsList() {
+    QList< ActionExtension* > sortedList = getActionExtensionMap().values().toSet().toList(); // to remove duplicates
+    qSort(sortedList.begin(), sortedList.end(), ExtensionManager::actionExtensionLessThan);
+
+    return sortedList;
+}
+
 // -------------------- unloadAllActionExtensions --------------------
 void ExtensionManager::unloadAllActionExtensions() {
     QList<QString> allExtensions = getActionExtensionMap().keys();
@@ -379,8 +384,7 @@ void ExtensionManager::registerFileExtension(QString fileExtension) {
 }
 
 // -------------------- promptRegisterFileExtensions --------------------
-bool ExtensionManager::promptRegisterFileExtensions(QStringList fileExtensions)
-{
+bool ExtensionManager::promptRegisterFileExtensions(QStringList fileExtensions) {
     // Prompt the user if he wishes those file extension to be associated with this application for default file opening.
     QMessageBox msgBox;
     msgBox.setWindowTitle(tr("Associate new file extensions for opening."));
@@ -399,7 +403,7 @@ QStringList ExtensionManager::getExtensionFilter() {
     // try to load all Components in the directory
     QStringList pluginFilter;
     // linux: .so, windows: .dll, macOs: .dylib
-    pluginFilter << "*.so." + QString(Core::soVersion) << "*.dylib";
+    pluginFilter << "*.so." + QString(Core::soVersion) << "*." + QString(Core::soVersion) + ".dylib";
     if (Core::isDebugBuild())
         pluginFilter << "*" + QString(Core::debugPostfix) +".dll";
     else
@@ -411,7 +415,7 @@ QStringList ExtensionManager::getExtensionFilter() {
 QStringList ExtensionManager::getPluginFileNames(QDir extensionsDir) {
     // loop to load component plugin, taking into account internal dependencies (i.e. dependency between
     // one component and another one.
-    QStringList pluginFileNames = extensionsDir.entryList(getExtensionFilter(), QDir::Files);
+    QStringList pluginFileNames = extensionsDir.entryList(getExtensionFilter(), QDir::Files, QDir::Name);
 
 #ifdef WIN32
     // Get the MSVC debug dlls
@@ -419,8 +423,7 @@ QStringList ExtensionManager::getPluginFileNames(QDir extensionsDir) {
 
     if (Core::isDebugBuild()) {
         return pluginFileNamesDebugMSVC;
-    }
-    else {
+    } else {
         // remove debug dll one by one
         foreach(QString debugDLL, pluginFileNamesDebugMSVC) {
             pluginFileNames.removeAll(debugDLL);
@@ -446,8 +449,7 @@ bool ExtensionManager::unloadActionExtension(QString fileName) {
         //-- delete extensions (and all its actions)
         delete ext;
         return true;
-    }
-    else
+    } else
         return false;
 }
 
@@ -475,8 +477,7 @@ bool ExtensionManager::unloadComponentExtension(QString extOrName) {
         delete cp;
         // try to unload
         unloaded = pluginLoader.unload();
-    }
-    else {
+    } else {
         cp = getDataDirectoryComponentExtensionMap().take(extOrName);
 
         if (cp != NULL) {
@@ -486,8 +487,7 @@ bool ExtensionManager::unloadComponentExtension(QString extOrName) {
             delete cp;
             // try to unload
             unloaded = pluginLoader.unload();
-        }
-        else {
+        } else {
             // look for the name in getComponentExtensionMap()
             QMutableMapIterator<QString, ComponentExtension *> it(getComponentExtensionMap());
 
@@ -503,13 +503,86 @@ bool ExtensionManager::unloadComponentExtension(QString extOrName) {
     return unloaded;
 }
 
+// -------------------- initPrivateLibDirs --------------------
+void ExtensionManager::initPrivateLibDirs() {
+    // Add the private lib dirs to the current application environment's PATH variable
+    // This modifies the current PATH variable in order for the OS to find the private
+    // libraries compiled as shared objects/dll/dylib needed by some extensions
+    static bool alreadyInitialized = false;
 
+    if(!alreadyInitialized) {
+        // Build directory
+        QDir privateBuildLibDir(Core::getCurrentWorkingDir());
+        if (privateBuildLibDir.cd("lib/"+QString(Core::shortVersion))) {
+            QByteArray privateBuildLibDirPath = privateBuildLibDir.canonicalPath().toUtf8();
+#ifdef WIN32 // for Windows
+            QByteArray path = qgetenv("PATH");
+            path.append(";");
+            path.append(privateBuildLibDirPath);
+            path.append(";");
+            path.append(privateBuildLibDirPath + "/actions");
+            path.append(";");
+            path.append(privateBuildLibDirPath + "/components");
+            qputenv("PATH",path);
+#endif
+            // update the application / qt plugins library path
+            Application::instance()->addLibraryPath(privateBuildLibDirPath);
+            Application::instance()->addLibraryPath(privateBuildLibDirPath + "/actions");
+            Application::instance()->addLibraryPath(privateBuildLibDirPath + "/components");
+        }
 
+        // Local install directory
+        QDir privateLocalLibDir(Core::getUserInstallDir());
+        if (privateLocalLibDir.cd("lib/"+QString(Core::shortVersion))) {
+            QByteArray privateLocalLibDirPath = privateLocalLibDir.canonicalPath().toUtf8();
+#ifdef WIN32 // for Windows
+            QByteArray path = qgetenv("PATH");
+            path.append(";");
+            path.append(privateLocalLibDirPath);
+            path.append(";");
+            path.append(privateLocalLibDirPath + "/actions");
+            path.append(";");
+            path.append(privateLocalLibDirPath + "/components");
+            qputenv("PATH",path);
+#endif
+            // update the application / qt plugins library path
+            Application::instance()->addLibraryPath(privateLocalLibDirPath);
+            Application::instance()->addLibraryPath(privateLocalLibDirPath + "/actions");
+            Application::instance()->addLibraryPath(privateLocalLibDirPath + "/components");
+        }
 
+        // Global install directory
+        QDir privateGlobalLibDir(Core::getGlobalInstallDir());
+        if (privateGlobalLibDir.cd("lib/"+QString(Core::shortVersion))) {
+            QByteArray privateGlobalLibDirPath = privateGlobalLibDir.canonicalPath().toUtf8();
+#ifdef WIN32 // for Windows
+            QByteArray path = qgetenv("PATH");
+            path.append(";");
+            path.append(privateGlobalLibDirPath);
+            path.append(";");
+            path.append(privateGlobalLibDirPath + "/actions");
+            path.append(";");
+            path.append(privateGlobalLibDirPath + "/components");
+            qputenv("PATH",path);
+#endif
+            // update the application / qt plugins library path
+            Application::instance()->addLibraryPath(privateGlobalLibDirPath);
+            Application::instance()->addLibraryPath(privateGlobalLibDirPath + "/actions");
+            Application::instance()->addLibraryPath(privateGlobalLibDirPath + "/components");
+        }
+        alreadyInitialized = true;
+    }
+}
 
+// -------------------- componentExtensionLessThan --------------------
+bool ExtensionManager::componentExtensionLessThan(const ComponentExtension* left, const ComponentExtension* right) {
+    return left->getName() < right->getName();
+}
 
-
-
+// -------------------- actionExtensionLessThan --------------------
+bool ExtensionManager::actionExtensionLessThan(ActionExtension* left, ActionExtension* right) {
+    return left->getName() < right->getName();
+}
 
 
 
