@@ -41,9 +41,9 @@
 #include <QDir>
 
 namespace camitk {
-/** 
+/**
  * @ingroup group_sdk_libraries_core
- * 
+ *
  * @brief
  * This class is used to manage all plugins loaded by the application.
  *
@@ -57,7 +57,7 @@ namespace camitk {
 class CAMITK_API ExtensionManager : public QObject {
 
 public:
-    /// 
+    ///
     enum {
     };
     /** \enum ExtensionType describes the CamiTK Extension Type (Action, Component, Application...).
@@ -69,7 +69,7 @@ public:
         COMPONENT,      ///< Component extensions: manages the data logic
         APPLICATION,    ///< MainWindow extensions: manages the application logic
         VIEWER          ///< Viewer extensions: manages the presentation and user interaction logic.
-    };    
+    };
 
     /// Autoload component and action extensions
     static void autoload();
@@ -80,14 +80,14 @@ public:
      *  - in the user config directory (CamiTK user install)
      *  - in the system-wide install (CamiTK global install)
      *  - and in the list of user-registered extensions (stored in the configuration directory)
-     * 
+     *
      * Duplicates found within the installation directory are removed (e.g. if you have the extension x.so in the build directory as
      * well as the user directory, only the extension in the build directory will be loaded (it takes precedence).
-     * 
+     *
      * @param type the extension type
      */
     static void autoload(ExtensionType type);
-    
+
     /** Load a specific extension from a file.
      *  This methods loads a ActionExtension, ComponentExtension,... plugin from a .dll/.so/.dylib filename
      *
@@ -106,36 +106,48 @@ public:
      *  - [L] for an extension installed in the user configuration directory (local install)
      *  - [W] for an extension loaded directly from the current working directory (build installation tree)
      *  - [U] for an extension loaded manually by the user
-     * 
+     *
      *  @return the string coding for the installation
      *  @param file the extension plugin file
      */
     static QString getInstallationString(QString file);
-    
+
     /** @name Component extension list management
        */
     ///@{
     /// get the plugin corresponding to a given extension or name (const, you can only use this method to get information, use open to open a file using a specific plugin)
     static const ComponentExtension * getComponentExtension(QString);
 
-    /** get all the registered component extensions that can manage file (default component extension)
-      * This is the public method (return a const, the extensions map is private
-      * and cannot be modified externally).
-      */
-    static const QMap<QString, ComponentExtension*> & getComponentExtensions();
+    /**
+     * @brief Get the list of registered ComponentExtension.
+     * The list contains unique elements (no duplicates possible) and is alphabitically sorted.
+     *
+     * @note
+     * The list is read-only and cannot be modified.
+     * This list is useful to loop over the loaded ComponentExtension, especially when order counts.
+     *
+     * @return list of unique ComponentExtension loaded in the Core.
+     */
+    static const QList<ComponentExtension*> getComponentExtensionsList();
 
-    /** get all the registered component extensions that can manage entire directories
-     * This is the public method (return a const, the extensions map is private
-      * and cannot be modified externally).
-      */
-    static const QMap<QString, ComponentExtension*> & getDataDirectoryComponents();
+    /**
+     * @brief Get the list of registered ComponentExtension working on directory.
+     * The list contains unique elements (no duplicates possible) and is alphabitically sorted.
+     *
+     * @note
+     * The list is read-only and cannot be modified.
+     * This list is useful to loop over the loaded ComponentExtension, especially when order counts.
+     *
+     * @return list of unique ComponentExtension working on data directory loaded in the Core.
+     */
+    static const QList<ComponentExtension*> getDataDirectoryComponentsList();
 
     /// get the list of all the suffixes managed by registered component extensions (all possible file suffix)
     static QStringList getFileExtensions();
 
     /// get the list of all the name of the registered Component data directory
     static QStringList getDataDirectoryExtNames();
-    
+
     /** Register the file extension with the current application for opening
      *  This function is called by registerFileExtensions
      *  @param fileExtension the file extension to associate with the current application for opening
@@ -146,26 +158,32 @@ public:
     /// @param fileExtensions The list of file extensions (without the prefixed '.').
     /// @return The decision of the user regarding the file association.
     static bool promptRegisterFileExtensions(QStringList fileExtensions);
-    
+
     /** Unload a plugin corresponding to a given extension or component name.
      * @return false if the plugin could not be unloaded - still in use somewhere
      */
     static bool unloadComponentExtension(QString);
     ///@}
 
-    
+
     /// @name Action extension list management
     ///@{
 
     /// unload all action extensions and delete instanciated actions
     static void unloadAllActionExtensions();
 
-    /** get all the registered action extension (key is the share object/dll/dylib filename that contains the ActionExtension).
-     * This is the public method (return a const, the extensions map is private
-     * and cannot be modified externally).
+    /**
+     * @brief Get the list of registered ActionExtension.
+     * The list contains unique elements (no duplicates possible) and is alphabitically sorted.
+     *
+     * @note
+     * The list is read-only and cannot be modified.
+     * This list is useful to loop over the loaded ActionExtension, especially when order counts.
+     *
+     * @return list of unique ActionExtension loaded in the Core.
      */
-    static const QMap<QString, ActionExtension*> & getActionExtensions();
-    
+    static const QList<ActionExtension*> getActionExtensionsList();
+
     /** Unload an action extension using its .dll/.so/.dylib filename
      * @return false if the plugin could not be unloaded - still in use somewhere
      */
@@ -173,7 +191,7 @@ public:
     ///@}
 
     ///@cond
-    // TODO CAMITK_DEPRECATED. This section list all the methods marked as deprecated. They are to be removed in CamiTK 4.0    
+    // TODO CAMITK_DEPRECATED. This section list all the methods marked as deprecated. They are to be removed in CamiTK 4.0
     /** Deprecated.
      * load a ComponentExtension plugin using a .dll/.so/.dylib filename
      * @param file the plugin filenamae (.dll/.so/.dylib)
@@ -197,8 +215,41 @@ public:
      */
     static void autoloadActionExtensions();
 
+    /**
+     * CAMITK_DEPRECATED
+     * Use getActionExtensionsList() (renamed in getActionExtensions()) instead
+     *
+     * Get all the registered action extension (key is the share object/dll/dylib filename that contains the ActionExtension).
+     * This is the public method (return a const, the extensions map is private
+     * and cannot be modified externally).
+     *
+     */
+    static const QMap<QString, ActionExtension*> & getActionExtensions();
+
+    /**
+     * CAMITK_DEPRECATED
+     * Use getComponentExtensionsList() (renamed in getComponentExtensions()) instead
+     *
+     * get all the registered component extensions that can manage file (default component extension)
+      * This is the public method (return a const, the extensions map is private
+      * and cannot be modified externally).
+      * The key is the component file extension (unique).
+      */
+    static const QMap<QString, ComponentExtension*> & getComponentExtensions();
+
+    /**
+     * CAMITK_DEPRECATED
+     * Use getDataDirectoryComponentsList() (renamed in getDataDirectoryComponents()) instead
+     *
+     * Get all the registered component extensions that can manage entire directories
+     * This is the public method (return a const, the extensions map is private
+      * and cannot be modified externally).
+      */
+    static const QMap<QString, ComponentExtension*> & getDataDirectoryComponents();
+
+
     ///@endcond
-    
+
 private:
     /** get the singleton map of loaded component plugins for files (the key is the file extension)
     * This is the private (intern) method.
@@ -232,6 +283,48 @@ private:
 
     /// return the list of shared objects in a directory considering debug/release on MSVC
     static QStringList getPluginFileNames(QDir);
+
+    /** Add the private library directories (lib/camitk-version) in the current session PATH:
+     *  - the current build library directory
+     *  - the local installation library directory
+     *  - the global installation library directory
+     *  Note that we also add the actions and component private library subdirectories.
+     */
+    static void initPrivateLibDirs();
+
+    /// @name Custom comparaison methods
+    /// @{
+    /**
+     * @brief Custom comparaison method between two ComponentExtension*
+     * This method uses the QString::<() (less than operator) to perform the comparaison
+     * of two ComponentExtension* based on their name.
+     * This method is used for sorting alphabitically a list of ComponentExtension*.
+     *
+     * @param left left ComponentExtension* to compare
+     * @param right right ComponentExtension* to compare
+     * @return the comparaison result, based on their name (alphabitically order)
+     */
+    static bool componentExtensionLessThan(const ComponentExtension* left, const ComponentExtension* right);
+
+    /**
+     * @brief Custom comparaison method between two ActionExtension*
+     * This method uses the QString::<() (less than operator) to perform the comparaison
+     * of two ActionExtension* based on their name.
+     * This method is used for sorting alphabitically a list of ActionExtension*.
+     *
+     * @param left left ActionExtension* to compare
+     * @param right right ActionExtension* to compare
+     * @return the comparaison result, based on their name (alphabitically order)
+     *
+     * @note This method does not take const input arguments as the ActionExtension::getName() accessor
+     * is a mutable method (not const).
+     * This should be updated, but would change the CamiTK API
+     * see https://forge.imag.fr/plugins/mediawiki/wiki/camitk/index.php/Core_developper_guidelines
+     */
+    static bool actionExtensionLessThan(ActionExtension* left, ActionExtension* right);
+    ///@}
+
+
 };
 
 }
