@@ -32,51 +32,43 @@ HistoryItem::HistoryItem() { }
 
 
 // --------------- Constructor -------------------
-HistoryItem::HistoryItem( QString name )
-{
-  this->name = name;
+HistoryItem::HistoryItem( QString name ) {
+    this->name = name;
 }
 
 // --------------- Destructor -------------------
-HistoryItem::~HistoryItem()
-{
+HistoryItem::~HistoryItem() {
 
 }
 
 // --------------- Accessor -------------------
-QString HistoryItem::getName()
-{
+QString HistoryItem::getName() {
     return this->name;
 }
 
 
 // --------------- addProperty -------------------
-void HistoryItem::addProperty ( QByteArray name, QVariant value )
-{
+void HistoryItem::addProperty ( QByteArray name, QVariant value ) {
     this->properties.insert(name, value);
 }
 
 // --------------- getInputComponents -------------------
-QList<HistoryComponent> HistoryItem::getInputHistoryComponents()
-{
+QList<HistoryComponent> HistoryItem::getInputHistoryComponents() {
     return this->inputHistoryComponents;
 }
 
 // --------------- setInputComponents -------------------
-void HistoryItem::setInputHistoryComponents ( QList<HistoryComponent> inputHistoryComponents )
-{
+void HistoryItem::setInputHistoryComponents ( QList<HistoryComponent> inputHistoryComponents ) {
     this->inputHistoryComponents = inputHistoryComponents;
 }
 
 // --------------- getOutputComponents -------------------
-QList<HistoryComponent> HistoryItem::getOutputHistoryComponents()
-{
+QList<HistoryComponent> HistoryItem::getOutputHistoryComponents() {
     return this->outputHistoryComponents;
 }
 
 // --------------- setOutputComponents -------------------
-void HistoryItem::setOutputHistoryComponents ( QList<HistoryComponent> outputHistoryComponents )
-{
+void HistoryItem::setOutputHistoryComponents ( QList<HistoryComponent> outputHistoryComponents ) {
     this->outputHistoryComponents = outputHistoryComponents;
 }
 
