@@ -37,8 +37,7 @@
 #include <QGroupBox>
 #include <QMessageBox>
 
-namespace camitk
-{
+namespace camitk {
 
 // -------------------- constructor --------------------
 Action::Action ( ActionExtension* extension ) : QObject() {
@@ -48,14 +47,21 @@ Action::Action ( ActionExtension* extension ) : QObject() {
     isEmbedded = true;
     actionWidget = NULL;
     autoUpdateProperties = false;
+	item = NULL;
 }
 
 // -------------------- destructor --------------------
 Action::~Action() {
     // delete all properties
     foreach(Property* prop, parameterMap.values())
-        delete prop;
+    delete prop;
     parameterMap.clear();
+
+	//delete History item
+	if( item )
+	{
+		delete item;
+	}
 }
 
 // -------------------- setName --------------------
@@ -65,69 +71,57 @@ void Action::setName ( QString name ) {
 }
 
 // -------------------- setDescription --------------------
-void Action::setDescription ( QString description )
-{
+void Action::setDescription ( QString description ) {
     this->description = description;
 }
 
 // -------------------- setComponent --------------------
-void Action::setComponent ( QString component )
-{
+void Action::setComponent ( QString component ) {
     this->component = component;
 }
 
 // -------------------- setFamily --------------------
-void Action::setFamily ( QString family )
-{
+void Action::setFamily ( QString family ) {
     this->family = family;
 }
 
 // -------------------- setTag --------------------
-void Action::addTag ( QString tag )
-{
+void Action::addTag ( QString tag ) {
     this->tags.append ( tag );
 }
 
 // -------------------- setEmbedded --------------------
-void Action::setEmbedded ( bool isEmbedded )
-{
+void Action::setEmbedded ( bool isEmbedded ) {
     this->isEmbedded = isEmbedded;
 }
 
 // -------------------- setIcon --------------------
-void Action::setIcon ( QPixmap icon )
-{
+void Action::setIcon ( QPixmap icon ) {
     this->icon = icon;
 }
 
 // -------------------- getExtensionName --------------------
-QString Action::getExtensionName() const
-{
+QString Action::getExtensionName() const {
     return extension->getName();
 }
 
 // -------------------- getIcon --------------------
-QPixmap Action::getIcon()
-{
+QPixmap Action::getIcon() {
     return icon;
 }
 
 // -------------------- getTargets --------------------
-const ComponentList Action::getTargets() const
-{
+const ComponentList Action::getTargets() const {
     return targetComponents;
 }
 
 // -------------------- getWidget --------------------
-QWidget* Action::getWidget()
-{
+QWidget* Action::getWidget() {
     // build or update the widget
     if ( !actionWidget ) {
         // Setting the widget containing the parameters, using the default widget
         actionWidget = new ActionWidget ( this );
-    }
-    else
-    {
+    } else {
         // make sure the widget has updated targets
         dynamic_cast<ActionWidget*> ( actionWidget )->updateTargets();
     }
@@ -140,10 +134,8 @@ QWidget* Action::getWidget()
 
 
 // -------------------- getQAction --------------------
-QAction* Action::getQAction()
-{
-    if ( !qAction )
-    {
+QAction* Action::getQAction() {
+    if ( !qAction ) {
         // create the corresponding QAction (using the icon, name and descriptions)
         qAction = new QAction ( getIcon(), getName(), this );
         qAction->setStatusTip ( getDescription() );
@@ -156,53 +148,42 @@ QAction* Action::getQAction()
 }
 
 // -------------------- trigger --------------------
-Action::ApplyStatus Action::trigger ( QWidget * parent )
-{
+Action::ApplyStatus Action::trigger ( QWidget * parent ) {
     //-- build the list of valid targets
     targetComponents.clear();
     ComponentList selComp = Application::getSelectedComponents();
 
-    foreach ( Component * comp, selComp )
-    {
+    foreach ( Component * comp, selComp ) {
         // check compatibility
-        if ( comp->isInstanceOf ( this->getComponent() ) )
+        if ( comp->isInstanceOf ( this->getComponent() ) ) {
             targetComponents.append ( comp );
+        }
     }
 
     //-- if there are some valid targets or if the action is generic
-    if ( targetComponents.size() > 0 || getComponent().isEmpty() )
-    {
-        if ( isEmbedded )
-        {
+    if ( targetComponents.size() > 0 || getComponent().isEmpty() ) {
+        if ( isEmbedded ) {
             // if there are no parents to use use the action viewer
             if ( !parent )
                 ActionViewer::getActionViewer()->embedActionWidget ( this );
-            else
-            {
+            else {
                 getWidget()->setParent ( parent );
                 getWidget()->show();
             }
-        }
-        else
-        {
+        } else {
             QWidget * w = getWidget();
 
-            if ( w )
-            {
+            if ( w ) {
                 // non embeded, just show/raise the window
                 w->show();
-            }
-            else
-            {
+            } else {
                 // non embeded, no widget -> call apply() directly
                 return applyAndRegister();
             }
         }
 
         return TRIGGERED;
-    }
-    else
-    {
+    } else {
         QMessageBox::information ( parent, "Cannot apply this Action to selection", "Sorry, but the action \"" + getName() + "\" cannot be applied on the currently selected component(s)" );
         return ERROR;
     }
@@ -210,8 +191,7 @@ Action::ApplyStatus Action::trigger ( QWidget * parent )
 }
 
 // -------------------- applyAndRegister --------------------
-Action::ApplyStatus Action::applyAndRegister()
-{
+Action::ApplyStatus Action::applyAndRegister() {
     ApplyStatus status;
 
     // call preprocess function to compute number of components before applying the action
@@ -221,8 +201,7 @@ Action::ApplyStatus Action::applyAndRegister()
     if ( targetComponents.size() > 0 || getComponent().isEmpty() ) {
         status = apply();
         this->postProcess();
-    }
-    else
+    } else
         status = Action::ABORTED;
 
     return status;
@@ -240,8 +219,7 @@ Action::ApplyStatus Action::applyInPipeline() {
     if ( targetComponents.size() > 0 || getComponent().isEmpty() ) {
         status = apply();
         postProcessInPipeline();
-    }
-    else
+    } else
         status = Action::ABORTED;
 
     return status;
@@ -251,8 +229,7 @@ Action::ApplyStatus Action::applyInPipeline() {
 void Action::setInputComponents ( ComponentList inputs ) {
     //-- build the list of valid targets
     targetComponents.clear();
-    foreach ( Component * comp, inputs )
-    {
+    foreach ( Component * comp, inputs ) {
         // check compatibility
         if ( comp->isInstanceOf ( this->getComponent() ) )
             targetComponents.append ( comp );
@@ -264,8 +241,7 @@ void Action::setInputComponent ( Component * input ) {
     targetComponents.clear();
 
     // check compatibility
-    if ( input->isInstanceOf ( this->getComponent() ) )
-    {
+    if ( input->isInstanceOf ( this->getComponent() ) ) {
         targetComponents.append ( input );
     }
 
@@ -286,8 +262,7 @@ Component * Action::getOutputComponent() {
 }
 
 // -------------------- preProcess ------------------------------
-void Action::preProcess()
-{
+void Action::preProcess() {
     // Create a new entry in the history
     this->item = new HistoryItem(this->name);
 
@@ -299,10 +274,8 @@ void Action::preProcess()
     // We will select the one selected as input of the current action
     this->topLevelSelectedComponents.clear();
     QList<HistoryComponent> topLevelSelectedHistoryComponents;
-    foreach(Component *comp, this->aliveBeforeComponents)
-    {
-        if(comp->isSelected())
-        {
+    foreach(Component *comp, this->aliveBeforeComponents) {
+        if(comp->isSelected()) {
             this->topLevelSelectedComponents.append(comp);
             topLevelSelectedHistoryComponents.append(HistoryComponent(comp));
         }
@@ -322,15 +295,13 @@ void Action::preProcessInPipeline() {
 }
 
 // -------------------- postProcess ------------------------------
-void Action::postProcess()
-{
+void Action::postProcess() {
     // Deduce the number of top level components created during the action, from aliveBeforeComponents
     ComponentList topLevelComponentCreated;
     QList<HistoryComponent> topLevelHistoryComponentCreated;
     topLevelHistoryComponentCreated.clear();
     foreach (Component * comp, Application::getTopLevelComponents() ) {
-        if (!this->aliveBeforeComponents.contains(comp))
-        {
+        if (!this->aliveBeforeComponents.contains(comp)) {
             topLevelComponentCreated.append(comp);
             topLevelHistoryComponentCreated.append(HistoryComponent(comp));
         }
@@ -342,7 +313,7 @@ void Action::postProcess()
     // Add the action's parameters to the history item
     // get back all the properties dynamically added to the action using Qt meta object
     foreach (QByteArray propertyName, dynamicPropertyNames())
-        item->addProperty(propertyName, property(propertyName));
+    item->addProperty(propertyName, property(propertyName));
 
     // Store the entry in the history.
     Application::addHistoryItem(*item);
@@ -380,10 +351,10 @@ Property* Action::getProperty(QString name) {
 // ---------------------- addParameter ----------------------------
 bool Action::addParameter(Property * prop) {
     // add a dynamic Qt Meta Object property with the same name
-    bool returnStatus = QObject::setProperty(prop->getName().toStdString().c_str(), prop->getInitialValue() );
+    bool returnStatus = setProperty(prop->getName().toStdString().c_str(), prop->getInitialValue() );
     // add to the map
     parameterMap.insert(prop->getName(),prop);
-    
+
     return returnStatus;
 }
 
