@@ -34,22 +34,22 @@
 #include <QtPlugin>
 #include <QPluginLoader>
 #include <QObject>
+#include <QTranslator>
 
-namespace camitk
-{
+namespace camitk {
 class Action;
-    
+
 // a bit simplistic, but greatly simply syntax (and explanation)
 // to be used in an ActionExtension register method
 #define registerNewAction(X) registerAction(new X(this))
 
 /**
- * @ingroup group_sdk_libraries_core_action 
- * 
+ * @ingroup group_sdk_libraries_core_action
+ *
  * @brief
  * This class describes what is a generic Action extension.
 * To add a ActionExtension to CamiTK core, write a new class that inherits from this class.
-* 
+*
 * The following methods HAVE to be redefined in your subclass:
 * - getName: return the name of your extension
 * - getDescription: return a small description
@@ -79,13 +79,33 @@ public :
 
     /// get the list of actions registered y this extension
     const ActionList & getActions();
-    
+
+    /// set the file path (once loaded as a dynamic library)
+    void setLocation(const QString loc) {
+        dynamicLibraryFileName = loc;
+    }
+
+    /// get the file path (location of the .dll/.so/.dylib) of this plugin
+    QString getLocation() const {
+        return dynamicLibraryFileName;
+    }
+
+    /// Load, for the selected langage (asked to the Application), the associated .qm file
+    void initResources();
+
 protected:
     /// register an action instance
     void registerAction(Action *);
 
     /// the list of actions
     ActionList actions;
+
+private:
+    /// the shared lib (.so, .dll or .dylib) used to instanciate the ComponentExtension subclass instance
+    QString dynamicLibraryFileName;
+
+	/// Provide internationalization support for text output.
+	QTranslator* translator;
 };
 
 }
