@@ -36,16 +36,20 @@ namespace camitk {
 // -------------------- constructor --------------------
 ActionWidget::ActionWidget(Action *action): QFrame() {
     myAction = action;
+
     // create the property editor tab itself
     setObjectName(myAction->getName());
-    
+
     QVBoxLayout * widgetLayout = new QVBoxLayout;
-        
+
+    // Action's name and icon
     QHBoxLayout *nameLayout = new QHBoxLayout;
     QLabel *iconPicture = new QLabel;
     iconPicture->setPixmap(myAction->getIcon());
+    iconPicture->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     nameLayout->addWidget(iconPicture);
-    actionNameLabel= new QLabel(myAction->getName());
+    actionNameLabel= new QLabel("<h3><b>" + myAction->getName() + "</b></h3>");
+    actionNameLabel->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
     nameLayout->addWidget(actionNameLabel);
     widgetLayout->addLayout(nameLayout);
 
@@ -58,20 +62,21 @@ ActionWidget::ActionWidget(Action *action): QFrame() {
     // Action description presentation
     descriptionLabelScrollArea = new QScrollArea();
     descriptionLabelScrollArea->setWidgetResizable(true);
+    descriptionLabelScrollArea->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Expanding);
     descriptionLabelScrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     descriptionLabelScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
-    descriptionLabel = new QLabel("<b>Description :</b> " + myAction->getDescription());
+    descriptionLabel = new QLabel("<b>Description :</b> <br />" + myAction->getDescription());
     descriptionLabel->setFrameStyle(QFrame::StyledPanel | QFrame::Sunken);
     descriptionLabel->setTextFormat(Qt::RichText);
     descriptionLabel->setLineWidth(3);
     descriptionLabel->setWordWrap(true);
     descriptionLabelScrollArea->setWidget(descriptionLabel);
-    descriptionLabelScrollArea->setMaximumHeight(descriptionLabel->heightForWidth(Application::getMainWindow()->size().width()/6));
     widgetLayout->addWidget(descriptionLabelScrollArea);
 
     // Targets list display
     targetLabelScrollArea = new QScrollArea();
     targetLabelScrollArea->setWidgetResizable(true);
+    targetLabelScrollArea->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Minimum);
     targetLabelScrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     targetLabelScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarAsNeeded);
     targetLabel = new QLabel(getTargetLabel());
@@ -83,16 +88,20 @@ ActionWidget::ActionWidget(Action *action): QFrame() {
 
     // first the property editor
     objectController = new ObjectController(this, ObjectController::BUTTON);
+    objectController->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
     widgetLayout->addWidget(objectController);
 
     // then the buttons
     buttonFrame = new QFrame();
     QHBoxLayout *buttonLayout = new QHBoxLayout;
+//    buttonLayout->setSizeConstraint(QHBoxLayout::SetMaximumSize);
 
     QPushButton *applyButton = new QPushButton("Apply");
+    applyButton->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
     buttonLayout->addWidget(applyButton);
 
     QPushButton *revertButton = new QPushButton("Revert");
+    revertButton->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::Fixed);
     buttonLayout->addWidget(revertButton);
 
     buttonFrame->setLayout(buttonLayout);
@@ -108,11 +117,11 @@ ActionWidget::ActionWidget(Action *action): QFrame() {
     QObject::connect(applyButton, SIGNAL(clicked()), myAction, SLOT(applyAndRegister()));
     QObject::connect(revertButton, SIGNAL(clicked()), objectController, SLOT(revert()));
 
-    setLayout(widgetLayout);
-
     // Now tell the ObjectController that this Action itself is the one to manage
     objectController->setObject(myAction);
     objectController->setMaximumHeight(objectController->sizeHint().height());
+
+    setLayout(widgetLayout);
 }
 
 // -------------------- destructor --------------------
@@ -141,12 +150,11 @@ void ActionWidget::updateTargets() {
     objectController->setObject(NULL);
     objectController->setObject(myAction);
     targetLabel->setText(getTargetLabel());
-    targetLabelScrollArea->setMaximumHeight(targetLabel->heightForWidth(Application::getMainWindow()->size().width()/6 + 50));
 }
 
 // -------------------- getTargetLabel --------------------
 QString ActionWidget::getTargetLabel() {
-    QString targetNames = "<b> Target(s) to apply the action on: </b> <ul>";
+    QString targetNames = tr("<b> Target(s) to apply the action on: </b> <ul>");
     foreach (Component * comp, myAction->getTargets()) {
         targetNames += "<li> " + comp->getName() + "<i> (" + comp->metaObject()->className() + ") </i>" + "</li>";
     }
@@ -155,7 +163,7 @@ QString ActionWidget::getTargetLabel() {
 
 // -------------------- setAutoUpdateProperty --------------------
 void ActionWidget::setAutoUpdateProperty(bool autoUpdate) {
-  objectController->setAutoUpdateProperty(autoUpdate);
+    objectController->setAutoUpdateProperty(autoUpdate);
 }
 
 }
