@@ -31,6 +31,7 @@
 #include "ExtensionManager.h"
 #include "Action.h"
 #include "HistoryComponent.h"
+#include "ImageComponent.h"
 
 // -- QT stuff
 #include <QSettings>
@@ -68,7 +69,7 @@ Application::Application(QString name, int & theArgc, char ** theArgv, bool auto
 
     initIcons(); // sometimes needed to get the icon when compiled in static mode
 
-    // recommanded (see exec() comment in QApplication)
+    // recommended (see exec() comment in QApplication)
     connect(this, SIGNAL(aboutToQuit()), SLOT(quitting()));
     connect(this, SIGNAL(lastWindowClosed()), SLOT(quitting()));
 
@@ -101,8 +102,7 @@ Application::Application(QString name, int & theArgc, char ** theArgv, bool auto
 
 
     // register file association with this application for opening
-    if (registerFileExtension)
-    {
+    if (registerFileExtension) {
         // TODO : remove ifdef WIN32 as soon as we handle file association for other platform than Windows
         // see ExtensionManager::registerFileExtension method.
 #ifdef WIN32
@@ -117,23 +117,20 @@ Application::Application(QString name, int & theArgc, char ** theArgv, bool auto
         fileExtensionForbidden.append("bmp");
         fileExtensionForbidden.append("tif");
         fileExtensionForbidden.append("tiff");
-        foreach (QString extensionFile, ExtensionManager::getFileExtensions())
-        {
+        foreach (QString extensionFile, ExtensionManager::getFileExtensions()) {
             // check the application can handle new file type
             if (!fileExtensionsAlreadyRegistered.contains(extensionFile) && !fileExtensionForbidden.contains(extensionFile))
                 newFileExtensions.append(extensionFile);
         }
 
         // check if the application handles new file types
-        if (!newFileExtensions.isEmpty())
-        {
+        if (!newFileExtensions.isEmpty()) {
             // new component extension(s) allow(s) the application to handle new file types
             // prompt the user if he wants them to be associated with this application for opening
-            if (ExtensionManager::promptRegisterFileExtensions(newFileExtensions))
-            {
+            if (ExtensionManager::promptRegisterFileExtensions(newFileExtensions)) {
                 // user agrees : register each new file type
                 foreach (QString fileExtensionToRegister, newFileExtensions)
-                    ExtensionManager::registerFileExtension(fileExtensionToRegister);
+                ExtensionManager::registerFileExtension(fileExtensionToRegister);
             }
 
             // save the file types in the application's settings in order not to be prompt again
@@ -142,13 +139,22 @@ Application::Application(QString name, int & theArgc, char ** theArgv, bool auto
         }
 #endif
     }
-
     settings.endGroup();
+
+    // Load the resources of the application (mainly its translation file)
+    initResources();
 }
 
 // ----------------- destructor --------------------
 Application::~Application() {
     // do not use the destructor to clean or free resources, but quitting()
+
+    if (translator)
+    {
+        //delete instance of internationalization support
+        delete translator;
+    }
+
 }
 
 // ----------------- destructor --------------------
@@ -217,8 +223,7 @@ void Application::showStatusBarMessage(QString msg, int timeout) {
 
     if (statusBar) {
         statusBar->showMessage(msg, timeout);
-    }
-    else {
+    } else {
         CAMITK_INFO("Application", "showStatusBarMessage", msg.toStdString() << std::endl);
     }
 }
@@ -334,9 +339,8 @@ Component * Application::open(const QString & fileName) {
         restoreOverrideCursor();
         resetProgressBar();
 
-        QMessageBox::warning(NULL, "ComponentExtension Opening Error...", "Cannot find the appropriate component plugin for opening:<br>" + fileName + " (extension " + extension + ")<p>To solve this problem, make sure that: <ul><li>A corresponding valid plugin is present in " + Core::getComponentDir() + "</li><li>Your application called <tt>ComponentExtension::autoloadExtensions()</tt> before calling <tt>ComponentExtension::open(...)</tt></li></ul>");
-    }
-    else {
+        QMessageBox::warning(NULL, "ComponentExtension Opening Error...", tr("Cannot find the appropriate component plugin for opening:<br>") + fileName + tr(" (extension ") + extension + tr(")<p>To solve this problem, make sure that: <ul><li>A corresponding valid plugin is present in ") + Core::getComponentDir() + tr("</li><li>Your application called <tt>ComponentExtension::autoloadExtensions()</tt> before calling <tt>ComponentExtension::open(...)</tt></li></ul>"));
+    } else {
 
         // -- ask the plugin to create the top level component
         try {
@@ -346,8 +350,7 @@ Component * Application::open(const QString & fileName) {
             // -- notify the application
             if ( comp == NULL ) {
                 showStatusBarMessage( tr ( "Error loading file:" ) + fileName );
-            }
-            else {
+            } else {
                 // add the document to the recent list
                 addRecentDocument(fileName);
                 showStatusBarMessage( tr ( QString("File " + fileName + " successfully loaded").toStdString().c_str() ) );
@@ -356,26 +359,23 @@ Component * Application::open(const QString & fileName) {
                 refresh();
             }
 
-        }
-        catch (AbortException & e) {
+        } catch (AbortException & e) {
             // restore the normal cursor/progress bar
             restoreOverrideCursor();
             resetProgressBar();
-            QMessageBox::warning(NULL, "Opening aborted...", "Extension: " + cp->getName() + "<br>Error: cannot open file " + fileName + "<br>Reason:<br>" + e.what());
+            QMessageBox::warning(NULL, "Opening aborted...", tr("Extension: ") + cp->getName() + tr("<br>Error: cannot open file ") + fileName + tr("<br>Reason:<br>") + e.what());
             comp = NULL;
-        }
-        catch (std::exception& e) {
+        } catch (std::exception& e) {
             // restore the normal cursor/progress bar
             restoreOverrideCursor();
             resetProgressBar();
-            QMessageBox::warning(NULL, "Opening aborted...", "Extension " + cp->getName() + "<br>Error: cannot open file " + fileName + "<br>External:<br>" + "This exception was not generated directly by the extension,<br>but by one of its dependency.<br>Reason:<br>" + e.what());
+            QMessageBox::warning(NULL, "Opening aborted...", tr("Extension ") + cp->getName() + tr("<br>Error: cannot open file ") + fileName + tr("<br>External:<br>") + tr("This exception was not generated directly by the extension,<br>but by one of its dependency.<br>Reason:<br>") + e.what());
             comp = NULL;
-        }
-        catch (...) {
+        } catch (...) {
             // restore the normal cursor/progress bar
             restoreOverrideCursor();
             resetProgressBar();
-            QMessageBox::warning(NULL, "Opening aborted...", "Extension " + cp->getName() + "<br>Error: cannot open file " + fileName + "<br>Unknown Reason:<br>" + "This exception was not generated directly by the extension,<br>but by one of its dependency.");
+            QMessageBox::warning(NULL, "Opening aborted...", tr("Extension ") + cp->getName() + tr("<br>Error: cannot open file ") + fileName + tr("<br>Unknown Reason:<br>") + tr("This exception was not generated directly by the extension,<br>but by one of its dependency."));
             comp = NULL;
         }
     }
@@ -383,6 +383,11 @@ Component * Application::open(const QString & fileName) {
     // restore the normal cursor/progress bar
     restoreOverrideCursor();
     resetProgressBar();
+
+    if (!comp->isTopLevel()) {
+        CAMITK_WARNING("Application", "Open", "Instanciating a NON top level component.")
+    }
+
     return comp;
 }
 
@@ -403,43 +408,41 @@ Component * Application::openDirectory(const QString & dirName, const QString &
             // -- notify the application
             if ( comp == NULL ) {
                 showStatusBarMessage( tr ( "Error loading directory:" ) + dirName );
-            }
-            else {
+            } else {
                 showStatusBarMessage( tr ( QString("Directory " + dirName + " successfully loaded").toStdString().c_str() ) );
                 // refresh all viewers
                 refresh();
             }
-        }
-        catch (AbortException & e) {
+        } catch (AbortException & e) {
             // restore the normal cursor/progress bar
             restoreOverrideCursor();
             resetProgressBar();
-            QMessageBox::warning(NULL, "Opening aborted...", "Extension: " + cp->getName() + "<br>Error: cannot open file " + dirName + "<br>Reason:<br>" + e.what());
+            QMessageBox::warning(NULL, "Opening aborted...", tr("Extension: ") + cp->getName() + tr("<br>Error: cannot open file ") + dirName + tr("<br>Reason:<br>") + e.what());
             comp = NULL;
-        }
-        catch (...) {
+        } catch (...) {
             // restore the normal cursor/progress bar
             restoreOverrideCursor();
             resetProgressBar();
-            QMessageBox::warning(NULL, "Opening aborted...", "Extension " + cp->getName() + " Error: cannot open directory " + dirName + "<br>Unknown Reason:<br>" + "This exception was not generated directly by the extension,<br>but by one of its dependency.");
+            QMessageBox::warning(NULL, "Opening aborted...", tr("Extension ") + cp->getName() + tr(" Error: cannot open directory ") + dirName + tr("<br>Unknown Reason:<br>") + tr("This exception was not generated directly by the extension,<br>but by one of its dependency."));
             delete comp;
             comp = NULL;
         }
-    }
-    else {
+    } else {
         // restore the normal cursor/progress bar
         restoreOverrideCursor();
         resetProgressBar();
-        QMessageBox::warning(NULL, "ComponentExtension Opening Error...", "Cannot find the appropriate component plugin for opening directory:<br>" + dirName
-                             + "<p>To solve this problem, make sure that:<ul>"
-                             +" <li>A corresponding valid plugin is present in one of the component directories: <tt>" + Core::getComponentDirectories().join(", ") + "</tt></li>"
-                             + "<li>And your application is initialized with the autoloadExtensions option;</li>"
-                             +" <li>Or your correctly registered your component in the CamiTK settings</li></ul>");
+        QMessageBox::warning(NULL, "ComponentExtension Opening Error...", tr("Cannot find the appropriate component plugin for opening directory:<br>") + dirName
+                             + tr("<p>To solve this problem, make sure that:<ul>")
+                             + tr(" <li>A corresponding valid plugin is present in one of the component directories: <tt>") + Core::getComponentDirectories().join(", ") + "</tt></li>"
+                             + tr("<li>And your application is initialized with the autoloadExtensions option;</li>")
+                             + tr(" <li>Or your correctly registered your component in the CamiTK settings</li></ul>"));
     }
 
     // restore the normal cursor/progress bar
     restoreOverrideCursor();
     resetProgressBar();
+
+
     return comp;
 }
 
@@ -452,7 +455,7 @@ bool Application::close ( Component *comp ) {
     // check if the top-level component needs to be saved
     if ( comp->getModified() ) {
         // dManager has changed, propose to save it
-        keyPressed = QMessageBox::warning ( NULL, "Closing...", "Component \"" + compName + "\" has been modified.\nDo you want to save your change before closing?", QMessageBox::Save | QMessageBox::Discard | QMessageBox::Cancel, QMessageBox::Save);
+        keyPressed = QMessageBox::warning ( NULL, "Closing...", tr("Component \"") + compName + tr("\" has been modified.\nDo you want to save your change before closing?"), QMessageBox::Save | QMessageBox::Discard | QMessageBox::Cancel, QMessageBox::Save);
 
         // Do we have to save or not?
         if ( keyPressed == QMessageBox::Save )
@@ -468,8 +471,7 @@ bool Application::close ( Component *comp ) {
 
         showStatusBarMessage( compName + tr ( " successfully closed..." ));
         return true;
-    }
-    else {
+    } else {
         // return that the close was cancelled
         showStatusBarMessage( tr ( "Close cancelled..." ));
         return false;
@@ -492,21 +494,35 @@ bool Application::save(Component* component) {
     ComponentExtension * cp = ExtensionManager::getComponentExtensions().value(extension);
 
     if (!cp) {
-        QMessageBox::warning(NULL, "Saving Error...", "Cannot find the appropriate component plugin for saving component:<br/>\"" + component->getName() + "\" in file:<br/>" + component->getFileName() + " (extension " + extension + ")"
-                             + "<p>To solve this problem, make sure that:<ul>"
-                             +" <li>A corresponding valid plugin is present in one of the component directories: <tt>" + Core::getComponentDirectories().join(", ") + "</tt></li>"
-                             + "<li>And your application is initialized with the autoloadExtensions option;</li>"
-                             +" <li>Or your correctly registered your component in the CamiTK settings</li></ul>");
+        QMessageBox::warning(NULL, "Saving Error...", tr("Cannot find the appropriate component plugin for saving component:<br/>\"") + component->getName() + tr("\" in file:<br/>") + component->getFileName() + tr(" (extension ") + extension + ")"
+                             + tr("<p>To solve this problem, make sure that:<ul>")
+                             + tr(" <li>A corresponding valid plugin is present in one of the component directories: <tt>") + Core::getComponentDirectories().join(", ") + "</tt></li>"
+                             + tr("<li>And your application is initialized with the autoloadExtensions option;</li>")
+                             + tr(" <li>Or your correctly registered your component in the CamiTK settings</li></ul>"));
         return false;
-    }
-    else {
+    } else { // ready to save
+
+        QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+
+        if(ImageComponent* imgComp = dynamic_cast<ImageComponent*>(component)) {
+            // If we deal with an ImageComponent, prepare it for saving
+            imgComp->prepareForSaving();
+        }
+
         if (cp->save(component)) {
+            if(ImageComponent* imgComp = dynamic_cast<ImageComponent*>(component)) {
+                // If we deal with an ImageComponent, revert changes made for saving it
+                imgComp->postSaving();
+            }
+
             // update the last used dir
             setLastUsedDirectory(QFileInfo(component->getFileName()).absoluteDir());
             showStatusBarMessage( component->getName() + tr ( " successfully saved..." ));
+
+            QApplication::restoreOverrideCursor();
             return true;
-        }
-        else {
+        } else {
+            QApplication::restoreOverrideCursor();
             return false;
         }
     }
@@ -537,8 +553,7 @@ int Application::registerAllActions(ActionExtension* ext) {
                          << ", family: " << action->getFamily().toStdString()
                          << ", description:\"" << action->getDescription().toStdString()
                          << "\"): extension of same name already registered by extension \"" << getAction(action->getName())->getExtensionName().toStdString() << "\"");
-        }
-        else {
+        } else {
             getActionMap().insert(action->getName(), action);
             registered++;
         }
@@ -576,8 +591,7 @@ ActionList Application::getActions(Component *component) {
             if (componentHierarchy.contains(currentAct->getComponent()))
                 actions.insert(currentAct);
         }
-    }
-    else {
+    } else {
         foreach (Action * currentAct, Application::getActions()) {
             if (currentAct->getComponent().isEmpty()) {
                 actions.insert(currentAct);
@@ -593,8 +607,7 @@ ActionList Application::getActions(ComponentList cList) {
     // if this is an empty list, return all action not based on a component
     if (cList.size() == 0) {
         return getActions(NULL);
-    }
-    else {
+    } else {
         ActionSet actions;
         foreach (Component * currentComp, cList) {
             actions += getActions(currentComp).toSet();
@@ -708,31 +721,26 @@ void Application::clearSelectedComponents() {
 }
 
 // -------------------- getHistory --------------------
-QStack<HistoryItem> & Application::getHistory()
-{
+QStack<HistoryItem> & Application::getHistory() {
     // static singleton declaration
     static QStack<HistoryItem> history;
     return history;
 }
 
 // -------------------- addHistory ------------------------------
-void Application::addHistoryItem(HistoryItem item)
-{
+void Application::addHistoryItem(HistoryItem item) {
     getHistory().push(item);
 }
 
 // -------------------- removeLastHistoryItem --------------------
-HistoryItem Application::removeLastHistoryItem()
-{
+HistoryItem Application::removeLastHistoryItem() {
     return getHistory().pop();
 }
 
 // -------------------- saveHistoryAsSXML --------------------
-void Application::saveHistoryAsSXML()
-{
+void Application::saveHistoryAsSXML() {
     // Empty history => do nothing
-    if(Application::getHistory().isEmpty())
-    {
+    if(Application::getHistory().isEmpty()) {
         cerr << "No history to save, aborting ..." << endl;
         return;
     }
@@ -774,8 +782,7 @@ void Application::saveHistoryAsSXML()
     QList<HistoryComponent> allCreatedComponents;
 
     // Main loop accross the different actions in the history
-    for(int i=0; i<Application::getHistory().size(); i++)
-    {
+    for(int i=0; i<Application::getHistory().size(); i++) {
         // Get the current history element, i.e. the action of the pipeline with its parameters
         HistoryItem crtHistoryItem = Application::getHistory().at(i);
         Action *crtAction = Application::getAction(crtHistoryItem.getName());
@@ -805,12 +812,10 @@ void Application::saveHistoryAsSXML()
         QDomText crtElement_actionNameText = doc->createTextNode(crtAction->getName());
         crtElement_actionName.appendChild(crtElement_actionNameText);
         // action parameters
-        if (!crtAction->dynamicPropertyNames().isEmpty())
-        {
+        if (!crtAction->dynamicPropertyNames().isEmpty()) {
             QDomElement crtElementAction_parameters = doc->createElement("camitk:parameters");
             crtElement_action.appendChild(crtElementAction_parameters);
-            foreach (QByteArray crtParameter, crtAction->dynamicPropertyNames())
-            {
+            foreach (QByteArray crtParameter, crtAction->dynamicPropertyNames()) {
                 QDomElement crtElementAction_parameter = doc->createElement("camitk:parameter");
                 crtElementAction_parameters.appendChild(crtElementAction_parameter);
                 crtElementAction_parameter.setAttribute("name", QString(crtParameter));
@@ -823,18 +828,15 @@ void Application::saveHistoryAsSXML()
         crtElement_action.appendChild(crtElement_actionParam);
 
         // action input components
-        if (!crtHistoryItem.getInputHistoryComponents().isEmpty())
-        {
+        if (!crtHistoryItem.getInputHistoryComponents().isEmpty()) {
             QDomElement crtElement_actionInputComp = doc->createElement("camitk:inputs");
             crtElement_action.appendChild(crtElement_actionInputComp);
 
-            for(int j=0; j<crtHistoryItem.getInputHistoryComponents().size(); j++)
-            {
+            for(int j=0; j<crtHistoryItem.getInputHistoryComponents().size(); j++) {
                 QDomElement crtElement_crtInputComp = doc->createElement("camitk:component");
                 // determine the type of each input component (image, meshes or other)
                 HistoryComponent crtInputHistoryComp = crtHistoryItem.getInputHistoryComponents().at(j);
-                switch(crtInputHistoryComp.getType())
-                {
+                switch(crtInputHistoryComp.getType()) {
                 case HistoryComponent::IMAGE_COMPONENT:
                     crtElement_crtInputComp.setAttribute("type", "ImageComponent");
                     break;
@@ -855,19 +857,16 @@ void Application::saveHistoryAsSXML()
         }
 
         // action output components
-        if (!crtHistoryItem.getOutputHistoryComponents().isEmpty())
-        {
+        if (!crtHistoryItem.getOutputHistoryComponents().isEmpty()) {
             QDomElement crtElement_actionOutputComp = doc->createElement("camitk:outputs");
             crtElement_action.appendChild(crtElement_actionOutputComp);
 
-            for(int j=0; j<crtHistoryItem.getOutputHistoryComponents().size(); j++)
-            {
+            for(int j=0; j<crtHistoryItem.getOutputHistoryComponents().size(); j++) {
                 QDomElement crtElement_crtOuputComp = doc->createElement("camitk:component");
                 // determine the type of each input component (image, meshes or other)
                 HistoryComponent crtOutputHistoryComp = crtHistoryItem.getOutputHistoryComponents().at(j);
                 allCreatedComponents.append(crtOutputHistoryComp); // note the component created
-                switch(crtOutputHistoryComp.getType())
-                {
+                switch(crtOutputHistoryComp.getType()) {
                 case HistoryComponent::IMAGE_COMPONENT:
                     crtElement_crtOuputComp.setAttribute("type", "ImageComponent");
                     break;
@@ -888,8 +887,7 @@ void Application::saveHistoryAsSXML()
         }
 
         // Transitions
-        if (Application::getHistory().size() >= 1) // else, no transition at all
-        {
+        if (Application::getHistory().size() >= 1) { // else, no transition at all
             // Next transition
             QDomElement crtElement_transitionNext = doc->createElement("transition");
             if (i == Application::getHistory().size() - 1) // Last action element => next element = Bye element.
@@ -904,24 +902,20 @@ void Application::saveHistoryAsSXML()
             crtElement_transitionBack.setAttribute("event", "Back");
             if (i == 0) // Back to Initialize state
                 crtElement_transitionBack.setAttribute("target", "Initialize");
-            else // Back to previous state and delete optional created component in memory
-            {
+            else { // Back to previous state and delete optional created component in memory
                 crtElement_transitionBack.setAttribute("target", "Action " + QString::number(i));
                 // Verify that previsous element has not created components in memory
                 HistoryItem previousItem = Application::getHistory().at(i-1);
-                if (!previousItem.getOutputHistoryComponents().isEmpty())
-                {
+                if (!previousItem.getOutputHistoryComponents().isEmpty()) {
                     // Ask for deletion of each component created at the previous element
                     QDomElement crtElementTransitionBack_onTransition =  doc->createElement("onTransition");
                     crtElement_transitionBack.appendChild(crtElementTransitionBack_onTransition);
                     QDomElement crtElementTransitionBack_close = doc->createElement("camitk:close");
                     crtElementTransitionBack_onTransition.appendChild(crtElementTransitionBack_close);
-                    foreach(HistoryComponent crtComp, previousItem.getOutputHistoryComponents())
-                    {
+                    foreach(HistoryComponent crtComp, previousItem.getOutputHistoryComponents()) {
                         QDomElement crtElementTransitionBack_comp = doc->createElement("camitk:component");
                         crtElementTransitionBack_close.appendChild(crtElementTransitionBack_comp);
-                        switch (crtComp.getType())
-                        {
+                        switch (crtComp.getType()) {
                         case HistoryComponent::IMAGE_COMPONENT:
                             crtElementTransitionBack_comp.setAttribute("type", "ImageComponent");
                             break;
@@ -965,18 +959,15 @@ void Application::saveHistoryAsSXML()
     finalElt_transition.setAttribute("target", "Initialize");
     finalElt.appendChild(finalElt_transition);
     // Ask for deletion of all components created in the pipeline
-    if (!allCreatedComponents.isEmpty())
-    {
+    if (!allCreatedComponents.isEmpty()) {
         QDomElement finalEltTransition_onTransition =  doc->createElement("onTransition");
         finalElt_transition.appendChild(finalEltTransition_onTransition);
         QDomElement finalEltTransition_close = doc->createElement("camitk:close");
         finalEltTransition_onTransition.appendChild(finalEltTransition_close);
-        foreach(HistoryComponent crtComp, allCreatedComponents)
-        {
+        foreach(HistoryComponent crtComp, allCreatedComponents) {
             QDomElement finalEltTransition_comp = doc->createElement("camitk:component");
             finalEltTransition_close.appendChild(finalEltTransition_comp);
-            switch (crtComp.getType())
-            {
+            switch (crtComp.getType()) {
             case HistoryComponent::IMAGE_COMPONENT:
                 finalEltTransition_comp.setAttribute("type", "ImageComponent");
                 break;
@@ -1001,16 +992,42 @@ void Application::saveHistoryAsSXML()
     QString outputFileName = QFileDialog::getSaveFileName(NULL, tr("Save history of actions ..."), Core::getCurrentWorkingDir() + "/actions_history.xml", tr("XML Files (*.xml)"));
 
     QFile *outputFile = new QFile(outputFileName);
-    if(outputFile->open(QFile::WriteOnly))
-    {
+    if(outputFile->open(QFile::WriteOnly)) {
         QTextStream out(outputFile);
         out << xml;
-    }
-    else
+    } else
         cerr << "Error opening file: " + outputFileName.toStdString() + " for writing.";
 }
 
 
+// -------------------- getSelectedLanguage --------------------
+QString Application::getSelectedLanguage() {
+    // Get the path of the Language File in the setting file
+    QSettings  & settings(Application::getSettings());
+    settings.beginGroup(Application::getName() + ".Application");
+    // Get the language an d flag for the current Application instance
+    QString language = settings.value("language").toString();
+    QString languageAbreviation = settings.value("languageAbreviation").toString();
+    QString flagFile = settings.value("flagFilename").toString();
+    settings.endGroup();
+
+    return languageAbreviation;
+}
+
+// -------------------- initResources --------------------
+void Application::initResources() {
+
+    // Get the selected language
+    QString selectedLanguage = Application::getSelectedLanguage();
+
+    // Load the application translation
+    translator = new QTranslator();
+    QString languageFile = ":/translate_" + getName().remove("camitk-") +"/translate/translate_" + selectedLanguage + ".qm";
+    if (!translator->load(languageFile))
+        CAMITK_WARNING("Application", "initResources", "Cannot load file: " + languageFile.toStdString())
+        else
+            QCoreApplication::installTranslator(translator);
+}
 
 }
 
