@@ -36,6 +36,7 @@
 #include <QFileInfo>
 #include <QStack>
 #include <QList>
+#include <QTranslator>
 
 class vtkObject;
 namespace camitk {
@@ -43,10 +44,11 @@ class MainWindow;
 class ActionExtension;
 class Action;
 class HistoryItem;
+class ComponentExtension;
 
-/** 
+/**
  * @ingroup group_sdk_libraries_core_application
- * 
+ *
  * @brief
  * The generic/default application.
  *  Once this class is intanciated in the main, everything is setup.
@@ -146,7 +148,9 @@ public:
      */
     ///@{
 
-    /// load the filename and returns the corresponding Component (return NULL if an error occurs)
+    /// load the filename and returns the corresponding top level Component (return NULL if an error occurs)
+    /// @note this method opens the filename and created the associated TOP LEVEL component
+    /// If you wish to open a subcomponent (not top level then), prefer directly calling its public constructor.
     static Component * open(const QString &);
 
     /** load a directory and returns the corresponding Component (return NULL if an error occurs)
@@ -293,16 +297,16 @@ public:
     ///@{
     /** Add the history item to the application history.
      * The item is added to the history stack of actions used in a pipeline
-     * @see removeLastHistoryItem() To pop back an action from the history use 
+     * @see removeLastHistoryItem() To pop back an action from the history use
      * @param item the item to add to the history
      */
     static void addHistoryItem(HistoryItem item);
 
     /** Remove the last pushed actions in the history of the current pipeline.
-     * @see addHistoryItem() To push back the item use 
+     * @see addHistoryItem() To push back the item use
      */
     static HistoryItem removeLastHistoryItem();
-    
+
     /**
      * Save the history as an SCXML file, stored using @see addHistoryItem() method.
      * This file can be interpreted by the camitk actionstatemachine executable
@@ -311,6 +315,16 @@ public:
 
     ///@}
 
+    /// @name Application resources management
+    ///@{
+
+
+    /**
+    * Returns for the current CamiTK application, the selected language (stored in its .ini configuration file)
+    */
+    static QString getSelectedLanguage();
+    ///@}
+
 
 
 
@@ -343,6 +357,9 @@ private:
 
     /// max number of recent document (default 10)
     static int maxRecentDocuments;
+
+	/// Provide internationalization support for text output.
+	QTranslator* translator;
     ///@}
 
     /// @name Components management
@@ -437,6 +454,10 @@ private:
     static ActionList sort(ActionSet);
     ///@}
 
+    /// Init the application resources by loading the language associated .qm file
+    void initResources();
+
+
 };
 
 }
