@@ -142,12 +142,10 @@ void MainWindow::addDockViewer ( Qt::DockWidgetArea dockingArea, Viewer* theView
             addDockWidget ( dockingArea, viewerDock );
             // update map
             dockWidgetMap.insert ( theViewer, viewerDock );
-        }
-        else {
+        } else {
             delete viewerDock;
         }
-    }
-    else {
+    } else {
         dockWidgetMap.value ( theViewer )->show();
     }
 }
@@ -190,8 +188,7 @@ void MainWindow::redirectToConsole ( bool visible ) {
         cout.init ( &std::cout, consoleWindowTextEdit );
         cerr.init ( &std::cerr, consoleWindowTextEdit );
         std::cerr << Core::version << std::endl;
-    }
-    else {
+    } else {
         cout.free();
         cerr.free();
         // unplug it
@@ -244,8 +241,7 @@ void MainWindow::closeEvent(QCloseEvent* event) {
         settings.endGroup();
 
         event->accept();
-    }
-    else
+    } else
         event->ignore();
 
 }
