@@ -143,7 +143,7 @@ void SettingsDialog::updateComponentExtensionList() {
     // set the different columns text and pixmaps
     // columns: name, state (i.e loaded or not), extension, location
     int i;
-    for (i = 0;i < ceList.size();i++) {
+    for (i = 0; i < ceList.size(); i++) {
         ComponentExtension *ce = ceList.at(i);
         // set the icon depending if this is a system-wide component (camitk icon) or user settings (user icon)
         myUI->componentExtensionList->setItem(i, 0, new QTableWidgetItem((userComponents.contains(ce->getLocation()) ? QPixmap(":/user") : QPixmap(":/camiTKIcon")), ce->getName()));
@@ -152,7 +152,7 @@ void SettingsDialog::updateComponentExtensionList() {
     }
 
     // list all data directory plugin
-    for (;(i - ceList.size()) < ceddList.size();i++) {
+    for (; (i - ceList.size()) < ceddList.size(); i++) {
         ComponentExtension *ce = ceddList.at(i - ceList.size());
         myUI->componentExtensionList->setItem(i, 0, new QTableWidgetItem((userComponents.contains(ce->getLocation()) ? QPixmap(":/user") : QPixmap(":/camiTKIcon")), ce->getName()));
         myUI->componentExtensionList->setItem(i, 1, new QTableWidgetItem("[directory]"));
@@ -198,7 +198,7 @@ void SettingsDialog::updateActionExtensionList() {
 // ------------------------------ accept -------------------------------
 void SettingsDialog::accept() {
     if (objectController->isModified()) {
-        if (QMessageBox::question(this, "Unsaved changes", "There are unsaved changes in current item.\nIf you click \"Discard\" now, they will be discarded,\nif you click \"Apply\" they will be applied.", QMessageBox::Discard, QMessageBox::Apply) == QMessageBox::Apply)
+        if (QMessageBox::question(this, "Unsaved changes", tr("There are unsaved changes in current item.\nIf you click \"Discard\" now, they will be discarded,\nif you click \"Apply\" they will be applied."), QMessageBox::Discard, QMessageBox::Apply) == QMessageBox::Apply)
             objectController->apply();
     }
 
@@ -209,13 +209,12 @@ void SettingsDialog::accept() {
 void SettingsDialog::on_objectList_itemSelectionChanged() {
     if (myUI->objectList->selectedItems().size() > 0) {
         if (objectController->isModified()) {
-            if (QMessageBox::question(this, "Unsaved changes", "There are unsaved changes in current item.\nIf you click \"Discard\" now, they will be discarded,\nif you click \"Apply\" they will be applied.", QMessageBox::Discard, QMessageBox::Apply) == QMessageBox::Apply)
+            if (QMessageBox::question(this, "Unsaved changes", tr("There are unsaved changes in current item.\nIf you click \"Discard\" now, they will be discarded,\nif you click \"Apply\" they will be applied."), QMessageBox::Discard, QMessageBox::Apply) == QMessageBox::Apply)
                 objectController->apply();
         }
         QListWidgetItem * selected = myUI->objectList->selectedItems()[0];
         objectController->setObject(editedObjectMap.value(selected->text()));
-    }
-    else {
+    } else {
         objectController->setObject(NULL);
     }
 }
@@ -259,9 +258,8 @@ void SettingsDialog::on_addComponentExtensionButton_released() {
 
     while (it != pluginFile.end()) {
         if (!ExtensionManager::loadExtension(ExtensionManager::COMPONENT, *it)) {
-            QMessageBox::warning(this, "ComponentExtension Error", "Can't load plugin from file" + (*it) + "!\nTry recompile the plugin\n(plugin might be outdated)");
-        }
-        else {
+            QMessageBox::warning(this, "ComponentExtension Error", tr("Can't load plugin from file") + (*it) + tr("!\nTry recompile the plugin\n(plugin might be outdated)"));
+        } else {
             Application::showStatusBarMessage("Plugin " + (*it) + " loaded.");
             // Add the filename in the application settings: this is a manually loaded plugin, it should therefore
             // be kept in a list for the next run
@@ -310,9 +308,8 @@ void SettingsDialog::on_addActionExtensionButton_released() {
 
     while (it != pluginFile.end()) {
         if (!ExtensionManager::loadExtension(ExtensionManager::ACTION, *it)) {
-            QMessageBox::warning(this, "ActionExtension Error", "Can't load plugin from file" + (*it) + "!\nTry recompile the plugin\n(plugin might be outdated)");
-        }
-        else {
+            QMessageBox::warning(this, "ActionExtension Error", tr("Can't load plugin from file") + (*it) + tr("!\nTry recompile the plugin\n(plugin might be outdated)"));
+        } else {
             Application::showStatusBarMessage("Plugin " + (*it) + " loaded.");
             // Add the filename in the application settings: this is a manually loaded plugin, it should therefore
             // be kept in a list for the next run
@@ -341,7 +338,7 @@ void SettingsDialog::on_removeActionExtensionButton_released() {
             if (a->getName() != actionName)
                 actionNames << a->getName();
         }
-        reallyDelete = (QMessageBox::warning(this, "Removing multiple actions", "Removing action \"" + actionName + " \" will also remove the following actions:<ul><li>" + actionNames.join("</li><li>") + "</li></ul>Are you sure you want to delete all these actions?", QMessageBox::Yes | QMessageBox::Cancel) == QMessageBox::Yes);
+        reallyDelete = (QMessageBox::warning(this, "Removing multiple actions", tr("Removing action \"") + actionName + tr(" \" will also remove the following actions:<ul><li>") + actionNames.join("</li><li>") + tr("</li></ul>Are you sure you want to delete all these actions?"), QMessageBox::Yes | QMessageBox::Cancel) == QMessageBox::Yes);
     }
     if (reallyDelete) {
         ExtensionManager::unloadActionExtension(actionFileName);
