@@ -30,6 +30,7 @@
 #include "Property.h"
 #include "Application.h"
 #include "Action.h"
+#include "Frame.h"
 
 // -- QT stuff
 #include <QSet>
@@ -79,13 +80,18 @@ Component::~Component() {
         delete mySlice;
     mySlice = NULL;
 
+    // delete Frame
+    if ( myFrame )
+        delete myFrame;
+    myFrame = NULL;
+
     // remove from selection
     if ( isSelectedFlag )
         setSelected ( false, false );
-    
+
     // delete all properties
     foreach(Property* prop, propertyMap.values())
-        delete prop;
+    delete prop;
     propertyMap.clear();
 }
 
@@ -100,14 +106,20 @@ void Component::init() {
     // initialize representation
     myGeometry = NULL;
     mySlice = NULL;
+    myFrame = NULL;
     actionsMenu = NULL;
-    
+
+    // create the Frame (does not depend on any representation, should be created for any Component)
+    myFrame = new Frame();
+
     // initialize other state
     isSelectedFlag = false;
 
     // install a filter to get the modification of the dynamic properties (see event method)
     installEventFilter(this);
 
+    // by default, the 1st PropertyExplorer tab is displayed
+    this->setIndexOfPropertyExplorerTab(0);
 }
 
 
@@ -153,7 +165,7 @@ bool Component::event(QEvent * e) {
 // ---------------------- updateProperty ----------------------------
 void Component::updateProperty(QString name, QVariant value) {
     CAMITK_INFO("Component", "updateProperty", "The value of property \"" << name.toStdString() << "\" has changed to: \"" << value.toString().toStdString() << "\"" << endl << "If you want to take this change/property into account, please redefine method \"updateProperty(QString name, QVariant value)\" in class " << metaObject()->className());
-    
+
 }
 
 // ---------------------- setDynamicProperty ----------------------------
@@ -163,8 +175,7 @@ bool Component::setDynamicProperty(const char* name, const QVariant& value, cons
         propertyMap[name]->setDescription(description);
         propertyMap[name]->setReadOnly(isReadOnly);
         return getPropertyObject()->setProperty(name,value);
-    }
-    else {
+    } else {
         // the dynamic property does not exist => create a camitk::Property
         Property *dynProp = new Property(name,QVariant(value),description,"");
         dynProp->setReadOnly(isReadOnly);
@@ -180,13 +191,13 @@ Property* Component::getProperty(QString name) {
 // ---------------------- addProperty ----------------------------
 bool Component::addProperty(Property * prop) {
     // add a dynamic Qt Meta Object property with the same name
-    bool returnStatus = QObject::setProperty(prop->getName().toStdString().c_str(), prop->getInitialValue() );
+    bool returnStatus = setProperty(prop->getName().toStdString().c_str(), prop->getInitialValue() );
     // add to the map
     propertyMap.insert(prop->getName(),prop);
-    
+
     return returnStatus;
 }
-    
+
 // -------------------- isTopLevel --------------------
 bool Component::isTopLevel() const {
     return ( myParentNode == NULL );
@@ -194,7 +205,7 @@ bool Component::isTopLevel() const {
 
 // -------------------- setParent ------------------
 void Component::setParent(InterfaceNode * pes) {
-    if (myParentNode == pes)
+    if (myParentNode == pes || pes == this)
         return;
 
     if (myParentNode != NULL) {
@@ -202,8 +213,7 @@ void Component::setParent(InterfaceNode * pes) {
         myParentNode->removeChild(this);
         // avoid infinite recursion
         myParentNode = NULL;
-    }
-    else {
+    } else {
         // remove this from the top-level list if needed
         Application::getTopLevelComponentList().removeAll(this);
     }
@@ -230,8 +240,7 @@ void Component::setVisibility ( Viewer *v, bool b ) {
     if ( it == myViewers.end() ) {
         // insert the new viewer with the corresponding boolean
         myViewers.insert ( v, b );
-    }
-    else
+    } else
         it.value() = b;
 }
 
@@ -240,8 +249,7 @@ bool Component::getVisibility ( Viewer * v ) const {
     QMap<Viewer *, bool>::const_iterator it = myViewers.constFind ( v );
     if ( it == myViewers.end() ) {
         return false;
-    }
-    else
+    } else
         return it.value();
 }
 
@@ -297,8 +305,7 @@ Component::Representation Component::getRepresentation() const {
                 // the Component has to instanciate
                 CAMITK_ERROR("Component", "getRepresentation()", "Component class \"" << classname.toStdString() << "\" implements service " << representationString.toStdString() << " but does not instanciate it!" << std::endl
                              << "\tPlease instanciate " <<  shouldInstanciateMember.toStdString() << " in initRepresentation() or change the implemented representation in the constructor.");
-            }
-            else {
+            } else {
                 // no representation should be instanciated!
                 CAMITK_ERROR("Component", "getRepresentation()", "Component class \"" << classname.toStdString() << "\" has no implemented representation (NO_REPRESENTATION) but " << instanciatedMember.toStdString() << " is instanciated. Please do not instanciate " << instanciatedMember.toStdString() << " in initRepresentation() or change the implemented service in the constructor.");
             }
@@ -310,66 +317,106 @@ Component::Representation Component::getRepresentation() const {
 // ---------------- actionLessThan ----------------
 extern bool actionLessThan(const camitk::Action* a1, const camitk::Action * a2);
 
+// -------------------- getActionMenu -----------------------
+QMenu* Component::getActionMenu() {
+
+    if (actionsMenu == NULL) {
+        actionsMenu = new QMenu();
+
+        //-- add all actions sorted by family
+        ActionList allActions = Application::getActions(this);
+        QMap<QString, ActionSet*> familyMap;
+        foreach(Action *action, allActions) {
+            ActionSet* familySet = familyMap.value(action->getFamily().toLower());
+            if (!familySet) {
+                familySet = new ActionSet;
+                familyMap.insert(action->getFamily().toLower(), familySet);
+            }
+            familySet->insert(action);
+        }
+
+        //-- create one sub menu per family (unless there is only one action)
+        foreach(ActionSet * familySet, familyMap.values()) {
+            // sort actions by name
+            ActionList familyList = familySet->toList();
+            qSort(familyList.begin(), familyList.end(), actionLessThan);
+            if (familyList.size() >= 1) {
+                QMenu *familyMenu = actionsMenu->addMenu(familyList.first()->getFamily());
+                foreach(Action* action, familyList) {
+                    familyMenu->addAction(action->getQAction());
+                }
+            } else
+                actionsMenu->addAction(familyList.first()->getQAction());
+        }
+
+        // no menu if no action
+        if (actionsMenu->actions().size() == 0) {
+            delete actionsMenu;
+            actionsMenu = NULL;
+        }
+    }
+    return actionsMenu;
+}
 // -------------------- getActionAndPopupMenu --------------------
+//TODO remove in CamiTK 4.0 CAMITK_DEPRECATED
 QMenu* Component::getActionAndPopupMenu() {
 
     if (actionsMenu == NULL) {
         actionsMenu = new QMenu();
 
-	//-- add all actions sorted by family
-	ActionList allActions = Application::getActions(this);
-	QMap<QString, ActionSet*> familyMap;
-	foreach (Action *action, allActions) {
-	    ActionSet* familySet = familyMap.value(action->getFamily().toLower());
-	    if (!familySet) {
-			familySet = new ActionSet;
-			familyMap.insert(action->getFamily().toLower(),familySet);
-	    }
-	    familySet->insert(action);
-	}
-	
-	// for family with only one action, modify family name so that sorting in the menu will appear correct
-	// (as the only visible item will not be the menu but the action's name itself)
-// 	foreach (ActionSet * familySet, familyMap.values()) {
-// 	    if (familySet->size()==1) {
-// 		// remove the family => why ? It's alwalys less messy to filter action by family, no ?
-// 		familyMap.remove((*familySet->begin())->getFamily().toLower());
-// 		// reinsert it but with the action's name as key
-// 		familyMap.value(0).insert((*familySet->begin())->getName().toLower(),familySet);
-// 	    }
-// 	}
-	
-	//-- create one sub menu per family (unless there is only one action)
-	foreach (ActionSet * familySet, familyMap.values()) {
-		// sort actions by name    
-		ActionList familyList = familySet->toList();
-		qSort(familyList.begin(), familyList.end(), actionLessThan);
-		if (familyList.size()>=1) {
-			QMenu *familyMenu = actionsMenu->addMenu(familyList.first()->getFamily());
-			foreach (Action* action, familyList) {
-				familyMenu->addAction(action->getQAction());
-			}
-		}
-		else
-			actionsMenu->addAction(familyList.first()->getQAction());
-	}
+        //-- add all actions sorted by family
+        ActionList allActions = Application::getActions(this);
+        QMap<QString, ActionSet*> familyMap;
+        foreach (Action *action, allActions) {
+            ActionSet* familySet = familyMap.value(action->getFamily().toLower());
+            if (!familySet) {
+                familySet = new ActionSet;
+                familyMap.insert(action->getFamily().toLower(),familySet);
+            }
+            familySet->insert(action);
+        }
 
-	// add popup action
-	QMenu *popup = getPopupMenu();
-	if (popup && popup->actions().size() > 0) {
-		if (allActions.size() > 0)
-			actionsMenu->addSeparator();
-		
-		foreach (QAction * action, popup->actions()) {
-			actionsMenu->addAction ( action );
-		}
-	}
+        // for family with only one action, modify family name so that sorting in the menu will appear correct
+        // (as the only visible item will not be the menu but the action's name itself)
+//     foreach (ActionSet * familySet, familyMap.values()) {
+//         if (familySet->size()==1) {
+//         // remove the family => why ? It's alwalys less messy to filter action by family, no ?
+//         familyMap.remove((*familySet->begin())->getFamily().toLower());
+//         // reinsert it but with the action's name as key
+//         familyMap.value(0).insert((*familySet->begin())->getName().toLower(),familySet);
+//         }
+//     }
 
-	// no menu if no action
-	if (actionsMenu->actions().size() == 0) {
-		delete actionsMenu;
-		actionsMenu = NULL;
-	}
+        //-- create one sub menu per family (unless there is only one action)
+        foreach (ActionSet * familySet, familyMap.values()) {
+            // sort actions by name
+            ActionList familyList = familySet->toList();
+            qSort(familyList.begin(), familyList.end(), actionLessThan);
+            if (familyList.size()>=1) {
+                QMenu *familyMenu = actionsMenu->addMenu(familyList.first()->getFamily());
+                foreach (Action* action, familyList) {
+                    familyMenu->addAction(action->getQAction());
+                }
+            } else
+                actionsMenu->addAction(familyList.first()->getQAction());
+        }
+
+        // add popup action
+        QMenu *popup = getPopupMenu();
+        if (popup && popup->actions().size() > 0) {
+            if (allActions.size() > 0)
+                actionsMenu->addSeparator();
+
+            foreach (QAction * action, popup->actions()) {
+                actionsMenu->addAction ( action );
+            }
+        }
+
+        // no menu if no action
+        if (actionsMenu->actions().size() == 0) {
+            delete actionsMenu;
+            actionsMenu = NULL;
+        }
     }
     return actionsMenu;
 }
@@ -378,9 +425,9 @@ QMenu* Component::getActionAndPopupMenu() {
 
 
 // -----------------------------------------------------------------------
-//                                                                         
-//                        InterfaceGeometry methods                        
-//                                                                         
+//
+//                        InterfaceGeometry methods
+//
 // -----------------------------------------------------------------------
 
 
@@ -409,8 +456,7 @@ void Component::getActorColor ( InterfaceGeometry::RenderingModes m, double d[4]
     if ( myGeometry ) {
         // get the color of myGeometry, is exists, and finished
         myGeometry->getActorColor ( m, d );
-    }
-    else {
+    } else {
         // return the firts existing Color in my children
         int i = 0;
         bool found = false;
@@ -420,7 +466,7 @@ void Component::getActorColor ( InterfaceGeometry::RenderingModes m, double d[4]
             i++;
         }
         if ( !found ) {
-            for ( unsigned int j = 0;j < 4;j++ )
+            for ( unsigned int j = 0; j < 4; j++ )
                 d[j] = 0.0;
         }
     }
@@ -438,7 +484,7 @@ void Component::getBounds ( double *bounds ) {
             // get child bounds
             childComponent->getBounds ( childBounds );
             // check compared to global bound
-            for ( int i = 0;i < 3;i++ ) {
+            for ( int i = 0; i < 3; i++ ) {
                 // compare min
                 if ( bounds[i*2] > childBounds[i*2] )
                     bounds[i*2] = childBounds[i*2];
@@ -473,9 +519,9 @@ double Component::getBoundingRadius() {
 
 
 // -----------------------------------------------------------------------
-//                                                                       
-//                        InterfaceBitMap methods                        
-//                                                                       
+//
+//                        InterfaceBitMap methods
+//
 // -----------------------------------------------------------------------
 
 
