@@ -31,11 +31,14 @@
 #include "InterfaceGeometry.h"
 #include "InterfaceBitMap.h"
 #include "InterfaceProperty.h"
+#include "InterfaceFrame.h"
 #include "AbortException.h"
+#include "Log.h"
 
 // -- QT stuff
 #include <QPixmap>
 #include <QMenu>
+#include <QVector>
 
 // -- vtk stuff
 #include <vtkWindowLevelLookupTable.h>
@@ -44,10 +47,13 @@
 #include <vtkSmartPointer.h>
 #include <vtkAlgorithmOutput.h>
 #include <vtkActor.h>
+#include <vtkAxesActor.h>
 #include <vtkActor2D.h>
 #include <vtkImageActor.h>
+#include <vtkTransform.h>
 
 // -- vtk stuff Classes
+class vtkActor;
 class vtkTexture;
 class vtkPointSet;
 class vtkUnstructuredGridAlgorithm;
@@ -250,13 +256,14 @@ namespace camitk {
 class Geometry;
 class Slice;
 class Viewer;
+class Frame;
 
 
-/** 
-* 
+/**
+*
 * @ingroup group_sdk_libraries_core_component
-* 
-* @brief 
+*
+* @brief
 * A Component represents something that
 * could be included in the explorer view, the interactive 3D viewer,
 * and that could have or not a contextual
@@ -289,7 +296,7 @@ class Viewer;
 *
 *
 */
-class CAMITK_API Component : public InterfaceProperty, public InterfaceNode, public InterfaceGeometry, public InterfaceBitMap {
+class CAMITK_API Component : public InterfaceProperty, public InterfaceNode, public InterfaceGeometry, public InterfaceBitMap, public InterfaceFrame {
     Q_OBJECT
 
 public:
@@ -343,6 +350,9 @@ public:
     /// get the top-level component
     virtual Component * getTopLevelComponent();
 
+    /// get the associated frame
+    virtual InterfaceFrame * getFrame();
+
     /// set the modified flag
     virtual void setModified(bool modified = true);
 
@@ -384,11 +394,8 @@ public:
     /// Overriden from QObject, this one is only intercepting signal for dynamic property changed (see constructor).
     bool event(QEvent* e);
 
-    /** Get a QMenu that contains all the action that can be applied to this component + the popup menu (if exists).
-     * This method will be soon deprecated and be replaced by getPopupMenu, which will not be maintain in its current
-     * version). You are encourage to build Action not getPopupMenu() anymore.
-     */
-    QMenu * getActionAndPopupMenu();
+    /// Get a QMenu that contains all the action that can be applied to this component.
+    QMenu * getActionMenu();
     ///@}
 
     /**
@@ -460,13 +467,13 @@ public:
     void updateProperty(QString name, QVariant value);
 
     ///@cond
-    // TODO CAMITK_DEPRECATED. This section list all the methods marked as deprecated. They are to be removed in CamiTK 4.0    
+    // TODO CAMITK_DEPRECATED. This section list all the methods marked as deprecated. They are to be removed in CamiTK 4.0
     /** specific setProperty method that can pass the description and the readOnly property.
      *  If the property already exists, it will just change its value (and descripion or readOnly property).
      * @deprecated
      *  This method is deprecated.\n
      *  Use addProperty(Property *) instead.
-     * 
+     *
      *  @param name the name of the property
      *  @param value the new value for the given property
      *  @param description the description associated with this property
@@ -474,27 +481,56 @@ public:
      *  @return false if the Qt Meta Object property was added by this method (otherwise the property was already defined and true is returned if it was successfully updated
      */
     virtual bool setDynamicProperty(const char *name, const QVariant &value, const char *description = "", bool isReadOnly=false);
+
+    /**
+     * Set the index of the tab in the ProperlyExplorer to select for display.
+     * The ProperlyExplorer may features several tabs of widget.
+     * This method allows to select the one to select for display in a given context.
+     * @param index the index to select in the tab of the ProperlyExplorer.
+     * @see PropertyExplorer
+     **/
+    virtual inline void setIndexOfPropertyExplorerTab(unsigned int index) {
+        this->indexOfPropertyExplorerTab = index;
+    }
+
+    /**
+     * Get the index of the tab in the ProperlyExplorer to select for display.
+     * The ProperlyExplorer may features several tabs of widget.
+     * This method allows to select the one to select for display in a given context.
+     * @return the index to select in the tab of the ProperlyExplorer.
+     * @see PropertyExplorer
+     **/
+    virtual inline unsigned int getIndexOfPropertyExplorerTab() {
+        return this->indexOfPropertyExplorerTab;
+    }
+
+    /** Deprecated.
+    * Get a QMenu that contains all the action that can be applied to this component + the popup menu (if exists).
+    * This method will be soon deprecated and be replaced by getPopupMenu, which will not be maintain in its current
+    * version). You are encourage to build Action not getPopupMenu() anymore.
+    */
+    QMenu * getActionAndPopupMenu();
     ///@}
     ///@endcond
-    
+
     /** Get a Property given its name
      *  @param name the property name
      *  @return NULL if the name does not match any property name
-     * 
+     *
      *  @see Property
      */
     Q_INVOKABLE virtual Property* getProperty(QString name);
-    
+
     /** Add a new CamiTK property to the component.
      * If the property already exist, it will just change its value.
-     * 
+     *
      * \note
      * The component takes ownership of the Property instance.
-     * 
+     *
      * @return false if the Qt Meta Object property was added by this method (otherwise the property was already defined and true is returned if it was successfully updated)
      */
     virtual bool addProperty(Property*);
-    
+
     /**
       * @name InterfaceNode
       * All the implemented InterfaceNode methods
@@ -556,8 +592,7 @@ public:
 
     // TODO : uses an object myRepresentation (which is a Geometry or a Slice)
     // to use a single delegate macro
-    virtual vtkSmartPointer<vtkProp> getProp(const QString &param)
-    {
+    virtual vtkSmartPointer<vtkProp> getProp(const QString &param) {
         if (myGeometry)
             return myGeometry->getProp(param);
         else if(mySlice)
@@ -603,12 +638,12 @@ public:
     /** an inherited class can redefine this method something specific.
      *  Default behaviour: do nothing.
      */
-    virtual void pointPicked(vtkIdType, bool) {};
+    virtual void pointPicked(vtkIdType, bool) {}
 
     /** an inherited class can redefine this method something specific.
      *  Default behaviour: do nothing.
      */
-    virtual void cellPicked(vtkIdType, bool) {};
+    virtual void cellPicked(vtkIdType, bool) {}
 
     // --
 
@@ -620,9 +655,9 @@ public:
       */
     virtual double getBoundingRadius();
 
-    delegate4(myGeometry, setPointPosition, const unsigned int, const double, const double, const double);
+    delegate4(myGeometry, setPointPosition, const unsigned int, const double, const double, const double)
 
-    delegateAndInvokeChildren1(myGeometry, setRenderingModes, const RenderingModes);
+    delegateAndInvokeChildren1(myGeometry, setRenderingModes, const RenderingModes)
 
     /// see Component.cpp
     virtual const InterfaceGeometry::RenderingModes getRenderingModes() const;
@@ -654,7 +689,9 @@ public:
 
     virtual void setGlyphType(const GlyphTypes type, const double size = 0.0);
 
-    delegate1(myGeometry, setLinesAsTubes, bool);
+    delegate1(myGeometry, setLinesAsTubes, bool)
+
+    delegate1(myGeometry, setMeshWorldTransform, vtkSmartPointer<vtkTransform>)
 
     ///@}
 
@@ -675,13 +712,15 @@ public:
 
     delegateGet0(mySlice, getPixelActor, vtkSmartPointer<vtkActor>)
 
+//    delegateGet0(mySlice, get2DAxesActor, vtkSmartPointer<vtkAxesActor>)
+
     delegate3(mySlice, pixelPicked, double, double, double)
 
     delegate0(mySlice, updatePickPlane)
 
-    delegate1(mySlice, setSlice, int);
+    delegate1(mySlice, setSlice, int)
 
-    delegate3(mySlice, setSlice, double, double, double);
+    delegate3(mySlice, setSlice, double, double, double)
 
     delegate1(mySlice, setRotationX, double)
 
@@ -691,7 +730,9 @@ public:
 
     delegateConstGet0(mySlice, getNumberOfColors, int)
 
-    delegate3(mySlice, setPixelRealPosition, double, double, double);
+    delegate3(mySlice, setPixelRealPosition, double, double, double)
+
+    delegate1(mySlice, setImageWorldTransform, vtkSmartPointer<vtkTransform>)
 
     /// see Component.cpp
     virtual double getRotationX() const;
@@ -710,6 +751,87 @@ public:
     ///@}
 
 
+    /**
+     * @name InterfaceFrame
+     * All the implemented InterfaceFrame methods
+     */
+    ///@{
+    const QString & getFrameName() const {
+        if(!myFrame)
+            CAMITK_ERROR("Component", "getFrameName", "Delegate myFrame is not instanciated.")
+            return myFrame->getFrameName();
+    }
+
+    delegate1(myFrame, setFrameName, QString)
+
+    InterfaceFrame* getParentFrame() const {
+        if(!myFrame)
+            CAMITK_ERROR("Component", "getParentFrame", "Delegate myFrame is not instanciated.")
+            return myFrame->getParentFrame();
+    }
+
+    void setParentFrame(InterfaceFrame* frame, bool keepTransform = true) {
+        if(!myFrame)
+            CAMITK_ERROR("Component", "setParentFrame", "Delegate myFrame is not instanciated.")
+            return myFrame->setParentFrame(frame, keepTransform);
+    }
+
+    const QVector<InterfaceFrame *> & getChildrenFrame() const {
+        if(!myFrame)
+            CAMITK_ERROR("Component", "getChildrenFrame", "Delegate myFrame is not instanciated.")
+            return myFrame->getChildrenFrame();
+    }
+
+    const vtkSmartPointer<vtkTransform> getTransformFromWorld() const {
+        if(!myFrame)
+            CAMITK_ERROR("Component", "getTransformFromWorld", "Delegate myFrame is not instanciated.")
+            return myFrame->getTransformFromWorld();
+    }
+
+    const vtkSmartPointer<vtkTransform> getTransform() const {
+        if(!myFrame)
+            CAMITK_ERROR("Component", "getTransform", "Delegate myFrame is not instanciated.")
+            return myFrame->getTransform();
+    }
+
+    const vtkSmartPointer<vtkTransform> getTransformFromFrame(InterfaceFrame * frame) const {
+        if(!myFrame)
+            CAMITK_ERROR("Component", "getTransformFromFrame", "Delegate myFrame is not instanciated.")
+            return myFrame->getTransformFromFrame(frame);
+    }
+
+    delegate1(myFrame, setTransform, vtkSmartPointer<vtkTransform>)
+
+    delegate0(myFrame, resetTransform)
+
+    delegate3(myFrame, translate, double, double, double)
+
+    delegate3(myFrame, rotate, double, double, double)
+
+    delegate3(myFrame, setTransformTranslation, double, double, double)
+
+    delegate3(myFrame, setTransformRotation, double, double, double)
+
+    vtkSmartPointer<vtkAxesActor> getFrameAxisActor() {
+        if(!myFrame)
+            CAMITK_ERROR("Component", "getFrameAxisActor", "Delegate myFrame is not instanciated.")
+            return myFrame->getFrameAxisActor();
+    }
+
+    delegate2(myFrame, setFrameVisibility, Viewer *, bool)
+
+    bool getFrameVisibility(Viewer * viewer) const {
+        if(!myFrame)
+            CAMITK_ERROR("Component", "getFrameVisibility", "Delegate myFrame is not instanciated.")
+            return myFrame->getFrameVisibility(viewer);
+    }
+
+    delegate1(myFrame, addFrameChild, InterfaceFrame *)
+
+    delegate1(myFrame, removeFrameChild, InterfaceFrame *)
+    ///@}
+
+
 protected:
     /// myGeometry is the 3d representation of this Component, the Component delegates all InterfaceGeometry activity to myGeometry (delegation pattern)
     InterfaceGeometry * myGeometry;
@@ -720,6 +842,9 @@ protected:
     /// who is the boss? The Component!
     InterfaceNode * myParentNode;
 
+    /// myFrame is the pose (position and orientation) of the Component in the world frame, the Component delegates all InterfaceFrame activity to myFrame (delegation pattern)
+    InterfaceFrame * myFrame;
+
     /// The explorer sub items
     ComponentList childrenComponent;
 
@@ -732,6 +857,9 @@ protected:
     /// the file name from which the Component is loaded
     QString myFileName;
 
+    /// The PropertyExplorer tab index to select once refreshed
+    unsigned int indexOfPropertyExplorerTab;
+
 
 private:
     /** @name Instance members
@@ -748,7 +876,7 @@ private:
     QString myName;
 
     /** Instanciate the concrete representation (either InterfaceGeometry or InterfaceBitMap) if needed.
-      * This method have to instanciate Slice (mySlice) or Geometry (myGeometry) that does all the work for this Component, i.e. the adaptee handler.
+      * This method has to instanciate Slice (mySlice) or Geometry (myGeometry) that does all the work for this Component, i.e. the adaptee handler.
       * Generally this method should be called in the Component constructor.
       */
     virtual void initRepresentation() = 0;
@@ -758,7 +886,7 @@ private:
 
     /// the action menu for this component
     QMenu * actionsMenu;
-    
+
     /// list of CamiTK property decorating the dynamic properties
     QMap<QString, Property*> propertyMap;
     ///@}
@@ -800,6 +928,11 @@ inline InterfaceNode * Component::getParent() {
     return ((Component*) myParentNode);
 }
 
+// -------------------- getFrame --------------------
+inline InterfaceFrame * Component::getFrame() {
+    return myFrame;
+}
+
 // -------------------- getPixmap ------------------
 inline QPixmap Component::getIcon() {
     return NULL;
