@@ -25,6 +25,8 @@
 
 // -- Core stuff
 #include "ComponentExtension.h"
+#include "Application.h"
+#include "Log.h"
 
 // -- QT stuff
 #include <QDir>
@@ -45,12 +47,28 @@ ComponentExtension::~ComponentExtension() {
 bool ComponentExtension::save(Component* component) const {
     QString extension = QFileInfo(component->getFileName()).completeSuffix();
 
-    QMessageBox::warning(NULL, "Saving Error", "Extension " + getName() + " can not export the component:<br/>\""
-    + component->getName() + "\"<br/>To the file format \"." + extension + "\"<br>This is not implemented yet.");
+    QMessageBox::warning(NULL, "Saving Error", tr("Extension ") + getName() + tr(" can not export the component:<br/>\"")
+                         + component->getName() + tr("\"<br/>To the file format \".") + extension + tr("\"<br>This is not implemented yet."));
 
     return false;
 }
 
+// -------------------- initResources --------------------
+void ComponentExtension::initResources() {
+    // Get the selected language
+    QString selectedLanguage = Application::getSelectedLanguage();
+
+    QString componentExtensionDirName = QDir(this->getLocation()).dirName();
+    // remove any occurence of "-debug.dll" or ".so" or ".dylib" on the extension file name
+    componentExtensionDirName.remove("-debug.dll").remove(".so").remove(".dylib");
+    QString languageFile = ":/translate_" + componentExtensionDirName + "/translate/translate_" + selectedLanguage + ".qm";
+    QTranslator* translator = new QTranslator();
+    if (!translator->load(languageFile))
+        CAMITK_WARNING("Application", "initResources", "Cannot load file: " + languageFile.toStdString())
+        else
+            QCoreApplication::installTranslator(translator);
+}
+
 
 
 }
