@@ -39,23 +39,23 @@
 #include <QMap>
 
 namespace camitk {
-/** 
+/**
   * @ingroup group_sdk_libraries_core_component
-  * 
-  * @brief 
+  *
+  * @brief
   * This class describes what is a generic Component extension.
   * To add a ComponentExtension to CamiTK core, write a new class that inherits from this class.
   *
   * There are two types of component extension: the classical one manages (mime type) file extension,
   * the other one manages all files in a given directory (e.g. Dicom images). For the latter you have
   * to redefine hasDataDirectory().
-  * 
+  *
   * The following methods HAVE to be redefined in your subclass:
   * - getName
   * - getDescription
   * - getFileExtensions
   * - open
-  * 
+  *
   * The following methods can be redefined:
   * - save: saving from a Component to one of the managed format
   * - hasDataDirectory: for directory type extension
@@ -84,7 +84,7 @@ public:
     virtual QStringList getFileExtensions() const = 0;
 
     /** get a new instance from data stored in a file (this is the most important method to redefine in your subclass)
-     * 
+     *
      *  \note The parameter is a filename with an absolute path (from Qt's QFileInfo::absoluteFilePath method):
      *   On Unix (including Mac OS) this will always begin with the root, '/', directory.
      *   On Windows this will always begin 'D:/' where D is a drive letter, except for network shares that are not mapped to a drive letter,
@@ -111,7 +111,7 @@ public:
      *  @return false if the operation was not performed properly or not performed at all.
      */
     virtual bool save(Component * component) const;
-    
+
     /// return true if this component manages directory instead of individual files (e.g. Dicom series are stored in directories, not files)
     virtual bool hasDataDirectory() const {
         return false;
@@ -126,7 +126,10 @@ public:
     void setLocation(const QString loc) {
         dynamicLibraryFileName = loc;
     }
-    
+
+    /// Load, for the selected langage (asked to the Application), the associated .qm file
+    void initResources();
+
     /// @}
 
 
