@@ -30,26 +30,24 @@
 // -- QT stuff
 #include <QMenu>
 
-namespace camitk
-{
+namespace camitk {
 //-------------------------- constructor -------------------------------
-ComponentPopupMenu::ComponentPopupMenu(Component *comp, QWidget* parent) : QMenu(comp->getName(), parent)
-{
-  // store my data component
-  myComponent = comp;
+ComponentPopupMenu::ComponentPopupMenu(Component *comp, QWidget* parent) : QMenu(comp->getName(), parent) {
+    // store my data component
+    myComponent = comp;
 }
 
 //-------------------------- addAction -------------------------------
 QAction * ComponentPopupMenu::addAction(const QString name, const char * member, bool isCheckable) {
-  QAction *action = QMenu::addAction(name, this, member);
-  action->setCheckable(isCheckable);
-  return action;
+    QAction *action = QMenu::addAction(name, this, member);
+    action->setCheckable(isCheckable);
+    return action;
 }
 
 
 //-------------------------- addSeparator -------------------------------
 QAction* ComponentPopupMenu::addSeparator() {
-  return QMenu::addSeparator();
+    return QMenu::addSeparator();
 }
 
 }
