@@ -36,8 +36,7 @@
 class vtkTransform;
 
 
-namespace camitk
-{
+namespace camitk {
 // -- Core stuff classes
 class Component;
 
@@ -45,8 +44,8 @@ class Component;
   * \note this class is deprecated, please use the Action framework.
   *
   * @ingroup group_sdk_libraries_core_component
-  * 
-  * @brief 
+  *
+  * @brief
   * Generic class for Component popup menu.
   * To create your own Component popup, create a class that inherits from this one. Your class could have as many
   * slot that you want. Create popup menu item and connect your slot using the addAction method.
@@ -57,46 +56,46 @@ class Component;
   * // -- ExampleComponentPopup.h
   * // ---------------------------
   * #include <ComponentPopupMenu.h>
-  * 
+  *
   * class ExampleComponentPopup : public camitk::ComponentPopupMenu  {
   *   Q _ OBJECT  // note: the spaces around the underscore have to be removed
-  * 
+  *
   *   public:
   *     ExampleComponentPopup(camitk::Component *, QWidget*);
-  * 
+  *
   *   public slots:
   *     void test();
   * };
-  * 
+  *
   * // -----------------------------
   * // -- ExampleComponentPopup.cpp
   * // -----------------------------
-  * 
+  *
   * #include "ExampleComponentPopup.h"
   * #include "ExampleComponent.h"
   * #include <QMessageBox>
   * using namespace camitk;
-  * 
+  *
   * ExampleComponentPopup::ExampleComponentPopup(Component *comp, QWidget *parent) : ComponentPopupMenu(comp,parent) {
   *   addAction("action test", SLOT(test()), true);
   * }
-  * 
+  *
   * void ExampleComponentPopup::test() {
-  *   // if you want to do something specific to the ExampleComponent class, then you can 
+  *   // if you want to do something specific to the ExampleComponent class, then you can
   *   // safely use dynamic cast as this:
   *   // ExampleComponent *comp = dynamic_cast<ExampleComponent*>(myComponent);
   *   // comp->specificMethodOfExampleComponent(...)
-  *   
+  *
   *   QString testMessage;
-  * 
-  *   // myComponent is known here, so we could ask for its name 
+  *
+  *   // myComponent is known here, so we could ask for its name
   *   // getName() is a generic Component method, not specific to ExampleComponent, no need to use dynamic_cast here
   *   testMessage = QString("This is a test on \"%1\" .\nNice isn't it?").arg(QString(myComponent->getName()));
-  *   
+  *
   *   QMessageBox::information( 0, "Test", testMessage);
-  * 
+  *
   * }
-  * 
+  *
   * // ----------------------
   * // -- ExampleComponent.h
   * // ----------------------
@@ -109,7 +108,7 @@ class Component;
   *   // the popup menu
   *   QMenu * myPopupMenu;
   * ...
-  * 
+  *
   * // ------------------------
   * // -- ExampleComponent.cpp
   * // ------------------------
@@ -127,23 +126,23 @@ class Component;
   *   if (!myPopupMenu) {
   *     myPopupMenu = new ExampleComponentPopup(this,parent);
   *   }
-  * 
+  *
   *   return myPopupMenu;
   * }
-  * 
+  *
   * ...
   * \endcode
-  * 
   *
-  * 
+  *
+  *
   */
 class CAMITK_API ComponentPopupMenu : public QMenu {
 
-  public:
+public:
     /// default constructor
     ComponentPopupMenu(Component *, QWidget*);
 
-  protected:
+protected:
     /** Add a new item to the popup menu)
       *  @param name string that will appears as the name of the menu item
       *  @param member is the slot to be connected to this action (slot that should be implemented in your subclass)
