@@ -38,35 +38,34 @@ class vtkPolyDataAlgorithm;
 class vtkActor;
 class vtkPolyDataMapper;
 
-namespace camitk
-{
-/** 
+namespace camitk {
+/**
  * @ingroup group_sdk_libraries_core_component
- * 
- * @brief 
- * A geometric object allows to create geometric object (sphere, arrow, ...) that can be
+ *
+ * @brief
+ * A geometric object allows one to create geometric object (sphere, arrow, ...) that can be
  * added directly in the scene using getActor().
  *
  * This is a pure vtk wrapper class (no Core stuff).
  *
- *  
+ *
  */
 
 class  CAMITK_API GeometricObject {
-  public:
+public:
 
     /// the geometric type
     enum Geometry {
-      ARROW,  ///< an arrow
-      SPHERE ///< a sphere (this is also the default)
+        ARROW,  ///< an arrow
+        SPHERE ///< a sphere (this is also the default)
     };
 
     /// possible direction of an object
     enum Direction {
-      X, ///< the object in the X direction, size = 0.1
-      Y, ///< the object in the Y direction, size = 0.1
-      Z, ///< the object in the Z direction, size = 0.1
-      USER_DEFINED /// < the object direction is defined by the user
+        X, ///< the object in the X direction, size = 0.1
+        Y, ///< the object in the Y direction, size = 0.1
+        Z, ///< the object in the Z direction, size = 0.1
+        USER_DEFINED /// < the object direction is defined by the user
     };
 
     /** constructor by default of a geometric object of type given in parameters.
@@ -116,7 +115,7 @@ class  CAMITK_API GeometricObject {
     /// return the type
     Geometry getType() const;
 
-  private:
+private:
 
     /// Bounding box of the object [xmin,xmax, ymin,ymax, zmin,zmax]
     float bounds[6];
@@ -144,7 +143,7 @@ class  CAMITK_API GeometricObject {
 };
 
 inline GeometricObject::Geometry GeometricObject::getType() const {
-  return myType;
+    return myType;
 }
 
 }
