@@ -48,6 +48,7 @@
 #include <vtkViewport.h>
 #include <vtkMath.h>
 #include <vtkLookupTable.h>
+#include <vtkTransformFilter.h>
 
 namespace camitk {
 //------------------------------- constructor ----------------------------------------
@@ -62,15 +63,11 @@ Geometry::Geometry(QString label, vtkSmartPointer<vtkPointSet> pointSetPtr, cons
     // TODO use a MeshUtil class for typeOf?
     if (pointSetPtr->IsA("vtkPolyData")) {
         this->pointSet = vtkSmartPointer<vtkPolyData>::New();
+    } else if (pointSetPtr->IsA("vtkUnstructuredGrid")) {
+        this->pointSet = vtkSmartPointer<vtkUnstructuredGrid>::New();
+    } else if (pointSetPtr->IsA("vtkStructuredGrid")) {
+        this->pointSet = vtkSmartPointer<vtkStructuredGrid>::New();
     }
-    else
-        if (pointSetPtr->IsA("vtkUnstructuredGrid")) {
-            this->pointSet = vtkSmartPointer<vtkUnstructuredGrid>::New();
-        }
-        else
-            if (pointSetPtr->IsA("vtkStructuredGrid")) {
-                this->pointSet = vtkSmartPointer<vtkStructuredGrid>::New();
-            }
     // Disconnect the previous Vtk Pipeline without memcopy
     // (equivalent of ITK DisconnectPipeline()...)
     // Note : this (i.e disconnect/deepcopy/shallowcopy) should not have to be done
@@ -87,12 +84,13 @@ Geometry::Geometry(QString label, vtkSmartPointer<vtkPointSet> pointSetPtr, cons
     pointsActor = NULL;
     tube = NULL;
     texture = NULL;
+    worldTransformFilter = NULL;
 
     // display options
     enhancedModes = InterfaceGeometry::Normal;
 
     //-- init color
-    for (unsigned int i = 0; i < 3;i++)
+    for (unsigned int i = 0; i < 3; i++)
         surfaceColor[i] = 0.8;
     surfaceColor[3] = 1.0;
 
@@ -111,7 +109,15 @@ Geometry::Geometry(QString label, vtkSmartPointer<vtkPointSet> pointSetPtr, cons
     //-- init generic filter and dataOutput and customPipelineOuput
     concreteData = vtkSmartPointer<vtkCastToConcrete>::New();
     concreteData->SetInput(this->pointSet);
-    dataOutput = concreteData->GetOutputPort();
+
+    worldTransformFilter = vtkSmartPointer<vtkTransformFilter>::New();
+    vtkSmartPointer<vtkTransform> transform = vtkSmartPointer<vtkTransform>::New();
+    transform->Identity();
+    worldTransformFilter->SetTransform(transform);
+    worldTransformFilter->SetInputConnection(concreteData->GetOutputPort());
+
+//    dataOutput = concreteData->GetOutputPort();
+    dataOutput = worldTransformFilter->GetOutputPort();
     customPipelineOutput = dataOutput;
 
     //-- init mapper
@@ -119,7 +125,7 @@ Geometry::Geometry(QString label, vtkSmartPointer<vtkPointSet> pointSetPtr, cons
     mapper->SetInputConnection(customPipelineOutput);
     mapper->ImmediateModeRenderingOn();
     mapper->SetResolveCoincidentTopologyToPolygonOffset();
-    
+
     // set the rainbow lookup table from blue to red
     vtkSmartPointer<vtkLookupTable> lut = vtkSmartPointer<vtkLookupTable>::New();
     lut->SetHueRange(0.667,0.0);
@@ -143,7 +149,7 @@ Geometry::~Geometry() {
         // remove the prop from any renderer/consummers
         vtkSmartPointer<vtkProp> prop = extraProp.value(i.key());
         prop->VisibilityOff();
-        for (int ic = 0;ic < prop->GetNumberOfConsumers();ic++) {
+        for (int ic = 0; ic < prop->GetNumberOfConsumers(); ic++) {
             vtkViewport *viewer = vtkViewport::SafeDownCast(prop->GetConsumer(ic));
             if (viewer)
                 viewer->RemoveViewProp(prop);
@@ -169,6 +175,15 @@ void Geometry::setPointSet(vtkSmartPointer<vtkPointSet> ps) {
     setGlyphType(InterfaceGeometry::Sphere);
 }
 
+//------------------------------- setMeshWorldTransform ----------------------------------------
+void Geometry::setMeshWorldTransform(vtkSmartPointer<vtkTransform> transform) {
+    // Do not delete vtkSmartTransform previous transform, but set it to NULL to
+    // decrement its counter
+//    worldTransformFilter->GetTransform()->Delete();
+
+    worldTransformFilter->SetTransform(transform);
+    worldTransformFilter->Update();
+}
 
 //------------------------------- setDataConnection ----------------------------------------
 void Geometry::setDataConnection(vtkSmartPointer<vtkAlgorithmOutput> outputPort) {
@@ -179,8 +194,7 @@ void Geometry::setDataConnection(vtkSmartPointer<vtkAlgorithmOutput> outputPort)
 
     if (tube) {
         tube->SetInputConnection(customPipelineOutput);
-    }
-    else
+    } else
         mapper->SetInputConnection(customPipelineOutput);
 
 }
@@ -212,38 +226,33 @@ vtkSmartPointer<vtkActor> Geometry::getActor(RenderingModes mode) {
             surfaceActor->PickableOn();
         }
         return surfaceActor;
-    }
-    else
-        if ((renderingModes & InterfaceGeometry::Wireframe) && (mode & InterfaceGeometry::Wireframe)) {
-            if (!wireframeActor) {
-                // This actor doesn't exist yet; create it.
-                wireframeActor = vtkSmartPointer<vtkActor>::New();
-                wireframeActor->SetMapper(mapper);
-                wireframeActor->GetProperty()->SetRepresentationToWireframe();
-                wireframeActor->GetProperty()->SetLineWidth(1.0);
-                setActorColor(InterfaceGeometry::Wireframe, wireframeColor);
+    } else if ((renderingModes & InterfaceGeometry::Wireframe) && (mode & InterfaceGeometry::Wireframe)) {
+        if (!wireframeActor) {
+            // This actor doesn't exist yet; create it.
+            wireframeActor = vtkSmartPointer<vtkActor>::New();
+            wireframeActor->SetMapper(mapper);
+            wireframeActor->GetProperty()->SetRepresentationToWireframe();
+            wireframeActor->GetProperty()->SetLineWidth(1.0);
+            setActorColor(InterfaceGeometry::Wireframe, wireframeColor);
 
-                // picking
-                wireframeActor->PickableOn();
-            }
-            return wireframeActor;
+            // picking
+            wireframeActor->PickableOn();
         }
-        else
-            if ((renderingModes & InterfaceGeometry::Points) && (mode & InterfaceGeometry::Points)) {
-                if (!pointsActor) {
-                    // This actor doesn't exist yet; create it.
-                    pointsActor = vtkSmartPointer<vtkActor>::New();
-                    pointsActor->SetMapper(mapper);
-                    pointsActor->GetProperty()->SetRepresentationToPoints();
-                    setActorColor(InterfaceGeometry::Points, pointsColor);
+        return wireframeActor;
+    } else if ((renderingModes & InterfaceGeometry::Points) && (mode & InterfaceGeometry::Points)) {
+        if (!pointsActor) {
+            // This actor doesn't exist yet; create it.
+            pointsActor = vtkSmartPointer<vtkActor>::New();
+            pointsActor->SetMapper(mapper);
+            pointsActor->GetProperty()->SetRepresentationToPoints();
+            setActorColor(InterfaceGeometry::Points, pointsColor);
 
-                    // picking
-                    pointsActor->PickableOn();
-                }
-                return pointsActor;
-            }
-            else
-                return NULL;
+            // picking
+            pointsActor->PickableOn();
+        }
+        return pointsActor;
+    } else
+        return NULL;
 }
 
 
@@ -297,7 +306,7 @@ void Geometry::buildGlyph(const GlyphTypes type) {
             hsv[2] = newV;
             vtkMath::HSVToRGB(hsv, rgb);
             // reduce intensity (too bright is not nice)
-            for (unsigned int i = 0;i < 3;i++) {
+            for (unsigned int i = 0; i < 3; i++) {
                 if (rgb[i] >= 1.0)
                     rgb[i] = 1.0;
                 if (rgb[i] >= 0.9)
@@ -308,8 +317,7 @@ void Geometry::buildGlyph(const GlyphTypes type) {
         glyphActor->SetVisibility(false);
         // insert the glyph in the visualization pipeline, as an extraprop
         addProp("glyph", glyphActor);
-    }
-    else {
+    } else {
         sphereGeom->SetRadius(glyphSize);
         sphereGeom->Update();
     }
@@ -349,13 +357,13 @@ void Geometry::updateLabel() {
         double position[3] = {0.0, 0.0, 0.0};
 
         // compute average position of all the points
-        for (int i = 0;i < pointSet->GetNumberOfPoints(); i++) {
+        for (int i = 0; i < pointSet->GetNumberOfPoints(); i++) {
             double pos[3];
             pointSet->GetPoint(i, pos);
-            for (unsigned j = 0;j < 3;j++)
+            for (unsigned j = 0; j < 3; j++)
                 position[j] += pos[j];
         }
-        for (unsigned j = 0;j < 3;j++)
+        for (unsigned j = 0; j < 3; j++)
             position[j] /= pointSet->GetNumberOfPoints();
 
         position[1] += glyphSize;
@@ -370,8 +378,7 @@ bool Geometry::addProp(const QString& name, vtkSmartPointer< vtkProp > prop ) {
     if (!extraProp.contains(name)) {
         extraProp.insert(name, prop);
         return true;
-    }
-    else
+    } else
         return false;
 }
 
@@ -380,14 +387,12 @@ vtkSmartPointer< vtkProp > Geometry::getProp(const QString& name) {
     // check for extra prop lazy instanciation
     if (name == "glyph")
         buildGlyph(Sphere);
-    else
-        if (name == "label")
-            buildLabel();
+    else if (name == "label")
+        buildLabel();
 
     if (extraProp.contains(name)) {
         return extraProp.value(name);
-    }
-    else
+    } else
         return NULL;
 }
 
@@ -407,7 +412,7 @@ bool Geometry::removeProp(const QString& name) {
         // remove the prop from any renderer/consummers
         vtkSmartPointer<vtkProp> prop = extraProp.value(name);
         prop->VisibilityOff();
-        for (int i = 0;i < prop->GetNumberOfConsumers();i++) {
+        for (int i = 0; i < prop->GetNumberOfConsumers(); i++) {
             vtkViewport *viewer = vtkViewport::SafeDownCast(prop->GetConsumer(i));
             if (viewer)
                 viewer->RemoveViewProp(prop);
@@ -415,8 +420,7 @@ bool Geometry::removeProp(const QString& name) {
         // remove it from the maps
         extraProp.remove(name);
         return true;
-    }
-    else
+    } else
         return false;
 }
 
@@ -430,7 +434,7 @@ void Geometry::setPointPosition(const unsigned int orderNumber, const double x,
 //------------------------------- setActorColor ----------------------------------------
 void Geometry::setActorColor(const RenderingModes mode, double *color) {
     if (mode & InterfaceGeometry::Surface) {
-        for (unsigned int i = 0;i < 4; i++)
+        for (unsigned int i = 0; i < 4; i++)
             surfaceColor[i] = color[i];
         if (surfaceActor) {
             surfaceActor->GetProperty()->SetColor(color);
@@ -439,7 +443,7 @@ void Geometry::setActorColor(const RenderingModes mode, double *color) {
     }
 
     if (mode & InterfaceGeometry::Wireframe) {
-        for (unsigned int i = 0;i < 4; i++)
+        for (unsigned int i = 0; i < 4; i++)
             wireframeColor[i] = color[i];
         if (wireframeActor) {
             wireframeActor->GetProperty()->SetColor(color);
@@ -449,7 +453,7 @@ void Geometry::setActorColor(const RenderingModes mode, double *color) {
     }
 
     if (mode & InterfaceGeometry::Points) {
-        for (unsigned int i = 0;i < 4; i++)
+        for (unsigned int i = 0; i < 4; i++)
             pointsColor[i] = color[i];
         if (pointsActor) {
             pointsActor->GetProperty()->SetColor(color);
@@ -471,23 +475,18 @@ void Geometry::setActorColor(const RenderingModes mode, const double r, const do
 //------------------------------- getActorColor ----------------------------------------
 void Geometry::getActorColor(const RenderingModes mode, double *color) {
     if (mode & InterfaceGeometry::Surface) {
-        for (unsigned int i = 0;i < 4;i++)
+        for (unsigned int i = 0; i < 4; i++)
             color[i] = surfaceColor[i];
+    } else if (mode & InterfaceGeometry::Wireframe) {
+        for (unsigned int i = 0; i < 4; i++)
+            color[i] = wireframeColor[i];
+    } else if (mode & InterfaceGeometry::Points) {
+        for (unsigned int i = 0; i < 4; i++)
+            color[i] = pointsColor[i];
+    } else {
+        for (unsigned int i = 0; i < 4; i++)
+            color[i] = 0.0;
     }
-    else
-        if (mode & InterfaceGeometry::Wireframe) {
-            for (unsigned int i = 0;i < 4;i++)
-                color[i] = wireframeColor[i];
-        }
-        else
-            if (mode & InterfaceGeometry::Points) {
-                for (unsigned int i = 0;i < 4;i++)
-                    color[i] = pointsColor[i];
-            }
-            else {
-                for (unsigned int i = 0;i < 4;i++)
-                    color[i] = 0.0;
-            }
 }
 
 //------------------------------- setColor ----------------------------------------
@@ -513,9 +512,8 @@ void Geometry::setActorOpacity(const RenderingModes mode, const double alpha) {
 
     if (alpha < 0.0)
         opacity = 0.0;
-    else
-        if (alpha > 1.0)
-            opacity = 1.0;
+    else if (alpha > 1.0)
+        opacity = 1.0;
 
     if (mode & InterfaceGeometry::Surface) {
         surfaceColor[3] = opacity;
@@ -543,17 +541,12 @@ void Geometry::setActorOpacity(const RenderingModes mode, const double alpha) {
 double Geometry::getActorOpacity(const RenderingModes mode) const {
     if (mode & InterfaceGeometry::Surface) {
         return surfaceColor[3];
-    }
-    else
-        if (mode & InterfaceGeometry::Wireframe) {
-            return wireframeColor[3];
-        }
-        else
-            if (mode & InterfaceGeometry::Points) {
-                return pointsColor[3];
-            }
-            else
-                return 0.0;
+    } else if (mode & InterfaceGeometry::Wireframe) {
+        return wireframeColor[3];
+    } else if (mode & InterfaceGeometry::Points) {
+        return pointsColor[3];
+    } else
+        return 0.0;
 }
 
 //------------------------------- setOpacity ----------------------------------------
@@ -561,8 +554,9 @@ void Geometry::setOpacity(const double alpha) {
     setActorOpacity(InterfaceGeometry::Surface | InterfaceGeometry::Wireframe | InterfaceGeometry::Points, alpha);
 }
 
+//------------------------------- setMapperScalarRange ----------------------------------------
 void Geometry::setMapperScalarRange ( double min, double max ) {
-  mapper->SetScalarRange(min, max);
+    mapper->SetScalarRange(min, max);
 }
 
 //------------------------------- setTexture ----------------------------------------
@@ -584,14 +578,12 @@ void Geometry::setGlyphType(const GlyphTypes type, const double size) {
         // update size to 0
         glyphSize = 0.0;
         // nothing else to do!
-    }
-    else {
+    } else {
         // check size
         if (size == 0.0) {
             // glyph is a not NoGlyph and size is zero, use a default value
             glyphSize = getBoundingRadius() / 100.0;
-        }
-        else {
+        } else {
             glyphSize = size; // can not be 0.0
         }
         // build the new glyph (get it ready)
@@ -674,8 +666,7 @@ void Geometry::setLinesAsTubes(bool isTubes) {
             tube->SetInputConnection(customPipelineOutput);
             mapper->SetInputConnection(tube->GetOutputPort());
         }
-    }
-    else {
+    } else {
         mapper->SetInputConnection(customPipelineOutput);
         tube = NULL;
     }
@@ -696,8 +687,7 @@ double Geometry::getBoundingRadius() {
         pointSet->GetPoint(0, pos);
         // radius = position
         radius = sqrt(pos[0] * pos[0] + pos[1] * pos[1] + pos[2] * pos[2]);
-    }
-    else {
+    } else {
         double bb[6];
         getBounds(bb);
         double xLength, yLength, zLength;
@@ -718,7 +708,7 @@ void Geometry::setPointData(vtkSmartPointer<vtkDataArray> da) {
         pointSet->GetPointData()->SetActiveScalars(da->GetName());
         // rescale colors
         mapper->SetScalarVisibility(1);
-        double range[2] = {0,1};        
+        double range[2] = {0.0, 1.0};
         pointSet->GetPointData()->GetScalars(da->GetName())->GetRange(range);
         mapper->SetScalarRange(range);
     }
