@@ -45,13 +45,13 @@ class vtkTubeFilter;
 class vtkCastToConcrete;
 class vtkTextMapper;
 class vtkSphereSource;
+class vtkTransformFilter;
 
-namespace camitk
-{
+namespace camitk {
 /**
  * @ingroup group_sdk_libraries_core_component
- * 
- * @brief 
+ *
+ * @brief
  * A 3D representation of a vtkPointSet to be displayed in a InteractiveViewer,
  * this class implements the InterfaceGeometry.
  *
@@ -86,18 +86,18 @@ namespace camitk
  *  The complete Vtk Pipeline looks like this:
  *
  * \verbatim
- *                                               +-----> getDataPort()
- *  +----------------+     +------------------+ /
- *  |  vtkPointSet   |     |vtkCastToConcrete |/
- *  |                |----\|                  |----\    your custom       ----\   ...
- *  |   pointSet     |----/|  concreteData    |----/     pipeline         ----/
- *  +----------------+     +------------------+
- *     ^           |
- *     |           |
- * setPointSet()   |
- *                 |
- *                 v
- *          getPointSet()
+ *                                                                          +-----> getDataPort()
+ *  +----------------+     +------------------+      +-------------------+ /
+ *  |  vtkPointSet   |     |vtkCastToConcrete |      |vtkTransformPolyDataFilter |/
+ *  |                |----\|                  |----\ |                   |----\ your custom       ----\   ...
+ *  |   pointSet     |----/|  concreteData    |----/ |data in world frame|----/  pipeline         ----/
+ *  +----------------+     +------------------+      +-------------------+|
+ *     ^           |                                                      |
+ *     |           |                                                      |
+ * setPointSet()   |                                                      |
+ *                 |                                                      |
+ *                 v                                                      v
+ *          getPointSet()                                       getPointSetWolrdCoords()
  *
  *
  * setDataConnection(..)
@@ -120,19 +120,19 @@ namespace camitk
  * \endverbatim
  * The other vtk (minor) ingredients not mentionned are specific vtkProp (actors, volumes and annotations)
  * By default two props are defined: label and glyph.
- * They can be accessed by getProp("label") and getProp("glyph"). 
+ * They can be accessed by getProp("label") and getProp("glyph").
  * You can also add your own additional custom props by using addProp(QString, vtkProp) and setPropVisible(QString, bool).
  */
 class CAMITK_API Geometry : public InterfaceGeometry {
 
-  public:
+public:
     /** Instanciate a Geometry using existing stuff.
      * \note when the Geometry is instanciated like this,
      * the object takes CONTROL of the vtkDataSet (hence, if you then delete this instance,
      * the vtkDataSet will be deleted as well).
      * dataSet thus becomes owned by the Geometry and will be deleted when necessary,
      * so do not pass the address of an object on the stack.
-     * 
+     *
      * @param label name to display on the label
      * @param pointSet the vtkDataSet to take as the vtk object to display
      * @param mode the default rendering mode
@@ -141,18 +141,18 @@ class CAMITK_API Geometry : public InterfaceGeometry {
 
     /// destructor
     virtual ~Geometry();
-  
+
     /// get the label of this Geometry instance
     virtual const QString getLabel() const {
-      return label;
+        return label;
     }
-    
+
     /// set the label of this Geometry instance
     virtual void setLabel(QString newName) {
-      label = newName;
-      updateLabel();
+        label = newName;
+        updateLabel();
     }
-    
+
     /**
       * @name InterfaceGeometry Vtk related inherited methods
       * All the implemented InterfaceGeometry methods (Geometry is the adaptee of Component)
@@ -160,15 +160,18 @@ class CAMITK_API Geometry : public InterfaceGeometry {
     ///@{
     /// Return the dataset associated to this object.
     virtual vtkSmartPointer<vtkPointSet> getPointSet() {
-      return pointSet;
+        return pointSet;
     }
 
     /// set the input data of the Geometry, \note if there is already a vtkPointSet, this method calls DeepCopy(ds)
     virtual void setPointSet(vtkSmartPointer<vtkPointSet> ds);
 
+    /// Set the world transform (if the Geometry depends on another Frame)
+    virtual void setMeshWorldTransform(vtkSmartPointer<vtkTransform>);
+
     /// get the custom algorithm pipeline input.
     virtual vtkSmartPointer<vtkAlgorithmOutput> getDataPort() const {
-      return dataOutput;
+        return dataOutput;
     }
 
     /// call this method with the custom algorithm pipeline output
@@ -196,7 +199,7 @@ class CAMITK_API Geometry : public InterfaceGeometry {
      *  @return true if the additional prop was added (i.e. another additional prop of the same name does not exist)
      */
     virtual bool addProp(const QString &,  vtkSmartPointer<vtkProp>);
-    
+
     /** remove a given additional prop.
      * @return true if effictively done
      */
@@ -232,16 +235,22 @@ class CAMITK_API Geometry : public InterfaceGeometry {
     /// @{
 
     /// Set the actor associated to a rendering mode visible or not.
-    virtual void setRenderingModes(const RenderingModes rMode) { renderingModes = rMode; }
+    virtual void setRenderingModes(const RenderingModes rMode) {
+        renderingModes = rMode;
+    }
 
     /// Return if the actor associated to a rendering mode is currently visible or not.
-    virtual const RenderingModes getRenderingModes() const { return renderingModes; }
+    virtual const RenderingModes getRenderingModes() const {
+        return renderingModes;
+    }
 
     /// set the enhanced mode
     virtual void setEnhancedModes(const EnhancedModes );
 
     /// get the current enhanced mode
-    virtual const EnhancedModes getEnhancedModes() const { return enhancedModes; }
+    virtual const EnhancedModes getEnhancedModes() const {
+        return enhancedModes;
+    }
 
     /// Set the color of given representation modes.
     virtual void setActorColor(const RenderingModes, double*);
@@ -266,8 +275,8 @@ class CAMITK_API Geometry : public InterfaceGeometry {
 
     /// Set the opacity of this object. WARNING color field (surfaceColor, ...) are not modified!
     virtual void setOpacity(const double);
-    
-    /// Set the mapper scalar range 
+
+    /// Set the mapper scalar range
     virtual void setMapperScalarRange(double min, double max);
 
     /// set the glyph information
@@ -279,7 +288,7 @@ class CAMITK_API Geometry : public InterfaceGeometry {
     ///@}
 
 
-  private:
+private:
 
     /** @name VTK members (data, filters, actors, etc...)
      */
@@ -301,10 +310,10 @@ class CAMITK_API Geometry : public InterfaceGeometry {
 
     /// The additional map for prop (include at least "label" and "glyph"
     QMap<QString, vtkSmartPointer<vtkProp> > extraProp;
-    
+
     /// the mapper to create the text
     vtkSmartPointer<vtkTextMapper> labelActorMapper;
-    
+
     /// the surface actor that manages the surfacic representation
     vtkSmartPointer<vtkActor> surfaceActor;
 
@@ -319,6 +328,10 @@ class CAMITK_API Geometry : public InterfaceGeometry {
 
     /// the tube filter (creates tubes insead of lines)
     vtkSmartPointer<vtkTubeFilter> tube;
+
+    /// the transform filter to place the mesh correctly with respect to its Frame
+    vtkSmartPointer<vtkTransformFilter> worldTransformFilter;
+
     ///@}
 
     /// @name Other members
