@@ -35,19 +35,19 @@
 // -- vtk stuff Classes
 class vtkImageActor;
 class vtkActor;
+class vtkAxesActor;
 class vtkImageData;
 class vtkWindowLevelLookupTable;
+class vtkTransform;
 
-
-namespace camitk
-{
+namespace camitk {
 // -- Core stuff Classes
 class Component;
 
-/** 
+/**
  * @ingroup group_sdk_libraries_core_component
- * 
- * @brief 
+ *
+ * @brief
  * This class describes what are the methods to implement
  * for a BitMap.
  * An InterfaceBitMap is a kind of simplifier/wrapper for vtkImageData.
@@ -62,60 +62,59 @@ class Component;
 
 class InterfaceBitMap {
 
-  public:
+public:
 
-    /** Common slices orientation: axial, sagittal, coronal or anything else.
-     * The slices organisation will depend on how the original volume image has been read
-     * (generally: RAI):
-     * RAI: Right Anterior  Inferior,
-     * LAI: Left  Anterior  Inferior,
-     * LAS: Left  Anterior  Superior,
-     * RAS: Right Anterior  Superior,
-     * LPS: Left  Posterior Superior,
-     * RPS: Right Posterior Superior,
-     * LPI: Left  Posterior Inferior,
-     * RPI: Right Posterior Inferior
+    /** @cond
+     * TODO CAMITK_DEPRECATED. this enum option is deprecated. It will be removed in CamiTK 4.0
+     * Deprecated.
+     * Use SliceOrientation for Slice or ArbitrarySlice class instead.
      *
-     * AXIAL_ORIENTATION:     from feet  to head of the patient in case of RAI, LAI, LPI and RPI
-     *                        from head  to feet of the patient in case of LAS, RAS, LPS and RPS
+     * Common slices orientation: axial, sagittal, coronal or anything else.
+     * The Image Component is supposed to be given in RAI orientation
+     * (see Image Reorientation Action Documentation).
      *
-     * CORONAL_ORIENTATION:   from front to back  of the patient in case of RAI, LAI, LAS and RAS
-     *                        from back  to front of the patient in case of LPI, RPI, LPS and RPS
+     * AXIAL_ORIENTATION:     from feet  to head of the patient in case of RAI
      *
-     * SAGITTAL_ORIENTATION:  from right to left facing the patient in case of RAI, RPI, RAS and RPS
-     *                        from left to right facing the patient in case of LAI, LAS, LPI and LPS
+     * CORONAL_ORIENTATION:   from the front to back  of the patient
      *
+     * SAGITTAL_ORIENTATION:  from the right to left of the patient
+     *
+     * Deprecated. Use ArbitrarySlice Class instead.
      * ARBITRARY_ORIENTATION: well give the orientation you want!
+     * @endcond
      */
     enum PossibleOrientation {
-      AXIAL_ORIENTATION,
-      CORONAL_ORIENTATION,
-      SAGITTAL_ORIENTATION,
-      ARBITRARY_ORIENTATION
+        AXIAL_ORIENTATION,
+        CORONAL_ORIENTATION,
+        SAGITTAL_ORIENTATION,
+        ARBITRARY_ORIENTATION
     };
 
     /// virtual destructor
     virtual ~InterfaceBitMap() {};
 
-    /** Return the displayed images as a vtkImageData. */
-    virtual vtkSmartPointer<vtkImageData> getImageData() const = 0;
-
     /// set the original volume image data (the source vtkImageData before any reslice) and refresh the vtk pipeline
     virtual void setOriginalVolume(vtkSmartPointer<vtkImageData>) = 0;
 
-    /** Return the vtkImageActor (vtkProp) representing a slice to be displayed in 2D. */
+    /// set the transformation for 3D image representation
+    virtual void setImageWorldTransform(vtkSmartPointer<vtkTransform>)=0;
+
+    /** Return the vtkImageActor (vtkProp) representing a slice to be displayed in 2D viewers. */
     virtual vtkSmartPointer<vtkImageActor> get2DImageActor() const = 0;
 
-	/** Return the vtkImageActor (vtkProp) representing a slice to be displayed in 2D. */
+    /** Return the vtkImageActor (vtkProp) representing a slice to be displayed in 3D viewers. */
     virtual vtkSmartPointer<vtkImageActor> get3DImageActor() const = 0;
 
-
-//     /** Return the vtkActor used to pick pixels in the slices. */
+    /** Return the vtkActor used to pick pixels in the slices. */
     virtual vtkSmartPointer<vtkActor> getPickPlaneActor() const = 0;
 
     /** Return the vtkActor used to pick pixels in the slices. */
     virtual vtkSmartPointer<vtkActor> getPixelActor() = 0;
 
+    /** Return 2D Axes at the proper slice origin */
+//    virtual vtkSmartPointer<vtkAxesActor> get2DAxesActor() = 0;
+
+
     /** This method is called when the associated plane has been picked in the InteractiveViewer,
      *  the given coordinates is position where the plane was picked.
      */
@@ -135,20 +134,9 @@ class InterfaceBitMap {
      * @param s the index of the slice to display (base 0). */
     virtual void setSlice(int s) = 0;
 
-    /// Set the slice corresponding to the given world coordinates
+    /// Set the slice corresponding to the given image coordinates (in RAI convention)
     virtual void setSlice(double x, double y, double z) = 0;
-    
-      /** Return the current angle applied to the arbitrary slice */
-    virtual double getRotationX() const = 0;
-    virtual double getRotationY() const = 0;
-    virtual double getRotationZ() const = 0;
-    
-    /** Set the current angle to the arbitrary slice */
-    virtual void setRotationX(double angle) = 0;
-    virtual void setRotationY(double angle) = 0;
-    virtual void setRotationZ(double angle) = 0;
-    
-    
+
     /** Return the number of colors in the images.
      * If color is coded on 1 byte, the images are on 256 grey level.
      * If color is coded on 2 bytes, the images are on 4096 grey level (not 65536). */
@@ -156,12 +144,33 @@ class InterfaceBitMap {
 
     /// move the pixel selection green indicator (pixelActor) to the given real position
     virtual void setPixelRealPosition(double, double, double) = 0;
-	
-	// TODO : put all of this into a dedicated interface
-	/// The additional map for prop (include at least "label" and "glyph"
+
+
+    ///@cond
+    // TODO CAMITK_DEPRECATED. This section list all the methods marked as deprecated. They are to be removed in CamiTK 4.0
+    /** Deprecated.
+     * Return the displayed images as a vtkImageData. */
+    virtual vtkSmartPointer<vtkImageData> getImageData() const = 0;
+    /** Deprecated. Should be implemented only on ArbitrarySlice.
+     * Return the current angle applied to the arbitrary slice */
+    virtual double getRotationX() const = 0;
+    virtual double getRotationY() const = 0;
+    virtual double getRotationZ() const = 0;
+
+    /** Deprecated. Should be implemented only on ArbitrarySlice.
+     * Set the current angle to the arbitrary slice */
+    virtual void setRotationX(double angle) = 0;
+    virtual void setRotationY(double angle) = 0;
+    virtual void setRotationZ(double angle) = 0;
+    ///@cond
+
+
+
+    // TODO : put all of this into a dedicated interface
+    /// The additional map for prop (include at least "label" and "glyph"
     QMap<QString, vtkSmartPointer<vtkProp> > extraProp;
-	
-	/// Return the vtkProp (actors, volumes and annotations) corresponding to the given name
+
+    /// Return the vtkProp (actors, volumes and annotations) corresponding to the given name
     virtual vtkSmartPointer<vtkProp> getProp(const QString &) = 0;
 
     /// return the number of additional prop
@@ -174,12 +183,12 @@ class InterfaceBitMap {
      *  @return true if the additional prop was added (i.e. another additional prop of the same name does not exist)
      */
     virtual bool addProp(const QString &,  vtkSmartPointer<vtkProp>) = 0;
-    
+
     /** remove a given additional prop.
      * @return true if effictively done
      */
     virtual bool removeProp(const QString &) = 0;
-	// END TODO
+    // END TODO
 
 };
 
