@@ -38,14 +38,14 @@ class vtkProp;
 class vtkDataArray;
 class vtkAlgorithm;
 class vtkAlgorithmOutput;
+class vtkTransform;
 
 
-namespace camitk
-{
+namespace camitk {
 /**
  * @ingroup group_sdk_libraries_core_component
- * 
- * @brief 
+ *
+ * @brief
  * This class describes what are the methods to implement
  * for a Geometry (rendering parameters, input/output, filters, picking parameters...)
  *
@@ -55,34 +55,34 @@ namespace camitk
  * See the introduction of GoF: "Program to an interface, not an implementation."
  * To see what Erich Gamma has to say about it: http://www.artima.com/lejava/articles/designprinciplesP.html
  * To see what Bjarne Stroustrup has to say about it: http://www.artima.com/intv/modern.html
- * 
+ *
  * @see Geometry
  */
 class InterfaceGeometry {
 
-  public:
+public:
     /// @enum RenderingMode (and QFlags RenderingModes) handle actor rendering options (render this InterfaceGeometry as a surface, a wireframe and set of points).
     enum RenderingMode {
-      None = 0x0,      ///< no rendering mode, the InterfaceGeometry is not visible
-      Surface = 0x1,   ///< the surface is visible
-      Wireframe = 0x2, ///< the wireframe is visible
-      Points = 0x4    ///< the points are visible
+        None = 0x0,      ///< no rendering mode, the InterfaceGeometry is not visible
+        Surface = 0x1,   ///< the surface is visible
+        Wireframe = 0x2, ///< the wireframe is visible
+        Points = 0x4    ///< the points are visible
     };
     Q_DECLARE_FLAGS(RenderingModes, RenderingMode)
 
     /// @enum EnhancedMode (and QFlags EnhancedModes) handle the way the rendering actors will be enhanced or not (from completely hidden to highlighted)
     enum EnhancedMode {
-      Normal = 0x0,       ///< the object is normally displayed
-      Hidden = 0x1,       ///< the object is hidden
-      Shaded = 0x2,       ///< the object is shaded
-      Highlighted = 0x4  ///< the object is highlighted
+        Normal = 0x0,       ///< the object is normally displayed
+        Hidden = 0x1,       ///< the object is hidden
+        Shaded = 0x2,       ///< the object is shaded
+        Highlighted = 0x4  ///< the object is highlighted
     };
     Q_DECLARE_FLAGS(EnhancedModes, EnhancedMode)
 
     /// @enum GlyphType (and QFlags GlyphTypes) is the type of glyph attached to the geometry representation
     enum GlyphType {
-      NoGlyph = 0x0,      ///< there are no glyph type attached to the geometry
-      Sphere = 0x1       ///< the glyph is a nice sphere
+        NoGlyph = 0x0,      ///< there are no glyph type attached to the geometry
+        Sphere = 0x1       ///< the glyph is a nice sphere
     };
     Q_DECLARE_FLAGS(GlyphTypes, GlyphType)
 
@@ -91,7 +91,7 @@ class InterfaceGeometry {
 
     /// get the string used to display the label
     virtual const QString getLabel() const = 0;
-    
+
     /// set the string used to display the label
     virtual void setLabel(QString newName) = 0;
 
@@ -102,7 +102,7 @@ class InterfaceGeometry {
 
     /** set the low-level data set.
      * \note if there is already a vtkPointSet, this method calls DeepCopy(ds)
-     * 
+     *
      * \note it is very important to overload this method in your Component subclass as this will be called by all the operators
      *  that operates a change directly on the data.
      */
@@ -111,6 +111,10 @@ class InterfaceGeometry {
     /// set the point data (may contains a lookup table). \note values have to be in interval [0..1]
     virtual void setPointData(vtkSmartPointer<vtkDataArray>) = 0;
 
+    /// set the transformation for 3D representation
+    virtual void setMeshWorldTransform(vtkSmartPointer<vtkTransform>)=0;
+
+
     /** get the custom algorithm pipeline input.
       * This method returns the unmodified data that you have to use
       * as an input for your filter/algorithm.
@@ -180,7 +184,7 @@ class InterfaceGeometry {
      *  the vtk picker can select a specific vtkPoint in the big Geometry.
      *
      *  A Component re-implementing this method can manage a specific selection process (or any other suitable
-     *  action). 
+     *  action).
      *
      *  @param pointId the vtkPoint id that was selected by picking
      *  @param pickingIsSelecting indicates if the current picking session is selecting or unselecting
@@ -204,9 +208,9 @@ class InterfaceGeometry {
 
     /// @name Helpers methods
     /// @{
-        
+
     /// compute the object's bounding box [xmin,xmax, ymin,ymax, zmin,zmax]
-    /// @param bounds the 6-sized double tab of the bounding box (in 3D). 
+    /// @param bounds the 6-sized double tab of the bounding box (in 3D).
     /// @warning bounds must points a 6 double-sized tab minimum.
     virtual void getBounds(double *bounds) = 0;
 
@@ -259,8 +263,8 @@ class InterfaceGeometry {
 
     /// Set the opacity of this object. WARNING color field (surfaceColor, ...) are not modified!
     virtual void setOpacity(const double) = 0;
-    
-    /// Set the mapper scalar range 
+
+    /// Set the mapper scalar range
     virtual void setMapperScalarRange(double min, double max) = 0;
 
     /** Set the glyph type (a glyph is a geometric representation attached to every point in the input dataset).
@@ -269,7 +273,7 @@ class InterfaceGeometry {
       * - if type is NoGlyph, then no glyph are shown
       *
       * To show the glyph call getProp("glyph")->SetVisibility(true) or getProp("glyph")->VisibilityOn().
-      * 
+      *
       * @param type the glyph type
       * @param size size of the glyph (default is 0.0)
       */
