@@ -32,23 +32,22 @@
 class QPixmap;
 class QMenu;
 
-namespace camitk
-{
+namespace camitk {
 
-/** 
+/**
  * @ingroup group_sdk_libraries_core_component
- * 
- * @brief 
+ *
+ * @brief
  * This class describe what are the methods to implement for a hierarchical tree node.
  *
  * An InterfaceNode can only have one parent, even if it is a child of more than
  * one InterfaceNodes.
- * 
+ *
  * Consequence: an InterfaceNode can be present many times in the hierarchy, but
  * can only depends from one parent.
  * To add an InterfaceNode as a child and change its parent to this use addChild().
  * To add an InterfaceNode as a child without modifying its parent, use attachChild().
- * 
+ *
  * This class defines an "interface" (in the OOP/java meaning of the term).
  * See the introduction of GoF: "Program to an interface, not an implementation."
  * To see what Erich Gamma has to say about it: http://www.artima.com/lejava/articles/designprinciplesP.html
@@ -56,7 +55,7 @@ namespace camitk
  *
  */
 class InterfaceNode {
-  public:
+public:
     /// empty virtual destructor, to avoid memory leak
     virtual ~InterfaceNode() {};
 
@@ -73,19 +72,19 @@ class InterfaceNode {
      *
      *  This is to be used with care. The preferred method to add a child component is
      *  to use the Component's constructor with the parent parameter: Component(Component *, const QString &, Representation rep) .
-     * 
+     *
      *  \note
      *  If the use of this method does not update the new child in the Explorer, then you may
-     *  need to force the rebuild of the explorer nodes by calling Component::refreshInterfaceNode() as follows: 
+     *  need to force the rebuild of the explorer nodes by calling Component::refreshInterfaceNode() as follows:
      *  \code
      *      this->addChild(otherComponent);
      *      this->refreshInterfaceNode(); // check first without this, it should work in most of the cases.
      *  \endcode
-     * 
+     *
      *  see attachChild() Component::refreshInterfaceNode()
      */
     virtual void addChild(InterfaceNode *) = 0;
-    
+
     /** add a child Component (but leave its parent unchanged)
      *
      * There can be some refresh problem, see the note in addChild()
@@ -103,7 +102,7 @@ class InterfaceNode {
 
     /// set the parent Component
     virtual void setParent(InterfaceNode *) = 0;
-    
+
     /// should the name be displayed in italic?
     virtual bool inItalic() const = 0;
 
@@ -124,7 +123,7 @@ class InterfaceNode {
       * \endcode
       *
       * 2. add these lines in your code (in MyComponent.cpp):
-      * 
+      *
       * \code
       * // use this two lines or better use a Qt resource bundle (recommanded!)
       * #include "myComponent_pixmap.xpm" // include the pixmap resource file or use a Qt resource bundle
