@@ -47,17 +47,21 @@
 #include <vtkDataSetMapper.h>
 #include <vtkLine.h>
 #include <vtkPolygon.h>
+#include <vtkTextProperty.h>
+#include <vtkTextMapper.h>
+#include <vtkAxesActor.h>
+#include <vtkTransformPolyDataFilter.h>
 
-namespace camitk
-{
-/** 
+namespace camitk {
+/**
  * @ingroup group_sdk_libraries_core_component
- * 
+ *
  * @brief
  * Display a slice (i.e. an image or BitMap) of an @ref camitk::ImageComponent "ImageComponent"
  *
- * Uses vtkImageActor::SetDisplayExtent for 3D Axial, Coronal and Sagittal representaiton.
- * Uses vtkImageReslice for 2D actors (for them to be facing the camera).
+ * Uses vtkImageActor::SetDisplayExtent for 3D and 2D Axial, Coronal and Sagittal representaiton.
+ * Re-position the camera for the 2D views.
+ *
  *
  *  \verbatim
  *       3D Volume                         2D Slice
@@ -73,28 +77,21 @@ namespace camitk
  *                                      ---|                |
  *                                     |   |    lut         |
  *                                     |   |________________|
- *  setOriginalVolume(..)              |                                                            __________________
- *   |                                 | setLookUpTable                                            |  vtkImageActor   |
- *   |                   setInput      |               /------------------------------------------\|(setDisplayExtent)|
- *   |   ________________       _______v____________  / /-----------------------------------------/|                  |
- *   |  |  vtkImageData  |     | vtkImageMapToColor |/ /                                           |   image3DActor   |
- *   |_\|                |----\|                    | /       _________________________            |__________________|
- *     /| originalVolume |----/|   imgToMapFilter   |\ \     |vtkImageChangeInformation|
- *      |________________|     |____________________| \ \---\|                         |
- *                                                     \----/|     image2DChangeInfo   |
- *                                                           |_________________________|
- *                                                                \ \        _______________        _______________
- *                                                                 \ \      |vtkImageReslice|      | vtkImageActor |
- *                                                                  \ \----\|               |-----\|               |
- *                                                                    -----/|image2DReslicer|-----/|  image2DActor |
- *                                                                          |_______________|\     |_______________|
- *                                                                                            \
- *                                                                                             v
- *                                                                                        getImageData()
- *
- *
- *
- *
+ *  setOriginalVolume(..)              |
+ *   |                                 | setLookUpTable
+ *   |                   setInput      |                                   __________________
+ *   |   ________________       _______v____________                      |  vtkImageActor   |
+ *   |  |  vtkImageData  |     | vtkImageMapToColor |                     |(setDisplayExtent)|
+ *   |_\|                |----\|                    |-------------------\ |                  |
+ *     /| originalVolume |----/|   imgToMapFilter   |-------------------/ |   image2DActor   |
+ *      |________________|     |____________________|     | |             |__________________|
+ *                                                        | |
+ *                                                        | |              _________________________            __________________
+ *                                                        | |             |  vtkTransformFilter     |          |  vtkImageActor   |
+ *                                                        |  -----------\ |(setWorldTransformation) | --------\|(setDisplayExtent)|
+ *                                                         -------------/ |                         | --------/|                  |
+ *                                                                        |                         |          |   image3DActor   |
+ *                                                                        |_________________________|          |__________________|
  *
  *
  *
@@ -102,8 +99,7 @@ namespace camitk
  *
  */
 
-class CAMITK_API Slice : public InterfaceBitMap
-{
+class CAMITK_API Slice : public InterfaceBitMap {
 public:
     /* -------------------------------------------------------------------- */
     /**@{                                                                   */
@@ -111,11 +107,46 @@ public:
     /**@{                                                                   */
     /* -------------------------------------------------------------------- */
 
-    /// Constructor
+    /** Common slices orientation: axial, sagittal, coronal axial_neuro.
+     * Axial, Sagittal and Coronal orientation are given in Radiologist point of view.
+     * The neurologist point of view is displayed in axial_neuro.
+     *
+     * The ImageComponent is supposed to be given in RAI orientation !
+     * (see Image Reorientation Action Documentation).
+     * @image imageRAI.png
+     *
+     * AXIAL:     from feet  to head of the patient
+     * @image axialView.png
+     *
+     * CORONAL:   from the front to back  of the patient
+     * @image coronalView.png
+     *
+     * SAGITTAL:  from the right to left of the patient
+     * @image sagittalView.png
+     *
+     * AXIAL_NEURO: from head to feet (other side of AXIAL
+     *
+     */
+    enum SliceOrientation {
+        AXIAL,
+        CORONAL,
+        SAGITTAL,
+        AXIAL_NEURO
+    };
+
+    /** @cond
+     * TODO CAMITK_DEPRECATED. this enum option is deprecated. It will be removed in CamiTK 4.0
+     * Deprecated.
+     * Use SliceOrientation for Slice or ArbitrarySlice class instead.
+     */
     Slice(vtkSmartPointer<vtkImageData> volume, PossibleOrientation AXIAL_ORIENTATION, vtkSmartPointer<vtkWindowLevelLookupTable> lookupTable=NULL);
+    ///@cond
+
+    /// Constructor
+    Slice(vtkSmartPointer<vtkImageData> volume, SliceOrientation AXIAL_ORIENTATION, vtkSmartPointer<vtkWindowLevelLookupTable> lookupTable=NULL);
 
     /// virtual destructor
-    virtual ~Slice() {};
+    virtual ~Slice();
 
     /* -------------------------------------------------------------------- */
     /**@}                                                                   */
@@ -123,16 +154,17 @@ public:
     /**@{                                                                   */
     /* -------------------------------------------------------------------- */
 
-    /** Return the displayed images as a vtkImageData. */
-    virtual vtkSmartPointer<vtkImageData> getImageData() const;
-
     /// set the original volume image data (the source vtkImageData before any reslice) and refresh the vtk pipeline
     virtual void setOriginalVolume(vtkSmartPointer<vtkImageData> img);
 
-    /** Return the vtkImageActor (vtkProp) representing a slice to be displayed in 2D. */
+    /// set the transformation for 3D image representation
+    virtual void setImageWorldTransform(vtkSmartPointer<vtkTransform>);
+
+
+    /** Return the vtkImageActor (vtkProp) representing a slice to be displayed in the 2D viewers. */
     virtual vtkSmartPointer<vtkImageActor> get2DImageActor() const;
 
-    /** Return the vtkImageActor (vtkProp) representing a slice to be displayed in 2D. */
+    /** Return the vtkImageActor (vtkProp) representing a slice to be displayed in the 3D viewers. */
     virtual vtkSmartPointer<vtkImageActor> get3DImageActor() const;
 
 
@@ -142,6 +174,9 @@ public:
     /** Return the vtkActor used to pick pixels in the slices. */
     virtual vtkSmartPointer<vtkActor> getPixelActor();
 
+    /** Return 2D Axes at the proper slice origin */
+    virtual vtkSmartPointer<vtkAxesActor> get2DAxesActor();
+
     /** This method is called when the associated plane has been picked in the InteractiveViewer,
      *  the given coordinates is position where the plane was picked.
      */
@@ -150,7 +185,7 @@ public:
     /** Compute the volume coordinates (xyz) from the resliced coordinates (ijk)
     * @param ijk: given resliced coordiantes (generally from a pixel picked in the pickPlane)
     * @param xyz: output (should be allocated before calling this function)
-    *     volume coordinates computed from the input
+    *     volume coordinates (with image at the origin in RAI convention) computed from the input
     */
     /// Todo: put this method in abstract slice
     void reslicedToVolumeCoords(const double *ijk, double *xyz);
@@ -171,26 +206,9 @@ public:
      * @param s the index of the slice to display (base 0). */
     virtual void setSlice(int s);
 
-    /// Set the slice corresponding to the given world coordinates
+    /// Set the slice corresponding to the given real image (RAI) coordinates
     virtual void setSlice(double x, double y, double z);
 
-    /** Return the current angle applied to the arbitrary slice */
-    virtual double getRotationX() const {
-        return currentXAngle;
-    };
-    virtual double getRotationY() const {
-        return currentYAngle;
-    };
-    virtual double getRotationZ() const {
-        return currentZAngle;
-    };
-
-    /** Set the current angle to the arbitrary slice */
-    virtual void setRotationX(double angle);
-    virtual void setRotationY(double angle);
-    virtual void setRotationZ(double angle);
-    void applyRotation();
-
     /** Return the number of colors in the images.
     * If color is coded on 1 byte, the images are on 256 grey level.
     * If color is coded on 2 bytes, the images are on 4096 grey level (not 65536). */
@@ -199,8 +217,46 @@ public:
     /// move the pixel selection green indicator (pixelActor) to the given real position
     virtual void setPixelRealPosition(double, double, double);
 
+
+    ///@cond
+    // TODO CAMITK_DEPRECATED. This section list all the methods marked as deprecated. They are to be removed in CamiTK 4.0
+    /** Deprecated.
+     * Return the displayed images as a vtkImageData. */
+    virtual vtkSmartPointer<vtkImageData> getImageData()const {
+        return NULL;
+    };
+    /** Deprecated. Should be implemented only on ArbitrarySlice.
+     * Return the current angle applied to the arbitrary slice */
+    virtual double getRotationX() const {
+        return 0.0;
+    };
+    /** Deprecated. Should be implemented only on ArbitrarySlice.
+     * Return the current angle applied to the arbitrary slice */
+    virtual double getRotationY() const {
+        return 0.0;
+    };
+    /** Deprecated. Should be implemented only on ArbitrarySlice.
+     * Return the current angle applied to the arbitrary slice */
+    virtual double getRotationZ() const {
+        return 0.0;
+    };
+
+    /** Deprecated. Should be implemented only on ArbitrarySlice.
+     * Set the current angle to the arbitrary slice */
+    virtual void setRotationX(double angle) {};
+    /** Deprecated. Should be implemented only on ArbitrarySlice.
+     * Set the current angle to the arbitrary slice */
+    virtual void setRotationY(double angle) {};
+    /** Deprecated. Should be implemented only on ArbitrarySlice.
+     * Set the current angle to the arbitrary slice */
+    virtual void setRotationZ(double angle) {};
+    /** Deprecated. Should be implemented only on ArbitrarySlice.
+     * Set the current angle to the arbitrary slice */
+    void applyRotation() {};
+    ///@endcond
+
     // TODO : put all of this into a dedicated interface
-    /// The additional map for prop (include at least "label" and "glyph"
+    /// The additional map for prop (include at least "label" and "glyph")
     QMap<QString, vtkSmartPointer<vtkProp> > extraProp;
 
     /// Return the vtkProp (actors, volumes and annotations) corresponding to the given name
@@ -231,50 +287,59 @@ protected:
     /**@{                                                                   */
     /* -------------------------------------------------------------------- */
 
-    /** Sets the given rotation transformation to the reslicer without
+    /** Initialize Attributes */
+    virtual void init();
+
+    /** Initialize actors and everything they need.*/
+    virtual void initActors();
+
+
+    ///@cond
+    // TODO CAMITK_DEPRECATED. This section list all the methods marked as deprecated. They are to be removed in CamiTK 4.0
+    /** Deprecated.
+     * Use setSliceOrientation(SliceOrientation orientation) instead.
+     * Set the orientation (and the transform matrix) of the slice.*/
+    void setSliceOrientation(PossibleOrientation orientation);
+
+    /** Deprecated.
+     * Set transformation for axial, sagittal and coronal (axial as default for arbitrary)*/
+    void setInitialSlicerTransformation() {};
+
+    /** Deprecated.
+     *  Update the coordsTransform attribute (to do when either slicer transformation or
+     *  slice number has changed). */
+    void updateLocalTransformation() {};
+
+    /** Deprecated.
+     * Computes local coordiantes from original coordinates and slicer transformation */
+    void computeReslicedDimensions() {};
+
+    /** Deprecated.
+        Sets the given rotation transformation to the reslicer without
     *  checking anything
     *  WARNING : This method is not implemented
     */
     void setTransformOrientation(double *xCosines, double *yCosines, double *zCosines);
 
-    /** Sets the given origin to the reslicer without checking anything.
-    *  Warning, if the origin is not at (0,0,s) or any combination, the
-    *  pickPlane may not be correctly placed.
-    *  WARNING : This method is not implemented
-    */
+    /** Deprecated.
+     *  Sets the given origin to the reslicer without checking anything.
+     *  Warning, if the origin is not at (0,0,s) or any combination, the
+     *  pickPlane may not be correctly placed.
+     *  WARNING : This method is not implemented
+     */
     void setTransformOrigin(double *resliceOrigin);
 
-    /** Initialize actors and everything they need.*/
-    void initActors();
-
-    /** Set transformation for axial, sagittal and coronal (axial as default for arbitrary)*/
-    void setInitialSlicerTransformation();
-
-    /** Update the coordsTransform attribute (to do when either slicer transformation or
-    *  slice number has changed). */
-    void updateLocalTransformation();
-
-    /** Computes local coordiantes from original coordinates and slicer transformation */
-    void computeReslicedDimensions();
-
-    /** Set the orientation (and the transform matrix) of the slice.*/
-    void setSliceOrientation(PossibleOrientation orientation);
+    ///@endcond
 
 
-
-
-private:
     /* -------------------------------------------------------------------- */
     /**@}                                                                   */
     /**@name          Attributes / Members of the class                     */
     /**@{                                                                   */
     /* ---------------------------------------------------------------------*/
 
-    /** Initialize / Creates members. */
-    void init();
-
     /** Direction of the reslice */
-    PossibleOrientation sliceOrientation;
+    SliceOrientation sliceOrientation;
 
     /** Smart pointer to the original volume to reslice (input of the vtk pipeline) */
     vtkSmartPointer<vtkImageData> originalVolume;
@@ -283,58 +348,27 @@ private:
     /// 0 & 1 -> x; 2 and 3 -> y; 4 & 5 -> z
     int extent[6];
 
-    /**@}                                                                   */
-    /**@name          Use to reslice 2D                                     */
-    /**@{                                                                   */
-
-    /** Original volume dimensions */
-    int originalDimensions[3];
-
-    /** Resliced Volume dimensions */
-    int reslicedDimensions[3];
-
-    /** Voxel size of the ORIGINAL image volume. Used to compute point coordinates between real world and index world.*/
-    double originalSpacing[3];
-
-    /** Voxel size of the RESLICED image volume. Used to compute point coordinates between real world and index world.*/
-    double resliceSpacing[3];
-
-    /** Angle apply to the arbitrary slice*/
-    double currentXAngle;
-    double currentYAngle;
-    double currentZAngle;
-
-    /** Transform matrix between resliced and original coords */
-    vtkSmartPointer<vtkMatrix4x4> coordsTransform;
-
-    /** Transform matrix between resliced and original coords taking the slice number into account. */
-    vtkSmartPointer<vtkMatrix4x4> sliceCoordsTransform;
-
-    /** Transformation between the reslice volume and the original volume. */
-    vtkSmartPointer<vtkTransform> transformReslice2Volume;
-
-    /**@}                                                                   */
-
     /** Keep track of the slice number                                      */
     int currentSliceIndex;
 
     /// Common lookup table
     vtkSmartPointer<vtkWindowLevelLookupTable>  lut;
 
+    /** Original volume dimensions in number of voxels (x, y and z) */
+    int originalDimensions[3];
+
+    /** Voxel size of the original image volume. Used to compute point coordinates between real world and index world.*/
+    double originalSpacing[3];
+
+    /** Real size (originalDimension * originalSpacing in x, y and z) of the original image */
+    double originalSize[3];
+
     /// To be able to extract a slice
     vtkSmartPointer<vtkImageMapToColors>		imgToMapFilter;
 
     /// 3D actor
     vtkSmartPointer<vtkImageActor>				image3DActor;
-
-    /**@{                                                                 */
-    /**@name For 2D actor                                                 */
-    /// Reslicer: cut the volume at the right plane and displays it facing the 2D camera
-    vtkSmartPointer<vtkImageReslice>            image2DReslicer;
-    /// To put the origin of the reslicer at (0, 0, 0)
-    ///  (mandatory to visualize 2D actor (axial, coronal or sagittal) properly in a 2D window)
-    vtkSmartPointer<vtkImageChangeInformation>	image2DChangeInfo;
-    /// 2D actor itself
+    /// 2D actor
     vtkSmartPointer<vtkImageActor>              image2DActor;
     /**@}                                                                   */
 
@@ -352,7 +386,7 @@ private:
 
     /** Actor representing the pickPlane. */
     vtkSmartPointer<vtkActor> pickPlaneActor;
-    /**@} */
+
 
     /**
      * Init the pixel actor for pixel picking
@@ -375,6 +409,12 @@ private:
     /** Actor representing a pixel, displayed over the image. */
     vtkSmartPointer<vtkActor> pixelActor;
 
+
+    void update2DAxesActorPosition();
+    void init2DAxesActor();
+    vtkSmartPointer<vtkAxesActor> axes2DActor;
+
+
 };
 
 }
