@@ -32,20 +32,18 @@
 
 
 
-namespace camitk
-{
-ImageComponentExtension::ImageComponentExtension() : ComponentExtension()
-{
+namespace camitk {
+ImageComponentExtension::ImageComponentExtension() : ComponentExtension() {
 }
 
 // --------------- getName -------------------
 QString ImageComponentExtension::getName() const {
-  return "Generic Image Volume Manager Plugin";
+    return "Generic Image Volume Manager Plugin";
 }
 
 // --------------- getDescription -------------------
 QString ImageComponentExtension::getDescription() const {
-  return "Interface all image volume manager plugins";
+    return "Interface all image volume manager plugins";
 }
 
 }
