@@ -39,20 +39,19 @@
 #include <QMap>
 
 
-namespace camitk
-{
-/** 
+namespace camitk {
+/**
  * @ingroup group_sdk_libraries_core_component_image
- * 
+ *
  * @brief
  * Abstract class created to support export file formats for ImageComponent
  * Any data component plugin creating an ImageComponent should inherit from this class.
- * 
+ *
  */
 
 class CAMITK_API ImageComponentExtension : public ComponentExtension {
 
-  public:
+public:
 
     /// get the plugin name
     virtual QString getName() const;
@@ -65,7 +64,7 @@ class CAMITK_API ImageComponentExtension : public ComponentExtension {
 
 protected:
     /// Constructor protected because the class is virtual
-    ImageComponentExtension(); 
+    ImageComponentExtension();
 
     /// the destructor
     virtual ~ImageComponentExtension() {};
