@@ -32,6 +32,7 @@
 #include "InteractiveViewer.h"
 #include "Log.h"
 #include "Application.h"
+#include "Frame.h"
 
 // -- VTK stuff
 #include <vtkUnstructuredGrid.h>
@@ -50,11 +51,16 @@ SingleImageComponent::SingleImageComponent(Component *parentComponent, Interface
 
     this->lut = lut;
 
+    // set my parent image as my parent frame
+    Frame * myParentFrame = (Frame *) dynamic_cast<Frame *>(parentComponent->getFrame());
+    this->setParentFrame(myParentFrame);
+
     // build the slice 3D
     initRepresentation();
 
     // by default, this slice is not shown in 3D
     this->viewSliceIn3D = false;
+
 }
 
 // -------------------- destructor  --------------------
@@ -66,6 +72,11 @@ void SingleImageComponent::setSelected(const bool b, const bool r) {
     dynamic_cast<ImageComponent*>(getParent())->setSelected(b, false);
 }
 
+// -------------------- setSelected --------------------
+void SingleImageComponent::setTransformFromParent(vtkSmartPointer<vtkTransform> transform) {
+    // Do nothing, my parent (the ImageComponent) should move !!!
+}
+
 // -------------------- singleImageSelected --------------------
 void SingleImageComponent::singleImageSelected(const bool b) {
     Component::setSelected(b, false);
@@ -86,20 +97,28 @@ void SingleImageComponent::setViewSliceIn3D(bool toggle) {
 
 // -------------------- initRepresentation --------------------
 void SingleImageComponent::initRepresentation() {
-    mySlice = new Slice(dynamic_cast<ImageComponent *>(getParentComponent())->getImageData(), sliceOrientation, this->lut);
-
     switch (sliceOrientation) {
     case InterfaceBitMap::AXIAL_ORIENTATION:
+        mySlice = new Slice(dynamic_cast<ImageComponent *>(getParentComponent())->getImageData(), Slice::AXIAL, this->lut);
         setVisibility(InteractiveViewer::getAxialViewer(), true);
+
+        mySlice->setImageWorldTransform(getTransformFromWorld());
         break;
     case InterfaceBitMap::CORONAL_ORIENTATION:
+        mySlice = new Slice(dynamic_cast<ImageComponent *>(getParentComponent())->getImageData(), Slice::CORONAL, this->lut);
         setVisibility(InteractiveViewer::getCoronalViewer(), true);
+
+        mySlice->setImageWorldTransform(getTransformFromWorld());
         break;
     case InterfaceBitMap::SAGITTAL_ORIENTATION:
+        mySlice = new Slice(dynamic_cast<ImageComponent *>(getParentComponent())->getImageData(), Slice::SAGITTAL, this->lut);
         setVisibility(InteractiveViewer::getSagittalViewer(), true);
+
+        mySlice->setImageWorldTransform(getTransformFromWorld());
         break;
     case InterfaceBitMap::ARBITRARY_ORIENTATION:
-        setVisibility(InteractiveViewer::getArbitraryViewer(), true);
+        mySlice = NULL;
+//        setVisibility(InteractiveViewer::getArbitraryViewer(), true);
         break;
     }
 }
@@ -107,24 +126,7 @@ void SingleImageComponent::initRepresentation() {
 
 // ---------------------- pixelPicked  ----------------------------
 void SingleImageComponent::pixelPicked(double i, double j, double k) {
-    // At this point, coordinates are represented in real frame (world frame)
-    double xyz[3];
-    double ijk[3];
-    double resliceSpacing[3];
-
-    // Get the spacing of the reslice data.
-    ((Slice*)mySlice)->getImageData()->GetSpacing( resliceSpacing );
-
-    // Compute coordiantes in the resliced volume. Coordinates are rounded.
-    ijk[0] = floor((i+0.5) / resliceSpacing[0]);
-    ijk[1] = floor((j+0.5) / resliceSpacing[1]);
-    ijk[2] = (int) ((Slice*)mySlice)->getSlice();
-
-    // Compute coordinates in original volume.
-    ((Slice*)mySlice)->reslicedToVolumeCoords(ijk, xyz);
-
-    //-- tell my parent
-    ((ImageComponent*)getParent())->pixelPicked(xyz[0], xyz[1], xyz[2], this);
+    ((ImageComponent*)getParent())->pixelPicked(i, j, k, this);
 }
 
 }
