@@ -32,21 +32,20 @@
 
 
 
-namespace camitk
-{
+namespace camitk {
 
 MeshComponentExtension::MeshComponentExtension()
-: ComponentExtension()
-{}
+    : ComponentExtension() {
+}
 
 // --------------- getName -------------------
 QString MeshComponentExtension::getName() const {
-  return "Generic Mesh Volume Manager Plugin";
+    return "Generic Mesh Volume Manager Plugin";
 }
 
 // --------------- getDescription -------------------
 QString MeshComponentExtension::getDescription() const {
-  return "Interface all mesh manager plugins";
+    return tr("Interface all mesh manager plugins");
 }
 
 
