@@ -39,20 +39,19 @@
 #include <QMap>
 
 
-namespace camitk
-{
-/** 
+namespace camitk {
+/**
  * @ingroup group_sdk_libraries_core_component_mesh
- * 
+ *
  * @brief
  * Abstract class created to support export file formats for MeshComponent
  * Any data component plugin creating a MeshComponent should inherit from this class.
- * 
+ *
  */
 
 class CAMITK_API MeshComponentExtension : public ComponentExtension {
 
-  public:
+public:
 
     /// get the plugin name
     virtual QString getName() const;
@@ -62,11 +61,11 @@ class CAMITK_API MeshComponentExtension : public ComponentExtension {
 
     /// get a new instance from data stored in a file (this is the most important method to redefine in your subclass)
     virtual Component * open
-(const QString &) throw (AbortException) = 0;
+    (const QString &) throw (AbortException) = 0;
 
 protected:
     /// Constructor protected because the class is virtual
-    MeshComponentExtension(); 
+    MeshComponentExtension();
 
     /// the destructor
     virtual ~MeshComponentExtension() {};
