@@ -31,11 +31,10 @@
 #include <exception>
 
 
-namespace camitk
-{
-/** 
+namespace camitk {
+/**
  * @ingroup group_sdk_libraries_core_utils
- * 
+ *
  * @brief
  * Exception class to handle abortion in component instanciation.
  * Particularly useful to handle constructor's abortion.
