@@ -34,18 +34,17 @@
 // -- QT stuff
 #include <QTextEdit>
 
-namespace camitk
-{
+namespace camitk {
 /**
- * 
+ *
  * @ingroup group_sdk_libraries_core_utils
- * 
+ *
  * @brief
  * Provides a console windows, within the CamiTK application.
- * 
+ *
  * \image html libraries/console.png "The console widget."
- * 
- * 
+ *
+ *
 Usage:
 \code
 #include <ConsoleStream.h>
@@ -69,8 +68,7 @@ Potential problem on windows (see thread)
 - The usage of int_type seems to require a using std::ios::int_type statement.
 */
 
-class ConsoleStream : public std::basic_streambuf<char>
-{
+class ConsoleStream : public std::basic_streambuf<char> {
 public:
     /// constructor to use when you are sure about both paramaters
     ConsoleStream(std::ostream *stream, QTextEdit* textEdit) {
@@ -123,8 +121,7 @@ protected:
         if (v == '\n') {
             logTextEdit->append(myString.c_str());
             myString.erase(myString.begin(), myString.end());
-        }
-        else
+        } else
             myString += v;
 
         return v;
