@@ -33,8 +33,7 @@
 
 #include <QProcessEnvironment>
 
-namespace camitk
-{
+namespace camitk {
 // global static logfile
 static std::ofstream logFile;
 
@@ -45,34 +44,34 @@ bool Log::showUserInfo = false;
 
 //--------------- showTime ------------------
 void Log::showTime(bool show) {
-  showTimeInfo = show;
+    showTimeInfo = show;
 }
 
 //--------------- getShowTime ------------------
 bool Log::getShowTime() {
-  return showTimeInfo;
+    return showTimeInfo;
 }
 
 //--------------- showUser ------------------
 void Log::showUser(bool show) {
-  showUserInfo = show;
+    showUserInfo = show;
 }
 
 //--------------- getShowUser ------------------
 bool Log::getShowUser() {
-  return showUserInfo;
+    return showUserInfo;
 }
 
 //--------------- getUserInformation ------------------
 std::string Log::getUserInformation() {
-  std::string username= QProcessEnvironment::systemEnvironment().value("USERNAME","").toStdString();
-  if (username == "")
-    username= QProcessEnvironment::systemEnvironment().value("LOGNAME","Unknown User Name").toStdString();
-  return username;
+    std::string username= QProcessEnvironment::systemEnvironment().value("USERNAME","").toStdString();
+    if (username == "")
+        username= QProcessEnvironment::systemEnvironment().value("LOGNAME","Unknown User Name").toStdString();
+    return username;
 }
 
 //---------------openLogFile------------------//
-void Log::openLogFile()   {  
+void Log::openLogFile()   {
     logFile.open("log.txt");
     logFilePtr = new std::ofstream;
     logFilePtr->open("log.txt");
@@ -90,8 +89,8 @@ void Log::closeLogFile()   {
 std::ostream * Log::getLogStream() {
     if (logFilePtr)
         return logFilePtr;
-    else 
-      return &std::cout;
+    else
+        return &std::cout;
 }
 
 }
