@@ -190,8 +190,7 @@ void ObjectControllerPrivate::updateClassProperties ( const QMetaObject *metaObj
                         subProperty->setValue ( flagToInt ( metaProperty.enumerator(), metaProperty.read ( m_object ).toInt() ) );
                     else
                         subProperty->setValue ( enumToInt ( metaProperty.enumerator(), metaProperty.read ( m_object ).toInt() ) );
-                }
-                else {
+                } else {
                     subProperty->setValue ( metaProperty.read ( m_object ) );
                 }
             }
@@ -206,8 +205,7 @@ QtVariantProperty * ObjectControllerPrivate::buildQtVariantProperty(QString name
     if ( !isReadable ) {
         buildProperty = m_readOnlyManager->addProperty ( QVariant::String, name);
         buildProperty->setValue ( QLatin1String ( "< Non Readable >" ) );
-    }
-    else if ( isEnumType ) {
+    } else if ( isEnumType ) {
         if ( isFlagType ) {
             buildProperty = m_manager->addProperty ( QtVariantPropertyManager::flagTypeId(), name );
             QMap<int, bool> valueMap;
@@ -224,8 +222,7 @@ QtVariantProperty * ObjectControllerPrivate::buildQtVariantProperty(QString name
                 buildProperty->setAttribute ( QLatin1String ( "flagNames" ), flagNames );
                 buildProperty->setValue ( flagToInt ( *metaEnum, value.toInt() ) );
             }
-        }
-        else {
+        } else {
             buildProperty = m_manager->addProperty ( QtVariantPropertyManager::enumTypeId(), name);
             QMap<int, bool> valueMap; // dont show multiple enum values which have the same values
             QStringList enumNames;
@@ -242,19 +239,16 @@ QtVariantProperty * ObjectControllerPrivate::buildQtVariantProperty(QString name
             buildProperty->setAttribute ( QLatin1String ( "enumNames" ), enumNames );
             buildProperty->setValue ( enumToInt ( *metaEnum, value.toInt() ) );
         }
-    }
-    else if ( m_manager->isPropertyTypeSupported ( type ) ) {
+    } else if ( m_manager->isPropertyTypeSupported ( type ) ) {
         if ( !isWritable ) {
             buildProperty = m_readOnlyManager->addProperty ( type,  name);
-        }
-        else if ( !isDesignable )
+        } else if ( !isDesignable )
             buildProperty = m_readOnlyManager->addProperty ( type, name + " (Non Designable)" );
         else
             buildProperty = m_manager->addProperty ( type, name );
 
         buildProperty->setValue ( value );
-    }
-    else {
+    } else {
         // a map is managed as a group
         if ( type == QMetaType::QVariantMap) {
             QString mapName = name;
@@ -270,8 +264,7 @@ QtVariantProperty * ObjectControllerPrivate::buildQtVariantProperty(QString name
                 buildProperty->addSubProperty(mapSubProperty);
             }
 
-        }
-        else {
+        } else {
             buildProperty = m_readOnlyManager->addProperty ( QVariant::String, name );
             buildProperty->setValue ( QLatin1String ( "< Unknown Type >" ) );
             buildProperty->setEnabled ( false );
@@ -341,8 +334,7 @@ void ObjectControllerPrivate::updateDynamicProperties ( const QObject *edited )
 
         if ( m_manager->isPropertyTypeSupported ( type ) ) {
             subProperty->setValue ( edited->property ( dynProp.at ( idx ) ) );
-        }
-        else {
+        } else {
             subProperty->setValue ( QLatin1String ( "< Unknown Type >" ) );
         }
     }
@@ -360,7 +352,7 @@ void ObjectControllerPrivate::addDynamicProperties ( QObject *edited ) {
         QVariant pValue = edited->property ( dynProp.at ( idx ) );
         QtVariantProperty  *subProperty = 0;
         QtProperty *groupProperty = NULL;
-        
+
         // check if the edited object use a list of camitk::Property to
         // add more information about the dynamic property
         Property* camitkProp = NULL;
@@ -371,8 +363,7 @@ void ObjectControllerPrivate::addDynamicProperties ( QObject *edited ) {
         if (!getPropertyExist || camitkProp==NULL) {
             // the old way, build a simple dynamic variant property
             subProperty = buildQtVariantProperty(pName, (QMetaType::Type) pValue.userType(), pValue, true, /* isWritable*/ true, false, false, true);
-        }
-        else {
+        } else {
             //-- use all the power of the camitk::Property
             // get then meta enum if available
             if (!camitkProp->getEnumTypeName().isNull()) {
@@ -381,8 +372,7 @@ void ObjectControllerPrivate::addDynamicProperties ( QObject *edited ) {
 
                 // Create the dynamic variant property + use the read only status
                 subProperty = buildQtVariantProperty(pName, (QMetaType::Type) pValue.userType(), pValue, true, /* isWritable*/ !camitkProp->getReadOnly(), true, false, true, &enumType);
-            }
-            else {
+            } else {
                 // Create the dynamic variant property + use the read only status
                 subProperty = buildQtVariantProperty(pName, (QMetaType::Type) pValue.userType(), pValue, true, /* isWritable*/ !camitkProp->getReadOnly(), false, false, true);
             }
@@ -393,23 +383,23 @@ void ObjectControllerPrivate::addDynamicProperties ( QObject *edited ) {
             }
 
 
-/*
-            // check if we can add icons
-            if (!camitkProp->getReadOnly() && !camitkProp->getEnumTypeName().isNull() && camitkProp->getEnumIcons().size()>0) {
-                std::cout << "mgr=" << subProperty->propertyManager() << std::endl;
-                QtEnumPropertyManager *testmgr = dynamic_cast<QtEnumPropertyManager*>(subProperty->propertyManager());
-                std::cout << "testmgr=" << testmgr << std::endl;
-                //m_browser->setFactoryForManager<>();
-                std::cout << "mgr class=" << subProperty->propertyManager()->metaObject()->className() << std::endl;
-                std::cout << "camitkProp->getEnumIcons().size()" << camitkProp->getEnumIcons().size() << std::endl;
-                QVariantMap vmap = camitkProp->getEnumIcons();
-                m_manager->setAttribute(subProperty,"enumIcons", vmap);
-                //m_manager->setUserData();
-                //std::cout << "yep..." << std::endl;
-               
-            }
+            /*
+                        // check if we can add icons
+                        if (!camitkProp->getReadOnly() && !camitkProp->getEnumTypeName().isNull() && camitkProp->getEnumIcons().size()>0) {
+                            std::cout << "mgr=" << subProperty->propertyManager() << std::endl;
+                            QtEnumPropertyManager *testmgr = dynamic_cast<QtEnumPropertyManager*>(subProperty->propertyManager());
+                            std::cout << "testmgr=" << testmgr << std::endl;
+                            //m_browser->setFactoryForManager<>();
+                            std::cout << "mgr class=" << subProperty->propertyManager()->metaObject()->className() << std::endl;
+                            std::cout << "camitkProp->getEnumIcons().size()" << camitkProp->getEnumIcons().size() << std::endl;
+                            QVariantMap vmap = camitkProp->getEnumIcons();
+                            m_manager->setAttribute(subProperty,"enumIcons", vmap);
+                            //m_manager->setUserData();
+                            //std::cout << "yep..." << std::endl;
 
-*/
+                        }
+
+            */
             // use description for tool tip and what's this
             QString description = camitkProp->getDescription();
             subProperty->setWhatsThis(description);
@@ -417,7 +407,7 @@ void ObjectControllerPrivate::addDynamicProperties ( QObject *edited ) {
 
             // remove rich-text for status tip string (using a reg exp)
             subProperty->setStatusTip(description.remove(QRegExp("<[^>]*>")));
-            
+
             //-- check for subgroup
             if (!camitkProp->getGroupName().isNull()) {
                 // check if the group property already exists
@@ -474,8 +464,7 @@ void ObjectControllerPrivate::valueChanged ( QtProperty *property, const QVarian
                 metaProperty.write ( m_object, intToFlag ( metaProperty.enumerator(), value.toInt() ) );
             else
                 metaProperty.write ( m_object, intToEnum ( metaProperty.enumerator(), value.toInt() ) );
-        }
-        else {
+        } else {
             metaProperty.write ( m_object, value );
         }
 
@@ -553,7 +542,7 @@ void ObjectController::setObject ( QObject *object ) {
         }
 
         d_ptr->m_topLevelProperties.clear();
-        
+
         // all the QtProperty instances are delete, just clear the groupProperties map (no need to delete)
         d_ptr->groupProperties.clear();
 
@@ -581,8 +570,7 @@ void ObjectController::setAutoUpdateProperty(bool autoUpdate) {
     if (autoUpdate) {
         connect ( d_ptr->m_manager, SIGNAL ( valueChanged ( QtProperty *, const QVariant & ) ),
                   this, SLOT ( valueChanged ( QtProperty *, const QVariant & ) ) );
-    }
-    else {
+    } else {
         connect ( d_ptr->m_manager, SIGNAL ( valueChanged ( QtProperty *, const QVariant & ) ),
                   this, SLOT ( saveChange ( QtProperty *, const QVariant & ) ) );
     }
@@ -597,8 +585,7 @@ void ObjectController::setViewMode ( ViewMode viewMode ) {
 
         if ( currentViewMode == TREE ) {    // in view mode TREE, the layout contains the property browser
             layout->removeWidget ( d_ptr->m_browser );
-        }
-        else if ( currentViewMode == GROUPBOX || currentViewMode == BUTTON ) { // whereas in view mode BUTTON and GROUPBOX, the layout contains the scroll wich contains the property browser
+        } else if ( currentViewMode == GROUPBOX || currentViewMode == BUTTON ) { // whereas in view mode BUTTON and GROUPBOX, the layout contains the scroll wich contains the property browser
             layout->removeWidget ( scroll );
         }
 
