@@ -26,12 +26,12 @@
 #ifndef OBJECTCONTROLLER_H
 #define OBJECTCONTROLLER_H
 
-// -- Core stuff
+// -- CamiTK includes
 #include "CamiTKAPI.h"
+#include <QtVariantProperty>
 
 // -- QT stuff
 #include <QtGui/QWidget>
-#include <QtVariantProperty>
 #include <QPushButton>
 #include <QVBoxLayout>
 #include <QScrollArea>
@@ -39,24 +39,23 @@
 #include <signal.h>
 
 
-namespace camitk
-{
+namespace camitk {
 class ObjectControllerPrivate;
 
 
-/** 
- * 
+/**
+ *
  * @ingroup group_sdk_libraries_core_utils
- * 
+ *
  * @brief
  * The object controller class.
 
   This is a special "magical" widget.
-  It allows to show the meta properties and dynamic property (see Qt Object Model / Property for lmore
+  It allows one to show the meta properties and dynamic property (see Qt Object Model / Property for lmore
   information on these).
   This class also automatically manage camitk::Property for components and actions.
   It is STRONGLY recommanded to use camitk::Property instead of Qt Meta Object property.
-  
+
   \note
   In order to benefit from the camitk::Property decoration, the class that needs to be edited
   by the ObjectController have to declare a getProperty() method using the Q_INVOKABLE macro.
@@ -77,10 +76,10 @@ class ObjectControllerPrivate;
 
   In order to handle a list of specific properties for your class, you
   have three choices:
-  - use camitk::Property (in Components or Actions): this is the recommanded way. 
+  - use camitk::Property (in Components or Actions): this is the recommanded way.
   camitk:Property overcomes the limitation of dynamic Qt Meta Object Properties.
   - write a new class inheriting from QObject and declare as many Q_PROPERTY as
-  needed. When send to the ObjectController class the Q_PROPERTY list will be 
+  needed. When send to the ObjectController class the Q_PROPERTY list will be
   read and the GUI interfaces build.
   - generate dynamic properties on-the-fly
 
@@ -88,20 +87,20 @@ class ObjectControllerPrivate;
   define min and max values and step for numeric properties as well as precision for
   float/double. A camitk::Property is necessarily dynamic.
   For component and action properties, this is the way to go.
-  
-  For a class that is neither a component or an action, you can still use the second 
-  and third method. 
+
+  For a class that is neither a component or an action, you can still use the second
+  and third method.
   The third method does even not need a new class. You have to create a new QObject
   instance, and add as many dynamic properties as you wish using QObject::setProperty
   method.
   You also have to install an event monitor in your class to be notified when a property
   has changed (see TestClass in "objectcontroller" application).
-  
+
   Three different view mode are available to represent/interact with the property values:
      - TREE based on a list view
      - GROUPBOX same as TREE, but each group of properties are viewed in a group box
      - BUTTON same as GROUPBOX, but buttons allow to show/hide the sub properties
-  
+
   The view mode can be changed at any time, even at run-time (see the "objectcontroller" application).
 
   How to use this class:
@@ -109,7 +108,7 @@ class ObjectControllerPrivate;
 \code
     // default view mode is TREE:
     ObjectController *theController = new ObjectController(this);
-    // Choose another initial view mode:  
+    // Choose another initial view mode:
     ObjectController *theController = new ObjectController(this, ObjectController::BUTTON );
 \endcode
      - to view/interact with the properties of a given QObject:
@@ -178,23 +177,23 @@ public:
 
     /// constructor of object controller with in parameters the parent widget and the view mode (default : TREE)
     ObjectController ( QWidget *parent = 0, ViewMode viewMode = TREE );
-    
+
     /// destructor of object controller
     ~ObjectController();
 
     /// mutatorMethod of the object at unroll in the property browser
     void setObject ( QObject *object );
-    
+
     /// accessorMethod of the object contains in the property browser
     QObject *object() const;
 
     /// if set, the properties are immediatly updated in the managed object (default false)
     void setAutoUpdateProperty(bool);
-    
+
     // [CAMITK ADDED]
     /// mutator Method of the view mode
     void setViewMode ( ViewMode viewMode );
-    
+
     // [CAMITK ADDED]
     /// accessorMethod of the view mode
     ViewMode getViewMode() const;
@@ -207,7 +206,7 @@ public slots:
     // [CAMITK ADDED]
     /// slot to apply change made by the user in the property editor
     void apply();
-    
+
     // [CAMITK ADDED]
     /// slot to revert the values of all properties (revert to values in memory)
     void revert();
@@ -217,7 +216,7 @@ private:
     ObjectControllerPrivate *d_ptr;
     Q_DECLARE_PRIVATE ( ObjectController )
     Q_DISABLE_COPY ( ObjectController )
-    
+
     // [CAMITK CHANGED]
     Q_PRIVATE_SLOT ( d_func(), void saveChange ( QtProperty *, const QVariant & ) )
     Q_PRIVATE_SLOT ( d_func(), void valueChanged ( QtProperty *, const QVariant & ) )
@@ -232,7 +231,7 @@ private:
 
     /// layout which will contains the propertybrowser and, in view mode GROUPBOX and BUTTON, the scroll
     QVBoxLayout *layout;
-    
+
     /// scroll add to navigate in the property browser
     QScrollArea *scroll;
 
@@ -295,11 +294,11 @@ public:
 
     /// the property manager for the read only property
     QtVariantPropertyManager *m_readOnlyManager;
-    
+
     // [CAMITK ADDED]
     /// build a QtVariantProperty from name, type, property...etc...
     QtVariantProperty * buildQtVariantProperty(QString name, QMetaType::Type type, QVariant value, bool isReadable, bool isWritable, bool isEnumType, bool isFlagType, bool isDesignable, QMetaEnum * metaEnum = NULL);
-    
+
     /// map of all the QtProperty that are top-level groups
     QMap<QString, QtProperty*> groupProperties;
 };
