@@ -35,32 +35,30 @@ class vtkActor;
 class vtkProperty;
 
 
-namespace camitk
-{
-/** 
+namespace camitk {
+/**
  * @ingroup group_sdk_libraries_core_utils
- * 
+ *
  * @brief
  * This class allows you to transform a plane(translation,rotation around an axis)
  * and visualize it.
  *
  *  This is a pure vtk wrapper class (no Core stuff).
  *
- * 
+ *
  */
 
-class  PlaneC
-{
-  public:
+class  PlaneC {
+public:
     /** a planeC could represent a plane of a bounding box */
     enum PlaneCType {
-      X_MIN, /**< the plane's normal is in X direction, the plane is at the min x */
-      Y_MIN, /**< the plane's normal is in Y direction, the plane is at the min y */
-      Z_MIN, /**< the plane's normal is in Z direction, the plane is at the min z */
-      X_MAX, /**< the plane's normal is in X direction, the plane is at the max x */
-      Y_MAX, /**< the plane's normal is in Y direction, the plane is at the max y */
-      Z_MAX, /**< the plane's normal is in Z direction, the plane is at the max z */
-      UNDEFINED, /**< the plane's normal is not defined yet */
+        X_MIN, /**< the plane's normal is in X direction, the plane is at the min x */
+        Y_MIN, /**< the plane's normal is in Y direction, the plane is at the min y */
+        Z_MIN, /**< the plane's normal is in Z direction, the plane is at the min z */
+        X_MAX, /**< the plane's normal is in X direction, the plane is at the max x */
+        Y_MAX, /**< the plane's normal is in Y direction, the plane is at the max y */
+        Z_MAX, /**< the plane's normal is in Z direction, the plane is at the max z */
+        UNDEFINED, /**< the plane's normal is not defined yet */
     };
     /**Constructor by default*/
     PlaneC();
@@ -117,7 +115,7 @@ class  PlaneC
 
 
 
-  private:
+private:
     vtkSmartPointer<vtkPlaneSource> plane;
     vtkSmartPointer<vtkPolyDataMapper> planeMapper;
     vtkSmartPointer<vtkActor> planeActor;
