@@ -31,28 +31,27 @@
 #include <QHBoxLayout>
 
 
-namespace camitk
-{
+namespace camitk {
 //--------------------- constructor ------------------------
 SliderSpinBoxWidget::SliderSpinBoxWidget(QWidget *parent) : QWidget(parent) {
 
-  setObjectName("camitk::SliderSpinBoxWidget");
+    setObjectName("camitk::SliderSpinBoxWidget");
 
-  //-- create UI
-  QVBoxLayout *vLayout= new QVBoxLayout(this);
+    //-- create UI
+    QVBoxLayout *vLayout= new QVBoxLayout(this);
 
-  spinBox = new QSpinBox;
-  spinBox->setFixedWidth(60);
-  vLayout->addWidget(spinBox);
+    spinBox = new QSpinBox;
+    spinBox->setFixedWidth(60);
+    vLayout->addWidget(spinBox);
 
-  QHBoxLayout *hLayout = new QHBoxLayout();
-  vLayout->addLayout(hLayout);
-  slider = new QSlider(Qt::Vertical);
-  hLayout->addWidget(slider);
+    QHBoxLayout *hLayout = new QHBoxLayout();
+    vLayout->addLayout(hLayout);
+    slider = new QSlider(Qt::Vertical);
+    hLayout->addWidget(slider);
 
-  //-- connect for synchronization
-  connect(spinBox, SIGNAL(valueChanged(int)), SLOT(spinBoxValueChanged(int)));
-  connect(slider, SIGNAL(valueChanged(int)), SLOT(sliderValueChanged(int)));
+    //-- connect for synchronization
+    connect(spinBox, SIGNAL(valueChanged(int)), SLOT(spinBoxValueChanged(int)));
+    connect(slider, SIGNAL(valueChanged(int)), SLOT(sliderValueChanged(int)));
 }
 
 //--------------------- destructor ------------------------
@@ -61,42 +60,42 @@ SliderSpinBoxWidget::~SliderSpinBoxWidget() {
 
 //--------------------- getValue ------------------------
 int SliderSpinBoxWidget::getValue() const {
-  return slider->value();
+    return slider->value();
 }
 
 //--------------------- setValue ------------------------
 void SliderSpinBoxWidget::setValue(int value) {
-  if (getValue() != value) {
-    updateSpinBoxValue(value);
-    updateSliderValue(value);
-  }
+    if (getValue() != value) {
+        updateSpinBoxValue(value);
+        updateSliderValue(value);
+    }
 }
 
 //--------------------- setRange ------------------------
 void SliderSpinBoxWidget::setRange(int min, int max) {
-  int pageStep = (max - min) / 10;
+    int pageStep = (max - min) / 10;
 
-  if (pageStep < 1)
-    pageStep = 1;
+    if (pageStep < 1)
+        pageStep = 1;
 
-  slider->setRange(min, max);
-  slider->setSingleStep(1);
-  slider->setPageStep(pageStep);
+    slider->setRange(min, max);
+    slider->setSingleStep(1);
+    slider->setPageStep(pageStep);
 
-  spinBox->setRange(min,max);
-  spinBox->setSingleStep(1);
+    spinBox->setRange(min,max);
+    spinBox->setSingleStep(1);
 }
 
 //--------------------- spinBoxValueChanged ------------------------
 void SliderSpinBoxWidget::spinBoxValueChanged(int value) {
-  updateSliderValue(value);
-  emit valueChanged(value);
+    updateSliderValue(value);
+    emit valueChanged(value);
 }
 
 //--------------------- sliderValueChanged ------------------------
 void SliderSpinBoxWidget::sliderValueChanged(int value) {
-  updateSpinBoxValue(value);
-  emit valueChanged(value);
+    updateSpinBoxValue(value);
+    emit valueChanged(value);
 }
 
 //--------------------- updateSpinBoxValue ------------------------
@@ -105,60 +104,60 @@ void SliderSpinBoxWidget::updateSpinBoxValue(int value) {
     bool alreadyBlocked = spinBox->signalsBlocked();
 
     if (!alreadyBlocked)
-      spinBox->blockSignals(true);
+        spinBox->blockSignals(true);
 
     spinBox->setValue(value);
 
     if (!alreadyBlocked)
-      spinBox->blockSignals(false);
+        spinBox->blockSignals(false);
 }
 
 //--------------------- updateSliderValue ------------------------
 void SliderSpinBoxWidget::updateSliderValue(int value) {
-  // -- set the slider value
-  bool alreadyBlocked = slider->signalsBlocked();
+    // -- set the slider value
+    bool alreadyBlocked = slider->signalsBlocked();
 
-  if (!alreadyBlocked)
-    slider->blockSignals(true);
+    if (!alreadyBlocked)
+        slider->blockSignals(true);
 
-  slider->setValue(value);
+    slider->setValue(value);
 
-  if (!alreadyBlocked)
-    slider->blockSignals(false);
+    if (!alreadyBlocked)
+        slider->blockSignals(false);
 }
 
 
 //--------------------- addSingleStep ------------------------
 void SliderSpinBoxWidget::addSingleStep() {
-  if (slider->value() <= (slider->maximum() - slider->singleStep()))
-    setValue(slider->value() + slider->singleStep());
-  else
-    setValue(slider->maximum());
+    if (slider->value() <= (slider->maximum() - slider->singleStep()))
+        setValue(slider->value() + slider->singleStep());
+    else
+        setValue(slider->maximum());
 }
 
 //--------------------- subSingleStep ------------------------
 void SliderSpinBoxWidget::subSingleStep() {
-  if (slider->value() >= (slider->minimum() + slider->singleStep()))
-    setValue(slider->value() - slider->singleStep());
-  else
-    setValue(slider->minimum());
+    if (slider->value() >= (slider->minimum() + slider->singleStep()))
+        setValue(slider->value() - slider->singleStep());
+    else
+        setValue(slider->minimum());
 }
 
 
 //--------------------- addPageStep ------------------------
 void SliderSpinBoxWidget::addPageStep() {
-  if (slider->value() <= (slider->maximum() - slider->pageStep()))
-    setValue(slider->value() + slider->pageStep());
-  else
-    setValue(slider->maximum());
+    if (slider->value() <= (slider->maximum() - slider->pageStep()))
+        setValue(slider->value() + slider->pageStep());
+    else
+        setValue(slider->maximum());
 }
 
 //--------------------- subPageStep ------------------------
 void SliderSpinBoxWidget::subPageStep() {
-  if (slider->value() >= (slider->minimum() + slider->pageStep()))
-    setValue(slider->value() - slider->pageStep());
-  else
-    setValue(slider->minimum());
+    if (slider->value() >= (slider->minimum() + slider->pageStep()))
+        setValue(slider->value() - slider->pageStep());
+    else
+        setValue(slider->minimum());
 }
 
 
