@@ -36,11 +36,10 @@
 #include <QSlider>
 
 
-namespace camitk
-{
-/** 
+namespace camitk {
+/**
  * @ingroup group_sdk_libraries_core_utils
- * 
+ *
  * @brief
  * This widget allows you to use a slider with a lineedit in a Dialog Box.
  * The [min,max] interval is divided by 100 line steps (10 page steps),
@@ -54,12 +53,12 @@ namespace camitk
  * In line edit, if the value is superior or inferior than the initial bounds, the
  * bounds are automatically updated.
  *
- *  
+ *
  */
 class CAMITK_API SliderTextWidget : public QWidget {
     Q_OBJECT
 
-  public:
+public:
     /// Default constructor, name is automatically used as the text label
     SliderTextWidget(QWidget* parent = 0, Qt::WFlags fl = 0);
 
@@ -80,13 +79,13 @@ class CAMITK_API SliderTextWidget : public QWidget {
     /// Update slider and lineedit GUI, emit the valueChanged signal only if the boolean is true (default=no)
     void setValue(const double, bool emitValueChanged = false);
 
-  signals:
+signals:
 
     /// Signal emitted when the value has changed (either directly using the slider or when the user pressed return)
     void valueChanged();
 
 
-  protected slots:
+protected slots:
     /// when the user press return in the line edit
     void returnPressed();
 
@@ -96,7 +95,7 @@ class CAMITK_API SliderTextWidget : public QWidget {
     /// When the user change the text
     void textModified(const QString &);
 
-  private:
+private:
     /// update the slider position
     void updateSlider();
 
@@ -132,7 +131,7 @@ class CAMITK_API SliderTextWidget : public QWidget {
 };
 
 inline double SliderTextWidget::getValue() const {
-  return value;
+    return value;
 }
 
 }
