@@ -34,6 +34,7 @@
 #include <QCompleter>
 #include <QLineEdit>
 #include <QDialog>
+#include <QGridLayout>
 
 #include "Log.h"
 
@@ -76,8 +77,7 @@ QWidget * ActionViewer::getWidget(QWidget * parent) {
             QDialog *myWidgetIsADialog = new QDialog(NULL);
             myWidgetIsADialog->setWindowTitle(objectName());
             myWidget = myWidgetIsADialog;
-        }
-        else
+        } else
             myWidget = new QWidget();
 
         QVBoxLayout * actionWidgetLayout = new QVBoxLayout();
@@ -119,6 +119,8 @@ QWidget * ActionViewer::getWidget(QWidget * parent) {
         myWidget->setLayout(actionWidgetLayout);
     }
 
+    // limit the width
+    myWidget->setMaximumWidth(450);
     return myWidget;
 }
 
@@ -132,8 +134,7 @@ void ActionViewer::setSearchPanelVisible(bool visibility) {
             QObject::connect(familyComboBox, SIGNAL(activated(int)), this, SLOT(changeFamily()));
             QObject::connect(nameComboBox, SIGNAL(activated(int)), this, SLOT(changeName()));
             QObject::connect(tagLineEdit, SIGNAL(editingFinished ()), this, SLOT(changeTag()));
-        }
-        else {
+        } else {
             // disconnect buttons
             QObject::disconnect(familyComboBox, SIGNAL(activated(int)), this, SLOT(changeFamily()));
             QObject::disconnect(nameComboBox, SIGNAL(activated(int)), this, SLOT(changeName()));
@@ -185,117 +186,115 @@ void ActionViewer::updateActionViewer(UpdateReason reason) {
     ActionList possibleActions;
 
     switch (reason) {
-        case ActionFamilyChanged:
-            //-- family was changed, fill the name combo box with this family actions
-            nameComboBox->clear();
-            nameComboBox->addItem("-- Select Action --");
+    case ActionFamilyChanged:
+        //-- family was changed, fill the name combo box with this family actions
+        nameComboBox->clear();
+        nameComboBox->addItem("-- Select Action --");
 
-            if (Application::getSelectedComponents().size() > 0)
-                possibleActions = Application::getActions(Application::getSelectedComponents());
-            else
-                // no selection => select only empty component actions
-                possibleActions = Application::getActions(NULL);
+        if (Application::getSelectedComponents().size() > 0)
+            possibleActions = Application::getActions(Application::getSelectedComponents());
+        else
+            // no selection => select only empty component actions
+            possibleActions = Application::getActions(NULL);
 
-            foreach (Action * action, possibleActions) {
-                if (action->getFamily() == familyComboBox->currentText() || familyComboBox->currentText() == QString("-- Select Family --"))
-                    nameComboBox->addItem(action->getName());
-            }
-            nameComboBox->model()->sort(0);
-            break;
+        foreach (Action * action, possibleActions) {
+            if (action->getFamily() == familyComboBox->currentText() || familyComboBox->currentText() == QString("-- Select Family --"))
+                nameComboBox->addItem(action->getName());
+        }
+        nameComboBox->model()->sort(0);
+        break;
 
-        case ActionNameChanged:
+    case ActionNameChanged:
 
-            //-- action name whas changed -> trigger the corresponding action
-            if (action) {
-                familyComboBox->setCurrentIndex(familyComboBox->findText(action->getFamily()));
-                action->trigger();
-            }
+        //-- action name whas changed -> trigger the corresponding action
+        if (action) {
+            familyComboBox->setCurrentIndex(familyComboBox->findText(action->getFamily()));
+            action->trigger();
+        }
 
-            break;
+        break;
 
-        case ActionTagChanged: {
-                //-- tag field was changed, fill the name combo box with the corresponding actions
-                ActionList actionset = Application::getActions(Application::getSelectedComponents(), tagLineEdit->text());
+    case ActionTagChanged: {
+        //-- tag field was changed, fill the name combo box with the corresponding actions
+        ActionList actionset = Application::getActions(Application::getSelectedComponents(), tagLineEdit->text());
 
-                if (!actionset.isEmpty()) {
-                    if (1 == actionset.size()) {
-                        action = *(actionset.begin());
-                        nameComboBox->setCurrentIndex(nameComboBox->findText(action->getName()));
-                        updateActionViewer(ActionNameChanged);
-                    }
-                    else {
-                        nameComboBox->clear();
-                        nameComboBox->addItem("-- Select Action --");
-                        foreach (Action * action, actionset) {
-                            nameComboBox->addItem(action->getName());
-                        }
-                    }
-
-                    nameComboBox->model()->sort(0);
-                }
-            }
-            break;
-
-        case ViewerRefresh:
-        default: {
-                //-- selection was changed, update combo boxes and tag list, and then check history
-                // copy selected component list (so that references are not used for comparison)
-                ComponentList selected(Application::getSelectedComponents());
-
-                //-- update the search panel
-                familyComboBox->clear();
+        if (!actionset.isEmpty()) {
+            if (1 == actionset.size()) {
+                action = *(actionset.begin());
+                nameComboBox->setCurrentIndex(nameComboBox->findText(action->getName()));
+                updateActionViewer(ActionNameChanged);
+            } else {
                 nameComboBox->clear();
-                QStringList wordList;
-                familyComboBox->addItem("-- Select Family --");
                 nameComboBox->addItem("-- Select Action --");
-
-                if (selected.size() > 0)
-                    possibleActions = Application::getActions(selected.last());
-                else
-                    // no selection => select only empty component actions
-                    possibleActions = Application::getActions(NULL);
-
-                // Complete family and action lists depending of the last selected component
-                foreach (Action * action, possibleActions) {
-                    if (familyComboBox->findText(action->getFamily()) == -1)
-                        familyComboBox->addItem(action->getFamily());
-
-                    if (nameComboBox->findText(action->getName()) == -1)
-                        nameComboBox->addItem(action->getName());
-
-                    foreach(QString tag, action->getTag()) {
-                        if (!wordList.contains(tag))
-                            wordList.append(tag);
-                    }
-                }
-                nameComboBox->model()->sort(0);
-                familyComboBox->model()->sort(0);
-
-                QCompleter * completer = new QCompleter(wordList, myWidget);
-                completer->setCaseSensitivity(Qt::CaseInsensitive);
-                tagLineEdit->setCompleter(completer);
-
-                //-- check history
-                // check if the same list of Component* was already used
-                QMap<ComponentList, Action*>::const_iterator it = widgetHistory.find(selected);
-
-                if (it != widgetHistory.end()) {
-                    // show the previously used widget
-                    if (it.value() == NULL)
-                        actionWidgetStack->setCurrentIndex(emptyActionWidgetIndex);
-                    else {
-                        // update search panel
-                        familyComboBox->setCurrentIndex(familyComboBox->findText(it.value()->getFamily()));
-                        nameComboBox->setCurrentIndex(nameComboBox->findText(it.value()->getName()));
-                        it.value()->trigger();
-                    }
-                }
-                else {
-                    // insert new index in history (NULL action, with empty widget)
-                    widgetHistory.insert(selected, NULL);
-                    actionWidgetStack->setCurrentIndex(emptyActionWidgetIndex);
+                foreach (Action * action, actionset) {
+                    nameComboBox->addItem(action->getName());
                 }
             }
+
+            nameComboBox->model()->sort(0);
+        }
+    }
+    break;
+
+    case ViewerRefresh:
+    default: {
+        //-- selection was changed, update combo boxes and tag list, and then check history
+        // copy selected component list (so that references are not used for comparison)
+        ComponentList selected(Application::getSelectedComponents());
+
+        //-- update the search panel
+        familyComboBox->clear();
+        nameComboBox->clear();
+        QStringList wordList;
+        familyComboBox->addItem("-- Select Family --");
+        nameComboBox->addItem("-- Select Action --");
+
+        if (selected.size() > 0)
+            possibleActions = Application::getActions(selected.last());
+        else
+            // no selection => select only empty component actions
+            possibleActions = Application::getActions(NULL);
+
+        // Complete family and action lists depending of the last selected component
+        foreach (Action * action, possibleActions) {
+            if (familyComboBox->findText(action->getFamily()) == -1)
+                familyComboBox->addItem(action->getFamily());
+
+            if (nameComboBox->findText(action->getName()) == -1)
+                nameComboBox->addItem(action->getName());
+
+            foreach(QString tag, action->getTag()) {
+                if (!wordList.contains(tag))
+                    wordList.append(tag);
+            }
+        }
+        nameComboBox->model()->sort(0);
+        familyComboBox->model()->sort(0);
+
+        QCompleter * completer = new QCompleter(wordList, myWidget);
+        completer->setCaseSensitivity(Qt::CaseInsensitive);
+        tagLineEdit->setCompleter(completer);
+
+        //-- check history
+        // check if the same list of Component* was already used
+        QMap<ComponentList, Action*>::const_iterator it = widgetHistory.find(selected);
+
+        if (it != widgetHistory.end()) {
+            // show the previously used widget
+            if (it.value() == NULL)
+                actionWidgetStack->setCurrentIndex(emptyActionWidgetIndex);
+            else {
+                // update search panel
+                familyComboBox->setCurrentIndex(familyComboBox->findText(it.value()->getFamily()));
+                nameComboBox->setCurrentIndex(nameComboBox->findText(it.value()->getName()));
+                it.value()->trigger();
+            }
+        } else {
+            // insert new index in history (NULL action, with empty widget)
+            widgetHistory.insert(selected, NULL);
+            actionWidgetStack->setCurrentIndex(emptyActionWidgetIndex);
+        }
+    }
     }
 
     familyComboBox->blockSignals(false);
@@ -328,7 +327,7 @@ void ActionViewer::embedActionWidget(Action *action) {
 
     // update search panel
     familyComboBox->setCurrentIndex(familyComboBox->findText(action->getFamily()));
-    updateActionViewer(ActionFamilyChanged); // to have only the actions of the same family 
+    updateActionViewer(ActionFamilyChanged); // to have only the actions of the same family
     nameComboBox->setCurrentIndex(nameComboBox->findText(action->getName()));
 }
 
