@@ -351,7 +351,7 @@ void Explorer::rightButtonPressed(const QPoint &clickedPoint) {
 
     if (selected) {
         Component * comp = (Component *) itemComponentMap.value(selected);
-        QMenu *actionsMenu = comp->getActionAndPopupMenu();
+        QMenu *actionsMenu = comp->getActionMenu();
         if (actionsMenu)
             actionsMenu->exec(QCursor::pos());
     }
@@ -377,7 +377,7 @@ void Explorer::renameItem() {
         }
 
     } else
-        QMessageBox::information(explorerTree, "Rename", "Please select an element in the explirer! \n");
+        QMessageBox::information(explorerTree, "Rename", tr("Please select an element in the explirer! \n"));
 }
 
 
