@@ -34,8 +34,7 @@
 #include <QTreeWidget>
 #include <QTreeWidgetItem>
 
-namespace camitk
-{
+namespace camitk {
 // -- Core stuff classes
 class InterfaceNode;
 class Component;
@@ -44,14 +43,14 @@ class Explorer;
 
 /**
  * @ingroup group_sdk_libraries_core_viewer
- * 
+ *
  * @brief
  * Explorer window, display the list of all data currently opened in the application.
  * All objects are displayed in a QListView widget and can be selected
  * (single/multiple selection is available).
- * 
+ *
  * \image html libraries/explorer.png "The component explorer viewer."
- * 
+ *
  * This viewer also manages a singleton (THE CamiTK explorer). See getInstance() for more information.
  * You do not have to use it, but it is convienent (and sometimes preferable) to use this instance
  * instead of creating your own one.
@@ -72,7 +71,7 @@ public:
     /// returns the unique instance of ActionViewer
     static Explorer* getInstance();
     /// @}
-    
+
     /** @name Inherited from Viewer
       */
     ///@{
