@@ -35,6 +35,8 @@
 //-- QT stuff
 #include <QFrame>
 #include <QPushButton>
+#include <QWidgetAction>
+#include <QComboBox>
 
 //-- vtk stuff
 #include <vtkType.h>
@@ -46,6 +48,7 @@ class vtkPicker;
 class vtkProp;
 class vtkObject;
 class vtkCamera;
+class vtkEventQtSlotConnect;
 
 namespace camitk {
 // -- Core stuff classes
@@ -73,7 +76,7 @@ protected:
 
 /**
   * @ingroup group_sdk_libraries_core_viewer
-  * 
+  *
   * @brief
   * InteractiveViewer is used to view 3D objects and slices (anything that provides either a InterfaceBitMap
   * or a InterfaceGeometry).
@@ -100,7 +103,7 @@ protected:
   * will return the corresponding default InteractiveViewer instance.
   * The list of InteractiveViewer instances is kept in this class as well.
   *
-  * InteractiveViewer class is completely independant from MainWindow application skeleton (and please keep it that way!)
+  * InteractiveViewer class is completely independent from MainWindow application skeleton (and please keep it that way!)
   *
   * InteractiveViewer manages a list of cameras. Each camera has a name. Use getCamera(QString) to
   * create a new camera, or get the default camera and setActiveCamera(QString) to change the active
@@ -128,7 +131,7 @@ protected:
   * Ctrl-Letter/Digit shortcuts should only be used for the application shortcuts.
   *
   * 2. That's it for now!
-  * 
+  *
   */
 
 class CAMITK_API InteractiveViewer : public Viewer {
@@ -154,10 +157,12 @@ public:
         PIXEL_PICKING,  ///< pick a pixel on a Slice
         POINT_PICKING,  ///< pick a point in the VTK representation of an Geometry
         CELL_PICKING,   ///< pick a cell in the VTK representation of an Geometry
+        AREA_CELL_PICKING, ///< pick cells that are inside a rectangular area in the VTK representation of an Geometry
+        AREA_POINT_PICKING, ///< pick points that are inside a rectangular area in the VTK representation of an Geometry
         NO_PICKING     ///< no picking possible
     };
 
-    /** \enum HighlightMode describes the current mode of display. It is usefull to change the
+    /** \enum HighlightMode describes the current mode of display. It is useful to change the
       * way the currently selected Components look compared to the unselected ones.
       * In the default mode a Component is not highlighted, not shaded and not hidden.
       */
@@ -242,13 +247,13 @@ public:
       * This method does not activate the given camera, please use setActiveCamera for this.
       */
     vtkSmartPointer<vtkCamera> getCamera ( QString cameraName = "default" );
-    
+
     /// call this method to take a screenshot using the given filename (the extension must be a supported format extension, see class RendererWindow)
     void screenshot ( QString );
 
 public slots:
     /// call this method to take a screenshot in various format and write the resulting image to a file
-    void screenshot();    
+    void screenshot();
     /// @}
 
     /** @name Viewing/Interaction Property
@@ -281,7 +286,7 @@ public slots:
       *
       * \note it is only possible to transform lines to tubes if
       * you build an Geometry using lines.
-      * 
+      *
       * @param tubes if true, then the lines have to be displayed as tube
       */
     void setLinesAsTubes ( bool tubes );
@@ -355,12 +360,6 @@ public:
 
 public slots:
 
-    /** Slot activated when something was picked in the 3D interactor.
-     * Process the picker accordingly to the current pickingMode state.
-     * It is connected to the RendererWidget actorPicked signal
-     */
-    void actorPicked ( vtkSmartPointer<vtkPicker> );
-
     /** Slot called when the InteractiveViewer slider has been changed. If there is a InterfaceBitMap in the scene,
      *    set the slice index with the new slider value. */
     void sliderChanged ( int );
@@ -457,7 +456,7 @@ protected:
 
     /// the right side frame (this is where the slider and screenshot buttons are shown)
     QFrame *sideFrame;
-    
+
     /// the InteractiveViewerFrame keyPressEvent is a good friend of InteractiveViewer
     friend void InteractiveViewerFrame::keyPressEvent ( QKeyEvent* e );
 
@@ -483,7 +482,7 @@ protected:
     QAction *pointsAction;
     QAction *colorAction;
     QAction *glyphAction;
-    
+
     /// display mode
     QAction *highlightSelectionAction;
     QAction *highlightSelectionOnlyAction;
@@ -501,16 +500,19 @@ protected:
     /// background color
     QAction *backgroundColorAction;
 
-    /// button allows to display the Axes in the InteractiveViewer
+    /// button allows one to display the Axes in the InteractiveViewer
     QAction *toggleAxesAction;
 
+    /// button allows one to display orientation decoration in SLICE_VIEWER mode
+    QAction *toggleOrientationDecorationsAction;
+
     /// button to remove the copyright
     QAction *toggleCopyrightAction;
 
-    /// button allows to display the labels of the object3D
+    /// button allows one to display the labels of the object3D
     QAction *toggleLabelAction;
 
-    /// button allows to display the lines as tubes (the lines are to be in vtkPolyData)
+    /// button allows one to display the lines as tubes (the lines are to be in vtkPolyData)
     QAction *toggleLinesAsTubesAction;
 
     /// back face culling
@@ -519,8 +521,10 @@ protected:
     /// action of the picking menu
     QAction *pickPointAction;
     QAction *pickCellAction;
+    QAction* pickCellRegionAction;
+    QAction* pickPointRegionAction;
     //TODO QAction *pickRegionAction; /// to pick a region by selecting top left / bottom right corners
-    
+
     ///@}
 
     /** @name Picking management
@@ -540,6 +544,9 @@ protected:
 
     /// was the picking effect updated (it has to be updated with the first picking for a given button down session)
     bool pickingEffectUpdated;
+
+    vtkSmartPointer<vtkEventQtSlotConnect> connector;
+
     ///@}
 
 
@@ -581,15 +588,20 @@ protected slots:
 
     void toggleAxes ( bool );
 
+    void toggleOrientationDecorations ( bool );
+
     void pickingModeChanged ( QAction* );
 
+    /// get the picker and populate the picked component with the picked stuff
+    void picked();
+
     void rightClick();
 
     /// if true currently selected Components label will have their label on (shown)
     void setLabel (bool);
 
     void setGlyph(bool);
-    
+
     ///@}
 };
 
