@@ -84,7 +84,7 @@ unsigned int MedicalImageViewer::numberOfViewedComponent() {
 void MedicalImageViewer::refresh(Viewer *whoIsAsking) {
     // just tell everyone to update!
     foreach(Viewer *v, viewers.values())
-        v->refresh(this);
+    v->refresh(this);
 
     // view everything?
     if (displayedTopLevelComponents != (unsigned) Application::getTopLevelComponents().size()) {
@@ -94,8 +94,7 @@ void MedicalImageViewer::refresh(Viewer *whoIsAsking) {
                 && InteractiveViewer::getCoronalViewer()->numberOfViewedComponent() > 0
                 && InteractiveViewer::getSagittalViewer()->numberOfViewedComponent() > 0) {
             visibleLayout = VIEWER_ALL;
-        }
-        else {
+        } else {
             visibleLayout = VIEWER_3D;
         }
 
@@ -133,13 +132,23 @@ QWidget * MedicalImageViewer::getWidget(QWidget * parent) {
         viewers.insert(VIEWER_SAGITTAL, InteractiveViewer::getSagittalViewer());
 
         //-- add the InteractiveViewers
+//        topLeftLayout = new QVBoxLayout();
+//        frameLayout->addLayout(topLeftLayout, 0, 0);
+//        topLeftLayout->addWidget(InteractiveViewer::getAxialViewer()->getWidget(frame)); // north-west
+//        topLeftLayout->addWidget(InteractiveViewer::getArbitraryViewer()->getWidget(frame)); // north-west
+//        frameLayout->addWidget(InteractiveViewer::getCoronalViewer()->getWidget(frame), 0, 1); // north-east
+//        frameLayout->addWidget(InteractiveViewer::getSagittalViewer()->getWidget(frame), 1, 0); // south-west
+//        frameLayout->addWidget(InteractiveViewer::get3DViewer()->getWidget(frame), 1, 1); // south-east
+
         topLeftLayout = new QVBoxLayout();
         frameLayout->addLayout(topLeftLayout, 0, 0);
-        topLeftLayout->addWidget(InteractiveViewer::getAxialViewer()->getWidget(frame)); // north-west
-        topLeftLayout->addWidget(InteractiveViewer::getArbitraryViewer()->getWidget(frame)); // north-west
-        frameLayout->addWidget(InteractiveViewer::getCoronalViewer()->getWidget(frame), 0, 1); // north-east
-        frameLayout->addWidget(InteractiveViewer::getSagittalViewer()->getWidget(frame), 1, 0); // south-west
-        frameLayout->addWidget(InteractiveViewer::get3DViewer()->getWidget(frame), 1, 1); // south-east
+        topLeftLayout->addWidget(InteractiveViewer::getAxialViewer()->getWidget(frame));
+//        frameLayout->addWidget(InteractiveViewer::getAxialViewer()->getWidget(frame), 0, 0); // north-west
+        frameLayout->addWidget(InteractiveViewer::getCoronalViewer()->getWidget(frame), 1, 0); // north-east
+        frameLayout->addWidget(InteractiveViewer::getSagittalViewer()->getWidget(frame), 1, 1); // south-west
+        frameLayout->addWidget(InteractiveViewer::get3DViewer()->getWidget(frame), 0, 1); // south-east
+
+
 
         //-- connect
         foreach(LayoutVisibility v, viewerVisibility) {
@@ -219,8 +228,7 @@ void MedicalImageViewer::updateLayout() {
         viewers.value(VIEWER_CORONAL)->getWidget(frame)->show();
         viewers.value(VIEWER_SAGITTAL)->getWidget(frame)->show();
         viewers.value(VIEWER_ARBITRARY)->getWidget(frame)->hide();
-    }
-    else {
+    } else {
         for (unsigned int i=0; viewerVisibility[i]!=VIEWER_ALL; i++) {
             viewers.value(viewerVisibility[i])->getWidget(frame)->hide();
         }
