@@ -39,15 +39,16 @@
 // -- QT stuff classes
 class QTabWidget;
 class QPushButton;
+class QWidget;
 
 namespace camitk {
 
 
 class ObjectController;
 
-/** 
+/**
  * @ingroup group_sdk_libraries_core_viewer
- * 
+ *
  * @brief
  * The property explorer.
  *
@@ -55,7 +56,7 @@ class ObjectController;
  * bellow the explorer. It has a default tab (property editor) and can
  * include any number of other tabs (where you can, of course, have any kind of widgets
  * you want: slider, labels, text, ...).
- * 
+ *
  * \image html libraries/propertyexplorer.png "The property explorer viewer."
  *
  * The property editor is a "magic" widget (aka as "poOOowerful" widget)
@@ -76,7 +77,7 @@ class ObjectController;
  * This viewer also manages a singleton (THE CamiTK PropertyExplorer). See getInstance() for more information.
  * You do not have to use it, but it is convienent (and sometimes preferable) to use this instance
  * instead of creating your own one.
- * 
+ *
  * @see ObjectController
  */
 class CAMITK_API PropertyExplorer : public Viewer {
@@ -94,10 +95,10 @@ public:
     /// destructor
     virtual ~PropertyExplorer();
 
-        /// returns the unique instance of ActionViewer
+    /// returns the unique instance of the PropertyExplorer
     static PropertyExplorer* getInstance();
     ///@}
-    
+
     /** @name Inherited from Viewer
       */
     ///@{
@@ -123,9 +124,25 @@ public:
     /// set the view mode
     void setViewMode(ObjectController::ViewMode);
     ///@}
-    
+
+    ///@name Tab selection management
+    ///@{
+
+    /// Select the tab containing the given widget in the PropertyExplorer.
+    /// @param widget the PropertyExplorer's widget of the tab to select.
+    /// @note the widget must have been previously added to the PropertyExplorer.
+    void selectWidget(QWidget* widget);
+
+    /// Select the tab of the given index in the PropertyExplorer.
+    /// @param index the index of the tab to display.
+    /// @note 0 <= index < currentComponent->getNumberOfPropertyWidget() else nothing is done
+    void selectIndex(unsigned int index);
+
+    ///@}
+
+
 private:
-    
+
     /// the widgets
     ObjectController *theController;
     QTabWidget *tabWidget;
@@ -140,6 +157,15 @@ private:
       * \note this method does not delete the different widgets that were included in the tabs, the Component should do it.
       */
     void clear();
+
+private slots:
+
+    /**
+     *  Update the PropertyExplorer tab index to display for the currently selected component
+     *  This method is used by the PropertyExplorer to tell for each component which tab has been selected for display.
+     *  @param index The index of the PropertyExplorer tab to display for the currently selected component.
+     **/
+    void updateTabIndexToDisplay(int index);
 };
 }
 #endif
