@@ -35,6 +35,7 @@
 #include <QCursor>
 
 // -- VTK stuff
+#include <vtkObjectFactory.h>
 // ---- SmartPointer
 #include <vtkSmartPointer.h>
 // ---- Interactor
@@ -76,6 +77,7 @@
 // ---- Picking
 #include <vtkPicker.h>
 #include <vtkProp3DCollection.h>
+#include <vtkAreaPicker.h>
 // ---- Axes
 #include <vtkAxesActor.h>
 #include <vtkCaptionActor2D.h>
@@ -91,6 +93,270 @@
 #include <vtkScalarBarRepresentation.h>
 
 namespace camitk {
+
+//--------------- Picking Interactor ---------------------------------------
+vtkCxxRevisionMacro(vtkInteractorStylePick, "$Revision: 1.1 $");
+vtkStandardNewMacro(vtkInteractorStylePick);
+//--------------------------------------------------------------------------
+vtkInteractorStylePick::vtkInteractorStylePick() {
+    this->AreaPicking = false;
+    this->StartPosition[0] = this->StartPosition[1] = 0;
+    this->EndPosition[0] = this->EndPosition[1] = 0;
+    this->Moving = 0;
+    this->PixelArray = vtkUnsignedCharArray::New();
+}
+
+//--------------------------------------------------------------------------
+vtkInteractorStylePick::~vtkInteractorStylePick() {
+    this->PixelArray->Delete();
+}
+
+//--------------------------------------------------------------------------
+void vtkInteractorStylePick::SetAreaPicking ( bool b ) {
+    this->AreaPicking = b;
+}
+
+//--------------------------------------------------------------------------
+void vtkInteractorStylePick::OnLeftButtonDown() {
+    if ( !this->Interactor ) {
+        return;
+    }
+
+    this->Moving = 1;
+
+    if ( AreaPicking ) {
+        vtkRenderWindow *renWin = this->Interactor->GetRenderWindow();
+
+        this->StartPosition[0] = this->Interactor->GetEventPosition() [0];
+        this->StartPosition[1] = this->Interactor->GetEventPosition() [1];
+        this->EndPosition[0] = this->StartPosition[0];
+        this->EndPosition[1] = this->StartPosition[1];
+
+        this->PixelArray->Initialize();
+        this->PixelArray->SetNumberOfComponents ( 4 );
+        int *size = renWin->GetSize();
+        this->PixelArray->SetNumberOfTuples ( size[0]*size[1] );
+
+        renWin->GetRGBACharPixelData ( 0, 0, size[0]-1, size[1]-1, 1, this->PixelArray );
+
+        this->FindPokedRenderer ( this->StartPosition[0], this->StartPosition[1] );
+    } else {
+        vtkRenderWindowInteractor *rwi = this->Interactor;
+        int *eventPos = rwi->GetEventPosition();
+        this->FindPokedRenderer ( eventPos[0], eventPos[1] );
+        this->StartPosition[0] = eventPos[0];
+        this->StartPosition[1] = eventPos[1];
+        this->EndPosition[0] = eventPos[0];
+        this->EndPosition[1] = eventPos[1];
+        this->Pick();
+    }
+}
+
+//--------------------------------------------------------------------------
+void vtkInteractorStylePick::OnMouseMove() {
+    if ( !this->Interactor || !this->Moving ) {
+        return;
+    }
+    if ( AreaPicking ) {
+        this->EndPosition[0] = this->Interactor->GetEventPosition() [0];
+        this->EndPosition[1] = this->Interactor->GetEventPosition() [1];
+        int *size = this->Interactor->GetRenderWindow()->GetSize();
+        if ( this->EndPosition[0] > ( size[0]-1 ) ) {
+            this->EndPosition[0] = size[0]-1;
+        }
+        if ( this->EndPosition[0] < 0 ) {
+            this->EndPosition[0] = 0;
+        }
+        if ( this->EndPosition[1] > ( size[1]-1 ) ) {
+            this->EndPosition[1] = size[1]-1;
+        }
+        if ( this->EndPosition[1] < 0 ) {
+            this->EndPosition[1] = 0;
+        }
+        this->RedrawRubberBand();
+    } else {
+        vtkRenderWindowInteractor *rwi = this->Interactor;
+        int *eventPos = rwi->GetEventPosition();
+        this->FindPokedRenderer ( eventPos[0], eventPos[1] );
+        this->StartPosition[0] = eventPos[0];
+        this->StartPosition[1] = eventPos[1];
+        this->EndPosition[0] = eventPos[0];
+        this->EndPosition[1] = eventPos[1];
+        this->Pick();
+    }
+}
+
+//--------------------------------------------------------------------------
+void vtkInteractorStylePick::OnLeftButtonUp() {
+    if ( !this->Interactor || !this->Moving ) {
+        return;
+    }
+
+    if ( AreaPicking ) {
+        if ( ( this->StartPosition[0] != this->EndPosition[0] )
+                || ( this->StartPosition[1] != this->EndPosition[1] ) ) {
+            this->Pick();
+        }
+    }
+
+    this->Moving = 0;
+}
+
+//--------------------------------------------------------------------------
+void vtkInteractorStylePick::RedrawRubberBand() {
+    //update the rubber band on the screen
+    int *size = this->Interactor->GetRenderWindow()->GetSize();
+
+    vtkUnsignedCharArray *tmpPixelArray = vtkUnsignedCharArray::New();
+    tmpPixelArray->DeepCopy ( this->PixelArray );
+    unsigned char *pixels = tmpPixelArray->GetPointer ( 0 );
+
+    int min[2], max[2];
+
+    min[0] = this->StartPosition[0] <= this->EndPosition[0] ?
+             this->StartPosition[0] : this->EndPosition[0];
+    if ( min[0] < 0 ) {
+        min[0] = 0;
+    }
+    if ( min[0] >= size[0] ) {
+        min[0] = size[0] - 1;
+    }
+
+    min[1] = this->StartPosition[1] <= this->EndPosition[1] ?
+             this->StartPosition[1] : this->EndPosition[1];
+    if ( min[1] < 0 ) {
+        min[1] = 0;
+    }
+    if ( min[1] >= size[1] ) {
+        min[1] = size[1] - 1;
+    }
+
+    max[0] = this->EndPosition[0] > this->StartPosition[0] ?
+             this->EndPosition[0] : this->StartPosition[0];
+    if ( max[0] < 0 ) {
+        max[0] = 0;
+    }
+    if ( max[0] >= size[0] ) {
+        max[0] = size[0] - 1;
+    }
+
+    max[1] = this->EndPosition[1] > this->StartPosition[1] ?
+             this->EndPosition[1] : this->StartPosition[1];
+    if ( max[1] < 0 ) {
+        max[1] = 0;
+    }
+    if ( max[1] >= size[1] ) {
+        max[1] = size[1] - 1;
+    }
+
+    int i;
+    for ( i = min[0]; i <= max[0]; i++ ) {
+        pixels[4* ( min[1]*size[0]+i )] = 255 ^ pixels[4* ( min[1]*size[0]+i )];
+        pixels[4* ( min[1]*size[0]+i ) +1] = 255 ^ pixels[4* ( min[1]*size[0]+i ) +1];
+        pixels[4* ( min[1]*size[0]+i ) +2] = 255 ^ pixels[4* ( min[1]*size[0]+i ) +2];
+        pixels[4* ( max[1]*size[0]+i )] = 255 ^ pixels[4* ( max[1]*size[0]+i )];
+        pixels[4* ( max[1]*size[0]+i ) +1] = 255 ^ pixels[4* ( max[1]*size[0]+i ) +1];
+        pixels[4* ( max[1]*size[0]+i ) +2] = 255 ^ pixels[4* ( max[1]*size[0]+i ) +2];
+    }
+    for ( i = min[1]+1; i < max[1]; i++ ) {
+        pixels[4* ( i*size[0]+min[0] )] = 255 ^ pixels[4* ( i*size[0]+min[0] )];
+        pixels[4* ( i*size[0]+min[0] ) +1] = 255 ^ pixels[4* ( i*size[0]+min[0] ) +1];
+        pixels[4* ( i*size[0]+min[0] ) +2] = 255 ^ pixels[4* ( i*size[0]+min[0] ) +2];
+        pixels[4* ( i*size[0]+max[0] )] = 255 ^ pixels[4* ( i*size[0]+max[0] )];
+        pixels[4* ( i*size[0]+max[0] ) +1] = 255 ^ pixels[4* ( i*size[0]+max[0] ) +1];
+        pixels[4* ( i*size[0]+max[0] ) +2] = 255 ^ pixels[4* ( i*size[0]+max[0] ) +2];
+    }
+
+    this->Interactor->GetRenderWindow()->SetRGBACharPixelData ( 0, 0, size[0]-1, size[1]-1, pixels, 0 );
+    this->Interactor->GetRenderWindow()->Frame();
+
+    tmpPixelArray->Delete();
+}
+
+//--------------------------------------------------------------------------
+void vtkInteractorStylePick::Pick() {
+    //find rubber band lower left, upper right and center
+    double rbcenter[3];
+    int *size = this->Interactor->GetRenderWindow()->GetSize();
+    int min[2], max[2];
+    min[0] = this->StartPosition[0] <= this->EndPosition[0] ?
+             this->StartPosition[0] : this->EndPosition[0];
+    if ( min[0] < 0 ) {
+        min[0] = 0;
+    }
+    if ( min[0] >= size[0] ) {
+        min[0] = size[0] - 2;
+    }
+
+    min[1] = this->StartPosition[1] <= this->EndPosition[1] ?
+             this->StartPosition[1] : this->EndPosition[1];
+    if ( min[1] < 0 ) {
+        min[1] = 0;
+    }
+    if ( min[1] >= size[1] ) {
+        min[1] = size[1] - 2;
+    }
+
+    max[0] = this->EndPosition[0] > this->StartPosition[0] ?
+             this->EndPosition[0] : this->StartPosition[0];
+    if ( max[0] < 0 ) {
+        max[0] = 0;
+    }
+    if ( max[0] >= size[0] ) {
+        max[0] = size[0] - 2;
+    }
+
+    max[1] = this->EndPosition[1] > this->StartPosition[1] ?
+             this->EndPosition[1] : this->StartPosition[1];
+    if ( max[1] < 0 ) {
+        max[1] = 0;
+    }
+    if ( max[1] >= size[1] ) {
+        max[1] = size[1] - 2;
+    }
+
+    rbcenter[0] = ( min[0] + max[0] ) /2.0;
+    rbcenter[1] = ( min[1] + max[1] ) /2.0;
+    rbcenter[2] = 0;
+
+    if ( this->State == VTKIS_NONE ) {
+        //tell the RenderWindowInteractor's picker to make it happen
+        vtkRenderWindowInteractor *rwi = this->Interactor;
+
+        vtkAssemblyPath *path = NULL;
+        rwi->StartPickCallback();
+        vtkAbstractPropPicker *picker =
+            vtkAbstractPropPicker::SafeDownCast ( rwi->GetPicker() );
+        if ( picker != NULL ) {
+            vtkAreaPicker *areaPicker = vtkAreaPicker::SafeDownCast ( picker );
+            if ( areaPicker != NULL ) {
+                areaPicker->AreaPick ( min[0], min[1], max[0], max[1],
+                                       this->CurrentRenderer );
+            } else {
+                picker->Pick ( rbcenter[0], rbcenter[1],
+                               0.0, this->CurrentRenderer );
+            }
+            path = picker->GetPath();
+        }
+        if ( path == NULL ) {
+            this->HighlightProp ( NULL );
+            this->PropPicked = 0;
+        } else {
+            //highlight the one prop that the picker saved in the path
+            //this->HighlightProp(path->GetFirstNode()->GetViewProp());
+            this->PropPicked = 1;
+        }
+        rwi->EndPickCallback();
+    }
+
+    this->Interactor->Render();
+}
+
+//--------------------------------------------------------------------------
+void vtkInteractorStylePick::PrintSelf ( ostream& os, vtkIndent indent ) {
+    this->Superclass::PrintSelf ( os, indent );
+}
+
 // static instanciation (global variable, global only for this file)
 QMap <RendererWidget::ScreenshotFormat , RendererWidget::ScreenshotFormatInfo*> screenshotMap;
 
@@ -131,22 +397,27 @@ RendererWidget::RendererWidget(QWidget* parent, ControlMode mode) : QVTKWidget(p
     interactor = vtkSmartPointer<QVTKInteractor>::New();
     interactor->SetRenderWindow( renderWindow );
     renderWindow->SetInteractor(interactor);
+    pickInteractorStyle = vtkSmartPointer<vtkInteractorStylePick>::New();
+
+    //-- interaction mode
+    //setInteractionMode(CONTROL);
 
     //-- camera control mode
     controlMode = NONE;
-    cameraOrientation = RIGHT_UP;
-    interactorStyle = NULL;
+    cameraOrientation = RIGHT_DOWN;
+    controlInteractorStyle = NULL;
     setControlMode(mode);
     setCameraOrientation( cameraOrientation );
     interactor->Initialize();
 
     //-- connection for picking and other interaction
-    connector = vtkSmartPointer<vtkEventQtSlotConnect>::New();
-    connector->Connect(interactor, vtkCommand::LeftButtonPressEvent, this, SLOT(leftClick()));
-    connector->Connect(interactor, vtkCommand::RightButtonPressEvent, this, SLOT(rightClick()));
+    //connector = vtkSmartPointer<vtkEventQtSlotConnect>::New();
+    //connector->Connect(interactor, vtkCommand::LeftButtonPressEvent, this, SLOT(leftClick()));
+    //connector->Connect(interactor, vtkCommand::RightButtonPressEvent, this, SLOT(rightClick()));
+    //connector->Connect(interactor, vtkCommand::LeftButtonReleaseEvent, this, SLOT(leftRelease()));
 
     pickingButtonDiverter = vtkSmartPointer<vtkCallbackCommand>::New();
-    pickingButtonDiverter->SetClientData(interactorStyle);
+    pickingButtonDiverter->SetClientData(controlInteractorStyle);
     pickingButtonDiverter->SetCallback(RendererWidget::divertionCallback);
     pickingDiverter = false;
 
@@ -191,15 +462,18 @@ RendererWidget::RendererWidget(QWidget* parent, ControlMode mode) : QVTKWidget(p
     addProp(axes);
 
     //-- annotated cube (right, left, anterior, posterior, inferior, superior)
+    // For image Display, the axis should be RAI :
+    // - X: from Right    [R]  (the Right of the patient) to Left      [L] (the Left of the patient)
+    // - Y: from Anterior [A]  (the Face of the patient)  to Posterior [P] (the Back of the patient)
+    // - Z: from Inferior [I]  (the Feet of the patient)  to Superior  [S] (the Head of the patient)
     annotatedCube = vtkSmartPointer<vtkAnnotatedCubeActor>::New();
-    annotatedCube->SetXPlusFaceText("R"); // right
-    annotatedCube->SetXMinusFaceText("L"); // left
-    annotatedCube->SetYPlusFaceText("A"); // anterior
-    annotatedCube->SetYMinusFaceText("P"); // posterior
-    annotatedCube->SetZPlusFaceText("I"); // inferior
-    annotatedCube->SetZMinusFaceText("S"); // superior
-    annotatedCube->SetXFaceTextRotation(-90);
-    annotatedCube->SetYFaceTextRotation(180);
+    annotatedCube->SetXMinusFaceText("R");
+    annotatedCube->SetXPlusFaceText("L");
+    annotatedCube->SetYMinusFaceText("A");
+    annotatedCube->SetYPlusFaceText("P");
+    annotatedCube->SetZMinusFaceText("I");
+    annotatedCube->SetZPlusFaceText("S");
+    annotatedCube->SetXFaceTextRotation(90);
     annotatedCube->SetZFaceTextRotation(90);
     annotatedCube->SetFaceTextScale(0.65);
     vtkSmartPointer<vtkTransform> transform = vtkTransform::New();
@@ -236,6 +510,46 @@ RendererWidget::RendererWidget(QWidget* parent, ControlMode mode) : QVTKWidget(p
     annotatedCube->VisibilityOff();
     addProp(annotatedCube);
 
+    // -- orientation decorations
+    QString orientationDecorationLetters[4];
+    orientationDecorationLetters[0] = "R";
+    orientationDecorationLetters[1] = "L";
+    orientationDecorationLetters[2] = "A";
+    orientationDecorationLetters[3] = "P";
+
+    vtkSmartPointer<vtkTextProperty> orientationDecorationsProp;
+    orientationDecorationsProp = vtkSmartPointer<vtkTextProperty>::New();
+    orientationDecorationsProp->SetFontSize(14);
+    orientationDecorationsProp->ShadowOff();
+    orientationDecorationsProp->SetColor(0.0, 1.0, 1.0);
+
+    for (int i = 0; i < 4; i++) {
+
+        orientationDecorationsTextMapper[i] = vtkSmartPointer<vtkTextMapper>::New();
+        orientationDecorationsTextMapper[i]->SetInput(orientationDecorationLetters[i].toStdString().c_str());
+        orientationDecorationsTextMapper[i]->GetTextProperty()->ShallowCopy(orientationDecorationsProp);
+
+        orientationDecorationActors[i] = vtkSmartPointer<vtkActor2D>::New();
+        orientationDecorationActors[i]->SetMapper(orientationDecorationsTextMapper[i]);
+        orientationDecorationActors[i]->GetPositionCoordinate()->SetCoordinateSystemToNormalizedViewport();
+    }
+    //      y ^
+    //        |
+    //        |
+    //  (0,0) +-----------> x
+    // Bottom
+    orientationDecorationActors[3]->GetPositionCoordinate()->SetValue(0.5, 0.05);
+    // Top
+    orientationDecorationActors[2]->GetPositionCoordinate()->SetValue(0.5, 0.95);
+    // Right
+    orientationDecorationActors[1]->GetPositionCoordinate()->SetValue(0.95, 0.5);
+    // Left
+    orientationDecorationActors[0]->GetPositionCoordinate()->SetValue(0.05, 0.5);
+    for (int i = 0; i < 4; i++)
+        addProp(orientationDecorationActors[i]);
+
+
+
     // -- text in background
     vtkSmartPointer<vtkTextProperty> copyrightTextProp = vtkSmartPointer<vtkTextProperty>::New();
     copyrightTextProp->ShallowCopy(axeXTextProp);
@@ -301,6 +615,10 @@ RendererWidget::RendererWidget(QWidget* parent, ControlMode mode) : QVTKWidget(p
 
 //----------------------   Destructor   ------------------------
 RendererWidget::~RendererWidget() {
+	// delete all properties
+	foreach(ScreenshotFormatInfo* sfi, screenshotMap.values())
+		delete sfi;
+	screenshotMap.clear();
 }
 
 //---------------------- buildScreenshotMap ------------------------
@@ -340,8 +658,7 @@ const RendererWidget::ScreenshotFormatInfo * RendererWidget::getScreenshotFormat
     if (found) {
         i--;
         return RendererWidget::getScreenshotFormatInfo(i);
-    }
-    else
+    } else
         return RendererWidget::getScreenshotFormatInfo(NOT_SUPPORTED);
 }
 
@@ -434,8 +751,7 @@ void RendererWidget::screenshot(QString filename) {
     if (exporter) {
         exporter->SetInput(GetRenderWindow());
         exporter->Write();
-    }
-    else {
+    } else {
         if (imageWriter) {
             // create the proper vtk filter for export
             vtkSmartPointer<vtkWindowToImageFilter> imageFilter = vtkSmartPointer<vtkWindowToImageFilter>::New();
@@ -499,8 +815,7 @@ void RendererWidget::toogle3DRedBlue() {
         GetRenderWindow()->SetStereoTypeToRedBlue();
         GetRenderWindow()->StereoRenderOn(); //On();
         GetRenderWindow()->StereoUpdate();
-    }
-    else {
+    } else {
         GetRenderWindow()->StereoRenderOff(); //On();
         GetRenderWindow()->StereoUpdate();
     }
@@ -516,6 +831,33 @@ void RendererWidget::toggleCopyright(bool c) {
     }
 }
 
+// // --------------------- getInteractionMode ------------------------
+// RendererWidget::InteractionMode RendererWidget::getInteractionMode() const {
+//   return interactionMode;
+// }
+//
+// // --------------------- setInteractionMode ------------------------
+// void RendererWidget::setInteractionMode ( RendererWidget::InteractionMode mode ) {
+//     if ( mode != interactionMode ) {
+//         interactionMode = mode;
+//         switch ( mode ) {
+//         case PICKING :
+//             pickInteractor->SetAreaPicking ( false );
+//             break;
+//         case AREA_PICKING :
+//             pickInteractor->SetAreaPicking ( true );
+// 	    break;
+//         case CONTROL :
+//         default :
+//             break;
+//         }
+//     }
+// }
+
+void RendererWidget::setAreaPicking(bool areaPicking) {
+    pickInteractorStyle->SetAreaPicking ( areaPicking );
+}
+
 // --------------------- getControlMode ----------------------------
 RendererWidget::ControlMode RendererWidget::getControlMode() const {
     return controlMode;
@@ -528,27 +870,34 @@ void RendererWidget::setControlMode(ControlMode mode) {
 
         switch (controlMode) {
         case JOYSTICK:
-            interactorStyle = vtkSmartPointer<vtkInteractorStyleJoystickCamera>::New();
+            controlInteractorStyle = vtkSmartPointer<vtkInteractorStyleJoystickCamera>::New();
             break;
-
         case TRACKBALL:
-            interactorStyle = vtkSmartPointer<vtkInteractorStyleTrackballCamera>::New();
+            controlInteractorStyle = vtkSmartPointer<vtkInteractorStyleTrackballCamera>::New();
             break;
         case TRACKBALL_2D:
-            interactorStyle = vtkSmartPointer<vtkInteractorStyleImage>::New();
+            controlInteractorStyle = vtkSmartPointer<vtkInteractorStyleImage>::New();
             break;
-
         default : //NONE
-            interactorStyle = NULL;
+            controlInteractorStyle = NULL;
             break;
         }
 
-        interactor->SetInteractorStyle(interactorStyle);
+        interactor->SetInteractorStyle(controlInteractorStyle);
 
         update();
     }
 }
 
+void RendererWidget::startPicking() {
+    interactor->SetInteractorStyle ( pickInteractorStyle );
+    update();
+}
+
+void RendererWidget::endPicking() {
+    interactor->SetInteractorStyle ( controlInteractorStyle );
+    update();
+}
 
 // --------------------- pick -----------------------------------
 void RendererWidget::pick() {
@@ -688,13 +1037,40 @@ void RendererWidget::updateAxes() {
     annotatedCube->GetAssembly()->SetUserTransform(transform);
 }
 
+
+// ----------------------- toogleOrientationDecorations ---------
+void RendererWidget::toggleOrientationDecorations(bool f) {
+    for (int i = 0; i < 4; i++) {
+        orientationDecorationActors[i]->SetVisibility(f);
+    }
+}
+
+// ----------------------- setOrientationDecorationsLetters ---------
+void RendererWidget::setOrientationDecorationsLetters(QString letters[4]) {
+    vtkSmartPointer<vtkTextProperty> orientationDecorationsProp;
+    orientationDecorationsProp = vtkSmartPointer<vtkTextProperty>::New();
+    orientationDecorationsProp->SetFontSize(14);
+    orientationDecorationsProp->ShadowOff();
+    orientationDecorationsProp->SetColor(0.0, 1.0, 1.0);
+
+    for (int i = 0; i < 4; i++) {
+        orientationDecorationsTextMapper[i]->SetInput(letters[i].toStdString().c_str());
+        if ((letters[i] == "R") || (letters[i] == "L"))
+            orientationDecorationsTextMapper[i]->GetTextProperty()->SetColor(1.0, 0.0, 0.0);
+        else if ((letters[i] == "A") || (letters[i] == "P"))
+            orientationDecorationsTextMapper[i]->GetTextProperty()->SetColor(0.0, 1.0, 0.0);
+        else if ((letters[i] == "S") || (letters[i] == "I"))
+            orientationDecorationsTextMapper[i]->GetTextProperty()->SetColor(0.0, 0.0, 1.0);
+    }
+
+}
+
 // ----------------------- setColorScale -----------------------
 void RendererWidget::setColorScale(bool state) {
     displayColorScale = state;
     if (displayColorScale) {
         colorBarWidget->EnabledOn();
-    }
-    else {
+    } else {
         colorBarWidget->EnabledOff();
     }
 }
@@ -785,8 +1161,7 @@ void RendererWidget::actorTransform(vtkSmartPointer<vtkActor> actor, double *box
 
     if (actor->GetUserMatrix() != NULL) {
         newTransform->SetMatrix(actor->GetUserMatrix());
-    }
-    else {
+    } else {
         newTransform->SetMatrix(oldMatrix);
     }
 
@@ -823,8 +1198,7 @@ void RendererWidget::actorTransform(vtkSmartPointer<vtkActor> actor, double *box
     // set the new Actor - Matrix
     if (actor->GetUserMatrix() != NULL) {
         newTransform->GetMatrix(actor->GetUserMatrix());
-    }
-    else {
+    } else {
         actor->SetPosition(newTransform->GetPosition());
         actor->SetScale(newTransform->GetScale());
         actor->SetOrientation(newTransform->GetOrientation());
@@ -865,44 +1239,57 @@ void RendererWidget::rotateCamera(double angle, int axe) {
 
 
 // --------------------- keyPressEvent --------------------------------
-void RendererWidget::keyPressEvent(QKeyEvent* e) {
+void RendererWidget::keyPressEvent(QKeyEvent* event) {
     // NOTE: nothing but the following line should be here
     // All interaction should be defined directly in the class that use this instance
     // for example, see InteractiveViewer::keyPressEvent method
-    e->ignore();
+    event->ignore();
 }
 
+void RendererWidget::mousePressEvent ( QMouseEvent* event ) {
+    if ( ( QApplication::keyboardModifiers() == Qt::ControlModifier ) &&
+            ( event->button() == Qt::LeftButton ) ) {
+        startPicking();
+        pickInteractorStyle->OnLeftButtonDown();
+    } else if ( event->button() == Qt::RightButton ) {
+        emit rightButtonPressed();
+    }
+    QVTKWidget::mousePressEvent ( event );
+}
 
-// --------------------- mouseReleaseEvent ----------------------------------
+//--------------------- mouseReleaseEvent ----------------------------------
 void RendererWidget::mouseReleaseEvent(QMouseEvent* event) {
-    interactorStyle->RemoveObserver(pickingButtonDiverter);
-    pickingDiverter = false;
-    update();
-    QVTKWidget::mouseReleaseEvent(event);
-    vtkSmartPointer<vtkPicker> emptyPicker;
-    emit actorPicked(emptyPicker);
+    QVTKWidget::mouseReleaseEvent ( event );
+    endPicking();
 }
 
 //---------------------------- slotLeftClick ---------------------------------
-void RendererWidget::leftClick() {
-    // Ctrl+Left click
-    if (QApplication::keyboardModifiers() == Qt::ControlModifier) {
-        // divert the left button press event, so that it won't
-        // have any effect on the scene while continuously allow picking
-        if (!pickingDiverter) {
-            pickingDiverter = true;
-            interactorStyle->AddObserver(vtkCommand::MouseMoveEvent, pickingButtonDiverter);
-        }
+// void RendererWidget::leftClick() {
+//     // Ctrl+Left click
+//     if (QApplication::keyboardModifiers() == Qt::ControlModifier) {
+//         // divert the left button press event, so that it won't
+//         // have any effect on the scene while continuously allow picking
+// //         if (!pickingDiverter) {
+// //             pickingDiverter = true;
+// //             interactorStyle->AddObserver(vtkCommand::MouseMoveEvent, pickingButtonDiverter);
+// //         }
+// //
+// //         // do the picking action
+// //         pick();
+// 	startPicking();
+// 	pickInteractorStyle->OnLeftButtonDown();
+//     }
+// }
 
-        // do the picking action
-        pick();
-    }
-}
+//---------------------------- slotLeftRelease ---------------------------------
+// void RendererWidget::leftRelease() {
+//
+// }
 
 //---------------------------- slotRightClick ---------------------------------
-void RendererWidget::rightClick() {
-    emit rightButtonPressed();
-}
+// void RendererWidget::rightClick() {
+//     emit rightButtonPressed();
+// }
 
 // --------------------- mouseMoveEvent ----------------------------------
 void RendererWidget::mouseMoveEvent(QMouseEvent* event) {
@@ -910,7 +1297,7 @@ void RendererWidget::mouseMoveEvent(QMouseEvent* event) {
         // continuous picking mode:
         // you don't have to release the button to do another picking
         // just keep the button pressed
-        pick();
+        //pick();
     }
     QVTKWidget::mouseMoveEvent(event);
 }
@@ -956,6 +1343,20 @@ void RendererWidget::resetCameraSettings() {
         cam->SetViewUp(0, -1, 0);
         cam->OrthogonalizeViewUp();
         break;
+        // For Coronal view of Coronal Viewer
+        // Image Reorientation Action Documentation...
+    case LEFT_BACK:
+        cam->SetPosition(0.0, -1.0, 0.0);
+        cam->SetFocalPoint(0.0, 0.0, 0.0);
+        cam->SetViewUp(0.0, 0.0, 1.0);
+        cam->OrthogonalizeViewUp();
+        break;
+    case BACK_DOWN:
+        cam->SetPosition(1.0, 0.0, 0.0);
+        cam->SetFocalPoint(0.0, 0.0, 0.0);
+        cam->SetViewUp(0.0, 0.0, 1.0);
+        cam->OrthogonalizeViewUp();
+        break;
     case RIGHT_UP:
     default:
         cam->SetPosition(0, 0, 1);
@@ -1001,7 +1402,7 @@ void RendererWidget::getMouse3DCoordinates(double & x, double & y, double & z) {
 }
 
 // --------------------- setPicker ----------------------
-void RendererWidget::setPicker(vtkSmartPointer<vtkPicker> woodyWood) {
+void RendererWidget::setPicker(vtkSmartPointer<vtkAbstractPropPicker> woodyWood) {
     if (GetInteractor()) {
         // I know, it is really Woody Wood Pecker, but you know, with a french accent...
         GetInteractor()->SetPicker(woodyWood);
