@@ -32,6 +32,7 @@
 // -- VTK stuff
 #include <QVTKWidget.h>
 #include <vtkSmartPointer.h>
+#include <vtkInteractorStyle.h>
 
 // -- VTK stuff classes
 class vtkRenderer;
@@ -47,20 +48,64 @@ class vtkCamera;
 class vtkAxesActor;
 class vtkAnnotatedCubeActor;
 class vtkScalarBarWidget;
+class vtkUnsignedCharArray;
+class vtkTextMapper;
 
-namespace camitk
-{
-  // -- Core stuff classes
+namespace camitk {
+// -- Core stuff classes
 class GeometricObject;
 
+/// Interactor used when we are in picking mode
+class vtkInteractorStylePick : public vtkInteractorStyle {
+
+public :
+
+    static vtkInteractorStylePick * New();
+    vtkTypeRevisionMacro ( vtkInteractorStylePick, vtkInteractorStyle );
+
+    void PrintSelf ( ostream& os, vtkIndent indent );
+
+    void SetAreaPicking(bool b);
+
+    virtual void OnLeftButtonDown();
+
+    virtual void OnLeftButtonUp();
+
+    virtual void OnMouseMove();
+
+protected :
+
+    vtkInteractorStylePick();
+    ~vtkInteractorStylePick();
+
+    virtual void Pick();
+
+    void RedrawRubberBand();
+
+    int StartPosition[2];
+    int EndPosition[2];
+
+    int Moving;
+
+    vtkUnsignedCharArray* PixelArray;
+
+    bool AreaPicking;
+
+// private :
+//
+//     vtkInteractorStylePick ( const vtkInteractorStylePick& ); // Not implemented
+//     void operator= ( const vtkInteractorStylePick& ); // Not implemented
+
+};
+
 /**
  * @ingroup group_sdk_libraries_core_viewer
- * 
+ *
  * @brief
  * RendererWidget implements all support methods to use camiTK with Qt interface.
  *
  * This class wraps the necessary VTK method for rendering, interactions, and signal/slot connections.
- * This class should be usable completely independantly of Core.
+ * This class should be usable completely independently of Core.
  *
  * The Core companion class is InteractiveViewer (which delegates all vtk stuff to RendererWidget.
  *
@@ -69,11 +114,10 @@ class GeometricObject;
  *
  * For developers: please check the coding policy in InteractiveViewer API documentation first.
  *
- * 
+ *
 **/
 
-class CAMITK_API RendererWidget : public QVTKWidget
-{
+class CAMITK_API RendererWidget : public QVTKWidget {
     Q_OBJECT
     Q_ENUMS(ControlMode CameraOrientation); // so that it can be used in property editor
 
@@ -93,7 +137,10 @@ public :
     enum CameraOrientation {
         RIGHT_DOWN,  ///< World axes are seen so that x points to the right, y points downward
         LEFT_UP,     ///< World axes are seen so that x points to the left, y points upward
-        RIGHT_UP     ///< World axes are seen so that x points to the right, y points upward
+        RIGHT_UP,    ///< World axes are seen so that x points to the right, y points upward
+        LEFT_BACK,   /// < World axes are seen so that x points to the left, y points backward. For Medical Images Coronal Views (see Image Reorientation Action Documentation)
+        BACK_DOWN,   /// < World axes are seen so that x points to backward, y points to the right. For Medical Images Sagittal Views (see Image Reorientation Action Documentation)
+
     };
 
     /// \enum ControlMode list of possible user interaction control mode
@@ -104,6 +151,13 @@ public :
         NONE
     };
 
+    /// \enum InteractionMode list of possible user interaction mode
+//     enum InteractionMode {
+// 	CONTROL, ///< mouse interaction mode (\see ControlMode)
+// 	PICKING, ///< picking mode
+// 	AREA_PICKING ///< area picking mode
+//     };
+
     /// \enum MouseButtonState state of the pressed button (for 3 buttons mouse)
     enum MouseButtonState {
         NO_BUTTON,      ///< no buttons are currently pressed
@@ -162,6 +216,15 @@ public :
 
     ///@name picking and interaction
     ///@{
+
+    /// Set the interaction mode like picking or control
+    //InteractionMode getInteractionMode() const;
+
+    /// Set the interaction mode like picking or control
+    //void setInteractionMode(InteractionMode mode);
+
+    void setAreaPicking(bool areaPicking);
+
     /// get the current control mode
     ControlMode getControlMode() const;
 
@@ -171,7 +234,7 @@ public :
     /** set the picker to handle the action
       * @param woodyWood the picker (sorry, I could not resist this one!)
       */
-    void setPicker(vtkSmartPointer<vtkPicker> woodyWood);
+    void setPicker(vtkSmartPointer<vtkAbstractPropPicker> woodyWood);
 
     /// Perform picking using the current mouse position
     void pick();
@@ -263,7 +326,7 @@ public :
 
     /// toggle stereo 3D red/blue rendering (you will need red/blue glasses)
     void toogle3DRedBlue();
-    
+
     /// toggle copyright text
     void toggleCopyright(bool);
 
@@ -273,6 +336,13 @@ public :
     /// update the axes sizes
     void updateAxes();
 
+    /// display orientation decorations
+    void toggleOrientationDecorations(bool);
+
+    /// give the lettres for orientation decoration: Left, Right, Top, Down
+    void setOrientationDecorationsLetters(QString letters[4]);
+
+
     /// display the color scale in the viewport, use setColorScaleMinMax to change the displayed values
     void setColorScale(bool);
 
@@ -326,12 +396,21 @@ public :
 protected slots:
     ///@name picking and interaction
     ///@{
-    /// manage left mouse click interactions, can emit actorPicked(..) signal
-    void leftClick();
+    /// manage left mouse click interactions
+    //void leftClick();
+
+    /// manage left mouse release interactions
+    //void leftRelease();
 
     /// manage right mouse click interactions, can emit rightButtonPressed() signal
-    void rightClick();
-    
+    //void rightClick();
+
+    /// start picking
+    void startPicking();
+
+    /// end picking
+    void endPicking();
+
     ///@}
 
 signals :
@@ -348,13 +427,16 @@ signals :
 
 
 protected:
+
+    virtual void mousePressEvent(QMouseEvent* event);
+
     /// overloaded mouse release handler because a potentialbug  in vtk 5.2.1
     virtual void mouseReleaseEvent(QMouseEvent* event);
 
     /// overloaded mouse move handler because a potentialbug  in vtk 5.2.1
     virtual void mouseMoveEvent(QMouseEvent* event);
 
-  protected :
+protected :
 
     ///@name picking and interaction
     ///@{
@@ -362,7 +444,10 @@ protected:
     vtkSmartPointer<QVTKInteractor> interactor;
 
     ///for the interaction with the scene
-    vtkSmartPointer<vtkInteractorStyle> interactorStyle;
+    vtkSmartPointer<vtkInteractorStyle> controlInteractorStyle;
+
+    ///// current interaction mode
+    //InteractionMode interactionMode;
 
     /// current control mode
     ControlMode controlMode;
@@ -388,7 +473,7 @@ protected:
 
     /// default point size
     double pointSize;
-    
+
     /// is rendering in 3D stereo red/blue
     bool rendering3DRedBlue;
     ///@}
@@ -396,7 +481,7 @@ protected:
     /// @name callback and interaction
     ///@{
     ///manage connections between vtk objets events and qt slots
-    vtkSmartPointer<vtkEventQtSlotConnect> connector;
+    //vtkSmartPointer<vtkEventQtSlotConnect> connector;
 
     /// a diverter observer callback (to be used to divert undesired events)
     static void divertionCallback(vtkObject * caller, unsigned long eid, void *clientdata, void *calldata) {};
@@ -407,6 +492,9 @@ protected:
     /// is the picking diverter used
     bool pickingDiverter;
 
+    /// picking interactor
+    vtkSmartPointer<vtkInteractorStylePick> pickInteractorStyle;
+
     ///@}
 
     ///@name screenshot management
@@ -437,12 +525,16 @@ protected:
 
     /// the scalar bar widget
     vtkSmartPointer<vtkScalarBarWidget> colorBarWidget;
-    
+
     /// axes actor
     vtkSmartPointer<vtkAxesActor> axes;
 
     /// annotated cube actor
     vtkSmartPointer<vtkAnnotatedCubeActor> annotatedCube;
+
+    vtkSmartPointer<vtkActor2D> orientationDecorationActors[4];
+    vtkSmartPointer<vtkTextMapper> orientationDecorationsTextMapper[4];
+
     ///@}
 
 };
