@@ -51,8 +51,7 @@
 QT_BEGIN_NAMESPACE
 #endif
 
-class QtButtonPropertyBrowserPrivate
-{
+class QtButtonPropertyBrowserPrivate {
     QtButtonPropertyBrowser *q_ptr;
     Q_DECLARE_PUBLIC(QtButtonPropertyBrowser)
 public:
@@ -62,17 +61,17 @@ public:
     void propertyInserted(QtBrowserItem *index, QtBrowserItem *afterIndex);
     void propertyRemoved(QtBrowserItem *index);
     void propertyChanged(QtBrowserItem *index);
-    QWidget *createEditor(QtProperty *property, QWidget *parent) const
-        { return q_ptr->createEditor(property, parent); }
+    QWidget *createEditor(QtProperty *property, QWidget *parent) const {
+        return q_ptr->createEditor(property, parent);
+    }
 
     void slotEditorDestroyed();
     void slotUpdate();
     void slotToggled(bool checked);
 
-    struct WidgetItem
-    {
+    struct WidgetItem {
         WidgetItem() : widget(0), label(0), widgetLabel(0),
-                button(0), container(0), layout(0), /*line(0), */parent(0), expanded(false) { }
+            button(0), container(0), layout(0), /*line(0), */parent(0), expanded(false) { }
         QWidget *widget; // can be null
         QLabel *label; // main label with property name
         QLabel *widgetLabel; // label substitute showing the current value if there is no widget
@@ -102,8 +101,7 @@ private:
     QList<WidgetItem *> m_recreateQueue;
 };
 
-QToolButton *QtButtonPropertyBrowserPrivate::createButton(QWidget *parent) const
-{
+QToolButton *QtButtonPropertyBrowserPrivate::createButton(QWidget *parent) const {
     QToolButton *button = new QToolButton(parent);
     button->setCheckable(true);
     button->setSizePolicy(QSizePolicy(QSizePolicy::Preferred, QSizePolicy::Fixed));
@@ -119,8 +117,7 @@ QToolButton *QtButtonPropertyBrowserPrivate::createButton(QWidget *parent) const
     return button;
 }
 
-int QtButtonPropertyBrowserPrivate::gridRow(WidgetItem *item) const
-{
+int QtButtonPropertyBrowserPrivate::gridRow(WidgetItem *item) const {
     QList<WidgetItem *> siblings;
     if (item->parent)
         siblings = item->parent->children;
@@ -138,24 +135,21 @@ int QtButtonPropertyBrowserPrivate::gridRow(WidgetItem *item) const
     return -1;
 }
 
-int QtButtonPropertyBrowserPrivate::gridSpan(WidgetItem *item) const
-{
+int QtButtonPropertyBrowserPrivate::gridSpan(WidgetItem *item) const {
     if (item->container && item->expanded)
         return 2;
     return 1;
 }
 
-void QtButtonPropertyBrowserPrivate::init(QWidget *parent)
-{
+void QtButtonPropertyBrowserPrivate::init(QWidget *parent) {
     m_mainLayout = new QGridLayout();
     parent->setLayout(m_mainLayout);
     QLayoutItem *item = new QSpacerItem(0, 0,
-                QSizePolicy::Fixed, QSizePolicy::Expanding);
+                                        QSizePolicy::Fixed, QSizePolicy::Expanding);
     m_mainLayout->addItem(item, 0, 0);
 }
 
-void QtButtonPropertyBrowserPrivate::slotEditorDestroyed()
-{
+void QtButtonPropertyBrowserPrivate::slotEditorDestroyed() {
     QWidget *editor = qobject_cast<QWidget *>(q_ptr->sender());
     if (!editor)
         return;
@@ -165,8 +159,7 @@ void QtButtonPropertyBrowserPrivate::slotEditorDestroyed()
     m_widgetToItem.remove(editor);
 }
 
-void QtButtonPropertyBrowserPrivate::slotUpdate()
-{
+void QtButtonPropertyBrowserPrivate::slotUpdate() {
     QListIterator<WidgetItem *> itItem(m_recreateQueue);
     while (itItem.hasNext()) {
         WidgetItem *item = itItem.next();
@@ -195,8 +188,7 @@ void QtButtonPropertyBrowserPrivate::slotUpdate()
     m_recreateQueue.clear();
 }
 
-void QtButtonPropertyBrowserPrivate::setExpanded(WidgetItem *item, bool expanded)
-{
+void QtButtonPropertyBrowserPrivate::setExpanded(WidgetItem *item, bool expanded) {
     if (item->expanded == expanded)
         return;
 
@@ -226,8 +218,7 @@ void QtButtonPropertyBrowserPrivate::setExpanded(WidgetItem *item, bool expanded
     item->button->setArrowType(expanded ? Qt::UpArrow : Qt::DownArrow);
 }
 
-void QtButtonPropertyBrowserPrivate::slotToggled(bool checked)
-{
+void QtButtonPropertyBrowserPrivate::slotToggled(bool checked) {
     WidgetItem *item = m_buttonToItem.value(q_ptr->sender());
     if (!item)
         return;
@@ -240,13 +231,11 @@ void QtButtonPropertyBrowserPrivate::slotToggled(bool checked)
         emit q_ptr->collapsed(m_itemToIndex.value(item));
 }
 
-void QtButtonPropertyBrowserPrivate::updateLater()
-{
+void QtButtonPropertyBrowserPrivate::updateLater() {
     QTimer::singleShot(0, q_ptr, SLOT(slotUpdate()));
 }
 
-void QtButtonPropertyBrowserPrivate::propertyInserted(QtBrowserItem *index, QtBrowserItem *afterIndex)
-{
+void QtButtonPropertyBrowserPrivate::propertyInserted(QtBrowserItem *index, QtBrowserItem *afterIndex) {
     WidgetItem *afterItem = m_indexToItem.value(afterIndex);
     WidgetItem *parentItem = m_indexToItem.value(index->parent());
 
@@ -340,8 +329,7 @@ void QtButtonPropertyBrowserPrivate::propertyInserted(QtBrowserItem *index, QtBr
     updateItem(newItem);
 }
 
-void QtButtonPropertyBrowserPrivate::propertyRemoved(QtBrowserItem *index)
-{
+void QtButtonPropertyBrowserPrivate::propertyRemoved(QtBrowserItem *index) {
     WidgetItem *item = m_indexToItem.value(index);
 
     m_indexToItem.remove(index);
@@ -410,8 +398,7 @@ void QtButtonPropertyBrowserPrivate::propertyRemoved(QtBrowserItem *index)
     delete item;
 }
 
-void QtButtonPropertyBrowserPrivate::insertRow(QGridLayout *layout, int row) const
-{
+void QtButtonPropertyBrowserPrivate::insertRow(QGridLayout *layout, int row) const {
     QMap<QLayoutItem *, QRect> itemToPos;
     int idx = 0;
     while (idx < layout->count()) {
@@ -431,8 +418,7 @@ void QtButtonPropertyBrowserPrivate::insertRow(QGridLayout *layout, int row) con
     }
 }
 
-void QtButtonPropertyBrowserPrivate::removeRow(QGridLayout *layout, int row) const
-{
+void QtButtonPropertyBrowserPrivate::removeRow(QGridLayout *layout, int row) const {
     QMap<QLayoutItem *, QRect> itemToPos;
     int idx = 0;
     while (idx < layout->count()) {
@@ -452,15 +438,13 @@ void QtButtonPropertyBrowserPrivate::removeRow(QGridLayout *layout, int row) con
     }
 }
 
-void QtButtonPropertyBrowserPrivate::propertyChanged(QtBrowserItem *index)
-{
+void QtButtonPropertyBrowserPrivate::propertyChanged(QtBrowserItem *index) {
     WidgetItem *item = m_indexToItem.value(index);
 
     updateItem(item);
 }
 
-void QtButtonPropertyBrowserPrivate::updateItem(WidgetItem *item)
-{
+void QtButtonPropertyBrowserPrivate::updateItem(WidgetItem *item) {
     QtProperty *property = m_itemToIndex[item]->property();
     if (item->button) {
         QFont font = item->button->font();
@@ -494,13 +478,13 @@ void QtButtonPropertyBrowserPrivate::updateItem(WidgetItem *item)
         item->widgetLabel->setFont(font);
         item->widgetLabel->setText("\t" + property->valueText());
         item->widgetLabel->setToolTip(property->toolTip());
-        item->widgetLabel->setEnabled(property->isEnabled());        
+        item->widgetLabel->setEnabled(property->isEnabled());
     }
     if (item->widget) {
         QFont font = item->widget->font();
-        font.setUnderline(false);        
+        font.setUnderline(false);
         item->widget->setFont(font);
-        item->widget->setEnabled(property->isEnabled());        
+        item->widget->setEnabled(property->isEnabled());
         item->widget->setToolTip(property->toolTip());
     }
 }
@@ -553,8 +537,7 @@ void QtButtonPropertyBrowserPrivate::updateItem(WidgetItem *item)
     Creates a property browser with the given \a parent.
 */
 QtButtonPropertyBrowser::QtButtonPropertyBrowser(QWidget *parent)
-    : QtAbstractPropertyBrowser(parent)
-{
+    : QtAbstractPropertyBrowser(parent) {
     d_ptr = new QtButtonPropertyBrowserPrivate;
     d_ptr->q_ptr = this;
 
@@ -571,8 +554,7 @@ QtButtonPropertyBrowser::QtButtonPropertyBrowser(QWidget *parent)
 
     \sa QtProperty, QtAbstractPropertyManager
 */
-QtButtonPropertyBrowser::~QtButtonPropertyBrowser()
-{
+QtButtonPropertyBrowser::~QtButtonPropertyBrowser() {
     const QMap<QtButtonPropertyBrowserPrivate::WidgetItem *, QtBrowserItem *>::ConstIterator icend = d_ptr->m_itemToIndex.constEnd();
     for (QMap<QtButtonPropertyBrowserPrivate::WidgetItem *, QtBrowserItem *>::ConstIterator  it =  d_ptr->m_itemToIndex.constBegin(); it != icend; ++it)
         delete it.key();
@@ -582,24 +564,21 @@ QtButtonPropertyBrowser::~QtButtonPropertyBrowser()
 /*!
     \reimp
 */
-void QtButtonPropertyBrowser::itemInserted(QtBrowserItem *item, QtBrowserItem *afterItem)
-{
+void QtButtonPropertyBrowser::itemInserted(QtBrowserItem *item, QtBrowserItem *afterItem) {
     d_ptr->propertyInserted(item, afterItem);
 }
 
 /*!
     \reimp
 */
-void QtButtonPropertyBrowser::itemRemoved(QtBrowserItem *item)
-{
+void QtButtonPropertyBrowser::itemRemoved(QtBrowserItem *item) {
     d_ptr->propertyRemoved(item);
 }
 
 /*!
     \reimp
 */
-void QtButtonPropertyBrowser::itemChanged(QtBrowserItem *item)
-{
+void QtButtonPropertyBrowser::itemChanged(QtBrowserItem *item) {
     d_ptr->propertyChanged(item);
 }
 
@@ -609,8 +588,7 @@ void QtButtonPropertyBrowser::itemChanged(QtBrowserItem *item)
     \sa isExpanded(), expanded(), collapsed()
 */
 
-void QtButtonPropertyBrowser::setExpanded(QtBrowserItem *item, bool expanded)
-{
+void QtButtonPropertyBrowser::setExpanded(QtBrowserItem *item, bool expanded) {
     QtButtonPropertyBrowserPrivate::WidgetItem *itm = d_ptr->m_indexToItem.value(item);
     if (itm)
         d_ptr->setExpanded(itm, expanded);
@@ -622,8 +600,7 @@ void QtButtonPropertyBrowser::setExpanded(QtBrowserItem *item, bool expanded)
     \sa setExpanded()
 */
 
-bool QtButtonPropertyBrowser::isExpanded(QtBrowserItem *item) const
-{
+bool QtButtonPropertyBrowser::isExpanded(QtBrowserItem *item) const {
     QtButtonPropertyBrowserPrivate::WidgetItem *itm = d_ptr->m_indexToItem.value(item);
     if (itm)
         return itm->expanded;
