@@ -50,8 +50,7 @@
 QT_BEGIN_NAMESPACE
 #endif
 
-class QtGroupBoxPropertyBrowserPrivate
-{
+class QtGroupBoxPropertyBrowserPrivate {
     QtGroupBoxPropertyBrowser *q_ptr;
     Q_DECLARE_PUBLIC(QtGroupBoxPropertyBrowser)
 public:
@@ -61,16 +60,16 @@ public:
     void propertyInserted(QtBrowserItem *index, QtBrowserItem *afterIndex);
     void propertyRemoved(QtBrowserItem *index);
     void propertyChanged(QtBrowserItem *index);
-    QWidget *createEditor(QtProperty *property, QWidget *parent) const
-        { return q_ptr->createEditor(property, parent); }
+    QWidget *createEditor(QtProperty *property, QWidget *parent) const {
+        return q_ptr->createEditor(property, parent);
+    }
 
     void slotEditorDestroyed();
     void slotUpdate();
 
-    struct WidgetItem
-    {
+    struct WidgetItem {
         WidgetItem() : widget(0), label(0), widgetLabel(0),
-                groupBox(0), layout(0), line(0), parent(0) { }
+            groupBox(0), layout(0), line(0), parent(0) { }
         QWidget *widget; // can be null
         QLabel *label;
         QLabel *widgetLabel;
@@ -96,17 +95,15 @@ private:
     QList<WidgetItem *> m_recreateQueue;
 };
 
-void QtGroupBoxPropertyBrowserPrivate::init(QWidget *parent)
-{
+void QtGroupBoxPropertyBrowserPrivate::init(QWidget *parent) {
     m_mainLayout = new QGridLayout();
     parent->setLayout(m_mainLayout);
     QLayoutItem *item = new QSpacerItem(0, 0,
-                QSizePolicy::Fixed, QSizePolicy::Expanding);
+                                        QSizePolicy::Fixed, QSizePolicy::Expanding);
     m_mainLayout->addItem(item, 0, 0);
 }
 
-void QtGroupBoxPropertyBrowserPrivate::slotEditorDestroyed()
-{
+void QtGroupBoxPropertyBrowserPrivate::slotEditorDestroyed() {
     QWidget *editor = qobject_cast<QWidget *>(q_ptr->sender());
     if (!editor)
         return;
@@ -116,8 +113,7 @@ void QtGroupBoxPropertyBrowserPrivate::slotEditorDestroyed()
     m_widgetToItem.remove(editor);
 }
 
-void QtGroupBoxPropertyBrowserPrivate::slotUpdate()
-{
+void QtGroupBoxPropertyBrowserPrivate::slotUpdate() {
     QListIterator<WidgetItem *> itItem(m_recreateQueue);
     while (itItem.hasNext()) {
         WidgetItem *item = itItem.next();
@@ -163,13 +159,11 @@ void QtGroupBoxPropertyBrowserPrivate::slotUpdate()
     m_recreateQueue.clear();
 }
 
-void QtGroupBoxPropertyBrowserPrivate::updateLater()
-{
+void QtGroupBoxPropertyBrowserPrivate::updateLater() {
     QTimer::singleShot(0, q_ptr, SLOT(slotUpdate()));
 }
 
-void QtGroupBoxPropertyBrowserPrivate::propertyInserted(QtBrowserItem *index, QtBrowserItem *afterIndex)
-{
+void QtGroupBoxPropertyBrowserPrivate::propertyInserted(QtBrowserItem *index, QtBrowserItem *afterIndex) {
     WidgetItem *afterItem = m_indexToItem.value(afterIndex);
     WidgetItem *parentItem = m_indexToItem.value(index->parent());
 
@@ -276,8 +270,7 @@ void QtGroupBoxPropertyBrowserPrivate::propertyInserted(QtBrowserItem *index, Qt
     updateItem(newItem);
 }
 
-void QtGroupBoxPropertyBrowserPrivate::propertyRemoved(QtBrowserItem *index)
-{
+void QtGroupBoxPropertyBrowserPrivate::propertyRemoved(QtBrowserItem *index) {
     WidgetItem *item = m_indexToItem.value(index);
 
     m_indexToItem.remove(index);
@@ -350,8 +343,7 @@ void QtGroupBoxPropertyBrowserPrivate::propertyRemoved(QtBrowserItem *index)
     delete item;
 }
 
-void QtGroupBoxPropertyBrowserPrivate::insertRow(QGridLayout *layout, int row) const
-{
+void QtGroupBoxPropertyBrowserPrivate::insertRow(QGridLayout *layout, int row) const {
     QMap<QLayoutItem *, QRect> itemToPos;
     int idx = 0;
     while (idx < layout->count()) {
@@ -371,8 +363,7 @@ void QtGroupBoxPropertyBrowserPrivate::insertRow(QGridLayout *layout, int row) c
     }
 }
 
-void QtGroupBoxPropertyBrowserPrivate::removeRow(QGridLayout *layout, int row) const
-{
+void QtGroupBoxPropertyBrowserPrivate::removeRow(QGridLayout *layout, int row) const {
     QMap<QLayoutItem *, QRect> itemToPos;
     int idx = 0;
     while (idx < layout->count()) {
@@ -392,22 +383,19 @@ void QtGroupBoxPropertyBrowserPrivate::removeRow(QGridLayout *layout, int row) c
     }
 }
 
-bool QtGroupBoxPropertyBrowserPrivate::hasHeader(WidgetItem *item) const
-{
+bool QtGroupBoxPropertyBrowserPrivate::hasHeader(WidgetItem *item) const {
     if (item->widget)
         return true;
     return false;
 }
 
-void QtGroupBoxPropertyBrowserPrivate::propertyChanged(QtBrowserItem *index)
-{
+void QtGroupBoxPropertyBrowserPrivate::propertyChanged(QtBrowserItem *index) {
     WidgetItem *item = m_indexToItem.value(index);
 
     updateItem(item);
 }
 
-void QtGroupBoxPropertyBrowserPrivate::updateItem(WidgetItem *item)
-{
+void QtGroupBoxPropertyBrowserPrivate::updateItem(WidgetItem *item) {
     QtProperty *property = m_itemToIndex[item]->property();
     if (item->groupBox) {
         QFont font = item->groupBox->font();
@@ -425,7 +413,7 @@ void QtGroupBoxPropertyBrowserPrivate::updateItem(WidgetItem *item)
         QFont font = item->label->font();
         font.setUnderline(property->isModified());
         // if the item->widget is NULL, then the property is read only
-        font.setItalic(!item->widget);        
+        font.setItalic(!item->widget);
         item->label->setFont(font);
         item->label->setText(property->propertyName());
         item->label->setToolTip(property->toolTip());
@@ -436,7 +424,7 @@ void QtGroupBoxPropertyBrowserPrivate::updateItem(WidgetItem *item)
     if (item->widgetLabel) {
         QFont font = item->widgetLabel->font();
         // if the item->widget is NULL, then the property is read only
-        font.setItalic(!item->widget);     
+        font.setItalic(!item->widget);
         font.setUnderline(false);
         item->widgetLabel->setFont(font);
         item->widgetLabel->setText("\t" + property->valueText());
@@ -446,7 +434,7 @@ void QtGroupBoxPropertyBrowserPrivate::updateItem(WidgetItem *item)
     if (item->widget) {
         QFont font = item->widget->font();
         // if the item->widget is NULL, then the property is read only
-        font.setItalic(!item->widget);     
+        font.setItalic(!item->widget);
         font.setUnderline(false);
         item->widget->setFont(font);
         item->widget->setEnabled(property->isEnabled());
@@ -487,8 +475,7 @@ void QtGroupBoxPropertyBrowserPrivate::updateItem(WidgetItem *item)
     Creates a property browser with the given \a parent.
 */
 QtGroupBoxPropertyBrowser::QtGroupBoxPropertyBrowser(QWidget *parent)
-    : QtAbstractPropertyBrowser(parent)
-{
+    : QtAbstractPropertyBrowser(parent) {
     d_ptr = new QtGroupBoxPropertyBrowserPrivate;
     d_ptr->q_ptr = this;
 
@@ -505,8 +492,7 @@ QtGroupBoxPropertyBrowser::QtGroupBoxPropertyBrowser(QWidget *parent)
 
     \sa QtProperty, QtAbstractPropertyManager
 */
-QtGroupBoxPropertyBrowser::~QtGroupBoxPropertyBrowser()
-{
+QtGroupBoxPropertyBrowser::~QtGroupBoxPropertyBrowser() {
     const QMap<QtGroupBoxPropertyBrowserPrivate::WidgetItem *, QtBrowserItem *>::ConstIterator icend = d_ptr->m_itemToIndex.constEnd();
     for (QMap<QtGroupBoxPropertyBrowserPrivate::WidgetItem *, QtBrowserItem *>::ConstIterator it = d_ptr->m_itemToIndex.constBegin(); it != icend; ++it)
         delete it.key();
@@ -516,24 +502,21 @@ QtGroupBoxPropertyBrowser::~QtGroupBoxPropertyBrowser()
 /*!
     \reimp
 */
-void QtGroupBoxPropertyBrowser::itemInserted(QtBrowserItem *item, QtBrowserItem *afterItem)
-{
+void QtGroupBoxPropertyBrowser::itemInserted(QtBrowserItem *item, QtBrowserItem *afterItem) {
     d_ptr->propertyInserted(item, afterItem);
 }
 
 /*!
     \reimp
 */
-void QtGroupBoxPropertyBrowser::itemRemoved(QtBrowserItem *item)
-{
+void QtGroupBoxPropertyBrowser::itemRemoved(QtBrowserItem *item) {
     d_ptr->propertyRemoved(item);
 }
 
 /*!
     \reimp
 */
-void QtGroupBoxPropertyBrowser::itemChanged(QtBrowserItem *item)
-{
+void QtGroupBoxPropertyBrowser::itemChanged(QtBrowserItem *item) {
     d_ptr->propertyChanged(item);
 }
 
