@@ -52,8 +52,7 @@
 QT_BEGIN_NAMESPACE
 #endif
 
-class QtPropertyPrivate
-{
+class QtPropertyPrivate {
 public:
     QtPropertyPrivate(QtAbstractPropertyManager *manager)
         : m_enabled(true),
@@ -74,17 +73,16 @@ public:
     QtAbstractPropertyManager * const m_manager;
 };
 
-class QtAbstractPropertyManagerPrivate
-{
+class QtAbstractPropertyManagerPrivate {
     QtAbstractPropertyManager *q_ptr;
     Q_DECLARE_PUBLIC(QtAbstractPropertyManager)
 public:
     void propertyDestroyed(QtProperty *property);
     void propertyChanged(QtProperty *property) const;
     void propertyRemoved(QtProperty *property,
-                QtProperty *parentProperty) const;
+                         QtProperty *parentProperty) const;
     void propertyInserted(QtProperty *property, QtProperty *parentProperty,
-                QtProperty *afterProperty) const;
+                          QtProperty *afterProperty) const;
 
     QSet<QtProperty *> m_properties;
 };
@@ -143,8 +141,7 @@ public:
 
     \sa QtAbstractPropertyManager::addProperty()
 */
-QtProperty::QtProperty(QtAbstractPropertyManager *manager)
-{
+QtProperty::QtProperty(QtAbstractPropertyManager *manager) {
     d_ptr = new QtPropertyPrivate(manager);
     d_ptr->q_ptr = this;
 }
@@ -158,8 +155,7 @@ QtProperty::QtProperty(QtAbstractPropertyManager *manager)
     \sa QtAbstractPropertyManager::clear()
 
 */
-QtProperty::~QtProperty()
-{
+QtProperty::~QtProperty() {
     QSetIterator<QtProperty *> itParent(d_ptr->m_parentItems);
     while (itParent.hasNext()) {
         QtProperty *property = itParent.next();
@@ -190,16 +186,14 @@ QtProperty::~QtProperty()
 
     \sa insertSubProperty(), removeSubProperty()
 */
-QList<QtProperty *> QtProperty::subProperties() const
-{
+QList<QtProperty *> QtProperty::subProperties() const {
     return d_ptr->m_subItems;
 }
 
 /*!
     Returns a pointer to the manager that owns this property.
 */
-QtAbstractPropertyManager *QtProperty::propertyManager() const
-{
+QtAbstractPropertyManager *QtProperty::propertyManager() const {
     return d_ptr->m_manager;
 }
 
@@ -208,8 +202,7 @@ QtAbstractPropertyManager *QtProperty::propertyManager() const
 
     \sa setToolTip()
 */
-QString QtProperty::toolTip() const
-{
+QString QtProperty::toolTip() const {
     return d_ptr->m_toolTip;
 }
 
@@ -218,8 +211,7 @@ QString QtProperty::toolTip() const
 
     \sa setStatusTip()
 */
-QString QtProperty::statusTip() const
-{
+QString QtProperty::statusTip() const {
     return d_ptr->m_statusTip;
 }
 
@@ -228,8 +220,7 @@ QString QtProperty::statusTip() const
 
     \sa setWhatsThis()
 */
-QString QtProperty::whatsThis() const
-{
+QString QtProperty::whatsThis() const {
     return d_ptr->m_whatsThis;
 }
 
@@ -238,8 +229,7 @@ QString QtProperty::whatsThis() const
 
     \sa setPropertyName()
 */
-QString QtProperty::propertyName() const
-{
+QString QtProperty::propertyName() const {
     return d_ptr->m_name;
 }
 
@@ -248,8 +238,7 @@ QString QtProperty::propertyName() const
 
     \sa setEnabled()
 */
-bool QtProperty::isEnabled() const
-{
+bool QtProperty::isEnabled() const {
     return d_ptr->m_enabled;
 }
 
@@ -258,8 +247,7 @@ bool QtProperty::isEnabled() const
 
     \sa setModified()
 */
-bool QtProperty::isModified() const
-{
+bool QtProperty::isModified() const {
     return d_ptr->m_modified;
 }
 
@@ -268,8 +256,7 @@ bool QtProperty::isModified() const
 
     \sa QtAbstractPropertyManager::hasValue()
 */
-bool QtProperty::hasValue() const
-{
+bool QtProperty::hasValue() const {
     return d_ptr->m_manager->hasValue(this);
 }
 
@@ -281,8 +268,7 @@ bool QtProperty::hasValue() const
 
     \sa QtAbstractPropertyManager::valueIcon()
 */
-QIcon QtProperty::valueIcon() const
-{
+QIcon QtProperty::valueIcon() const {
     return d_ptr->m_manager->valueIcon(this);
 }
 
@@ -294,8 +280,7 @@ QIcon QtProperty::valueIcon() const
 
     \sa QtAbstractPropertyManager::valueText()
 */
-QString QtProperty::valueText() const
-{
+QString QtProperty::valueText() const {
     return d_ptr->m_manager->valueText(this);
 }
 
@@ -307,8 +292,7 @@ QString QtProperty::valueText() const
 
     \sa QtAbstractPropertyManager::valueText()
 */
-QString QtProperty::displayText() const
-{
+QString QtProperty::displayText() const {
     return d_ptr->m_manager->displayText(this);
 }
 
@@ -317,8 +301,7 @@ QString QtProperty::displayText() const
 
     \sa toolTip()
 */
-void QtProperty::setToolTip(const QString &text)
-{
+void QtProperty::setToolTip(const QString &text) {
     if (d_ptr->m_toolTip == text)
         return;
 
@@ -331,8 +314,7 @@ void QtProperty::setToolTip(const QString &text)
 
     \sa statusTip()
 */
-void QtProperty::setStatusTip(const QString &text)
-{
+void QtProperty::setStatusTip(const QString &text) {
     if (d_ptr->m_statusTip == text)
         return;
 
@@ -345,8 +327,7 @@ void QtProperty::setStatusTip(const QString &text)
 
     \sa whatsThis()
 */
-void QtProperty::setWhatsThis(const QString &text)
-{
+void QtProperty::setWhatsThis(const QString &text) {
     if (d_ptr->m_whatsThis == text)
         return;
 
@@ -361,8 +342,7 @@ void QtProperty::setWhatsThis(const QString &text)
 
     \sa propertyName()
 */
-void QtProperty::setPropertyName(const QString &text)
-{
+void QtProperty::setPropertyName(const QString &text) {
     if (d_ptr->m_name == text)
         return;
 
@@ -375,8 +355,7 @@ void QtProperty::setPropertyName(const QString &text)
 
     \sa isEnabled()
 */
-void QtProperty::setEnabled(bool enable)
-{
+void QtProperty::setEnabled(bool enable) {
     if (d_ptr->m_enabled == enable)
         return;
 
@@ -389,8 +368,7 @@ void QtProperty::setEnabled(bool enable)
 
     \sa isModified()
 */
-void QtProperty::setModified(bool modified)
-{
+void QtProperty::setModified(bool modified) {
     if (d_ptr->m_modified == modified)
         return;
 
@@ -406,8 +384,7 @@ void QtProperty::setModified(bool modified)
 
     \sa insertSubProperty(), removeSubProperty()
 */
-void QtProperty::addSubProperty(QtProperty *property)
-{
+void QtProperty::addSubProperty(QtProperty *property) {
     QtProperty *after = 0;
     if (d_ptr->m_subItems.count() > 0)
         after = d_ptr->m_subItems.last();
@@ -428,8 +405,7 @@ void QtProperty::addSubProperty(QtProperty *property)
     \sa addSubProperty(), removeSubProperty()
 */
 void QtProperty::insertSubProperty(QtProperty *property,
-            QtProperty *afterProperty)
-{
+                                   QtProperty *afterProperty) {
     if (!property)
         return;
 
@@ -477,8 +453,7 @@ void QtProperty::insertSubProperty(QtProperty *property,
 
     \sa addSubProperty(), insertSubProperty()
 */
-void QtProperty::removeSubProperty(QtProperty *property)
-{
+void QtProperty::removeSubProperty(QtProperty *property) {
     if (!property)
         return;
 
@@ -500,15 +475,13 @@ void QtProperty::removeSubProperty(QtProperty *property)
 /*!
     \internal
 */
-void QtProperty::propertyChanged()
-{
+void QtProperty::propertyChanged() {
     d_ptr->m_manager->d_ptr->propertyChanged(this);
 }
 
 ////////////////////////////////
 
-void QtAbstractPropertyManagerPrivate::propertyDestroyed(QtProperty *property)
-{
+void QtAbstractPropertyManagerPrivate::propertyDestroyed(QtProperty *property) {
     if (m_properties.contains(property)) {
         emit q_ptr->propertyDestroyed(property);
         q_ptr->uninitializeProperty(property);
@@ -516,20 +489,17 @@ void QtAbstractPropertyManagerPrivate::propertyDestroyed(QtProperty *property)
     }
 }
 
-void QtAbstractPropertyManagerPrivate::propertyChanged(QtProperty *property) const
-{
+void QtAbstractPropertyManagerPrivate::propertyChanged(QtProperty *property) const {
     emit q_ptr->propertyChanged(property);
 }
 
 void QtAbstractPropertyManagerPrivate::propertyRemoved(QtProperty *property,
-            QtProperty *parentProperty) const
-{
+        QtProperty *parentProperty) const {
     emit q_ptr->propertyRemoved(property, parentProperty);
 }
 
 void QtAbstractPropertyManagerPrivate::propertyInserted(QtProperty *property,
-            QtProperty *parentProperty, QtProperty *afterProperty) const
-{
+        QtProperty *parentProperty, QtProperty *afterProperty) const {
     emit q_ptr->propertyInserted(property, parentProperty, afterProperty);
 }
 
@@ -650,8 +620,7 @@ void QtAbstractPropertyManagerPrivate::propertyInserted(QtProperty *property,
     Creates an abstract property manager with the given \a parent.
 */
 QtAbstractPropertyManager::QtAbstractPropertyManager(QObject *parent)
-    : QObject(parent)
-{
+    : QObject(parent) {
     d_ptr = new QtAbstractPropertyManagerPrivate;
     d_ptr->q_ptr = this;
 
@@ -661,8 +630,7 @@ QtAbstractPropertyManager::QtAbstractPropertyManager(QObject *parent)
     Destroys the manager. All properties created by the manager are
     destroyed.
 */
-QtAbstractPropertyManager::~QtAbstractPropertyManager()
-{
+QtAbstractPropertyManager::~QtAbstractPropertyManager() {
     clear();
     delete d_ptr;
 }
@@ -672,8 +640,7 @@ QtAbstractPropertyManager::~QtAbstractPropertyManager()
 
     \sa propertyDestroyed(), uninitializeProperty()
 */
-void QtAbstractPropertyManager::clear() const
-{
+void QtAbstractPropertyManager::clear() const {
     while (!properties().isEmpty()) {
         QSetIterator<QtProperty *> itProperty(properties());
         QtProperty *prop = itProperty.next();
@@ -686,8 +653,7 @@ void QtAbstractPropertyManager::clear() const
 
     \sa addProperty()
 */
-QSet<QtProperty *> QtAbstractPropertyManager::properties() const
-{
+QSet<QtProperty *> QtAbstractPropertyManager::properties() const {
     return d_ptr->m_properties;
 }
 
@@ -698,8 +664,7 @@ QSet<QtProperty *> QtAbstractPropertyManager::properties() const
 
     \sa QtProperty::hasValue()
 */
-bool QtAbstractPropertyManager::hasValue(const QtProperty *property) const
-{
+bool QtAbstractPropertyManager::hasValue(const QtProperty *property) const {
     Q_UNUSED(property)
     return true;
 }
@@ -713,8 +678,7 @@ bool QtAbstractPropertyManager::hasValue(const QtProperty *property) const
 
     \sa QtProperty::valueIcon()
 */
-QIcon QtAbstractPropertyManager::valueIcon(const QtProperty *property) const
-{
+QIcon QtAbstractPropertyManager::valueIcon(const QtProperty *property) const {
     Q_UNUSED(property)
     return QIcon();
 }
@@ -728,8 +692,7 @@ QIcon QtAbstractPropertyManager::valueIcon(const QtProperty *property) const
 
     \sa QtProperty::valueText()
 */
-QString QtAbstractPropertyManager::valueText(const QtProperty *property) const
-{
+QString QtAbstractPropertyManager::valueText(const QtProperty *property) const {
     Q_UNUSED(property)
     return QString();
 }
@@ -743,8 +706,7 @@ QString QtAbstractPropertyManager::valueText(const QtProperty *property) const
 
     \sa QtProperty::valueText()
 */
-QString QtAbstractPropertyManager::displayText(const QtProperty *property) const
-{
+QString QtAbstractPropertyManager::displayText(const QtProperty *property) const {
     Q_UNUSED(property)
     return QString();
 }
@@ -757,8 +719,7 @@ QString QtAbstractPropertyManager::displayText(const QtProperty *property) const
 
     \sa QtProperty::valueText()
 */
-EchoMode QtAbstractPropertyManager::echoMode(const QtProperty *property) const
-{
+EchoMode QtAbstractPropertyManager::echoMode(const QtProperty *property) const {
     Q_UNUSED(property)
     return QLineEdit::Normal;
 }
@@ -771,8 +732,7 @@ EchoMode QtAbstractPropertyManager::echoMode(const QtProperty *property) const
 
     \sa initializeProperty(), properties()
 */
-QtProperty *QtAbstractPropertyManager::addProperty(const QString &name)
-{
+QtProperty *QtAbstractPropertyManager::addProperty(const QString &name) {
     QtProperty *property = createProperty();
     if (property) {
         property->setPropertyName(name);
@@ -791,8 +751,7 @@ QtProperty *QtAbstractPropertyManager::addProperty(const QString &name)
 
     \sa addProperty(), initializeProperty()
 */
-QtProperty *QtAbstractPropertyManager::createProperty()
-{
+QtProperty *QtAbstractPropertyManager::createProperty() {
     return new QtProperty(this);
 }
 
@@ -824,8 +783,7 @@ QtProperty *QtAbstractPropertyManager::createProperty()
 
     \sa clear(),  propertyDestroyed()
 */
-void QtAbstractPropertyManager::uninitializeProperty(QtProperty *property)
-{
+void QtAbstractPropertyManager::uninitializeProperty(QtProperty *property) {
     Q_UNUSED(property)
 }
 
@@ -1099,8 +1057,7 @@ void QtAbstractPropertyManager::uninitializeProperty(QtProperty *property)
 */
 
 ////////////////////////////////////
-class QtBrowserItemPrivate
-{
+class QtBrowserItemPrivate {
 public:
     QtBrowserItemPrivate(QtAbstractPropertyBrowser *browser, QtProperty *property, QtBrowserItem *parent)
         : m_browser(browser), m_property(property), m_parent(parent), q_ptr(0) {}
@@ -1118,16 +1075,14 @@ public:
 
 };
 
-void QtBrowserItemPrivate::addChild(QtBrowserItem *index, QtBrowserItem *after)
-{
+void QtBrowserItemPrivate::addChild(QtBrowserItem *index, QtBrowserItem *after) {
     if (m_children.contains(index))
         return;
     int idx = m_children.indexOf(after) + 1; // we insert after returned idx, if it was -1 then we set idx to 0;
     m_children.insert(idx, index);
 }
 
-void QtBrowserItemPrivate::removeChild(QtBrowserItem *index)
-{
+void QtBrowserItemPrivate::removeChild(QtBrowserItem *index) {
     m_children.removeAll(index);
 }
 
@@ -1160,8 +1115,7 @@ void QtBrowserItemPrivate::removeChild(QtBrowserItem *index)
     \sa QtAbstractPropertyBrowser::items()
 */
 
-QtProperty *QtBrowserItem::property() const
-{
+QtProperty *QtBrowserItem::property() const {
     return d_ptr->m_property;
 }
 
@@ -1172,8 +1126,7 @@ QtProperty *QtBrowserItem::property() const
     \sa children()
 */
 
-QtBrowserItem *QtBrowserItem::parent() const
-{
+QtBrowserItem *QtBrowserItem::parent() const {
     return d_ptr->m_parent;
 }
 
@@ -1192,8 +1145,7 @@ QtBrowserItem *QtBrowserItem::parent() const
     The \e childrenItems list represents the same list as \e childrenProperties.
 */
 
-QList<QtBrowserItem *> QtBrowserItem::children() const
-{
+QList<QtBrowserItem *> QtBrowserItem::children() const {
     return d_ptr->m_children;
 }
 
@@ -1201,19 +1153,16 @@ QList<QtBrowserItem *> QtBrowserItem::children() const
     Returns the property browser which owns \e this item.
 */
 
-QtAbstractPropertyBrowser *QtBrowserItem::browser() const
-{
+QtAbstractPropertyBrowser *QtBrowserItem::browser() const {
     return d_ptr->m_browser;
 }
 
-QtBrowserItem::QtBrowserItem(QtAbstractPropertyBrowser *browser, QtProperty *property, QtBrowserItem *parent)
-{
+QtBrowserItem::QtBrowserItem(QtAbstractPropertyBrowser *browser, QtProperty *property, QtBrowserItem *parent) {
     d_ptr = new QtBrowserItemPrivate(browser, property, parent);
     d_ptr->q_ptr = this;
 }
 
-QtBrowserItem::~QtBrowserItem()
-{
+QtBrowserItem::~QtBrowserItem() {
     delete d_ptr;
 }
 
@@ -1221,23 +1170,22 @@ QtBrowserItem::~QtBrowserItem()
 ////////////////////////////////////
 
 typedef QMap<QtAbstractPropertyBrowser *, QMap<QtAbstractPropertyManager *,
-                            QtAbstractEditorFactoryBase *> > Map1;
+        QtAbstractEditorFactoryBase *> > Map1;
 typedef QMap<QtAbstractPropertyManager *, QMap<QtAbstractEditorFactoryBase *,
-                            QList<QtAbstractPropertyBrowser *> > > Map2;
+        QList<QtAbstractPropertyBrowser *> > > Map2;
 Q_GLOBAL_STATIC(Map1, m_viewToManagerToFactory)
 Q_GLOBAL_STATIC(Map2, m_managerToFactoryToViews)
 
-class QtAbstractPropertyBrowserPrivate
-{
+class QtAbstractPropertyBrowserPrivate {
     QtAbstractPropertyBrowser *q_ptr;
     Q_DECLARE_PUBLIC(QtAbstractPropertyBrowser)
 public:
     QtAbstractPropertyBrowserPrivate();
 
     void insertSubTree(QtProperty *property,
-            QtProperty *parentProperty);
+                       QtProperty *parentProperty);
     void removeSubTree(QtProperty *property,
-            QtProperty *parentProperty);
+                       QtProperty *parentProperty);
     void createBrowserIndexes(QtProperty *property, QtProperty *parentProperty, QtProperty *afterProperty);
     void removeBrowserIndexes(QtProperty *property, QtProperty *parentProperty);
     QtBrowserItem *createBrowserIndex(QtProperty *property, QtBrowserItem *parentIndex, QtBrowserItem *afterIndex);
@@ -1245,7 +1193,7 @@ public:
     void clearIndex(QtBrowserItem *index);
 
     void slotPropertyInserted(QtProperty *property,
-            QtProperty *parentProperty, QtProperty *afterProperty);
+                              QtProperty *parentProperty, QtProperty *afterProperty);
     void slotPropertyRemoved(QtProperty *property, QtProperty *parentProperty);
     void slotPropertyDestroyed(QtProperty *property);
     void slotPropertyDataChanged(QtProperty *property);
@@ -1262,13 +1210,11 @@ public:
 };
 
 QtAbstractPropertyBrowserPrivate::QtAbstractPropertyBrowserPrivate() :
-   m_currentItem(0)
-{
+    m_currentItem(0) {
 }
 
 void QtAbstractPropertyBrowserPrivate::insertSubTree(QtProperty *property,
-            QtProperty *parentProperty)
-{
+        QtProperty *parentProperty) {
     if (m_propertyToParents.contains(property)) {
         // property was already inserted, so its manager is connected
         // and all its children are inserted and theirs managers are connected
@@ -1282,16 +1228,16 @@ void QtAbstractPropertyBrowserPrivate::insertSubTree(QtProperty *property,
     if (m_managerToProperties[manager].isEmpty()) {
         // connect manager's signals
         q_ptr->connect(manager, SIGNAL(propertyInserted(QtProperty *,
-                            QtProperty *, QtProperty *)),
-                q_ptr, SLOT(slotPropertyInserted(QtProperty *,
-                            QtProperty *, QtProperty *)));
+                                       QtProperty *, QtProperty *)),
+                       q_ptr, SLOT(slotPropertyInserted(QtProperty *,
+                                   QtProperty *, QtProperty *)));
         q_ptr->connect(manager, SIGNAL(propertyRemoved(QtProperty *,
-                            QtProperty *)),
-                q_ptr, SLOT(slotPropertyRemoved(QtProperty *, QtProperty *)));
+                                       QtProperty *)),
+                       q_ptr, SLOT(slotPropertyRemoved(QtProperty *, QtProperty *)));
         q_ptr->connect(manager, SIGNAL(propertyDestroyed(QtProperty *)),
-                q_ptr, SLOT(slotPropertyDestroyed(QtProperty *)));
+                       q_ptr, SLOT(slotPropertyDestroyed(QtProperty *)));
         q_ptr->connect(manager, SIGNAL(propertyChanged(QtProperty *)),
-                q_ptr, SLOT(slotPropertyDataChanged(QtProperty *)));
+                       q_ptr, SLOT(slotPropertyDataChanged(QtProperty *)));
     }
     m_managerToProperties[manager].append(property);
     m_propertyToParents[property].append(parentProperty);
@@ -1305,8 +1251,7 @@ void QtAbstractPropertyBrowserPrivate::insertSubTree(QtProperty *property,
 }
 
 void QtAbstractPropertyBrowserPrivate::removeSubTree(QtProperty *property,
-            QtProperty *parentProperty)
-{
+        QtProperty *parentProperty) {
     if (!m_propertyToParents.contains(property)) {
         // ASSERT
         return;
@@ -1322,16 +1267,16 @@ void QtAbstractPropertyBrowserPrivate::removeSubTree(QtProperty *property,
     if (m_managerToProperties[manager].isEmpty()) {
         // disconnect manager's signals
         q_ptr->disconnect(manager, SIGNAL(propertyInserted(QtProperty *,
-                            QtProperty *, QtProperty *)),
-                q_ptr, SLOT(slotPropertyInserted(QtProperty *,
-                            QtProperty *, QtProperty *)));
+                                          QtProperty *, QtProperty *)),
+                          q_ptr, SLOT(slotPropertyInserted(QtProperty *,
+                                      QtProperty *, QtProperty *)));
         q_ptr->disconnect(manager, SIGNAL(propertyRemoved(QtProperty *,
-                            QtProperty *)),
-                q_ptr, SLOT(slotPropertyRemoved(QtProperty *, QtProperty *)));
+                                          QtProperty *)),
+                          q_ptr, SLOT(slotPropertyRemoved(QtProperty *, QtProperty *)));
         q_ptr->disconnect(manager, SIGNAL(propertyDestroyed(QtProperty *)),
-                q_ptr, SLOT(slotPropertyDestroyed(QtProperty *)));
+                          q_ptr, SLOT(slotPropertyDestroyed(QtProperty *)));
         q_ptr->disconnect(manager, SIGNAL(propertyChanged(QtProperty *)),
-                q_ptr, SLOT(slotPropertyDataChanged(QtProperty *)));
+                          q_ptr, SLOT(slotPropertyDataChanged(QtProperty *)));
 
         m_managerToProperties.remove(manager);
     }
@@ -1344,8 +1289,7 @@ void QtAbstractPropertyBrowserPrivate::removeSubTree(QtProperty *property,
     }
 }
 
-void QtAbstractPropertyBrowserPrivate::createBrowserIndexes(QtProperty *property, QtProperty *parentProperty, QtProperty *afterProperty)
-{
+void QtAbstractPropertyBrowserPrivate::createBrowserIndexes(QtProperty *property, QtProperty *parentProperty, QtProperty *afterProperty) {
     QMap<QtBrowserItem *, QtBrowserItem *> parentToAfter;
     if (afterProperty) {
         QMap<QtProperty *, QList<QtBrowserItem *> >::ConstIterator it =
@@ -1363,7 +1307,7 @@ void QtAbstractPropertyBrowserPrivate::createBrowserIndexes(QtProperty *property
         }
     } else if (parentProperty) {
         QMap<QtProperty *, QList<QtBrowserItem *> >::ConstIterator it =
-                m_propertyToIndexes.find(parentProperty);
+            m_propertyToIndexes.find(parentProperty);
         if (it == m_propertyToIndexes.constEnd())
             return;
 
@@ -1383,8 +1327,7 @@ void QtAbstractPropertyBrowserPrivate::createBrowserIndexes(QtProperty *property
 }
 
 QtBrowserItem *QtAbstractPropertyBrowserPrivate::createBrowserIndex(QtProperty *property,
-        QtBrowserItem *parentIndex, QtBrowserItem *afterIndex)
-{
+        QtBrowserItem *parentIndex, QtBrowserItem *afterIndex) {
     QtBrowserItem *newIndex = new QtBrowserItem(q_ptr, property, parentIndex);
     if (parentIndex) {
         parentIndex->d_ptr->addChild(newIndex, afterIndex);
@@ -1406,8 +1349,7 @@ QtBrowserItem *QtAbstractPropertyBrowserPrivate::createBrowserIndex(QtProperty *
     return newIndex;
 }
 
-void QtAbstractPropertyBrowserPrivate::removeBrowserIndexes(QtProperty *property, QtProperty *parentProperty)
-{
+void QtAbstractPropertyBrowserPrivate::removeBrowserIndexes(QtProperty *property, QtProperty *parentProperty) {
     QList<QtBrowserItem *> toRemove;
     QMap<QtProperty *, QList<QtBrowserItem *> >::ConstIterator it =
         m_propertyToIndexes.find(property);
@@ -1430,8 +1372,7 @@ void QtAbstractPropertyBrowserPrivate::removeBrowserIndexes(QtProperty *property
     }
 }
 
-void QtAbstractPropertyBrowserPrivate::removeBrowserIndex(QtBrowserItem *index)
-{
+void QtAbstractPropertyBrowserPrivate::removeBrowserIndex(QtBrowserItem *index) {
     QList<QtBrowserItem *> children = index->children();
     for (int i = children.count(); i > 0; i--) {
         removeBrowserIndex(children.at(i - 1));
@@ -1455,8 +1396,7 @@ void QtAbstractPropertyBrowserPrivate::removeBrowserIndex(QtBrowserItem *index)
     delete index;
 }
 
-void QtAbstractPropertyBrowserPrivate::clearIndex(QtBrowserItem *index)
-{
+void QtAbstractPropertyBrowserPrivate::clearIndex(QtBrowserItem *index) {
     QList<QtBrowserItem *> children = index->children();
     QListIterator<QtBrowserItem *> itChild(children);
     while (itChild.hasNext()) {
@@ -1466,8 +1406,7 @@ void QtAbstractPropertyBrowserPrivate::clearIndex(QtBrowserItem *index)
 }
 
 void QtAbstractPropertyBrowserPrivate::slotPropertyInserted(QtProperty *property,
-        QtProperty *parentProperty, QtProperty *afterProperty)
-{
+        QtProperty *parentProperty, QtProperty *afterProperty) {
     if (!m_propertyToParents.contains(parentProperty))
         return;
     createBrowserIndexes(property, parentProperty, afterProperty);
@@ -1476,8 +1415,7 @@ void QtAbstractPropertyBrowserPrivate::slotPropertyInserted(QtProperty *property
 }
 
 void QtAbstractPropertyBrowserPrivate::slotPropertyRemoved(QtProperty *property,
-        QtProperty *parentProperty)
-{
+        QtProperty *parentProperty) {
     if (!m_propertyToParents.contains(parentProperty))
         return;
     removeSubTree(property, parentProperty); // this line should be probably moved down after propertyRemoved call
@@ -1485,20 +1423,18 @@ void QtAbstractPropertyBrowserPrivate::slotPropertyRemoved(QtProperty *property,
     removeBrowserIndexes(property, parentProperty);
 }
 
-void QtAbstractPropertyBrowserPrivate::slotPropertyDestroyed(QtProperty *property)
-{
+void QtAbstractPropertyBrowserPrivate::slotPropertyDestroyed(QtProperty *property) {
     if (!m_subItems.contains(property))
         return;
     q_ptr->removeProperty(property);
 }
 
-void QtAbstractPropertyBrowserPrivate::slotPropertyDataChanged(QtProperty *property)
-{
+void QtAbstractPropertyBrowserPrivate::slotPropertyDataChanged(QtProperty *property) {
     if (!m_propertyToParents.contains(property))
         return;
 
     QMap<QtProperty *, QList<QtBrowserItem *> >::ConstIterator it =
-            m_propertyToIndexes.find(property);
+        m_propertyToIndexes.find(property);
     if (it == m_propertyToIndexes.constEnd())
         return;
 
@@ -1710,8 +1646,7 @@ void QtAbstractPropertyBrowserPrivate::slotPropertyDataChanged(QtProperty *prope
     Creates an abstract property browser with the given \a parent.
 */
 QtAbstractPropertyBrowser::QtAbstractPropertyBrowser(QWidget *parent)
-    : QWidget(parent)
-{
+    : QWidget(parent) {
     d_ptr = new QtAbstractPropertyBrowserPrivate;
     d_ptr->q_ptr = this;
 
@@ -1729,8 +1664,7 @@ QtAbstractPropertyBrowser::QtAbstractPropertyBrowser(QWidget *parent)
 
     \sa QtAbstractPropertyManager::~QtAbstractPropertyManager()
 */
-QtAbstractPropertyBrowser::~QtAbstractPropertyBrowser()
-{
+QtAbstractPropertyBrowser::~QtAbstractPropertyBrowser() {
     QList<QtBrowserItem *> indexes = topLevelItems();
     QListIterator<QtBrowserItem *> itItem(indexes);
     while (itItem.hasNext())
@@ -1746,8 +1680,7 @@ QtAbstractPropertyBrowser::~QtAbstractPropertyBrowser()
 
     \sa addProperty(), insertProperty(), removeProperty()
 */
-QList<QtProperty *> QtAbstractPropertyBrowser::properties() const
-{
+QList<QtProperty *> QtAbstractPropertyBrowser::properties() const {
     return d_ptr->m_subItems;
 }
 
@@ -1760,8 +1693,7 @@ QList<QtProperty *> QtAbstractPropertyBrowser::properties() const
     \sa topLevelItem()
 */
 
-QList<QtBrowserItem *> QtAbstractPropertyBrowser::items(QtProperty *property) const
-{
+QList<QtBrowserItem *> QtAbstractPropertyBrowser::items(QtProperty *property) const {
     return d_ptr->m_propertyToIndexes.value(property);
 }
 
@@ -1774,8 +1706,7 @@ QList<QtBrowserItem *> QtAbstractPropertyBrowser::items(QtProperty *property) co
     \sa topLevelItems(), items()
 */
 
-QtBrowserItem *QtAbstractPropertyBrowser::topLevelItem(QtProperty *property) const
-{
+QtBrowserItem *QtAbstractPropertyBrowser::topLevelItem(QtProperty *property) const {
     return d_ptr->m_topLevelPropertyToIndex.value(property);
 }
 
@@ -1785,8 +1716,7 @@ QtBrowserItem *QtAbstractPropertyBrowser::topLevelItem(QtProperty *property) con
     \sa topLevelItem()
 */
 
-QList<QtBrowserItem *> QtAbstractPropertyBrowser::topLevelItems() const
-{
+QList<QtBrowserItem *> QtAbstractPropertyBrowser::topLevelItems() const {
     return d_ptr->m_topLevelIndexes;
 }
 
@@ -1796,8 +1726,7 @@ QList<QtBrowserItem *> QtAbstractPropertyBrowser::topLevelItems() const
 
     \sa removeProperty(), QtAbstractPropertyManager::clear()
 */
-void QtAbstractPropertyBrowser::clear()
-{
+void QtAbstractPropertyBrowser::clear() {
     QList<QtProperty *> subList = properties();
     QListIterator<QtProperty *> itSub(subList);
     itSub.toBack();
@@ -1819,8 +1748,7 @@ void QtAbstractPropertyBrowser::clear()
 
     \sa insertProperty(), QtProperty::addSubProperty(), properties()
 */
-QtBrowserItem *QtAbstractPropertyBrowser::addProperty(QtProperty *property)
-{
+QtBrowserItem *QtAbstractPropertyBrowser::addProperty(QtProperty *property) {
     QtProperty *afterProperty = 0;
     if (d_ptr->m_subItems.count() > 0)
         afterProperty = d_ptr->m_subItems.last();
@@ -1844,8 +1772,7 @@ QtBrowserItem *QtAbstractPropertyBrowser::addProperty(QtProperty *property)
     \sa addProperty(), QtProperty::insertSubProperty(), properties()
 */
 QtBrowserItem *QtAbstractPropertyBrowser::insertProperty(QtProperty *property,
-            QtProperty *afterProperty)
-{
+        QtProperty *afterProperty) {
     if (!property)
         return 0;
 
@@ -1885,8 +1812,7 @@ QtBrowserItem *QtAbstractPropertyBrowser::insertProperty(QtProperty *property,
 
     \sa clear(), QtProperty::removeSubProperty(), properties()
 */
-void QtAbstractPropertyBrowser::removeProperty(QtProperty *property)
-{
+void QtAbstractPropertyBrowser::removeProperty(QtProperty *property) {
     if (!property)
         return;
 
@@ -1928,13 +1854,12 @@ void QtAbstractPropertyBrowser::removeProperty(QtProperty *property)
     \sa setFactoryForManager()
 */
 QWidget *QtAbstractPropertyBrowser::createEditor(QtProperty *property,
-                QWidget *parent)
-{
+        QWidget *parent) {
     QtAbstractEditorFactoryBase *factory = 0;
     QtAbstractPropertyManager *manager = property->propertyManager();
 
     if (m_viewToManagerToFactory()->contains(this) &&
-        (*m_viewToManagerToFactory())[this].contains(manager)) {
+            (*m_viewToManagerToFactory())[this].contains(manager)) {
         factory = (*m_viewToManagerToFactory())[this][manager];
     }
 
@@ -1944,19 +1869,18 @@ QWidget *QtAbstractPropertyBrowser::createEditor(QtProperty *property,
 }
 
 bool QtAbstractPropertyBrowser::addFactory(QtAbstractPropertyManager *abstractManager,
-            QtAbstractEditorFactoryBase *abstractFactory)
-{
+        QtAbstractEditorFactoryBase *abstractFactory) {
     bool connectNeeded = false;
     if (!m_managerToFactoryToViews()->contains(abstractManager) ||
-        !(*m_managerToFactoryToViews())[abstractManager].contains(abstractFactory)) {
+            !(*m_managerToFactoryToViews())[abstractManager].contains(abstractFactory)) {
         connectNeeded = true;
     } else if ((*m_managerToFactoryToViews())[abstractManager][abstractFactory]
-                    .contains(this)) {
+               .contains(this)) {
         return connectNeeded;
     }
 
     if (m_viewToManagerToFactory()->contains(this) &&
-        (*m_viewToManagerToFactory())[this].contains(abstractManager)) {
+            (*m_viewToManagerToFactory())[this].contains(abstractManager)) {
         unsetFactoryForManager(abstractManager);
     }
 
@@ -1973,15 +1897,14 @@ bool QtAbstractPropertyBrowser::addFactory(QtAbstractPropertyManager *abstractMa
 
     \sa setFactoryForManager()
 */
-void QtAbstractPropertyBrowser::unsetFactoryForManager(QtAbstractPropertyManager *manager)
-{
+void QtAbstractPropertyBrowser::unsetFactoryForManager(QtAbstractPropertyManager *manager) {
     if (!m_viewToManagerToFactory()->contains(this) ||
-        !(*m_viewToManagerToFactory())[this].contains(manager)) {
+            !(*m_viewToManagerToFactory())[this].contains(manager)) {
         return;
     }
 
     QtAbstractEditorFactoryBase *abstractFactory =
-                (*m_viewToManagerToFactory())[this][manager];
+        (*m_viewToManagerToFactory())[this][manager];
     (*m_viewToManagerToFactory())[this].remove(manager);
     if ((*m_viewToManagerToFactory())[this].isEmpty()) {
         (*m_viewToManagerToFactory()).remove(this);
@@ -2002,8 +1925,7 @@ void QtAbstractPropertyBrowser::unsetFactoryForManager(QtAbstractPropertyManager
 
     \sa setCurrentItem()
 */
-QtBrowserItem *QtAbstractPropertyBrowser::currentItem() const
-{
+QtBrowserItem *QtAbstractPropertyBrowser::currentItem() const {
     return d_ptr->m_currentItem;
 }
 
@@ -2012,8 +1934,7 @@ QtBrowserItem *QtAbstractPropertyBrowser::currentItem() const
 
     \sa currentItem(), currentItemChanged()
 */
-void QtAbstractPropertyBrowser::setCurrentItem(QtBrowserItem *item)
-{
+void QtAbstractPropertyBrowser::setCurrentItem(QtBrowserItem *item) {
     QtBrowserItem *oldItem = d_ptr->m_currentItem;
     d_ptr->m_currentItem = item;
     if (oldItem != item)
