@@ -52,11 +52,11 @@ QT_BEGIN_NAMESPACE
 #if defined(_WIN32)
 #    if defined(COMPILE_QTPROPERTYBROWSER)
 #		define QT_QTPROPERTYBROWSER_EXPORT __declspec(dllexport)
-#    else      
+#    else
 #		define QT_QTPROPERTYBROWSER_EXPORT __declspec(dllimport)
 #    endif
 #else
-	#define QT_QTPROPERTYBROWSER_EXPORT
+#define QT_QTPROPERTYBROWSER_EXPORT
 #endif
 
 typedef QLineEdit::EchoMode EchoMode;
@@ -66,13 +66,12 @@ class QtPropertyPrivate;
 
 /**
  * @ingroup group_sdk_libraries_qtpropertybrowser
- * 
- * @brief 
+ *
+ * @brief
  * The description of this class will come soon !
- * 
+ *
  **/
-class QT_QTPROPERTYBROWSER_EXPORT QtProperty
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtProperty {
 public:
     virtual ~QtProperty();
 
@@ -112,8 +111,7 @@ private:
 
 class QtAbstractPropertyManagerPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtAbstractPropertyManager : public QObject
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtAbstractPropertyManager : public QObject {
     Q_OBJECT
 public:
 
@@ -127,7 +125,7 @@ public:
 Q_SIGNALS:
 
     void propertyInserted(QtProperty *property,
-                QtProperty *parent, QtProperty *after);
+                          QtProperty *parent, QtProperty *after);
     void propertyChanged(QtProperty *property);
     void propertyRemoved(QtProperty *property, QtProperty *parent);
     void propertyDestroyed(QtProperty *property);
@@ -147,8 +145,7 @@ private:
     Q_DISABLE_COPY(QtAbstractPropertyManager)
 };
 
-class QT_QTPROPERTYBROWSER_EXPORT QtAbstractEditorFactoryBase : public QObject
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtAbstractEditorFactoryBase : public QObject {
     Q_OBJECT
 public:
     virtual QWidget *createEditor(QtProperty *property, QWidget *parent) = 0;
@@ -164,12 +161,10 @@ protected Q_SLOTS:
 };
 
 template <class PropertyManager>
-class QtAbstractEditorFactory : public QtAbstractEditorFactoryBase
-{
+class QtAbstractEditorFactory : public QtAbstractEditorFactoryBase {
 public:
     explicit QtAbstractEditorFactory(QObject *parent) : QtAbstractEditorFactoryBase(parent) {}
-    QWidget *createEditor(QtProperty *property, QWidget *parent)
-    {
+    QWidget *createEditor(QtProperty *property, QWidget *parent) {
         QSetIterator<PropertyManager *> it(m_managers);
         while (it.hasNext()) {
             PropertyManager *manager = it.next();
@@ -179,30 +174,26 @@ public:
         }
         return 0;
     }
-    void addPropertyManager(PropertyManager *manager)
-    {
+    void addPropertyManager(PropertyManager *manager) {
         if (m_managers.contains(manager))
             return;
         m_managers.insert(manager);
         connectPropertyManager(manager);
         connect(manager, SIGNAL(destroyed(QObject *)),
-                    this, SLOT(managerDestroyed(QObject *)));
+                this, SLOT(managerDestroyed(QObject *)));
     }
-    void removePropertyManager(PropertyManager *manager)
-    {
+    void removePropertyManager(PropertyManager *manager) {
         if (!m_managers.contains(manager))
             return;
         disconnect(manager, SIGNAL(destroyed(QObject *)),
-                    this, SLOT(managerDestroyed(QObject *)));
+                   this, SLOT(managerDestroyed(QObject *)));
         disconnectPropertyManager(manager);
         m_managers.remove(manager);
     }
-    QSet<PropertyManager *> propertyManagers() const
-    {
+    QSet<PropertyManager *> propertyManagers() const {
         return m_managers;
     }
-    PropertyManager *propertyManager(QtProperty *property) const
-    {
+    PropertyManager *propertyManager(QtProperty *property) const {
         QtAbstractPropertyManager *manager = property->propertyManager();
         QSetIterator<PropertyManager *> itManager(m_managers);
         while (itManager.hasNext()) {
@@ -216,10 +207,9 @@ public:
 protected:
     virtual void connectPropertyManager(PropertyManager *manager) = 0;
     virtual QWidget *createEditor(PropertyManager *manager, QtProperty *property,
-                QWidget *parent) = 0;
+                                  QWidget *parent) = 0;
     virtual void disconnectPropertyManager(PropertyManager *manager) = 0;
-    void managerDestroyed(QObject *manager)
-    {
+    void managerDestroyed(QObject *manager) {
         QSetIterator<PropertyManager *> it(m_managers);
         while (it.hasNext()) {
             PropertyManager *m = it.next();
@@ -230,8 +220,7 @@ protected:
         }
     }
 private:
-    void breakConnection(QtAbstractPropertyManager *manager)
-    {
+    void breakConnection(QtAbstractPropertyManager *manager) {
         QSetIterator<PropertyManager *> it(m_managers);
         while (it.hasNext()) {
             PropertyManager *m = it.next();
@@ -249,8 +238,7 @@ private:
 class QtAbstractPropertyBrowser;
 class QtBrowserItemPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtBrowserItem
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtBrowserItem {
 public:
     QtProperty *property() const;
     QtBrowserItem *parent() const;
@@ -265,8 +253,7 @@ private:
 
 class QtAbstractPropertyBrowserPrivate;
 
-class QT_QTPROPERTYBROWSER_EXPORT QtAbstractPropertyBrowser : public QWidget
-{
+class QT_QTPROPERTYBROWSER_EXPORT QtAbstractPropertyBrowser : public QWidget {
     Q_OBJECT
 public:
 
@@ -281,7 +268,7 @@ public:
 
     template <class PropertyManager>
     void setFactoryForManager(PropertyManager *manager,
-                    QtAbstractEditorFactory<PropertyManager> *factory) {
+                              QtAbstractEditorFactory<PropertyManager> *factory) {
         QtAbstractPropertyManager *abstractManager = manager;
         QtAbstractEditorFactoryBase *abstractFactory = factory;
 
@@ -314,15 +301,15 @@ protected:
 private:
 
     bool addFactory(QtAbstractPropertyManager *abstractManager,
-                QtAbstractEditorFactoryBase *abstractFactory);
+                    QtAbstractEditorFactoryBase *abstractFactory);
 
     QtAbstractPropertyBrowserPrivate *d_ptr;
     Q_DECLARE_PRIVATE(QtAbstractPropertyBrowser)
     Q_DISABLE_COPY(QtAbstractPropertyBrowser)
     Q_PRIVATE_SLOT(d_func(), void slotPropertyInserted(QtProperty *,
-                            QtProperty *, QtProperty *))
+                   QtProperty *, QtProperty *))
     Q_PRIVATE_SLOT(d_func(), void slotPropertyRemoved(QtProperty *,
-                            QtProperty *))
+                   QtProperty *))
     Q_PRIVATE_SLOT(d_func(), void slotPropertyDestroyed(QtProperty *))
     Q_PRIVATE_SLOT(d_func(), void slotPropertyDataChanged(QtProperty *))
 
