@@ -57,8 +57,7 @@ QT_BEGIN_NAMESPACE
 
 class QtPropertyEditorView;
 
-class QtTreePropertyBrowserPrivate
-{
+class QtTreePropertyBrowserPrivate {
     QtTreePropertyBrowser *q_ptr;
     Q_DECLARE_PUBLIC(QtTreePropertyBrowser)
 
@@ -69,8 +68,9 @@ public:
     void propertyInserted(QtBrowserItem *index, QtBrowserItem *afterIndex);
     void propertyRemoved(QtBrowserItem *index);
     void propertyChanged(QtBrowserItem *index);
-    QWidget *createEditor(QtProperty *property, QWidget *parent) const
-        { return q_ptr->createEditor(property, parent); }
+    QWidget *createEditor(QtProperty *property, QWidget *parent) const {
+        return q_ptr->createEditor(property, parent);
+    }
     QtProperty *indexToProperty(const QModelIndex &index) const;
     QTreeWidgetItem *indexToItem(const QModelIndex &index) const;
     QtBrowserItem *indexToBrowserItem(const QModelIndex &index) const;
@@ -84,8 +84,12 @@ public:
 
     QColor calculatedBackgroundColor(QtBrowserItem *item) const;
 
-    QtPropertyEditorView *treeWidget() const { return m_treeWidget; }
-    bool markPropertiesWithoutValue() const { return m_markPropertiesWithoutValue; }
+    QtPropertyEditorView *treeWidget() const {
+        return m_treeWidget;
+    }
+    bool markPropertiesWithoutValue() const {
+        return m_markPropertiesWithoutValue;
+    }
 
     QtBrowserItem *currentItem() const;
     void setCurrentItem(QtBrowserItem *browserItem, bool block);
@@ -115,17 +119,18 @@ private:
 };
 
 // ------------ QtPropertyEditorView
-class QtPropertyEditorView : public QTreeWidget
-{
+class QtPropertyEditorView : public QTreeWidget {
     Q_OBJECT
 public:
     QtPropertyEditorView(QWidget *parent = 0);
 
-    void setEditorPrivate(QtTreePropertyBrowserPrivate *editorPrivate)
-        { m_editorPrivate = editorPrivate; }
+    void setEditorPrivate(QtTreePropertyBrowserPrivate *editorPrivate) {
+        m_editorPrivate = editorPrivate;
+    }
 
-    QTreeWidgetItem *indexToItem(const QModelIndex &index) const
-        { return itemFromIndex(index); }
+    QTreeWidgetItem *indexToItem(const QModelIndex &index) const {
+        return itemFromIndex(index);
+    }
 
 protected:
     void keyPressEvent(QKeyEvent *event);
@@ -138,13 +143,11 @@ private:
 
 QtPropertyEditorView::QtPropertyEditorView(QWidget *parent) :
     QTreeWidget(parent),
-    m_editorPrivate(0)
-{
+    m_editorPrivate(0) {
     connect(header(), SIGNAL(sectionDoubleClicked(int)), this, SLOT(resizeColumnToContents(int)));
 }
 
-void QtPropertyEditorView::drawRow(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const
-{
+void QtPropertyEditorView::drawRow(QPainter *painter, const QStyleOptionViewItem &option, const QModelIndex &index) const {
     QStyleOptionViewItemV3 opt = option;
     bool hasValue = true;
     if (m_editorPrivate) {
@@ -171,8 +174,7 @@ void QtPropertyEditorView::drawRow(QPainter *painter, const QStyleOptionViewItem
     painter->restore();
 }
 
-void QtPropertyEditorView::keyPressEvent(QKeyEvent *event)
-{
+void QtPropertyEditorView::keyPressEvent(QKeyEvent *event) {
     switch (event->key()) {
     case Qt::Key_Return:
     case Qt::Key_Enter:
@@ -197,8 +199,7 @@ void QtPropertyEditorView::keyPressEvent(QKeyEvent *event)
     QTreeWidget::keyPressEvent(event);
 }
 
-void QtPropertyEditorView::mousePressEvent(QMouseEvent *event)
-{
+void QtPropertyEditorView::mousePressEvent(QMouseEvent *event) {
     QTreeWidget::mousePressEvent(event);
     QTreeWidgetItem *item = itemAt(event->pos());
 
@@ -215,44 +216,46 @@ void QtPropertyEditorView::mousePressEvent(QMouseEvent *event)
 }
 
 // ------------ QtPropertyEditorDelegate
-class QtPropertyEditorDelegate : public QItemDelegate
-{
+class QtPropertyEditorDelegate : public QItemDelegate {
     Q_OBJECT
 public:
     QtPropertyEditorDelegate(QObject *parent = 0)
-        : QItemDelegate(parent), m_editorPrivate(0), m_editedItem(0), m_editedWidget(0), m_disablePainting(false)
-        {}
+        : QItemDelegate(parent), m_editorPrivate(0), m_editedItem(0), m_editedWidget(0), m_disablePainting(false) {
+    }
 
-    void setEditorPrivate(QtTreePropertyBrowserPrivate *editorPrivate)
-        { m_editorPrivate = editorPrivate; }
+    void setEditorPrivate(QtTreePropertyBrowserPrivate *editorPrivate) {
+        m_editorPrivate = editorPrivate;
+    }
 
     QWidget *createEditor(QWidget *parent, const QStyleOptionViewItem &option,
-            const QModelIndex &index) const;
+                          const QModelIndex &index) const;
 
     void updateEditorGeometry(QWidget *editor, const QStyleOptionViewItem &option,
-            const QModelIndex &index) const;
+                              const QModelIndex &index) const;
 
     void paint(QPainter *painter, const QStyleOptionViewItem &option,
-            const QModelIndex &index) const;
+               const QModelIndex &index) const;
 
     QSize sizeHint(const QStyleOptionViewItem &option, const QModelIndex &index) const;
 
     void setModelData(QWidget *, QAbstractItemModel *,
-            const QModelIndex &) const {}
+                      const QModelIndex &) const {}
 
     void setEditorData(QWidget *, const QModelIndex &) const {}
 
     bool eventFilter(QObject *object, QEvent *event);
     void closeEditor(QtProperty *property);
 
-    QTreeWidgetItem *editedItem() const { return m_editedItem; }
+    QTreeWidgetItem *editedItem() const {
+        return m_editedItem;
+    }
 
 protected:
 
     void drawDecoration(QPainter *painter, const QStyleOptionViewItem &option,
-            const QRect &rect, const QPixmap &pixmap) const;
+                        const QRect &rect, const QPixmap &pixmap) const;
     void drawDisplay(QPainter *painter, const QStyleOptionViewItem &option,
-            const QRect &rect, const QString &text) const;
+                     const QRect &rect, const QString &text) const;
 
 private slots:
     void slotEditorDestroyed(QObject *object);
@@ -271,8 +274,7 @@ private:
     mutable bool m_disablePainting;
 };
 
-int QtPropertyEditorDelegate::indentation(const QModelIndex &index) const
-{
+int QtPropertyEditorDelegate::indentation(const QModelIndex &index) const {
     if (!m_editorPrivate)
         return 0;
 
@@ -287,8 +289,7 @@ int QtPropertyEditorDelegate::indentation(const QModelIndex &index) const
     return indent * m_editorPrivate->treeWidget()->indentation();
 }
 
-void QtPropertyEditorDelegate::slotEditorDestroyed(QObject *object)
-{
+void QtPropertyEditorDelegate::slotEditorDestroyed(QObject *object) {
     if (QWidget *w = qobject_cast<QWidget *>(object)) {
         const EditorToPropertyMap::iterator it = m_editorToProperty.find(w);
         if (it != m_editorToProperty.end()) {
@@ -302,15 +303,13 @@ void QtPropertyEditorDelegate::slotEditorDestroyed(QObject *object)
     }
 }
 
-void QtPropertyEditorDelegate::closeEditor(QtProperty *property)
-{
+void QtPropertyEditorDelegate::closeEditor(QtProperty *property) {
     if (QWidget *w = m_propertyToEditor.value(property, 0))
         w->deleteLater();
 }
 
 QWidget *QtPropertyEditorDelegate::createEditor(QWidget *parent,
-        const QStyleOptionViewItem &, const QModelIndex &index) const
-{
+        const QStyleOptionViewItem &, const QModelIndex &index) const {
     if (index.column() == 1 && m_editorPrivate) {
         QtProperty *property = m_editorPrivate->indexToProperty(index);
         QTreeWidgetItem *item = m_editorPrivate->indexToItem(index);
@@ -332,15 +331,13 @@ QWidget *QtPropertyEditorDelegate::createEditor(QWidget *parent,
 }
 
 void QtPropertyEditorDelegate::updateEditorGeometry(QWidget *editor,
-        const QStyleOptionViewItem &option, const QModelIndex &index) const
-{
+        const QStyleOptionViewItem &option, const QModelIndex &index) const {
     Q_UNUSED(index)
     editor->setGeometry(option.rect.adjusted(0, 0, 0, -1));
 }
 
 void QtPropertyEditorDelegate::paint(QPainter *painter, const QStyleOptionViewItem &option,
-            const QModelIndex &index) const
-{
+                                     const QModelIndex &index) const {
     bool hasValue = true;
     if (m_editorPrivate) {
         QtProperty *property = m_editorPrivate->indexToProperty(index);
@@ -374,7 +371,7 @@ void QtPropertyEditorDelegate::paint(QPainter *painter, const QStyleOptionViewIt
     }
     QItemDelegate::paint(painter, opt, index);
     if (option.type)
-    m_disablePainting = false;
+        m_disablePainting = false;
 
     opt.palette.setCurrentColorGroup(QPalette::Active);
     QColor color = static_cast<QRgb>(QApplication::style()->styleHint(QStyle::SH_Table_GridLineColor, &opt));
@@ -388,8 +385,7 @@ void QtPropertyEditorDelegate::paint(QPainter *painter, const QStyleOptionViewIt
 }
 
 void QtPropertyEditorDelegate::drawDecoration(QPainter *painter, const QStyleOptionViewItem &option,
-            const QRect &rect, const QPixmap &pixmap) const
-{
+        const QRect &rect, const QPixmap &pixmap) const {
     if (m_disablePainting)
         return;
 
@@ -397,8 +393,7 @@ void QtPropertyEditorDelegate::drawDecoration(QPainter *painter, const QStyleOpt
 }
 
 void QtPropertyEditorDelegate::drawDisplay(QPainter *painter, const QStyleOptionViewItem &option,
-            const QRect &rect, const QString &text) const
-{
+        const QRect &rect, const QString &text) const {
     if (m_disablePainting)
         return;
 
@@ -406,13 +401,11 @@ void QtPropertyEditorDelegate::drawDisplay(QPainter *painter, const QStyleOption
 }
 
 QSize QtPropertyEditorDelegate::sizeHint(const QStyleOptionViewItem &option,
-            const QModelIndex &index) const
-{
+        const QModelIndex &index) const {
     return QItemDelegate::sizeHint(option, index) + QSize(3, 4);
 }
 
-bool QtPropertyEditorDelegate::eventFilter(QObject *object, QEvent *event)
-{
+bool QtPropertyEditorDelegate::eventFilter(QObject *object, QEvent *event) {
     if (event->type() == QEvent::FocusOut) {
         QFocusEvent *fe = static_cast<QFocusEvent *>(event);
         if (fe->reason() == Qt::ActiveWindowFocusReason)
@@ -428,13 +421,11 @@ QtTreePropertyBrowserPrivate::QtTreePropertyBrowserPrivate() :
     m_resizeMode(QtTreePropertyBrowser::Stretch),
     m_delegate(0),
     m_markPropertiesWithoutValue(false),
-    m_browserChangedBlocked(false)
-{
+    m_browserChangedBlocked(false) {
 }
 
 // Draw an icon indicating opened/closing branches
-static QIcon drawIndicatorIcon(const QPalette &palette, QStyle *style)
-{
+static QIcon drawIndicatorIcon(const QPalette &palette, QStyle *style) {
     QPixmap pix(14, 14);
     pix.fill(Qt::transparent);
     QStyleOption branchOption;
@@ -462,8 +453,7 @@ static QIcon drawIndicatorIcon(const QPalette &palette, QStyle *style)
     return rc;
 }
 
-void QtTreePropertyBrowserPrivate::init(QWidget *parent)
-{
+void QtTreePropertyBrowserPrivate::init(QWidget *parent) {
     QHBoxLayout *layout = new QHBoxLayout(parent);
     layout->setMargin(0);
     m_treeWidget = new QtPropertyEditorView(parent);
@@ -491,15 +481,13 @@ void QtTreePropertyBrowserPrivate::init(QWidget *parent)
     QObject::connect(m_treeWidget, SIGNAL(currentItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)), q_ptr, SLOT(slotCurrentTreeItemChanged(QTreeWidgetItem*,QTreeWidgetItem*)));
 }
 
-QtBrowserItem *QtTreePropertyBrowserPrivate::currentItem() const
-{
+QtBrowserItem *QtTreePropertyBrowserPrivate::currentItem() const {
     if (QTreeWidgetItem *treeItem = m_treeWidget->currentItem())
         return m_itemToIndex.value(treeItem);
     return 0;
 }
 
-void QtTreePropertyBrowserPrivate::setCurrentItem(QtBrowserItem *browserItem, bool block)
-{
+void QtTreePropertyBrowserPrivate::setCurrentItem(QtBrowserItem *browserItem, bool block) {
     const bool blocked = block ? m_treeWidget->blockSignals(true) : false;
     if (browserItem == 0)
         m_treeWidget->setCurrentItem(0);
@@ -509,8 +497,7 @@ void QtTreePropertyBrowserPrivate::setCurrentItem(QtBrowserItem *browserItem, bo
         m_treeWidget->blockSignals(blocked);
 }
 
-QtProperty *QtTreePropertyBrowserPrivate::indexToProperty(const QModelIndex &index) const
-{
+QtProperty *QtTreePropertyBrowserPrivate::indexToProperty(const QModelIndex &index) const {
     QTreeWidgetItem *item = m_treeWidget->indexToItem(index);
     QtBrowserItem *idx = m_itemToIndex.value(item);
     if (idx)
@@ -518,24 +505,20 @@ QtProperty *QtTreePropertyBrowserPrivate::indexToProperty(const QModelIndex &ind
     return 0;
 }
 
-QtBrowserItem *QtTreePropertyBrowserPrivate::indexToBrowserItem(const QModelIndex &index) const
-{
+QtBrowserItem *QtTreePropertyBrowserPrivate::indexToBrowserItem(const QModelIndex &index) const {
     QTreeWidgetItem *item = m_treeWidget->indexToItem(index);
     return m_itemToIndex.value(item);
 }
 
-QTreeWidgetItem *QtTreePropertyBrowserPrivate::indexToItem(const QModelIndex &index) const
-{
+QTreeWidgetItem *QtTreePropertyBrowserPrivate::indexToItem(const QModelIndex &index) const {
     return m_treeWidget->indexToItem(index);
 }
 
-bool QtTreePropertyBrowserPrivate::lastColumn(int column) const
-{
+bool QtTreePropertyBrowserPrivate::lastColumn(int column) const {
     return m_treeWidget->header()->visualIndex(column) == m_treeWidget->columnCount() - 1;
 }
 
-void QtTreePropertyBrowserPrivate::disableItem(QTreeWidgetItem *item) const
-{
+void QtTreePropertyBrowserPrivate::disableItem(QTreeWidgetItem *item) const {
     Qt::ItemFlags flags = item->flags();
     if (flags & Qt::ItemIsEnabled) {
         flags &= ~Qt::ItemIsEnabled;
@@ -549,8 +532,7 @@ void QtTreePropertyBrowserPrivate::disableItem(QTreeWidgetItem *item) const
     }
 }
 
-void QtTreePropertyBrowserPrivate::enableItem(QTreeWidgetItem *item) const
-{
+void QtTreePropertyBrowserPrivate::enableItem(QTreeWidgetItem *item) const {
     Qt::ItemFlags flags = item->flags();
     flags |= Qt::ItemIsEnabled;
     item->setFlags(flags);
@@ -564,16 +546,14 @@ void QtTreePropertyBrowserPrivate::enableItem(QTreeWidgetItem *item) const
     }
 }
 
-bool QtTreePropertyBrowserPrivate::hasValue(QTreeWidgetItem *item) const
-{
+bool QtTreePropertyBrowserPrivate::hasValue(QTreeWidgetItem *item) const {
     QtBrowserItem *browserItem = m_itemToIndex.value(item);
     if (browserItem)
         return browserItem->property()->hasValue();
     return false;
 }
 
-void QtTreePropertyBrowserPrivate::propertyInserted(QtBrowserItem *index, QtBrowserItem *afterIndex)
-{
+void QtTreePropertyBrowserPrivate::propertyInserted(QtBrowserItem *index, QtBrowserItem *afterIndex) {
     QTreeWidgetItem *afterItem = m_indexToItem.value(afterIndex);
     QTreeWidgetItem *parentItem = m_indexToItem.value(index->parent());
 
@@ -592,8 +572,7 @@ void QtTreePropertyBrowserPrivate::propertyInserted(QtBrowserItem *index, QtBrow
     updateItem(newItem);
 }
 
-void QtTreePropertyBrowserPrivate::propertyRemoved(QtBrowserItem *index)
-{
+void QtTreePropertyBrowserPrivate::propertyRemoved(QtBrowserItem *index) {
     QTreeWidgetItem *item = m_indexToItem.value(index);
 
     if (m_treeWidget->currentItem() == item) {
@@ -607,15 +586,13 @@ void QtTreePropertyBrowserPrivate::propertyRemoved(QtBrowserItem *index)
     m_indexToBackgroundColor.remove(index);
 }
 
-void QtTreePropertyBrowserPrivate::propertyChanged(QtBrowserItem *index)
-{
+void QtTreePropertyBrowserPrivate::propertyChanged(QtBrowserItem *index) {
     QTreeWidgetItem *item = m_indexToItem.value(index);
 
     updateItem(item);
 }
 
-void QtTreePropertyBrowserPrivate::updateItem(QTreeWidgetItem *item)
-{
+void QtTreePropertyBrowserPrivate::updateItem(QTreeWidgetItem *item) {
     QtProperty *property = m_itemToIndex[item]->property();
     QIcon expandIcon;
     if (property->hasValue()) {
@@ -654,8 +631,7 @@ void QtTreePropertyBrowserPrivate::updateItem(QTreeWidgetItem *item)
     m_treeWidget->viewport()->update();
 }
 
-QColor QtTreePropertyBrowserPrivate::calculatedBackgroundColor(QtBrowserItem *item) const
-{
+QColor QtTreePropertyBrowserPrivate::calculatedBackgroundColor(QtBrowserItem *item) const {
     QtBrowserItem *i = item;
     const QMap<QtBrowserItem *, QColor>::const_iterator itEnd = m_indexToBackgroundColor.constEnd();
     while (i) {
@@ -667,43 +643,37 @@ QColor QtTreePropertyBrowserPrivate::calculatedBackgroundColor(QtBrowserItem *it
     return QColor();
 }
 
-void QtTreePropertyBrowserPrivate::slotCollapsed(const QModelIndex &index)
-{
+void QtTreePropertyBrowserPrivate::slotCollapsed(const QModelIndex &index) {
     QTreeWidgetItem *item = indexToItem(index);
     QtBrowserItem *idx = m_itemToIndex.value(item);
     if (item)
         emit q_ptr->collapsed(idx);
 }
 
-void QtTreePropertyBrowserPrivate::slotExpanded(const QModelIndex &index)
-{
+void QtTreePropertyBrowserPrivate::slotExpanded(const QModelIndex &index) {
     QTreeWidgetItem *item = indexToItem(index);
     QtBrowserItem *idx = m_itemToIndex.value(item);
     if (item)
         emit q_ptr->expanded(idx);
 }
 
-void QtTreePropertyBrowserPrivate::slotCurrentBrowserItemChanged(QtBrowserItem *item)
-{
+void QtTreePropertyBrowserPrivate::slotCurrentBrowserItemChanged(QtBrowserItem *item) {
     if (!m_browserChangedBlocked && item != currentItem())
         setCurrentItem(item, true);
 }
 
-void QtTreePropertyBrowserPrivate::slotCurrentTreeItemChanged(QTreeWidgetItem *newItem, QTreeWidgetItem *)
-{
+void QtTreePropertyBrowserPrivate::slotCurrentTreeItemChanged(QTreeWidgetItem *newItem, QTreeWidgetItem *) {
     QtBrowserItem *browserItem = newItem ? m_itemToIndex.value(newItem) : 0;
     m_browserChangedBlocked = true;
     q_ptr->setCurrentItem(browserItem);
     m_browserChangedBlocked = false;
 }
 
-QTreeWidgetItem *QtTreePropertyBrowserPrivate::editedItem() const
-{
+QTreeWidgetItem *QtTreePropertyBrowserPrivate::editedItem() const {
     return m_delegate->editedItem();
 }
 
-void QtTreePropertyBrowserPrivate::editItem(QtBrowserItem *browserItem)
-{
+void QtTreePropertyBrowserPrivate::editItem(QtBrowserItem *browserItem) {
     if (QTreeWidgetItem *treeItem = m_indexToItem.value(browserItem, 0)) {
         m_treeWidget->setCurrentItem (treeItem, 1);
         m_treeWidget->editItem(treeItem, 1);
@@ -757,8 +727,7 @@ void QtTreePropertyBrowserPrivate::editItem(QtBrowserItem *browserItem)
     Creates a property browser with the given \a parent.
 */
 QtTreePropertyBrowser::QtTreePropertyBrowser(QWidget *parent)
-    : QtAbstractPropertyBrowser(parent)
-{
+    : QtAbstractPropertyBrowser(parent) {
     d_ptr = new QtTreePropertyBrowserPrivate;
     d_ptr->q_ptr = this;
 
@@ -776,8 +745,7 @@ QtTreePropertyBrowser::QtTreePropertyBrowser(QWidget *parent)
 
     \sa QtProperty, QtAbstractPropertyManager
 */
-QtTreePropertyBrowser::~QtTreePropertyBrowser()
-{
+QtTreePropertyBrowser::~QtTreePropertyBrowser() {
     delete d_ptr;
 }
 
@@ -785,13 +753,11 @@ QtTreePropertyBrowser::~QtTreePropertyBrowser()
     \property QtTreePropertyBrowser::indentation
     \brief indentation of the items in the tree view.
 */
-int QtTreePropertyBrowser::indentation() const
-{
+int QtTreePropertyBrowser::indentation() const {
     return d_ptr->m_treeWidget->indentation();
 }
 
-void QtTreePropertyBrowser::setIndentation(int i)
-{
+void QtTreePropertyBrowser::setIndentation(int i) {
     d_ptr->m_treeWidget->setIndentation(i);
 }
 
@@ -799,13 +765,11 @@ void QtTreePropertyBrowser::setIndentation(int i)
   \property QtTreePropertyBrowser::rootIsDecorated
   \brief whether to show controls for expanding and collapsing root items.
 */
-bool QtTreePropertyBrowser::rootIsDecorated() const
-{
+bool QtTreePropertyBrowser::rootIsDecorated() const {
     return d_ptr->m_treeWidget->rootIsDecorated();
 }
 
-void QtTreePropertyBrowser::setRootIsDecorated(bool show)
-{
+void QtTreePropertyBrowser::setRootIsDecorated(bool show) {
     d_ptr->m_treeWidget->setRootIsDecorated(show);
     QMapIterator<QTreeWidgetItem *, QtBrowserItem *> it(d_ptr->m_itemToIndex);
     while (it.hasNext()) {
@@ -820,13 +784,11 @@ void QtTreePropertyBrowser::setRootIsDecorated(bool show)
   \brief whether to draw the background using alternating colors.
   By default this property is set to true.
 */
-bool QtTreePropertyBrowser::alternatingRowColors() const
-{
+bool QtTreePropertyBrowser::alternatingRowColors() const {
     return d_ptr->m_treeWidget->alternatingRowColors();
 }
 
-void QtTreePropertyBrowser::setAlternatingRowColors(bool enable)
-{
+void QtTreePropertyBrowser::setAlternatingRowColors(bool enable) {
     d_ptr->m_treeWidget->setAlternatingRowColors(enable);
     QMapIterator<QTreeWidgetItem *, QtBrowserItem *> it(d_ptr->m_itemToIndex);
 }
@@ -835,13 +797,11 @@ void QtTreePropertyBrowser::setAlternatingRowColors(bool enable)
   \property QtTreePropertyBrowser::headerVisible
   \brief whether to show the header.
 */
-bool QtTreePropertyBrowser::isHeaderVisible() const
-{
+bool QtTreePropertyBrowser::isHeaderVisible() const {
     return d_ptr->m_headerVisible;
 }
 
-void QtTreePropertyBrowser::setHeaderVisible(bool visible)
-{
+void QtTreePropertyBrowser::setHeaderVisible(bool visible) {
     if (d_ptr->m_headerVisible == visible)
         return;
 
@@ -875,24 +835,30 @@ void QtTreePropertyBrowser::setHeaderVisible(bool visible)
     \brief the resize mode of setions in the header.
 */
 
-QtTreePropertyBrowser::ResizeMode QtTreePropertyBrowser::resizeMode() const
-{
+QtTreePropertyBrowser::ResizeMode QtTreePropertyBrowser::resizeMode() const {
     return d_ptr->m_resizeMode;
 }
 
-void QtTreePropertyBrowser::setResizeMode(QtTreePropertyBrowser::ResizeMode mode)
-{
+void QtTreePropertyBrowser::setResizeMode(QtTreePropertyBrowser::ResizeMode mode) {
     if (d_ptr->m_resizeMode == mode)
         return;
 
     d_ptr->m_resizeMode = mode;
     QHeaderView::ResizeMode m = QHeaderView::Stretch;
     switch (mode) {
-        case QtTreePropertyBrowser::Interactive:      m = QHeaderView::Interactive;      break;
-        case QtTreePropertyBrowser::Fixed:            m = QHeaderView::Fixed;            break;
-        case QtTreePropertyBrowser::ResizeToContents: m = QHeaderView::ResizeToContents; break;
-        case QtTreePropertyBrowser::Stretch:
-        default:                                      m = QHeaderView::Stretch;          break;
+    case QtTreePropertyBrowser::Interactive:
+        m = QHeaderView::Interactive;
+        break;
+    case QtTreePropertyBrowser::Fixed:
+        m = QHeaderView::Fixed;
+        break;
+    case QtTreePropertyBrowser::ResizeToContents:
+        m = QHeaderView::ResizeToContents;
+        break;
+    case QtTreePropertyBrowser::Stretch:
+    default:
+        m = QHeaderView::Stretch;
+        break;
     }
     d_ptr->m_treeWidget->header()->setResizeMode(m);
 }
@@ -902,13 +868,11 @@ void QtTreePropertyBrowser::setResizeMode(QtTreePropertyBrowser::ResizeMode mode
     \brief the position of the splitter between the colunms.
 */
 
-int QtTreePropertyBrowser::splitterPosition() const
-{
+int QtTreePropertyBrowser::splitterPosition() const {
     return d_ptr->m_treeWidget->header()->sectionSize(0);
 }
 
-void QtTreePropertyBrowser::setSplitterPosition(int position)
-{
+void QtTreePropertyBrowser::setSplitterPosition(int position) {
     d_ptr->m_treeWidget->header()->resizeSection(0, position);
 }
 
@@ -918,8 +882,7 @@ void QtTreePropertyBrowser::setSplitterPosition(int position)
     \sa isExpanded(), expanded(), collapsed()
 */
 
-void QtTreePropertyBrowser::setExpanded(QtBrowserItem *item, bool expanded)
-{
+void QtTreePropertyBrowser::setExpanded(QtBrowserItem *item, bool expanded) {
     QTreeWidgetItem *treeItem = d_ptr->m_indexToItem.value(item);
     if (treeItem)
         treeItem->setExpanded(expanded);
@@ -931,8 +894,7 @@ void QtTreePropertyBrowser::setExpanded(QtBrowserItem *item, bool expanded)
     \sa setExpanded()
 */
 
-bool QtTreePropertyBrowser::isExpanded(QtBrowserItem *item) const
-{
+bool QtTreePropertyBrowser::isExpanded(QtBrowserItem *item) const {
     QTreeWidgetItem *treeItem = d_ptr->m_indexToItem.value(item);
     if (treeItem)
         return treeItem->isExpanded();
@@ -946,8 +908,7 @@ bool QtTreePropertyBrowser::isExpanded(QtBrowserItem *item) const
     \since 4.5
 */
 
-bool QtTreePropertyBrowser::isItemVisible(QtBrowserItem *item) const
-{
+bool QtTreePropertyBrowser::isItemVisible(QtBrowserItem *item) const {
     if (const QTreeWidgetItem *treeItem = d_ptr->m_indexToItem.value(item))
         return !treeItem->isHidden();
     return false;
@@ -960,8 +921,7 @@ bool QtTreePropertyBrowser::isItemVisible(QtBrowserItem *item) const
    \since 4.5
 */
 
-void QtTreePropertyBrowser::setItemVisible(QtBrowserItem *item, bool visible)
-{
+void QtTreePropertyBrowser::setItemVisible(QtBrowserItem *item, bool visible) {
     if (QTreeWidgetItem *treeItem = d_ptr->m_indexToItem.value(item))
         treeItem->setHidden(!visible);
 }
@@ -973,8 +933,7 @@ void QtTreePropertyBrowser::setItemVisible(QtBrowserItem *item, bool visible)
     \sa backgroundColor(), calculatedBackgroundColor()
 */
 
-void QtTreePropertyBrowser::setBackgroundColor(QtBrowserItem *item, const QColor &color)
-{
+void QtTreePropertyBrowser::setBackgroundColor(QtBrowserItem *item, const QColor &color) {
     if (!d_ptr->m_indexToItem.contains(item))
         return;
     if (color.isValid())
@@ -990,8 +949,7 @@ void QtTreePropertyBrowser::setBackgroundColor(QtBrowserItem *item, const QColor
     \sa calculatedBackgroundColor(), setBackgroundColor()
 */
 
-QColor QtTreePropertyBrowser::backgroundColor(QtBrowserItem *item) const
-{
+QColor QtTreePropertyBrowser::backgroundColor(QtBrowserItem *item) const {
     return d_ptr->m_indexToBackgroundColor.value(item);
 }
 
@@ -1003,8 +961,7 @@ QColor QtTreePropertyBrowser::backgroundColor(QtBrowserItem *item) const
     \sa backgroundColor(), setBackgroundColor()
 */
 
-QColor QtTreePropertyBrowser::calculatedBackgroundColor(QtBrowserItem *item) const
-{
+QColor QtTreePropertyBrowser::calculatedBackgroundColor(QtBrowserItem *item) const {
     return d_ptr->calculatedBackgroundColor(item);
 }
 
@@ -1017,8 +974,7 @@ QColor QtTreePropertyBrowser::calculatedBackgroundColor(QtBrowserItem *item) con
 
     \sa propertiesWithoutValueMarked()
 */
-void QtTreePropertyBrowser::setPropertiesWithoutValueMarked(bool mark)
-{
+void QtTreePropertyBrowser::setPropertiesWithoutValueMarked(bool mark) {
     if (d_ptr->m_markPropertiesWithoutValue == mark)
         return;
 
@@ -1032,40 +988,35 @@ void QtTreePropertyBrowser::setPropertiesWithoutValueMarked(bool mark)
     d_ptr->m_treeWidget->viewport()->update();
 }
 
-bool QtTreePropertyBrowser::propertiesWithoutValueMarked() const
-{
+bool QtTreePropertyBrowser::propertiesWithoutValueMarked() const {
     return d_ptr->m_markPropertiesWithoutValue;
 }
 
 /*!
     \reimp
 */
-void QtTreePropertyBrowser::itemInserted(QtBrowserItem *item, QtBrowserItem *afterItem)
-{
+void QtTreePropertyBrowser::itemInserted(QtBrowserItem *item, QtBrowserItem *afterItem) {
     d_ptr->propertyInserted(item, afterItem);
 }
 
 /*!
     \reimp
 */
-void QtTreePropertyBrowser::itemRemoved(QtBrowserItem *item)
-{
+void QtTreePropertyBrowser::itemRemoved(QtBrowserItem *item) {
     d_ptr->propertyRemoved(item);
 }
 
 /*!
     \reimp
 */
-void QtTreePropertyBrowser::itemChanged(QtBrowserItem *item)
-{
+void QtTreePropertyBrowser::itemChanged(QtBrowserItem *item) {
     d_ptr->propertyChanged(item);
 }
 
 /*!
     Sets the current item to \a item and opens the relevant editor for it.
 */
-void QtTreePropertyBrowser::editItem(QtBrowserItem *item)
-{
+void QtTreePropertyBrowser::editItem(QtBrowserItem *item) {
     d_ptr->editItem(item);
 }
 
